/* Emacs: this is -*- C -*- code, */
/* generated 2007-09-09T13:48:48-0400 by Liar version UNKNOWN. */

#include "liarc.h"

#define LABEL_1_4 3
#define LABEL_1_5 5
#define ENVIRONMENT_LABEL_1_3 11
#define DEBUGGING_LABEL_1_2 10
#define OBJECT_1_1 9
#define OBJECT_1_0 8
#define FREE_REFERENCE_1_0 7
#define FREE_REFERENCES_LABEL_1_0 6
#define NUMBER_OF_LINKER_SECTIONS_1_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
asstop_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_1_4);
      goto compiler_compiled_code_pathname_type_0;

    case 1:
      current_block = (Rpc - LABEL_1_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (compiler_compiled_code_pathname_type_4)
DEFLABEL (compiler_compiled_code_pathname_type_0)
  INTERRUPT_CHECK (26, LABEL_1_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_7;
  Wrd5 = Wrd9;

DEFLABEL (label_6)
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_5;
  Rvl = (current_block [OBJECT_1_1]);
  goto pop_return;

DEFLABEL (label_5)
  Rvl = (current_block [OBJECT_1_0]);
  goto pop_return;

DEFLABEL (label_7)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_5])), (Wrd6.pObj));

DEFLABEL (label_2)
  (Wrd5.Obj) = Rvl;
  goto label_6;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_2_4 3
#define ENVIRONMENT_LABEL_2_3 9
#define DEBUGGING_LABEL_2_2 8
#define OBJECT_2_0 7
#define EXECUTE_CACHE_2_5 5
#define FREE_REFERENCES_LABEL_2_0 4
#define NUMBER_OF_LINKER_SECTIONS_2_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
asstop_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_2_4);
      goto compiler_file_output_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (compiler_file_output_3)
DEFLABEL (compiler_file_output_0)
  INTERRUPT_CHECK (26, LABEL_2_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_2_0]);
  (Rsp [2]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_3_4 3
#define ENVIRONMENT_LABEL_3_3 8
#define DEBUGGING_LABEL_3_2 7
#define EXECUTE_CACHE_3_5 5
#define FREE_REFERENCES_LABEL_3_0 4
#define NUMBER_OF_LINKER_SECTIONS_3_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
asstop_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_3_4);
      goto compiler_output__procedure_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (compiler_output__procedure_3)
DEFLABEL (compiler_output__procedure_0)
  INTERRUPT_CHECK (26, LABEL_3_4);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4_4 3
#define ENVIRONMENT_LABEL_4_3 5
#define DEBUGGING_LABEL_4_2 4
#define FREE_REFERENCES_LABEL_4_0 4
#define NUMBER_OF_LINKER_SECTIONS_4_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
asstop_so_code_4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4_4);
      goto compiler_output__compiled_expression_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (compiler_output__compiled_expression_3)
DEFLABEL (compiler_output__compiled_expression_0)
  INTERRUPT_CHECK (26, LABEL_4_4);
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_5_4 3
#define ENVIRONMENT_LABEL_5_3 5
#define DEBUGGING_LABEL_5_2 4
#define FREE_REFERENCES_LABEL_5_0 4
#define NUMBER_OF_LINKER_SECTIONS_5_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
asstop_so_code_5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_5_4);
      goto compile_scode_internal_hook_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (compile_scode_internal_hook_3)
DEFLABEL (compile_scode_internal_hook_0)
  INTERRUPT_CHECK (26, LABEL_5_4);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_6_4 3
#define LABEL_6_7 5
#define LABEL_6_5 7
#define LABEL_6_8 9
#define LABEL_6_11 11
#define ENVIRONMENT_LABEL_6_3 22
#define DEBUGGING_LABEL_6_2 21
#define EXECUTE_CACHE_6_10 13
#define EXECUTE_CACHE_6_9 15
#define EXECUTE_CACHE_6_6 17
#define FREE_REFERENCE_6_0 20
#define FREE_REFERENCES_LABEL_6_0 12
#define NUMBER_OF_LINKER_SECTIONS_6_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
asstop_so_code_6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_6_4);
      goto assemble_link_3;

    case 1:
      current_block = (Rpc - LABEL_6_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_6_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_6_8);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_6_11);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (assemble_link_7)
DEFLABEL (assemble_link_3)
  INTERRUPT_CHECK (26, LABEL_6_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_6_5);
  (Wrd5.Obj) = (Rsp [0]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_10;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_10]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_6_7);

DEFLABEL (label_10)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_8]))));
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_6_8);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6_0]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_9;
  Wrd6 = Wrd10;

DEFLABEL (label_8)
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_9)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_6_11])), (Wrd7.pObj));

DEFLABEL (label_5)
  (Wrd6.Obj) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_7_4 3
#define LABEL_7_7 5
#define LABEL_7_8 7
#define LABEL_7_5 9
#define LABEL_7_6 11
#define LABEL_7_10 13
#define LABEL_7_11 15
#define LABEL_7_13 17
#define ENVIRONMENT_LABEL_7_3 35
#define DEBUGGING_LABEL_7_2 34
#define EXECUTE_CACHE_7_16 19
#define EXECUTE_CACHE_7_17 21
#define EXECUTE_CACHE_7_15 23
#define EXECUTE_CACHE_7_14 25
#define EXECUTE_CACHE_7_12 27
#define EXECUTE_CACHE_7_9 29
#define FREE_REFERENCE_7_1 32
#define FREE_REFERENCE_7_0 33
#define FREE_REFERENCES_LABEL_7_0 18
#define NUMBER_OF_LINKER_SECTIONS_7_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
asstop_so_code_7 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd31;
  machine_word Wrd25;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd11;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_7_4);
      goto wrap_lap_5;

    case 1:
      current_block = (Rpc - LABEL_7_7);
      goto label_7;

    case 2:
      current_block = (Rpc - LABEL_7_8);
      goto label_8;

    case 3:
      current_block = (Rpc - LABEL_7_5);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_7_6);
      goto continuation_0;

    case 5:
      current_block = (Rpc - LABEL_7_10);
      goto continuation_2;

    case 6:
      current_block = (Rpc - LABEL_7_11);
      goto continuation_1;

    case 7:
      current_block = (Rpc - LABEL_7_13);
      goto continuation_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (wrap_lap_10)
DEFLABEL (wrap_lap_5)
  INTERRUPT_CHECK (26, LABEL_7_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_15;
  Wrd11 = Wrd15;

DEFLABEL (label_14)
  if ((Wrd11.Obj) == ((SCHEME_OBJECT) 0))
    goto label_11;
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_10]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_11]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_12]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_7_11);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_16]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_7_10);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_15]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_7_6);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_14]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_7_5);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_13]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_14]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_7_13);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_17]));

DEFLABEL (label_11)
  (Wrd26.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7_1]));
  (Wrd29.Obj) = ((Wrd26.pObj) [0]);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if ((Wrd30.uLng) == 50)
    goto label_13;
  Wrd25 = Wrd29;

DEFLABEL (label_12)
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd31.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd31.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_9]));

DEFLABEL (label_13)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_7_8])), (Wrd26.pObj));

DEFLABEL (label_8)
  (Wrd25.Obj) = Rvl;
  goto label_12;

DEFLABEL (label_15)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_7_7])), (Wrd12.pObj));

DEFLABEL (label_7)
  (Wrd11.Obj) = Rvl;
  goto label_14;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_8_4 3
#define LABEL_8_5 5
#define TAG_8_6 1
#define LABEL_8_12 7
#define LABEL_8_13 9
#define LABEL_8_7 11
#define TAG_8_8 4
#define LABEL_8_9 13
#define TAG_8_10 5
#define LABEL_8_14 15
#define LABEL_8_15 17
#define ENVIRONMENT_LABEL_8_3 28
#define DEBUGGING_LABEL_8_2 27
#define OBJECT_8_1 26
#define OBJECT_8_0 25
#define EXECUTE_CACHE_8_11 19
#define FREE_REFERENCE_8_0 22
#define FREE_ASSIGNMENT_8_0 24
#define FREE_REFERENCES_LABEL_8_0 18
#define NUMBER_OF_LINKER_SECTIONS_8_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
asstop_so_code_8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd31;
  machine_word Wrd19;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  machine_word Wrd32;
  machine_word Wrd28;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd23;
  machine_word Wrd24;
  machine_word Wrd20;
  machine_word Wrd16;
  machine_word Wrd17;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd14;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd10;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_8_4);
      goto bind_assembler_linker_top_level_variables_16;

    case 1:
      current_block = (Rpc - LABEL_8_5);
      goto lambda_24;

    case 2:
      current_block = (Rpc - LABEL_8_12);
      goto label_18;

    case 3:
      current_block = (Rpc - LABEL_8_13);
      goto label_19;

    case 4:
      current_block = (Rpc - LABEL_8_7);
      goto lambda_25;

    case 5:
      current_block = (Rpc - LABEL_8_9);
      goto lambda_26;

    case 6:
      current_block = (Rpc - LABEL_8_14);
      goto label_20;

    case 7:
      current_block = (Rpc - LABEL_8_15);
      goto label_21;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (bind_assembler_linker_top_level_variables_23)
DEFLABEL (bind_assembler_linker_top_level_variables_16)
  INTERRUPT_CHECK (26, LABEL_8_4);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_8_0]);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd12.pObj) = (& (Rhp [-1]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd17.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_8_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_8_5])));
  Rhp += 2;
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd17.pObj)));
  Wrd20 = Wrd17;
  ((Wrd20.pObj) [2]) = (Wrd7.Obj);
  ((Wrd20.pObj) [3]) = (Wrd13.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd24.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_8_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_8_7])));
  Rhp += 1;
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd24.pObj)));
  Wrd25 = Wrd24;
  (Wrd26.Obj) = (Rsp [2]);
  ((Wrd25.pObj) [2]) = (Wrd26.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd29.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_8_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_8_9])));
  Rhp += 2;
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd29.pObj)));
  Wrd32 = Wrd29;
  ((Wrd32.pObj) [2]) = (Wrd7.Obj);
  ((Wrd32.pObj) [3]) = (Wrd13.Obj);
  (Rsp [2]) = (Wrd28.Obj);
  (Rsp [1]) = (Wrd23.Obj);
  (Rsp [0]) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8_11]));

DEFLABEL (lambda_24)
  CLOSURE_HEADER (LABEL_8_5);

DEFLABEL (lambda_6)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_8_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_32;

DEFLABEL (label_31)
  Wrd19 = Wrd23;

DEFLABEL (label_30)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_8_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_29;

DEFLABEL (label_28)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_27)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [2]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_8_1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_29)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_28;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_8_13])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_19)
  goto label_27;

DEFLABEL (label_32)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_31;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_8_12])), (Wrd20.pObj));

DEFLABEL (label_18)
  (Wrd19.Obj) = Rvl;
  goto label_30;

DEFLABEL (lambda_25)
  CLOSURE_HEADER (LABEL_8_7);

DEFLABEL (lambda_7)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (lambda_26)
  CLOSURE_HEADER (LABEL_8_9);

DEFLABEL (lambda_14)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_8_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_38;

DEFLABEL (label_37)
  Wrd19 = Wrd23;

DEFLABEL (label_36)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_8_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_35;

DEFLABEL (label_34)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_33)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_8_1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_35)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_34;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_8_15])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_21)
  goto label_33;

DEFLABEL (label_38)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_37;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_8_14])), (Wrd20.pObj));

DEFLABEL (label_20)
  (Wrd19.Obj) = Rvl;
  goto label_36;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_9_4 3
#define LABEL_9_5 5
#define TAG_9_6 1
#define LABEL_9_12 7
#define LABEL_9_13 9
#define LABEL_9_14 11
#define LABEL_9_15 13
#define LABEL_9_16 15
#define LABEL_9_17 17
#define LABEL_9_18 19
#define LABEL_9_19 21
#define LABEL_9_20 23
#define LABEL_9_21 25
#define LABEL_9_22 27
#define LABEL_9_23 29
#define LABEL_9_24 31
#define LABEL_9_25 33
#define LABEL_9_26 35
#define LABEL_9_27 37
#define LABEL_9_28 39
#define LABEL_9_29 41
#define LABEL_9_30 43
#define LABEL_9_31 45
#define LABEL_9_32 47
#define LABEL_9_33 49
#define LABEL_9_34 51
#define LABEL_9_35 53
#define LABEL_9_36 55
#define LABEL_9_37 57
#define LABEL_9_38 59
#define LABEL_9_39 61
#define LABEL_9_40 63
#define LABEL_9_41 65
#define LABEL_9_7 67
#define TAG_9_8 32
#define LABEL_9_9 69
#define TAG_9_10 33
#define LABEL_9_42 71
#define LABEL_9_43 73
#define LABEL_9_44 75
#define LABEL_9_45 77
#define LABEL_9_46 79
#define LABEL_9_47 81
#define LABEL_9_48 83
#define LABEL_9_49 85
#define LABEL_9_50 87
#define LABEL_9_51 89
#define LABEL_9_52 91
#define LABEL_9_53 93
#define LABEL_9_54 95
#define LABEL_9_55 97
#define LABEL_9_56 99
#define LABEL_9_57 101
#define LABEL_9_58 103
#define LABEL_9_59 105
#define LABEL_9_60 107
#define LABEL_9_61 109
#define LABEL_9_62 111
#define LABEL_9_63 113
#define LABEL_9_64 115
#define LABEL_9_65 117
#define LABEL_9_66 119
#define LABEL_9_67 121
#define LABEL_9_68 123
#define LABEL_9_69 125
#define LABEL_9_70 127
#define LABEL_9_71 129
#define ENVIRONMENT_LABEL_9_3 167
#define DEBUGGING_LABEL_9_2 166
#define OBJECT_9_0 165
#define EXECUTE_CACHE_9_11 131
#define FREE_REFERENCE_9_14 134
#define FREE_REFERENCE_9_13 135
#define FREE_REFERENCE_9_12 136
#define FREE_REFERENCE_9_11 137
#define FREE_REFERENCE_9_10 138
#define FREE_REFERENCE_9_9 139
#define FREE_REFERENCE_9_8 140
#define FREE_REFERENCE_9_7 141
#define FREE_REFERENCE_9_6 142
#define FREE_REFERENCE_9_5 143
#define FREE_REFERENCE_9_4 144
#define FREE_REFERENCE_9_3 145
#define FREE_REFERENCE_9_2 146
#define FREE_REFERENCE_9_1 147
#define FREE_REFERENCE_9_0 148
#define FREE_ASSIGNMENT_9_14 150
#define FREE_ASSIGNMENT_9_13 151
#define FREE_ASSIGNMENT_9_12 152
#define FREE_ASSIGNMENT_9_11 153
#define FREE_ASSIGNMENT_9_10 154
#define FREE_ASSIGNMENT_9_9 155
#define FREE_ASSIGNMENT_9_8 156
#define FREE_ASSIGNMENT_9_7 157
#define FREE_ASSIGNMENT_9_6 158
#define FREE_ASSIGNMENT_9_5 159
#define FREE_ASSIGNMENT_9_4 160
#define FREE_ASSIGNMENT_9_3 161
#define FREE_ASSIGNMENT_9_2 162
#define FREE_ASSIGNMENT_9_1 163
#define FREE_ASSIGNMENT_9_0 164
#define FREE_REFERENCES_LABEL_9_0 130
#define NUMBER_OF_LINKER_SECTIONS_9_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
asstop_so_code_9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd664;
  machine_word Wrd663;
  machine_word Wrd662;
  machine_word Wrd661;
  machine_word Wrd660;
  machine_word Wrd656;
  machine_word Wrd655;
  machine_word Wrd648;
  machine_word Wrd647;
  machine_word Wrd635;
  machine_word Wrd640;
  machine_word Wrd639;
  machine_word Wrd636;
  machine_word Wrd632;
  machine_word Wrd625;
  machine_word Wrd624;
  machine_word Wrd623;
  machine_word Wrd620;
  machine_word Wrd619;
  machine_word Wrd618;
  machine_word Wrd617;
  machine_word Wrd616;
  machine_word Wrd612;
  machine_word Wrd611;
  machine_word Wrd604;
  machine_word Wrd603;
  machine_word Wrd591;
  machine_word Wrd596;
  machine_word Wrd595;
  machine_word Wrd592;
  machine_word Wrd588;
  machine_word Wrd581;
  machine_word Wrd580;
  machine_word Wrd579;
  machine_word Wrd576;
  machine_word Wrd575;
  machine_word Wrd574;
  machine_word Wrd573;
  machine_word Wrd572;
  machine_word Wrd568;
  machine_word Wrd567;
  machine_word Wrd560;
  machine_word Wrd559;
  machine_word Wrd547;
  machine_word Wrd552;
  machine_word Wrd551;
  machine_word Wrd548;
  machine_word Wrd544;
  machine_word Wrd537;
  machine_word Wrd536;
  machine_word Wrd535;
  machine_word Wrd532;
  machine_word Wrd531;
  machine_word Wrd530;
  machine_word Wrd529;
  machine_word Wrd528;
  machine_word Wrd524;
  machine_word Wrd523;
  machine_word Wrd516;
  machine_word Wrd515;
  machine_word Wrd503;
  machine_word Wrd508;
  machine_word Wrd507;
  machine_word Wrd504;
  machine_word Wrd500;
  machine_word Wrd493;
  machine_word Wrd492;
  machine_word Wrd491;
  machine_word Wrd488;
  machine_word Wrd487;
  machine_word Wrd486;
  machine_word Wrd485;
  machine_word Wrd484;
  machine_word Wrd480;
  machine_word Wrd479;
  machine_word Wrd472;
  machine_word Wrd471;
  machine_word Wrd459;
  machine_word Wrd464;
  machine_word Wrd463;
  machine_word Wrd460;
  machine_word Wrd456;
  machine_word Wrd449;
  machine_word Wrd448;
  machine_word Wrd447;
  machine_word Wrd444;
  machine_word Wrd443;
  machine_word Wrd442;
  machine_word Wrd441;
  machine_word Wrd440;
  machine_word Wrd436;
  machine_word Wrd435;
  machine_word Wrd428;
  machine_word Wrd427;
  machine_word Wrd415;
  machine_word Wrd420;
  machine_word Wrd419;
  machine_word Wrd416;
  machine_word Wrd412;
  machine_word Wrd405;
  machine_word Wrd404;
  machine_word Wrd403;
  machine_word Wrd400;
  machine_word Wrd399;
  machine_word Wrd398;
  machine_word Wrd397;
  machine_word Wrd396;
  machine_word Wrd392;
  machine_word Wrd391;
  machine_word Wrd384;
  machine_word Wrd383;
  machine_word Wrd371;
  machine_word Wrd376;
  machine_word Wrd375;
  machine_word Wrd372;
  machine_word Wrd368;
  machine_word Wrd361;
  machine_word Wrd360;
  machine_word Wrd359;
  machine_word Wrd356;
  machine_word Wrd355;
  machine_word Wrd354;
  machine_word Wrd353;
  machine_word Wrd352;
  machine_word Wrd348;
  machine_word Wrd347;
  machine_word Wrd340;
  machine_word Wrd339;
  machine_word Wrd327;
  machine_word Wrd332;
  machine_word Wrd331;
  machine_word Wrd328;
  machine_word Wrd324;
  machine_word Wrd317;
  machine_word Wrd316;
  machine_word Wrd315;
  machine_word Wrd312;
  machine_word Wrd311;
  machine_word Wrd310;
  machine_word Wrd309;
  machine_word Wrd308;
  machine_word Wrd304;
  machine_word Wrd303;
  machine_word Wrd296;
  machine_word Wrd295;
  machine_word Wrd283;
  machine_word Wrd288;
  machine_word Wrd287;
  machine_word Wrd284;
  machine_word Wrd280;
  machine_word Wrd273;
  machine_word Wrd272;
  machine_word Wrd271;
  machine_word Wrd268;
  machine_word Wrd267;
  machine_word Wrd266;
  machine_word Wrd265;
  machine_word Wrd264;
  machine_word Wrd260;
  machine_word Wrd259;
  machine_word Wrd239;
  machine_word Wrd244;
  machine_word Wrd243;
  machine_word Wrd240;
  machine_word Wrd236;
  machine_word Wrd229;
  machine_word Wrd228;
  machine_word Wrd227;
  machine_word Wrd224;
  machine_word Wrd223;
  machine_word Wrd222;
  machine_word Wrd221;
  machine_word Wrd220;
  machine_word Wrd216;
  machine_word Wrd215;
  machine_word Wrd208;
  machine_word Wrd207;
  machine_word Wrd195;
  machine_word Wrd200;
  machine_word Wrd199;
  machine_word Wrd196;
  machine_word Wrd192;
  machine_word Wrd185;
  machine_word Wrd184;
  machine_word Wrd183;
  machine_word Wrd179;
  machine_word Wrd178;
  machine_word Wrd177;
  machine_word Wrd176;
  machine_word Wrd172;
  machine_word Wrd171;
  machine_word Wrd164;
  machine_word Wrd155;
  machine_word Wrd152;
  machine_word Wrd148;
  machine_word Wrd141;
  machine_word Wrd140;
  machine_word Wrd136;
  machine_word Wrd135;
  machine_word Wrd134;
  machine_word Wrd128;
  machine_word Wrd119;
  machine_word Wrd107;
  machine_word Wrd112;
  machine_word Wrd111;
  machine_word Wrd104;
  machine_word Wrd95;
  machine_word Wrd92;
  machine_word Wrd89;
  machine_word Wrd88;
  machine_word Wrd83;
  machine_word Wrd76;
  machine_word Wrd75;
  machine_word Wrd63;
  machine_word Wrd68;
  machine_word Wrd64;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd32;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd16;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  machine_word Wrd314;
  machine_word Wrd254;
  machine_word Wrd255;
  machine_word Wrd252;
  machine_word Wrd251;
  machine_word Wrd249;
  machine_word Wrd250;
  machine_word Wrd246;
  machine_word Wrd186;
  machine_word Wrd187;
  machine_word Wrd181;
  machine_word Wrd180;
  machine_word Wrd175;
  machine_word Wrd174;
  machine_word Wrd169;
  machine_word Wrd168;
  machine_word Wrd163;
  machine_word Wrd162;
  machine_word Wrd157;
  machine_word Wrd156;
  machine_word Wrd151;
  machine_word Wrd150;
  machine_word Wrd145;
  machine_word Wrd144;
  machine_word Wrd139;
  machine_word Wrd138;
  machine_word Wrd133;
  machine_word Wrd132;
  machine_word Wrd127;
  machine_word Wrd126;
  machine_word Wrd121;
  machine_word Wrd120;
  machine_word Wrd115;
  machine_word Wrd114;
  machine_word Wrd109;
  machine_word Wrd108;
  machine_word Wrd103;
  machine_word Wrd102;
  machine_word Wrd97;
  machine_word Wrd96;
  machine_word Wrd91;
  machine_word Wrd90;
  machine_word Wrd85;
  machine_word Wrd84;
  machine_word Wrd79;
  machine_word Wrd78;
  machine_word Wrd73;
  machine_word Wrd72;
  machine_word Wrd67;
  machine_word Wrd66;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd10;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_9_4);
      goto bind_assembler_linker_variables_184;

    case 1:
      current_block = (Rpc - LABEL_9_5);
      goto lambda_248;

    case 2:
      current_block = (Rpc - LABEL_9_12);
      goto label_186;

    case 3:
      current_block = (Rpc - LABEL_9_13);
      goto label_187;

    case 4:
      current_block = (Rpc - LABEL_9_14);
      goto label_188;

    case 5:
      current_block = (Rpc - LABEL_9_15);
      goto label_189;

    case 6:
      current_block = (Rpc - LABEL_9_16);
      goto label_190;

    case 7:
      current_block = (Rpc - LABEL_9_17);
      goto label_191;

    case 8:
      current_block = (Rpc - LABEL_9_18);
      goto label_192;

    case 9:
      current_block = (Rpc - LABEL_9_19);
      goto label_193;

    case 10:
      current_block = (Rpc - LABEL_9_20);
      goto label_194;

    case 11:
      current_block = (Rpc - LABEL_9_21);
      goto label_195;

    case 12:
      current_block = (Rpc - LABEL_9_22);
      goto label_196;

    case 13:
      current_block = (Rpc - LABEL_9_23);
      goto label_197;

    case 14:
      current_block = (Rpc - LABEL_9_24);
      goto label_198;

    case 15:
      current_block = (Rpc - LABEL_9_25);
      goto label_199;

    case 16:
      current_block = (Rpc - LABEL_9_26);
      goto label_200;

    case 17:
      current_block = (Rpc - LABEL_9_27);
      goto label_201;

    case 18:
      current_block = (Rpc - LABEL_9_28);
      goto label_202;

    case 19:
      current_block = (Rpc - LABEL_9_29);
      goto label_203;

    case 20:
      current_block = (Rpc - LABEL_9_30);
      goto label_204;

    case 21:
      current_block = (Rpc - LABEL_9_31);
      goto label_205;

    case 22:
      current_block = (Rpc - LABEL_9_32);
      goto label_206;

    case 23:
      current_block = (Rpc - LABEL_9_33);
      goto label_207;

    case 24:
      current_block = (Rpc - LABEL_9_34);
      goto label_208;

    case 25:
      current_block = (Rpc - LABEL_9_35);
      goto label_209;

    case 26:
      current_block = (Rpc - LABEL_9_36);
      goto label_210;

    case 27:
      current_block = (Rpc - LABEL_9_37);
      goto label_211;

    case 28:
      current_block = (Rpc - LABEL_9_38);
      goto label_212;

    case 29:
      current_block = (Rpc - LABEL_9_39);
      goto label_213;

    case 30:
      current_block = (Rpc - LABEL_9_40);
      goto label_214;

    case 31:
      current_block = (Rpc - LABEL_9_41);
      goto label_215;

    case 32:
      current_block = (Rpc - LABEL_9_7);
      goto lambda_249;

    case 33:
      current_block = (Rpc - LABEL_9_9);
      goto lambda_250;

    case 34:
      current_block = (Rpc - LABEL_9_42);
      goto label_216;

    case 35:
      current_block = (Rpc - LABEL_9_43);
      goto label_217;

    case 36:
      current_block = (Rpc - LABEL_9_44);
      goto label_218;

    case 37:
      current_block = (Rpc - LABEL_9_45);
      goto label_219;

    case 38:
      current_block = (Rpc - LABEL_9_46);
      goto label_220;

    case 39:
      current_block = (Rpc - LABEL_9_47);
      goto label_221;

    case 40:
      current_block = (Rpc - LABEL_9_48);
      goto label_222;

    case 41:
      current_block = (Rpc - LABEL_9_49);
      goto label_223;

    case 42:
      current_block = (Rpc - LABEL_9_50);
      goto label_224;

    case 43:
      current_block = (Rpc - LABEL_9_51);
      goto label_225;

    case 44:
      current_block = (Rpc - LABEL_9_52);
      goto label_226;

    case 45:
      current_block = (Rpc - LABEL_9_53);
      goto label_227;

    case 46:
      current_block = (Rpc - LABEL_9_54);
      goto label_228;

    case 47:
      current_block = (Rpc - LABEL_9_55);
      goto label_229;

    case 48:
      current_block = (Rpc - LABEL_9_56);
      goto label_230;

    case 49:
      current_block = (Rpc - LABEL_9_57);
      goto label_231;

    case 50:
      current_block = (Rpc - LABEL_9_58);
      goto label_232;

    case 51:
      current_block = (Rpc - LABEL_9_59);
      goto label_233;

    case 52:
      current_block = (Rpc - LABEL_9_60);
      goto label_234;

    case 53:
      current_block = (Rpc - LABEL_9_61);
      goto label_235;

    case 54:
      current_block = (Rpc - LABEL_9_62);
      goto label_236;

    case 55:
      current_block = (Rpc - LABEL_9_63);
      goto label_237;

    case 56:
      current_block = (Rpc - LABEL_9_64);
      goto label_238;

    case 57:
      current_block = (Rpc - LABEL_9_65);
      goto label_239;

    case 58:
      current_block = (Rpc - LABEL_9_66);
      goto label_240;

    case 59:
      current_block = (Rpc - LABEL_9_67);
      goto label_241;

    case 60:
      current_block = (Rpc - LABEL_9_68);
      goto label_242;

    case 61:
      current_block = (Rpc - LABEL_9_69);
      goto label_243;

    case 62:
      current_block = (Rpc - LABEL_9_70);
      goto label_244;

    case 63:
      current_block = (Rpc - LABEL_9_71);
      goto label_245;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (bind_assembler_linker_variables_247)
DEFLABEL (bind_assembler_linker_variables_184)
  INTERRUPT_CHECK (26, LABEL_9_4);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd12.pObj) = (& (Rhp [-1]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd18.pObj) = (& (Rhp [-1]));
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd18.pObj)));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd24.pObj) = (& (Rhp [-1]));
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd24.pObj)));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd30.pObj) = (& (Rhp [-1]));
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd30.pObj)));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd36.pObj) = (& (Rhp [-1]));
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd36.pObj)));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd42.pObj) = (& (Rhp [-1]));
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd42.pObj)));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd48.pObj) = (& (Rhp [-1]));
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd48.pObj)));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd54.pObj) = (& (Rhp [-1]));
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd54.pObj)));
  (* (--Rsp)) = (Wrd55.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd60.pObj) = (& (Rhp [-1]));
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd60.pObj)));
  (* (--Rsp)) = (Wrd61.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd66.pObj) = (& (Rhp [-1]));
  (Wrd67.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd66.pObj)));
  (* (--Rsp)) = (Wrd67.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd72.pObj) = (& (Rhp [-1]));
  (Wrd73.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd72.pObj)));
  (* (--Rsp)) = (Wrd73.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd78.pObj) = (& (Rhp [-1]));
  (Wrd79.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd78.pObj)));
  (* (--Rsp)) = (Wrd79.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd84.pObj) = (& (Rhp [-1]));
  (Wrd85.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd84.pObj)));
  (* (--Rsp)) = (Wrd85.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd90.pObj) = (& (Rhp [-1]));
  (Wrd91.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd90.pObj)));
  (* (--Rsp)) = (Wrd91.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd96.pObj) = (& (Rhp [-1]));
  (Wrd97.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd96.pObj)));
  (* (--Rsp)) = (Wrd97.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd102.pObj) = (& (Rhp [-1]));
  (Wrd103.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd102.pObj)));
  (* (--Rsp)) = (Wrd103.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd108.pObj) = (& (Rhp [-1]));
  (Wrd109.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd108.pObj)));
  (* (--Rsp)) = (Wrd109.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd114.pObj) = (& (Rhp [-1]));
  (Wrd115.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd114.pObj)));
  (* (--Rsp)) = (Wrd115.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd120.pObj) = (& (Rhp [-1]));
  (Wrd121.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd120.pObj)));
  (* (--Rsp)) = (Wrd121.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd126.pObj) = (& (Rhp [-1]));
  (Wrd127.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd126.pObj)));
  (* (--Rsp)) = (Wrd127.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd132.pObj) = (& (Rhp [-1]));
  (Wrd133.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd132.pObj)));
  (* (--Rsp)) = (Wrd133.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd138.pObj) = (& (Rhp [-1]));
  (Wrd139.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd138.pObj)));
  (* (--Rsp)) = (Wrd139.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd144.pObj) = (& (Rhp [-1]));
  (Wrd145.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd144.pObj)));
  (* (--Rsp)) = (Wrd145.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd150.pObj) = (& (Rhp [-1]));
  (Wrd151.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd150.pObj)));
  (* (--Rsp)) = (Wrd151.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd156.pObj) = (& (Rhp [-1]));
  (Wrd157.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd156.pObj)));
  (* (--Rsp)) = (Wrd157.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd162.pObj) = (& (Rhp [-1]));
  (Wrd163.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd162.pObj)));
  (* (--Rsp)) = (Wrd163.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd168.pObj) = (& (Rhp [-1]));
  (Wrd169.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd168.pObj)));
  (* (--Rsp)) = (Wrd169.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd174.pObj) = (& (Rhp [-1]));
  (Wrd175.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd174.pObj)));
  (* (--Rsp)) = (Wrd175.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd180.pObj) = (& (Rhp [-1]));
  (Wrd181.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd180.pObj)));
  (* (--Rsp)) = (Wrd181.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 33));
  (Wrd187.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_9_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_9_5])));
  Rhp += 30;
  (Wrd186.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd187.pObj)));
  Wrd246 = Wrd187;
  ((Wrd246.pObj) [2]) = (Wrd7.Obj);
  ((Wrd246.pObj) [3]) = (Wrd13.Obj);
  ((Wrd246.pObj) [4]) = (Wrd19.Obj);
  ((Wrd246.pObj) [5]) = (Wrd25.Obj);
  ((Wrd246.pObj) [6]) = (Wrd31.Obj);
  ((Wrd246.pObj) [7]) = (Wrd37.Obj);
  ((Wrd246.pObj) [8]) = (Wrd43.Obj);
  ((Wrd246.pObj) [9]) = (Wrd49.Obj);
  ((Wrd246.pObj) [10]) = (Wrd55.Obj);
  ((Wrd246.pObj) [11]) = (Wrd61.Obj);
  ((Wrd246.pObj) [12]) = (Wrd67.Obj);
  ((Wrd246.pObj) [13]) = (Wrd73.Obj);
  ((Wrd246.pObj) [14]) = (Wrd79.Obj);
  ((Wrd246.pObj) [15]) = (Wrd85.Obj);
  ((Wrd246.pObj) [16]) = (Wrd91.Obj);
  ((Wrd246.pObj) [17]) = (Wrd97.Obj);
  ((Wrd246.pObj) [18]) = (Wrd103.Obj);
  ((Wrd246.pObj) [19]) = (Wrd109.Obj);
  ((Wrd246.pObj) [20]) = (Wrd115.Obj);
  ((Wrd246.pObj) [21]) = (Wrd121.Obj);
  ((Wrd246.pObj) [22]) = (Wrd127.Obj);
  ((Wrd246.pObj) [23]) = (Wrd133.Obj);
  ((Wrd246.pObj) [24]) = (Wrd139.Obj);
  ((Wrd246.pObj) [25]) = (Wrd145.Obj);
  ((Wrd246.pObj) [26]) = (Wrd151.Obj);
  ((Wrd246.pObj) [27]) = (Wrd157.Obj);
  ((Wrd246.pObj) [28]) = (Wrd163.Obj);
  ((Wrd246.pObj) [29]) = (Wrd169.Obj);
  ((Wrd246.pObj) [30]) = (Wrd175.Obj);
  ((Wrd246.pObj) [31]) = (Wrd181.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd250.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_9_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_9_7])));
  Rhp += 1;
  (Wrd249.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd250.pObj)));
  Wrd251 = Wrd250;
  (Wrd252.Obj) = (Rsp [30]);
  ((Wrd251.pObj) [2]) = (Wrd252.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 33));
  (Wrd255.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_9_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_9_9])));
  Rhp += 30;
  (Wrd254.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd255.pObj)));
  Wrd314 = Wrd255;
  ((Wrd314.pObj) [2]) = (Wrd7.Obj);
  ((Wrd314.pObj) [3]) = (Wrd13.Obj);
  ((Wrd314.pObj) [4]) = (Wrd19.Obj);
  ((Wrd314.pObj) [5]) = (Wrd25.Obj);
  ((Wrd314.pObj) [6]) = (Wrd31.Obj);
  ((Wrd314.pObj) [7]) = (Wrd37.Obj);
  ((Wrd314.pObj) [8]) = (Wrd43.Obj);
  ((Wrd314.pObj) [9]) = (Wrd49.Obj);
  ((Wrd314.pObj) [10]) = (Wrd55.Obj);
  ((Wrd314.pObj) [11]) = (Wrd61.Obj);
  ((Wrd314.pObj) [12]) = (Wrd67.Obj);
  ((Wrd314.pObj) [13]) = (Wrd73.Obj);
  ((Wrd314.pObj) [14]) = (Wrd79.Obj);
  ((Wrd314.pObj) [15]) = (Wrd85.Obj);
  ((Wrd314.pObj) [16]) = (Wrd91.Obj);
  ((Wrd314.pObj) [17]) = (Wrd97.Obj);
  ((Wrd314.pObj) [18]) = (Wrd103.Obj);
  ((Wrd314.pObj) [19]) = (Wrd109.Obj);
  ((Wrd314.pObj) [20]) = (Wrd115.Obj);
  ((Wrd314.pObj) [21]) = (Wrd121.Obj);
  ((Wrd314.pObj) [22]) = (Wrd127.Obj);
  ((Wrd314.pObj) [23]) = (Wrd133.Obj);
  ((Wrd314.pObj) [24]) = (Wrd139.Obj);
  ((Wrd314.pObj) [25]) = (Wrd145.Obj);
  ((Wrd314.pObj) [26]) = (Wrd151.Obj);
  ((Wrd314.pObj) [27]) = (Wrd157.Obj);
  ((Wrd314.pObj) [28]) = (Wrd163.Obj);
  ((Wrd314.pObj) [29]) = (Wrd169.Obj);
  ((Wrd314.pObj) [30]) = (Wrd175.Obj);
  ((Wrd314.pObj) [31]) = (Wrd181.Obj);
  (Rsp [30]) = (Wrd254.Obj);
  (Rsp [29]) = (Wrd249.Obj);
  (Rsp [28]) = (Wrd186.Obj);
  Rsp = (& (Rsp [28]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_11]));

DEFLABEL (lambda_248)
  CLOSURE_HEADER (LABEL_9_5);

DEFLABEL (lambda_90)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [31]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_340;

DEFLABEL (label_339)
  Wrd19 = Wrd23;

DEFLABEL (label_338)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_9_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_337;

DEFLABEL (label_336)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_335)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [16]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  (Wrd51.Obj) = ((Wrd46.pObj) [30]);
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [0]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd60.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd52.pObj) [0]) = (Wrd60.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd64.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_1]));
  (Wrd67.Obj) = ((Wrd64.pObj) [0]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if ((Wrd68.uLng) == 50)
    goto label_334;

DEFLABEL (label_333)
  Wrd63 = Wrd67;

DEFLABEL (label_332)
  (* (--Rsp)) = (Wrd63.Obj);
  (Wrd75.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_9_1]));
  (Wrd76.Obj) = (Rsp [1]);
  (Wrd83.Obj) = ((Wrd75.pObj) [0]);
  (Wrd84.uLng) = (OBJECT_TYPE (Wrd83.Obj));
  if ((Wrd84.uLng) == 50)
    goto label_331;

DEFLABEL (label_330)
  ((Wrd75.pObj) [0]) = (Wrd76.Obj);

DEFLABEL (label_329)
  (Wrd88.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd89.Obj) = (Rsp [0]);
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd89.Obj));
  (Wrd91.Obj) = ((Wrd90.pObj) [15]);
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  ((Wrd92.pObj) [0]) = (Wrd88.Obj);
  (Wrd95.Obj) = ((Wrd90.pObj) [29]);
  (Wrd96.pObj) = (OBJECT_ADDRESS (Wrd95.Obj));
  (Wrd97.Obj) = ((Wrd96.pObj) [0]);
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd104.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd96.pObj) [0]) = (Wrd104.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd108.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_2]));
  (Wrd111.Obj) = ((Wrd108.pObj) [0]);
  (Wrd112.uLng) = (OBJECT_TYPE (Wrd111.Obj));
  if ((Wrd112.uLng) == 50)
    goto label_328;

DEFLABEL (label_327)
  Wrd107 = Wrd111;

DEFLABEL (label_326)
  (* (--Rsp)) = (Wrd107.Obj);
  (Wrd119.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_9_2]));
  (Wrd120.Obj) = (Rsp [1]);
  (Wrd127.Obj) = ((Wrd119.pObj) [0]);
  (Wrd128.uLng) = (OBJECT_TYPE (Wrd127.Obj));
  if ((Wrd128.uLng) == 50)
    goto label_325;

DEFLABEL (label_324)
  ((Wrd119.pObj) [0]) = (Wrd120.Obj);

DEFLABEL (label_323)
  (Wrd132.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd133.Obj) = (Rsp [0]);
  (Wrd134.pObj) = (OBJECT_ADDRESS (Wrd133.Obj));
  (Wrd135.Obj) = ((Wrd134.pObj) [14]);
  (Wrd136.pObj) = (OBJECT_ADDRESS (Wrd135.Obj));
  ((Wrd136.pObj) [0]) = (Wrd132.Obj);
  (Wrd139.Obj) = ((Wrd134.pObj) [28]);
  (Wrd140.pObj) = (OBJECT_ADDRESS (Wrd139.Obj));
  (Wrd141.Obj) = ((Wrd140.pObj) [0]);
  (* (--Rsp)) = (Wrd141.Obj);
  (Wrd148.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd140.pObj) [0]) = (Wrd148.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd141.Obj);
  (Wrd152.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_3]));
  (Wrd155.Obj) = ((Wrd152.pObj) [0]);
  (Wrd156.uLng) = (OBJECT_TYPE (Wrd155.Obj));
  if ((Wrd156.uLng) == 50)
    goto label_322;

DEFLABEL (label_321)
  Wrd151 = Wrd155;

DEFLABEL (label_320)
  (* (--Rsp)) = (Wrd151.Obj);
  (Wrd163.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_9_3]));
  (Wrd164.Obj) = (Rsp [1]);
  (Wrd171.Obj) = ((Wrd163.pObj) [0]);
  (Wrd172.uLng) = (OBJECT_TYPE (Wrd171.Obj));
  if ((Wrd172.uLng) == 50)
    goto label_319;

DEFLABEL (label_318)
  ((Wrd163.pObj) [0]) = (Wrd164.Obj);

DEFLABEL (label_317)
  (Wrd176.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd177.Obj) = (Rsp [0]);
  (Wrd178.pObj) = (OBJECT_ADDRESS (Wrd177.Obj));
  (Wrd179.Obj) = ((Wrd178.pObj) [13]);
  (Wrd180.pObj) = (OBJECT_ADDRESS (Wrd179.Obj));
  ((Wrd180.pObj) [0]) = (Wrd176.Obj);
  (Wrd183.Obj) = ((Wrd178.pObj) [27]);
  (Wrd184.pObj) = (OBJECT_ADDRESS (Wrd183.Obj));
  (Wrd185.Obj) = ((Wrd184.pObj) [0]);
  (* (--Rsp)) = (Wrd185.Obj);
  (Wrd192.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd184.pObj) [0]) = (Wrd192.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd185.Obj);
  (Wrd196.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_4]));
  (Wrd199.Obj) = ((Wrd196.pObj) [0]);
  (Wrd200.uLng) = (OBJECT_TYPE (Wrd199.Obj));
  if ((Wrd200.uLng) == 50)
    goto label_316;

DEFLABEL (label_315)
  Wrd195 = Wrd199;

DEFLABEL (label_314)
  (* (--Rsp)) = (Wrd195.Obj);
  (Wrd207.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_9_4]));
  (Wrd208.Obj) = (Rsp [1]);
  (Wrd215.Obj) = ((Wrd207.pObj) [0]);
  (Wrd216.uLng) = (OBJECT_TYPE (Wrd215.Obj));
  if ((Wrd216.uLng) == 50)
    goto label_313;

DEFLABEL (label_312)
  ((Wrd207.pObj) [0]) = (Wrd208.Obj);

DEFLABEL (label_311)
  (Wrd220.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd221.Obj) = (Rsp [0]);
  (Wrd222.pObj) = (OBJECT_ADDRESS (Wrd221.Obj));
  (Wrd223.Obj) = ((Wrd222.pObj) [12]);
  (Wrd224.pObj) = (OBJECT_ADDRESS (Wrd223.Obj));
  ((Wrd224.pObj) [0]) = (Wrd220.Obj);
  (Wrd227.Obj) = ((Wrd222.pObj) [26]);
  (Wrd228.pObj) = (OBJECT_ADDRESS (Wrd227.Obj));
  (Wrd229.Obj) = ((Wrd228.pObj) [0]);
  (* (--Rsp)) = (Wrd229.Obj);
  (Wrd236.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd228.pObj) [0]) = (Wrd236.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd229.Obj);
  (Wrd240.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_5]));
  (Wrd243.Obj) = ((Wrd240.pObj) [0]);
  (Wrd244.uLng) = (OBJECT_TYPE (Wrd243.Obj));
  if ((Wrd244.uLng) == 50)
    goto label_310;

DEFLABEL (label_309)
  Wrd239 = Wrd243;

DEFLABEL (label_308)
  (* (--Rsp)) = (Wrd239.Obj);
  (Wrd251.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_9_5]));
  (Wrd252.Obj) = (Rsp [1]);
  (Wrd259.Obj) = ((Wrd251.pObj) [0]);
  (Wrd260.uLng) = (OBJECT_TYPE (Wrd259.Obj));
  if ((Wrd260.uLng) == 50)
    goto label_307;

DEFLABEL (label_306)
  ((Wrd251.pObj) [0]) = (Wrd252.Obj);

DEFLABEL (label_305)
  (Wrd264.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd265.Obj) = (Rsp [0]);
  (Wrd266.pObj) = (OBJECT_ADDRESS (Wrd265.Obj));
  (Wrd267.Obj) = ((Wrd266.pObj) [11]);
  (Wrd268.pObj) = (OBJECT_ADDRESS (Wrd267.Obj));
  ((Wrd268.pObj) [0]) = (Wrd264.Obj);
  (Wrd271.Obj) = ((Wrd266.pObj) [25]);
  (Wrd272.pObj) = (OBJECT_ADDRESS (Wrd271.Obj));
  (Wrd273.Obj) = ((Wrd272.pObj) [0]);
  (* (--Rsp)) = (Wrd273.Obj);
  (Wrd280.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd272.pObj) [0]) = (Wrd280.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd273.Obj);
  (Wrd284.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_6]));
  (Wrd287.Obj) = ((Wrd284.pObj) [0]);
  (Wrd288.uLng) = (OBJECT_TYPE (Wrd287.Obj));
  if ((Wrd288.uLng) == 50)
    goto label_304;

DEFLABEL (label_303)
  Wrd283 = Wrd287;

DEFLABEL (label_302)
  (* (--Rsp)) = (Wrd283.Obj);
  (Wrd295.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_9_6]));
  (Wrd296.Obj) = (Rsp [1]);
  (Wrd303.Obj) = ((Wrd295.pObj) [0]);
  (Wrd304.uLng) = (OBJECT_TYPE (Wrd303.Obj));
  if ((Wrd304.uLng) == 50)
    goto label_301;

DEFLABEL (label_300)
  ((Wrd295.pObj) [0]) = (Wrd296.Obj);

DEFLABEL (label_299)
  (Wrd308.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd309.Obj) = (Rsp [0]);
  (Wrd310.pObj) = (OBJECT_ADDRESS (Wrd309.Obj));
  (Wrd311.Obj) = ((Wrd310.pObj) [10]);
  (Wrd312.pObj) = (OBJECT_ADDRESS (Wrd311.Obj));
  ((Wrd312.pObj) [0]) = (Wrd308.Obj);
  (Wrd315.Obj) = ((Wrd310.pObj) [24]);
  (Wrd316.pObj) = (OBJECT_ADDRESS (Wrd315.Obj));
  (Wrd317.Obj) = ((Wrd316.pObj) [0]);
  (* (--Rsp)) = (Wrd317.Obj);
  (Wrd324.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd316.pObj) [0]) = (Wrd324.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd317.Obj);
  (Wrd328.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_7]));
  (Wrd331.Obj) = ((Wrd328.pObj) [0]);
  (Wrd332.uLng) = (OBJECT_TYPE (Wrd331.Obj));
  if ((Wrd332.uLng) == 50)
    goto label_298;

DEFLABEL (label_297)
  Wrd327 = Wrd331;

DEFLABEL (label_296)
  (* (--Rsp)) = (Wrd327.Obj);
  (Wrd339.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_9_7]));
  (Wrd340.Obj) = (Rsp [1]);
  (Wrd347.Obj) = ((Wrd339.pObj) [0]);
  (Wrd348.uLng) = (OBJECT_TYPE (Wrd347.Obj));
  if ((Wrd348.uLng) == 50)
    goto label_295;

DEFLABEL (label_294)
  ((Wrd339.pObj) [0]) = (Wrd340.Obj);

DEFLABEL (label_293)
  (Wrd352.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd353.Obj) = (Rsp [0]);
  (Wrd354.pObj) = (OBJECT_ADDRESS (Wrd353.Obj));
  (Wrd355.Obj) = ((Wrd354.pObj) [9]);
  (Wrd356.pObj) = (OBJECT_ADDRESS (Wrd355.Obj));
  ((Wrd356.pObj) [0]) = (Wrd352.Obj);
  (Wrd359.Obj) = ((Wrd354.pObj) [23]);
  (Wrd360.pObj) = (OBJECT_ADDRESS (Wrd359.Obj));
  (Wrd361.Obj) = ((Wrd360.pObj) [0]);
  (* (--Rsp)) = (Wrd361.Obj);
  (Wrd368.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd360.pObj) [0]) = (Wrd368.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd361.Obj);
  (Wrd372.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_8]));
  (Wrd375.Obj) = ((Wrd372.pObj) [0]);
  (Wrd376.uLng) = (OBJECT_TYPE (Wrd375.Obj));
  if ((Wrd376.uLng) == 50)
    goto label_292;

DEFLABEL (label_291)
  Wrd371 = Wrd375;

DEFLABEL (label_290)
  (* (--Rsp)) = (Wrd371.Obj);
  (Wrd383.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_9_8]));
  (Wrd384.Obj) = (Rsp [1]);
  (Wrd391.Obj) = ((Wrd383.pObj) [0]);
  (Wrd392.uLng) = (OBJECT_TYPE (Wrd391.Obj));
  if ((Wrd392.uLng) == 50)
    goto label_289;

DEFLABEL (label_288)
  ((Wrd383.pObj) [0]) = (Wrd384.Obj);

DEFLABEL (label_287)
  (Wrd396.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd397.Obj) = (Rsp [0]);
  (Wrd398.pObj) = (OBJECT_ADDRESS (Wrd397.Obj));
  (Wrd399.Obj) = ((Wrd398.pObj) [8]);
  (Wrd400.pObj) = (OBJECT_ADDRESS (Wrd399.Obj));
  ((Wrd400.pObj) [0]) = (Wrd396.Obj);
  (Wrd403.Obj) = ((Wrd398.pObj) [22]);
  (Wrd404.pObj) = (OBJECT_ADDRESS (Wrd403.Obj));
  (Wrd405.Obj) = ((Wrd404.pObj) [0]);
  (* (--Rsp)) = (Wrd405.Obj);
  (Wrd412.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd404.pObj) [0]) = (Wrd412.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd405.Obj);
  (Wrd416.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_9]));
  (Wrd419.Obj) = ((Wrd416.pObj) [0]);
  (Wrd420.uLng) = (OBJECT_TYPE (Wrd419.Obj));
  if ((Wrd420.uLng) == 50)
    goto label_286;

DEFLABEL (label_285)
  Wrd415 = Wrd419;

DEFLABEL (label_284)
  (* (--Rsp)) = (Wrd415.Obj);
  (Wrd427.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_9_9]));
  (Wrd428.Obj) = (Rsp [1]);
  (Wrd435.Obj) = ((Wrd427.pObj) [0]);
  (Wrd436.uLng) = (OBJECT_TYPE (Wrd435.Obj));
  if ((Wrd436.uLng) == 50)
    goto label_283;

DEFLABEL (label_282)
  ((Wrd427.pObj) [0]) = (Wrd428.Obj);

DEFLABEL (label_281)
  (Wrd440.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd441.Obj) = (Rsp [0]);
  (Wrd442.pObj) = (OBJECT_ADDRESS (Wrd441.Obj));
  (Wrd443.Obj) = ((Wrd442.pObj) [7]);
  (Wrd444.pObj) = (OBJECT_ADDRESS (Wrd443.Obj));
  ((Wrd444.pObj) [0]) = (Wrd440.Obj);
  (Wrd447.Obj) = ((Wrd442.pObj) [21]);
  (Wrd448.pObj) = (OBJECT_ADDRESS (Wrd447.Obj));
  (Wrd449.Obj) = ((Wrd448.pObj) [0]);
  (* (--Rsp)) = (Wrd449.Obj);
  (Wrd456.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd448.pObj) [0]) = (Wrd456.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd449.Obj);
  (Wrd460.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_10]));
  (Wrd463.Obj) = ((Wrd460.pObj) [0]);
  (Wrd464.uLng) = (OBJECT_TYPE (Wrd463.Obj));
  if ((Wrd464.uLng) == 50)
    goto label_280;

DEFLABEL (label_279)
  Wrd459 = Wrd463;

DEFLABEL (label_278)
  (* (--Rsp)) = (Wrd459.Obj);
  (Wrd471.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_9_10]));
  (Wrd472.Obj) = (Rsp [1]);
  (Wrd479.Obj) = ((Wrd471.pObj) [0]);
  (Wrd480.uLng) = (OBJECT_TYPE (Wrd479.Obj));
  if ((Wrd480.uLng) == 50)
    goto label_277;

DEFLABEL (label_276)
  ((Wrd471.pObj) [0]) = (Wrd472.Obj);

DEFLABEL (label_275)
  (Wrd484.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd485.Obj) = (Rsp [0]);
  (Wrd486.pObj) = (OBJECT_ADDRESS (Wrd485.Obj));
  (Wrd487.Obj) = ((Wrd486.pObj) [6]);
  (Wrd488.pObj) = (OBJECT_ADDRESS (Wrd487.Obj));
  ((Wrd488.pObj) [0]) = (Wrd484.Obj);
  (Wrd491.Obj) = ((Wrd486.pObj) [20]);
  (Wrd492.pObj) = (OBJECT_ADDRESS (Wrd491.Obj));
  (Wrd493.Obj) = ((Wrd492.pObj) [0]);
  (* (--Rsp)) = (Wrd493.Obj);
  (Wrd500.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd492.pObj) [0]) = (Wrd500.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd493.Obj);
  (Wrd504.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_11]));
  (Wrd507.Obj) = ((Wrd504.pObj) [0]);
  (Wrd508.uLng) = (OBJECT_TYPE (Wrd507.Obj));
  if ((Wrd508.uLng) == 50)
    goto label_274;

DEFLABEL (label_273)
  Wrd503 = Wrd507;

DEFLABEL (label_272)
  (* (--Rsp)) = (Wrd503.Obj);
  (Wrd515.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_9_11]));
  (Wrd516.Obj) = (Rsp [1]);
  (Wrd523.Obj) = ((Wrd515.pObj) [0]);
  (Wrd524.uLng) = (OBJECT_TYPE (Wrd523.Obj));
  if ((Wrd524.uLng) == 50)
    goto label_271;

DEFLABEL (label_270)
  ((Wrd515.pObj) [0]) = (Wrd516.Obj);

DEFLABEL (label_269)
  (Wrd528.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd529.Obj) = (Rsp [0]);
  (Wrd530.pObj) = (OBJECT_ADDRESS (Wrd529.Obj));
  (Wrd531.Obj) = ((Wrd530.pObj) [5]);
  (Wrd532.pObj) = (OBJECT_ADDRESS (Wrd531.Obj));
  ((Wrd532.pObj) [0]) = (Wrd528.Obj);
  (Wrd535.Obj) = ((Wrd530.pObj) [19]);
  (Wrd536.pObj) = (OBJECT_ADDRESS (Wrd535.Obj));
  (Wrd537.Obj) = ((Wrd536.pObj) [0]);
  (* (--Rsp)) = (Wrd537.Obj);
  (Wrd544.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd536.pObj) [0]) = (Wrd544.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd537.Obj);
  (Wrd548.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_12]));
  (Wrd551.Obj) = ((Wrd548.pObj) [0]);
  (Wrd552.uLng) = (OBJECT_TYPE (Wrd551.Obj));
  if ((Wrd552.uLng) == 50)
    goto label_268;

DEFLABEL (label_267)
  Wrd547 = Wrd551;

DEFLABEL (label_266)
  (* (--Rsp)) = (Wrd547.Obj);
  (Wrd559.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_9_12]));
  (Wrd560.Obj) = (Rsp [1]);
  (Wrd567.Obj) = ((Wrd559.pObj) [0]);
  (Wrd568.uLng) = (OBJECT_TYPE (Wrd567.Obj));
  if ((Wrd568.uLng) == 50)
    goto label_265;

DEFLABEL (label_264)
  ((Wrd559.pObj) [0]) = (Wrd560.Obj);

DEFLABEL (label_263)
  (Wrd572.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd573.Obj) = (Rsp [0]);
  (Wrd574.pObj) = (OBJECT_ADDRESS (Wrd573.Obj));
  (Wrd575.Obj) = ((Wrd574.pObj) [4]);
  (Wrd576.pObj) = (OBJECT_ADDRESS (Wrd575.Obj));
  ((Wrd576.pObj) [0]) = (Wrd572.Obj);
  (Wrd579.Obj) = ((Wrd574.pObj) [18]);
  (Wrd580.pObj) = (OBJECT_ADDRESS (Wrd579.Obj));
  (Wrd581.Obj) = ((Wrd580.pObj) [0]);
  (* (--Rsp)) = (Wrd581.Obj);
  (Wrd588.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd580.pObj) [0]) = (Wrd588.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd581.Obj);
  (Wrd592.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_13]));
  (Wrd595.Obj) = ((Wrd592.pObj) [0]);
  (Wrd596.uLng) = (OBJECT_TYPE (Wrd595.Obj));
  if ((Wrd596.uLng) == 50)
    goto label_262;

DEFLABEL (label_261)
  Wrd591 = Wrd595;

DEFLABEL (label_260)
  (* (--Rsp)) = (Wrd591.Obj);
  (Wrd603.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_9_13]));
  (Wrd604.Obj) = (Rsp [1]);
  (Wrd611.Obj) = ((Wrd603.pObj) [0]);
  (Wrd612.uLng) = (OBJECT_TYPE (Wrd611.Obj));
  if ((Wrd612.uLng) == 50)
    goto label_259;

DEFLABEL (label_258)
  ((Wrd603.pObj) [0]) = (Wrd604.Obj);

DEFLABEL (label_257)
  (Wrd616.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd617.Obj) = (Rsp [0]);
  (Wrd618.pObj) = (OBJECT_ADDRESS (Wrd617.Obj));
  (Wrd619.Obj) = ((Wrd618.pObj) [3]);
  (Wrd620.pObj) = (OBJECT_ADDRESS (Wrd619.Obj));
  ((Wrd620.pObj) [0]) = (Wrd616.Obj);
  (Wrd623.Obj) = ((Wrd618.pObj) [17]);
  (Wrd624.pObj) = (OBJECT_ADDRESS (Wrd623.Obj));
  (Wrd625.Obj) = ((Wrd624.pObj) [0]);
  (* (--Rsp)) = (Wrd625.Obj);
  (Wrd632.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd624.pObj) [0]) = (Wrd632.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd625.Obj);
  (Wrd636.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_14]));
  (Wrd639.Obj) = ((Wrd636.pObj) [0]);
  (Wrd640.uLng) = (OBJECT_TYPE (Wrd639.Obj));
  if ((Wrd640.uLng) == 50)
    goto label_256;

DEFLABEL (label_255)
  Wrd635 = Wrd639;

DEFLABEL (label_254)
  (* (--Rsp)) = (Wrd635.Obj);
  (Wrd647.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_9_14]));
  (Wrd648.Obj) = (Rsp [1]);
  (Wrd655.Obj) = ((Wrd647.pObj) [0]);
  (Wrd656.uLng) = (OBJECT_TYPE (Wrd655.Obj));
  if ((Wrd656.uLng) == 50)
    goto label_253;

DEFLABEL (label_252)
  ((Wrd647.pObj) [0]) = (Wrd648.Obj);

DEFLABEL (label_251)
  (Wrd660.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd661.Obj) = (Rsp [0]);
  (Wrd662.pObj) = (OBJECT_ADDRESS (Wrd661.Obj));
  (Wrd663.Obj) = ((Wrd662.pObj) [2]);
  (Wrd664.pObj) = (OBJECT_ADDRESS (Wrd663.Obj));
  ((Wrd664.pObj) [0]) = (Wrd660.Obj);
  Rvl = (current_block [OBJECT_9_0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_253)
  if ((Wrd655.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_252;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_9_41])), (Wrd647.pObj), (Wrd648.Obj));

DEFLABEL (label_215)
  goto label_251;

DEFLABEL (label_256)
  if ((Wrd639.Obj) == (Wrd632.Obj))
    goto label_255;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_9_40])), (Wrd636.pObj));

DEFLABEL (label_214)
  (Wrd635.Obj) = Rvl;
  goto label_254;

DEFLABEL (label_259)
  if ((Wrd611.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_258;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_9_39])), (Wrd603.pObj), (Wrd604.Obj));

DEFLABEL (label_213)
  goto label_257;

DEFLABEL (label_262)
  if ((Wrd595.Obj) == (Wrd588.Obj))
    goto label_261;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_9_38])), (Wrd592.pObj));

DEFLABEL (label_212)
  (Wrd591.Obj) = Rvl;
  goto label_260;

DEFLABEL (label_265)
  if ((Wrd567.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_264;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_9_37])), (Wrd559.pObj), (Wrd560.Obj));

DEFLABEL (label_211)
  goto label_263;

DEFLABEL (label_268)
  if ((Wrd551.Obj) == (Wrd544.Obj))
    goto label_267;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_9_36])), (Wrd548.pObj));

DEFLABEL (label_210)
  (Wrd547.Obj) = Rvl;
  goto label_266;

DEFLABEL (label_271)
  if ((Wrd523.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_270;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_9_35])), (Wrd515.pObj), (Wrd516.Obj));

DEFLABEL (label_209)
  goto label_269;

DEFLABEL (label_274)
  if ((Wrd507.Obj) == (Wrd500.Obj))
    goto label_273;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_9_34])), (Wrd504.pObj));

DEFLABEL (label_208)
  (Wrd503.Obj) = Rvl;
  goto label_272;

DEFLABEL (label_277)
  if ((Wrd479.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_276;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_9_33])), (Wrd471.pObj), (Wrd472.Obj));

DEFLABEL (label_207)
  goto label_275;

DEFLABEL (label_280)
  if ((Wrd463.Obj) == (Wrd456.Obj))
    goto label_279;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_9_32])), (Wrd460.pObj));

DEFLABEL (label_206)
  (Wrd459.Obj) = Rvl;
  goto label_278;

DEFLABEL (label_283)
  if ((Wrd435.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_282;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_9_31])), (Wrd427.pObj), (Wrd428.Obj));

DEFLABEL (label_205)
  goto label_281;

DEFLABEL (label_286)
  if ((Wrd419.Obj) == (Wrd412.Obj))
    goto label_285;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_9_30])), (Wrd416.pObj));

DEFLABEL (label_204)
  (Wrd415.Obj) = Rvl;
  goto label_284;

DEFLABEL (label_289)
  if ((Wrd391.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_288;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_9_29])), (Wrd383.pObj), (Wrd384.Obj));

DEFLABEL (label_203)
  goto label_287;

DEFLABEL (label_292)
  if ((Wrd375.Obj) == (Wrd368.Obj))
    goto label_291;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_9_28])), (Wrd372.pObj));

DEFLABEL (label_202)
  (Wrd371.Obj) = Rvl;
  goto label_290;

DEFLABEL (label_295)
  if ((Wrd347.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_294;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_9_27])), (Wrd339.pObj), (Wrd340.Obj));

DEFLABEL (label_201)
  goto label_293;

DEFLABEL (label_298)
  if ((Wrd331.Obj) == (Wrd324.Obj))
    goto label_297;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_9_26])), (Wrd328.pObj));

DEFLABEL (label_200)
  (Wrd327.Obj) = Rvl;
  goto label_296;

DEFLABEL (label_301)
  if ((Wrd303.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_300;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_9_25])), (Wrd295.pObj), (Wrd296.Obj));

DEFLABEL (label_199)
  goto label_299;

DEFLABEL (label_304)
  if ((Wrd287.Obj) == (Wrd280.Obj))
    goto label_303;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_9_24])), (Wrd284.pObj));

DEFLABEL (label_198)
  (Wrd283.Obj) = Rvl;
  goto label_302;

DEFLABEL (label_307)
  if ((Wrd259.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_306;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_9_23])), (Wrd251.pObj), (Wrd252.Obj));

DEFLABEL (label_197)
  goto label_305;

DEFLABEL (label_310)
  if ((Wrd243.Obj) == (Wrd236.Obj))
    goto label_309;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_9_22])), (Wrd240.pObj));

DEFLABEL (label_196)
  (Wrd239.Obj) = Rvl;
  goto label_308;

DEFLABEL (label_313)
  if ((Wrd215.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_312;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_9_21])), (Wrd207.pObj), (Wrd208.Obj));

DEFLABEL (label_195)
  goto label_311;

DEFLABEL (label_316)
  if ((Wrd199.Obj) == (Wrd192.Obj))
    goto label_315;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_9_20])), (Wrd196.pObj));

DEFLABEL (label_194)
  (Wrd195.Obj) = Rvl;
  goto label_314;

DEFLABEL (label_319)
  if ((Wrd171.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_318;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_9_19])), (Wrd163.pObj), (Wrd164.Obj));

DEFLABEL (label_193)
  goto label_317;

DEFLABEL (label_322)
  if ((Wrd155.Obj) == (Wrd148.Obj))
    goto label_321;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_9_18])), (Wrd152.pObj));

DEFLABEL (label_192)
  (Wrd151.Obj) = Rvl;
  goto label_320;

DEFLABEL (label_325)
  if ((Wrd127.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_324;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_9_17])), (Wrd119.pObj), (Wrd120.Obj));

DEFLABEL (label_191)
  goto label_323;

DEFLABEL (label_328)
  if ((Wrd111.Obj) == (Wrd104.Obj))
    goto label_327;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_9_16])), (Wrd108.pObj));

DEFLABEL (label_190)
  (Wrd107.Obj) = Rvl;
  goto label_326;

DEFLABEL (label_331)
  if ((Wrd83.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_330;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_9_15])), (Wrd75.pObj), (Wrd76.Obj));

DEFLABEL (label_189)
  goto label_329;

DEFLABEL (label_334)
  if ((Wrd67.Obj) == (Wrd60.Obj))
    goto label_333;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_9_14])), (Wrd64.pObj));

DEFLABEL (label_188)
  (Wrd63.Obj) = Rvl;
  goto label_332;

DEFLABEL (label_337)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_336;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_9_13])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_187)
  goto label_335;

DEFLABEL (label_340)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_339;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_9_12])), (Wrd20.pObj));

DEFLABEL (label_186)
  (Wrd19.Obj) = Rvl;
  goto label_338;

DEFLABEL (lambda_249)
  CLOSURE_HEADER (LABEL_9_7);

DEFLABEL (lambda_91)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (lambda_250)
  CLOSURE_HEADER (LABEL_9_9);

DEFLABEL (lambda_182)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [16]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_430;

DEFLABEL (label_429)
  Wrd19 = Wrd23;

DEFLABEL (label_428)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_9_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_427;

DEFLABEL (label_426)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_425)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [31]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  (Wrd51.Obj) = ((Wrd46.pObj) [15]);
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [0]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd60.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd52.pObj) [0]) = (Wrd60.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd64.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_1]));
  (Wrd67.Obj) = ((Wrd64.pObj) [0]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if ((Wrd68.uLng) == 50)
    goto label_424;

DEFLABEL (label_423)
  Wrd63 = Wrd67;

DEFLABEL (label_422)
  (* (--Rsp)) = (Wrd63.Obj);
  (Wrd75.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_9_1]));
  (Wrd76.Obj) = (Rsp [1]);
  (Wrd83.Obj) = ((Wrd75.pObj) [0]);
  (Wrd84.uLng) = (OBJECT_TYPE (Wrd83.Obj));
  if ((Wrd84.uLng) == 50)
    goto label_421;

DEFLABEL (label_420)
  ((Wrd75.pObj) [0]) = (Wrd76.Obj);

DEFLABEL (label_419)
  (Wrd88.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd89.Obj) = (Rsp [0]);
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd89.Obj));
  (Wrd91.Obj) = ((Wrd90.pObj) [30]);
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  ((Wrd92.pObj) [0]) = (Wrd88.Obj);
  (Wrd95.Obj) = ((Wrd90.pObj) [14]);
  (Wrd96.pObj) = (OBJECT_ADDRESS (Wrd95.Obj));
  (Wrd97.Obj) = ((Wrd96.pObj) [0]);
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd104.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd96.pObj) [0]) = (Wrd104.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd108.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_2]));
  (Wrd111.Obj) = ((Wrd108.pObj) [0]);
  (Wrd112.uLng) = (OBJECT_TYPE (Wrd111.Obj));
  if ((Wrd112.uLng) == 50)
    goto label_418;

DEFLABEL (label_417)
  Wrd107 = Wrd111;

DEFLABEL (label_416)
  (* (--Rsp)) = (Wrd107.Obj);
  (Wrd119.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_9_2]));
  (Wrd120.Obj) = (Rsp [1]);
  (Wrd127.Obj) = ((Wrd119.pObj) [0]);
  (Wrd128.uLng) = (OBJECT_TYPE (Wrd127.Obj));
  if ((Wrd128.uLng) == 50)
    goto label_415;

DEFLABEL (label_414)
  ((Wrd119.pObj) [0]) = (Wrd120.Obj);

DEFLABEL (label_413)
  (Wrd132.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd133.Obj) = (Rsp [0]);
  (Wrd134.pObj) = (OBJECT_ADDRESS (Wrd133.Obj));
  (Wrd135.Obj) = ((Wrd134.pObj) [29]);
  (Wrd136.pObj) = (OBJECT_ADDRESS (Wrd135.Obj));
  ((Wrd136.pObj) [0]) = (Wrd132.Obj);
  (Wrd139.Obj) = ((Wrd134.pObj) [13]);
  (Wrd140.pObj) = (OBJECT_ADDRESS (Wrd139.Obj));
  (Wrd141.Obj) = ((Wrd140.pObj) [0]);
  (* (--Rsp)) = (Wrd141.Obj);
  (Wrd148.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd140.pObj) [0]) = (Wrd148.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd141.Obj);
  (Wrd152.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_3]));
  (Wrd155.Obj) = ((Wrd152.pObj) [0]);
  (Wrd156.uLng) = (OBJECT_TYPE (Wrd155.Obj));
  if ((Wrd156.uLng) == 50)
    goto label_412;

DEFLABEL (label_411)
  Wrd151 = Wrd155;

DEFLABEL (label_410)
  (* (--Rsp)) = (Wrd151.Obj);
  (Wrd163.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_9_3]));
  (Wrd164.Obj) = (Rsp [1]);
  (Wrd171.Obj) = ((Wrd163.pObj) [0]);
  (Wrd172.uLng) = (OBJECT_TYPE (Wrd171.Obj));
  if ((Wrd172.uLng) == 50)
    goto label_409;

DEFLABEL (label_408)
  ((Wrd163.pObj) [0]) = (Wrd164.Obj);

DEFLABEL (label_407)
  (Wrd176.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd177.Obj) = (Rsp [0]);
  (Wrd178.pObj) = (OBJECT_ADDRESS (Wrd177.Obj));
  (Wrd179.Obj) = ((Wrd178.pObj) [28]);
  (Wrd180.pObj) = (OBJECT_ADDRESS (Wrd179.Obj));
  ((Wrd180.pObj) [0]) = (Wrd176.Obj);
  (Wrd183.Obj) = ((Wrd178.pObj) [12]);
  (Wrd184.pObj) = (OBJECT_ADDRESS (Wrd183.Obj));
  (Wrd185.Obj) = ((Wrd184.pObj) [0]);
  (* (--Rsp)) = (Wrd185.Obj);
  (Wrd192.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd184.pObj) [0]) = (Wrd192.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd185.Obj);
  (Wrd196.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_4]));
  (Wrd199.Obj) = ((Wrd196.pObj) [0]);
  (Wrd200.uLng) = (OBJECT_TYPE (Wrd199.Obj));
  if ((Wrd200.uLng) == 50)
    goto label_406;

DEFLABEL (label_405)
  Wrd195 = Wrd199;

DEFLABEL (label_404)
  (* (--Rsp)) = (Wrd195.Obj);
  (Wrd207.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_9_4]));
  (Wrd208.Obj) = (Rsp [1]);
  (Wrd215.Obj) = ((Wrd207.pObj) [0]);
  (Wrd216.uLng) = (OBJECT_TYPE (Wrd215.Obj));
  if ((Wrd216.uLng) == 50)
    goto label_403;

DEFLABEL (label_402)
  ((Wrd207.pObj) [0]) = (Wrd208.Obj);

DEFLABEL (label_401)
  (Wrd220.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd221.Obj) = (Rsp [0]);
  (Wrd222.pObj) = (OBJECT_ADDRESS (Wrd221.Obj));
  (Wrd223.Obj) = ((Wrd222.pObj) [27]);
  (Wrd224.pObj) = (OBJECT_ADDRESS (Wrd223.Obj));
  ((Wrd224.pObj) [0]) = (Wrd220.Obj);
  (Wrd227.Obj) = ((Wrd222.pObj) [11]);
  (Wrd228.pObj) = (OBJECT_ADDRESS (Wrd227.Obj));
  (Wrd229.Obj) = ((Wrd228.pObj) [0]);
  (* (--Rsp)) = (Wrd229.Obj);
  (Wrd236.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd228.pObj) [0]) = (Wrd236.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd229.Obj);
  (Wrd240.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_5]));
  (Wrd243.Obj) = ((Wrd240.pObj) [0]);
  (Wrd244.uLng) = (OBJECT_TYPE (Wrd243.Obj));
  if ((Wrd244.uLng) == 50)
    goto label_400;

DEFLABEL (label_399)
  Wrd239 = Wrd243;

DEFLABEL (label_398)
  (* (--Rsp)) = (Wrd239.Obj);
  (Wrd251.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_9_5]));
  (Wrd252.Obj) = (Rsp [1]);
  (Wrd259.Obj) = ((Wrd251.pObj) [0]);
  (Wrd260.uLng) = (OBJECT_TYPE (Wrd259.Obj));
  if ((Wrd260.uLng) == 50)
    goto label_397;

DEFLABEL (label_396)
  ((Wrd251.pObj) [0]) = (Wrd252.Obj);

DEFLABEL (label_395)
  (Wrd264.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd265.Obj) = (Rsp [0]);
  (Wrd266.pObj) = (OBJECT_ADDRESS (Wrd265.Obj));
  (Wrd267.Obj) = ((Wrd266.pObj) [26]);
  (Wrd268.pObj) = (OBJECT_ADDRESS (Wrd267.Obj));
  ((Wrd268.pObj) [0]) = (Wrd264.Obj);
  (Wrd271.Obj) = ((Wrd266.pObj) [10]);
  (Wrd272.pObj) = (OBJECT_ADDRESS (Wrd271.Obj));
  (Wrd273.Obj) = ((Wrd272.pObj) [0]);
  (* (--Rsp)) = (Wrd273.Obj);
  (Wrd280.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd272.pObj) [0]) = (Wrd280.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd273.Obj);
  (Wrd284.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_6]));
  (Wrd287.Obj) = ((Wrd284.pObj) [0]);
  (Wrd288.uLng) = (OBJECT_TYPE (Wrd287.Obj));
  if ((Wrd288.uLng) == 50)
    goto label_394;

DEFLABEL (label_393)
  Wrd283 = Wrd287;

DEFLABEL (label_392)
  (* (--Rsp)) = (Wrd283.Obj);
  (Wrd295.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_9_6]));
  (Wrd296.Obj) = (Rsp [1]);
  (Wrd303.Obj) = ((Wrd295.pObj) [0]);
  (Wrd304.uLng) = (OBJECT_TYPE (Wrd303.Obj));
  if ((Wrd304.uLng) == 50)
    goto label_391;

DEFLABEL (label_390)
  ((Wrd295.pObj) [0]) = (Wrd296.Obj);

DEFLABEL (label_389)
  (Wrd308.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd309.Obj) = (Rsp [0]);
  (Wrd310.pObj) = (OBJECT_ADDRESS (Wrd309.Obj));
  (Wrd311.Obj) = ((Wrd310.pObj) [25]);
  (Wrd312.pObj) = (OBJECT_ADDRESS (Wrd311.Obj));
  ((Wrd312.pObj) [0]) = (Wrd308.Obj);
  (Wrd315.Obj) = ((Wrd310.pObj) [9]);
  (Wrd316.pObj) = (OBJECT_ADDRESS (Wrd315.Obj));
  (Wrd317.Obj) = ((Wrd316.pObj) [0]);
  (* (--Rsp)) = (Wrd317.Obj);
  (Wrd324.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd316.pObj) [0]) = (Wrd324.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd317.Obj);
  (Wrd328.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_7]));
  (Wrd331.Obj) = ((Wrd328.pObj) [0]);
  (Wrd332.uLng) = (OBJECT_TYPE (Wrd331.Obj));
  if ((Wrd332.uLng) == 50)
    goto label_388;

DEFLABEL (label_387)
  Wrd327 = Wrd331;

DEFLABEL (label_386)
  (* (--Rsp)) = (Wrd327.Obj);
  (Wrd339.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_9_7]));
  (Wrd340.Obj) = (Rsp [1]);
  (Wrd347.Obj) = ((Wrd339.pObj) [0]);
  (Wrd348.uLng) = (OBJECT_TYPE (Wrd347.Obj));
  if ((Wrd348.uLng) == 50)
    goto label_385;

DEFLABEL (label_384)
  ((Wrd339.pObj) [0]) = (Wrd340.Obj);

DEFLABEL (label_383)
  (Wrd352.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd353.Obj) = (Rsp [0]);
  (Wrd354.pObj) = (OBJECT_ADDRESS (Wrd353.Obj));
  (Wrd355.Obj) = ((Wrd354.pObj) [24]);
  (Wrd356.pObj) = (OBJECT_ADDRESS (Wrd355.Obj));
  ((Wrd356.pObj) [0]) = (Wrd352.Obj);
  (Wrd359.Obj) = ((Wrd354.pObj) [8]);
  (Wrd360.pObj) = (OBJECT_ADDRESS (Wrd359.Obj));
  (Wrd361.Obj) = ((Wrd360.pObj) [0]);
  (* (--Rsp)) = (Wrd361.Obj);
  (Wrd368.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd360.pObj) [0]) = (Wrd368.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd361.Obj);
  (Wrd372.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_8]));
  (Wrd375.Obj) = ((Wrd372.pObj) [0]);
  (Wrd376.uLng) = (OBJECT_TYPE (Wrd375.Obj));
  if ((Wrd376.uLng) == 50)
    goto label_382;

DEFLABEL (label_381)
  Wrd371 = Wrd375;

DEFLABEL (label_380)
  (* (--Rsp)) = (Wrd371.Obj);
  (Wrd383.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_9_8]));
  (Wrd384.Obj) = (Rsp [1]);
  (Wrd391.Obj) = ((Wrd383.pObj) [0]);
  (Wrd392.uLng) = (OBJECT_TYPE (Wrd391.Obj));
  if ((Wrd392.uLng) == 50)
    goto label_379;

DEFLABEL (label_378)
  ((Wrd383.pObj) [0]) = (Wrd384.Obj);

DEFLABEL (label_377)
  (Wrd396.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd397.Obj) = (Rsp [0]);
  (Wrd398.pObj) = (OBJECT_ADDRESS (Wrd397.Obj));
  (Wrd399.Obj) = ((Wrd398.pObj) [23]);
  (Wrd400.pObj) = (OBJECT_ADDRESS (Wrd399.Obj));
  ((Wrd400.pObj) [0]) = (Wrd396.Obj);
  (Wrd403.Obj) = ((Wrd398.pObj) [7]);
  (Wrd404.pObj) = (OBJECT_ADDRESS (Wrd403.Obj));
  (Wrd405.Obj) = ((Wrd404.pObj) [0]);
  (* (--Rsp)) = (Wrd405.Obj);
  (Wrd412.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd404.pObj) [0]) = (Wrd412.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd405.Obj);
  (Wrd416.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_9]));
  (Wrd419.Obj) = ((Wrd416.pObj) [0]);
  (Wrd420.uLng) = (OBJECT_TYPE (Wrd419.Obj));
  if ((Wrd420.uLng) == 50)
    goto label_376;

DEFLABEL (label_375)
  Wrd415 = Wrd419;

DEFLABEL (label_374)
  (* (--Rsp)) = (Wrd415.Obj);
  (Wrd427.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_9_9]));
  (Wrd428.Obj) = (Rsp [1]);
  (Wrd435.Obj) = ((Wrd427.pObj) [0]);
  (Wrd436.uLng) = (OBJECT_TYPE (Wrd435.Obj));
  if ((Wrd436.uLng) == 50)
    goto label_373;

DEFLABEL (label_372)
  ((Wrd427.pObj) [0]) = (Wrd428.Obj);

DEFLABEL (label_371)
  (Wrd440.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd441.Obj) = (Rsp [0]);
  (Wrd442.pObj) = (OBJECT_ADDRESS (Wrd441.Obj));
  (Wrd443.Obj) = ((Wrd442.pObj) [22]);
  (Wrd444.pObj) = (OBJECT_ADDRESS (Wrd443.Obj));
  ((Wrd444.pObj) [0]) = (Wrd440.Obj);
  (Wrd447.Obj) = ((Wrd442.pObj) [6]);
  (Wrd448.pObj) = (OBJECT_ADDRESS (Wrd447.Obj));
  (Wrd449.Obj) = ((Wrd448.pObj) [0]);
  (* (--Rsp)) = (Wrd449.Obj);
  (Wrd456.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd448.pObj) [0]) = (Wrd456.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd449.Obj);
  (Wrd460.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_10]));
  (Wrd463.Obj) = ((Wrd460.pObj) [0]);
  (Wrd464.uLng) = (OBJECT_TYPE (Wrd463.Obj));
  if ((Wrd464.uLng) == 50)
    goto label_370;

DEFLABEL (label_369)
  Wrd459 = Wrd463;

DEFLABEL (label_368)
  (* (--Rsp)) = (Wrd459.Obj);
  (Wrd471.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_9_10]));
  (Wrd472.Obj) = (Rsp [1]);
  (Wrd479.Obj) = ((Wrd471.pObj) [0]);
  (Wrd480.uLng) = (OBJECT_TYPE (Wrd479.Obj));
  if ((Wrd480.uLng) == 50)
    goto label_367;

DEFLABEL (label_366)
  ((Wrd471.pObj) [0]) = (Wrd472.Obj);

DEFLABEL (label_365)
  (Wrd484.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd485.Obj) = (Rsp [0]);
  (Wrd486.pObj) = (OBJECT_ADDRESS (Wrd485.Obj));
  (Wrd487.Obj) = ((Wrd486.pObj) [21]);
  (Wrd488.pObj) = (OBJECT_ADDRESS (Wrd487.Obj));
  ((Wrd488.pObj) [0]) = (Wrd484.Obj);
  (Wrd491.Obj) = ((Wrd486.pObj) [5]);
  (Wrd492.pObj) = (OBJECT_ADDRESS (Wrd491.Obj));
  (Wrd493.Obj) = ((Wrd492.pObj) [0]);
  (* (--Rsp)) = (Wrd493.Obj);
  (Wrd500.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd492.pObj) [0]) = (Wrd500.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd493.Obj);
  (Wrd504.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_11]));
  (Wrd507.Obj) = ((Wrd504.pObj) [0]);
  (Wrd508.uLng) = (OBJECT_TYPE (Wrd507.Obj));
  if ((Wrd508.uLng) == 50)
    goto label_364;

DEFLABEL (label_363)
  Wrd503 = Wrd507;

DEFLABEL (label_362)
  (* (--Rsp)) = (Wrd503.Obj);
  (Wrd515.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_9_11]));
  (Wrd516.Obj) = (Rsp [1]);
  (Wrd523.Obj) = ((Wrd515.pObj) [0]);
  (Wrd524.uLng) = (OBJECT_TYPE (Wrd523.Obj));
  if ((Wrd524.uLng) == 50)
    goto label_361;

DEFLABEL (label_360)
  ((Wrd515.pObj) [0]) = (Wrd516.Obj);

DEFLABEL (label_359)
  (Wrd528.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd529.Obj) = (Rsp [0]);
  (Wrd530.pObj) = (OBJECT_ADDRESS (Wrd529.Obj));
  (Wrd531.Obj) = ((Wrd530.pObj) [20]);
  (Wrd532.pObj) = (OBJECT_ADDRESS (Wrd531.Obj));
  ((Wrd532.pObj) [0]) = (Wrd528.Obj);
  (Wrd535.Obj) = ((Wrd530.pObj) [4]);
  (Wrd536.pObj) = (OBJECT_ADDRESS (Wrd535.Obj));
  (Wrd537.Obj) = ((Wrd536.pObj) [0]);
  (* (--Rsp)) = (Wrd537.Obj);
  (Wrd544.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd536.pObj) [0]) = (Wrd544.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd537.Obj);
  (Wrd548.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_12]));
  (Wrd551.Obj) = ((Wrd548.pObj) [0]);
  (Wrd552.uLng) = (OBJECT_TYPE (Wrd551.Obj));
  if ((Wrd552.uLng) == 50)
    goto label_358;

DEFLABEL (label_357)
  Wrd547 = Wrd551;

DEFLABEL (label_356)
  (* (--Rsp)) = (Wrd547.Obj);
  (Wrd559.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_9_12]));
  (Wrd560.Obj) = (Rsp [1]);
  (Wrd567.Obj) = ((Wrd559.pObj) [0]);
  (Wrd568.uLng) = (OBJECT_TYPE (Wrd567.Obj));
  if ((Wrd568.uLng) == 50)
    goto label_355;

DEFLABEL (label_354)
  ((Wrd559.pObj) [0]) = (Wrd560.Obj);

DEFLABEL (label_353)
  (Wrd572.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd573.Obj) = (Rsp [0]);
  (Wrd574.pObj) = (OBJECT_ADDRESS (Wrd573.Obj));
  (Wrd575.Obj) = ((Wrd574.pObj) [19]);
  (Wrd576.pObj) = (OBJECT_ADDRESS (Wrd575.Obj));
  ((Wrd576.pObj) [0]) = (Wrd572.Obj);
  (Wrd579.Obj) = ((Wrd574.pObj) [3]);
  (Wrd580.pObj) = (OBJECT_ADDRESS (Wrd579.Obj));
  (Wrd581.Obj) = ((Wrd580.pObj) [0]);
  (* (--Rsp)) = (Wrd581.Obj);
  (Wrd588.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd580.pObj) [0]) = (Wrd588.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd581.Obj);
  (Wrd592.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_13]));
  (Wrd595.Obj) = ((Wrd592.pObj) [0]);
  (Wrd596.uLng) = (OBJECT_TYPE (Wrd595.Obj));
  if ((Wrd596.uLng) == 50)
    goto label_352;

DEFLABEL (label_351)
  Wrd591 = Wrd595;

DEFLABEL (label_350)
  (* (--Rsp)) = (Wrd591.Obj);
  (Wrd603.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_9_13]));
  (Wrd604.Obj) = (Rsp [1]);
  (Wrd611.Obj) = ((Wrd603.pObj) [0]);
  (Wrd612.uLng) = (OBJECT_TYPE (Wrd611.Obj));
  if ((Wrd612.uLng) == 50)
    goto label_349;

DEFLABEL (label_348)
  ((Wrd603.pObj) [0]) = (Wrd604.Obj);

DEFLABEL (label_347)
  (Wrd616.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd617.Obj) = (Rsp [0]);
  (Wrd618.pObj) = (OBJECT_ADDRESS (Wrd617.Obj));
  (Wrd619.Obj) = ((Wrd618.pObj) [18]);
  (Wrd620.pObj) = (OBJECT_ADDRESS (Wrd619.Obj));
  ((Wrd620.pObj) [0]) = (Wrd616.Obj);
  (Wrd623.Obj) = ((Wrd618.pObj) [2]);
  (Wrd624.pObj) = (OBJECT_ADDRESS (Wrd623.Obj));
  (Wrd625.Obj) = ((Wrd624.pObj) [0]);
  (* (--Rsp)) = (Wrd625.Obj);
  (Wrd632.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd624.pObj) [0]) = (Wrd632.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd625.Obj);
  (Wrd636.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_14]));
  (Wrd639.Obj) = ((Wrd636.pObj) [0]);
  (Wrd640.uLng) = (OBJECT_TYPE (Wrd639.Obj));
  if ((Wrd640.uLng) == 50)
    goto label_346;

DEFLABEL (label_345)
  Wrd635 = Wrd639;

DEFLABEL (label_344)
  (* (--Rsp)) = (Wrd635.Obj);
  (Wrd647.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_9_14]));
  (Wrd648.Obj) = (Rsp [1]);
  (Wrd655.Obj) = ((Wrd647.pObj) [0]);
  (Wrd656.uLng) = (OBJECT_TYPE (Wrd655.Obj));
  if ((Wrd656.uLng) == 50)
    goto label_343;

DEFLABEL (label_342)
  ((Wrd647.pObj) [0]) = (Wrd648.Obj);

DEFLABEL (label_341)
  (Wrd660.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd661.Obj) = (Rsp [0]);
  (Wrd662.pObj) = (OBJECT_ADDRESS (Wrd661.Obj));
  (Wrd663.Obj) = ((Wrd662.pObj) [17]);
  (Wrd664.pObj) = (OBJECT_ADDRESS (Wrd663.Obj));
  ((Wrd664.pObj) [0]) = (Wrd660.Obj);
  Rvl = (current_block [OBJECT_9_0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_343)
  if ((Wrd655.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_342;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_9_71])), (Wrd647.pObj), (Wrd648.Obj));

DEFLABEL (label_245)
  goto label_341;

DEFLABEL (label_346)
  if ((Wrd639.Obj) == (Wrd632.Obj))
    goto label_345;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_9_70])), (Wrd636.pObj));

DEFLABEL (label_244)
  (Wrd635.Obj) = Rvl;
  goto label_344;

DEFLABEL (label_349)
  if ((Wrd611.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_348;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_9_69])), (Wrd603.pObj), (Wrd604.Obj));

DEFLABEL (label_243)
  goto label_347;

DEFLABEL (label_352)
  if ((Wrd595.Obj) == (Wrd588.Obj))
    goto label_351;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_9_68])), (Wrd592.pObj));

DEFLABEL (label_242)
  (Wrd591.Obj) = Rvl;
  goto label_350;

DEFLABEL (label_355)
  if ((Wrd567.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_354;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_9_67])), (Wrd559.pObj), (Wrd560.Obj));

DEFLABEL (label_241)
  goto label_353;

DEFLABEL (label_358)
  if ((Wrd551.Obj) == (Wrd544.Obj))
    goto label_357;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_9_66])), (Wrd548.pObj));

DEFLABEL (label_240)
  (Wrd547.Obj) = Rvl;
  goto label_356;

DEFLABEL (label_361)
  if ((Wrd523.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_360;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_9_65])), (Wrd515.pObj), (Wrd516.Obj));

DEFLABEL (label_239)
  goto label_359;

DEFLABEL (label_364)
  if ((Wrd507.Obj) == (Wrd500.Obj))
    goto label_363;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_9_64])), (Wrd504.pObj));

DEFLABEL (label_238)
  (Wrd503.Obj) = Rvl;
  goto label_362;

DEFLABEL (label_367)
  if ((Wrd479.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_366;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_9_63])), (Wrd471.pObj), (Wrd472.Obj));

DEFLABEL (label_237)
  goto label_365;

DEFLABEL (label_370)
  if ((Wrd463.Obj) == (Wrd456.Obj))
    goto label_369;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_9_62])), (Wrd460.pObj));

DEFLABEL (label_236)
  (Wrd459.Obj) = Rvl;
  goto label_368;

DEFLABEL (label_373)
  if ((Wrd435.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_372;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_9_61])), (Wrd427.pObj), (Wrd428.Obj));

DEFLABEL (label_235)
  goto label_371;

DEFLABEL (label_376)
  if ((Wrd419.Obj) == (Wrd412.Obj))
    goto label_375;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_9_60])), (Wrd416.pObj));

DEFLABEL (label_234)
  (Wrd415.Obj) = Rvl;
  goto label_374;

DEFLABEL (label_379)
  if ((Wrd391.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_378;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_9_59])), (Wrd383.pObj), (Wrd384.Obj));

DEFLABEL (label_233)
  goto label_377;

DEFLABEL (label_382)
  if ((Wrd375.Obj) == (Wrd368.Obj))
    goto label_381;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_9_58])), (Wrd372.pObj));

DEFLABEL (label_232)
  (Wrd371.Obj) = Rvl;
  goto label_380;

DEFLABEL (label_385)
  if ((Wrd347.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_384;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_9_57])), (Wrd339.pObj), (Wrd340.Obj));

DEFLABEL (label_231)
  goto label_383;

DEFLABEL (label_388)
  if ((Wrd331.Obj) == (Wrd324.Obj))
    goto label_387;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_9_56])), (Wrd328.pObj));

DEFLABEL (label_230)
  (Wrd327.Obj) = Rvl;
  goto label_386;

DEFLABEL (label_391)
  if ((Wrd303.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_390;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_9_55])), (Wrd295.pObj), (Wrd296.Obj));

DEFLABEL (label_229)
  goto label_389;

DEFLABEL (label_394)
  if ((Wrd287.Obj) == (Wrd280.Obj))
    goto label_393;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_9_54])), (Wrd284.pObj));

DEFLABEL (label_228)
  (Wrd283.Obj) = Rvl;
  goto label_392;

DEFLABEL (label_397)
  if ((Wrd259.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_396;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_9_53])), (Wrd251.pObj), (Wrd252.Obj));

DEFLABEL (label_227)
  goto label_395;

DEFLABEL (label_400)
  if ((Wrd243.Obj) == (Wrd236.Obj))
    goto label_399;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_9_52])), (Wrd240.pObj));

DEFLABEL (label_226)
  (Wrd239.Obj) = Rvl;
  goto label_398;

DEFLABEL (label_403)
  if ((Wrd215.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_402;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_9_51])), (Wrd207.pObj), (Wrd208.Obj));

DEFLABEL (label_225)
  goto label_401;

DEFLABEL (label_406)
  if ((Wrd199.Obj) == (Wrd192.Obj))
    goto label_405;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_9_50])), (Wrd196.pObj));

DEFLABEL (label_224)
  (Wrd195.Obj) = Rvl;
  goto label_404;

DEFLABEL (label_409)
  if ((Wrd171.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_408;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_9_49])), (Wrd163.pObj), (Wrd164.Obj));

DEFLABEL (label_223)
  goto label_407;

DEFLABEL (label_412)
  if ((Wrd155.Obj) == (Wrd148.Obj))
    goto label_411;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_9_48])), (Wrd152.pObj));

DEFLABEL (label_222)
  (Wrd151.Obj) = Rvl;
  goto label_410;

DEFLABEL (label_415)
  if ((Wrd127.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_414;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_9_47])), (Wrd119.pObj), (Wrd120.Obj));

DEFLABEL (label_221)
  goto label_413;

DEFLABEL (label_418)
  if ((Wrd111.Obj) == (Wrd104.Obj))
    goto label_417;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_9_46])), (Wrd108.pObj));

DEFLABEL (label_220)
  (Wrd107.Obj) = Rvl;
  goto label_416;

DEFLABEL (label_421)
  if ((Wrd83.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_420;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_9_45])), (Wrd75.pObj), (Wrd76.Obj));

DEFLABEL (label_219)
  goto label_419;

DEFLABEL (label_424)
  if ((Wrd67.Obj) == (Wrd60.Obj))
    goto label_423;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_9_44])), (Wrd64.pObj));

DEFLABEL (label_218)
  (Wrd63.Obj) = Rvl;
  goto label_422;

DEFLABEL (label_427)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_426;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_9_43])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_217)
  goto label_425;

DEFLABEL (label_430)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_429;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_9_42])), (Wrd20.pObj));

DEFLABEL (label_216)
  (Wrd19.Obj) = Rvl;
  goto label_428;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_10_4 3
#define LABEL_10_5 5
#define LABEL_10_6 7
#define LABEL_10_7 9
#define LABEL_10_8 11
#define LABEL_10_9 13
#define LABEL_10_10 15
#define LABEL_10_11 17
#define LABEL_10_12 19
#define LABEL_10_13 21
#define LABEL_10_14 23
#define LABEL_10_15 25
#define LABEL_10_16 27
#define LABEL_10_17 29
#define LABEL_10_18 31
#define LABEL_10_19 33
#define LABEL_10_20 35
#define ENVIRONMENT_LABEL_10_3 56
#define DEBUGGING_LABEL_10_2 55
#define OBJECT_10_1 54
#define OBJECT_10_0 53
#define FREE_ASSIGNMENT_10_15 37
#define FREE_ASSIGNMENT_10_14 38
#define FREE_ASSIGNMENT_10_13 39
#define FREE_ASSIGNMENT_10_12 40
#define FREE_ASSIGNMENT_10_11 41
#define FREE_ASSIGNMENT_10_10 42
#define FREE_ASSIGNMENT_10_9 43
#define FREE_ASSIGNMENT_10_8 44
#define FREE_ASSIGNMENT_10_7 45
#define FREE_ASSIGNMENT_10_6 46
#define FREE_ASSIGNMENT_10_5 47
#define FREE_ASSIGNMENT_10_4 48
#define FREE_ASSIGNMENT_10_3 49
#define FREE_ASSIGNMENT_10_2 50
#define FREE_ASSIGNMENT_10_1 51
#define FREE_ASSIGNMENT_10_0 52
#define FREE_REFERENCES_LABEL_10_0 36
#define NUMBER_OF_LINKER_SECTIONS_10_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
asstop_so_code_10 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd224;
  machine_word Wrd223;
  machine_word Wrd214;
  machine_word Wrd213;
  machine_word Wrd210;
  machine_word Wrd209;
  machine_word Wrd200;
  machine_word Wrd199;
  machine_word Wrd196;
  machine_word Wrd195;
  machine_word Wrd186;
  machine_word Wrd185;
  machine_word Wrd182;
  machine_word Wrd181;
  machine_word Wrd172;
  machine_word Wrd171;
  machine_word Wrd168;
  machine_word Wrd167;
  machine_word Wrd158;
  machine_word Wrd157;
  machine_word Wrd154;
  machine_word Wrd153;
  machine_word Wrd144;
  machine_word Wrd143;
  machine_word Wrd140;
  machine_word Wrd139;
  machine_word Wrd130;
  machine_word Wrd129;
  machine_word Wrd126;
  machine_word Wrd125;
  machine_word Wrd116;
  machine_word Wrd115;
  machine_word Wrd112;
  machine_word Wrd111;
  machine_word Wrd102;
  machine_word Wrd101;
  machine_word Wrd98;
  machine_word Wrd97;
  machine_word Wrd88;
  machine_word Wrd87;
  machine_word Wrd84;
  machine_word Wrd83;
  machine_word Wrd74;
  machine_word Wrd73;
  machine_word Wrd70;
  machine_word Wrd69;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_10_4);
      goto assembler_linker_resetB_0;

    case 1:
      current_block = (Rpc - LABEL_10_5);
      goto label_2;

    case 2:
      current_block = (Rpc - LABEL_10_6);
      goto label_3;

    case 3:
      current_block = (Rpc - LABEL_10_7);
      goto label_4;

    case 4:
      current_block = (Rpc - LABEL_10_8);
      goto label_5;

    case 5:
      current_block = (Rpc - LABEL_10_9);
      goto label_6;

    case 6:
      current_block = (Rpc - LABEL_10_10);
      goto label_7;

    case 7:
      current_block = (Rpc - LABEL_10_11);
      goto label_8;

    case 8:
      current_block = (Rpc - LABEL_10_12);
      goto label_9;

    case 9:
      current_block = (Rpc - LABEL_10_13);
      goto label_10;

    case 10:
      current_block = (Rpc - LABEL_10_14);
      goto label_11;

    case 11:
      current_block = (Rpc - LABEL_10_15);
      goto label_12;

    case 12:
      current_block = (Rpc - LABEL_10_16);
      goto label_13;

    case 13:
      current_block = (Rpc - LABEL_10_17);
      goto label_14;

    case 14:
      current_block = (Rpc - LABEL_10_18);
      goto label_15;

    case 15:
      current_block = (Rpc - LABEL_10_19);
      goto label_16;

    case 16:
      current_block = (Rpc - LABEL_10_20);
      goto label_17;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (assembler_linker_resetB_19)
DEFLABEL (assembler_linker_resetB_0)
  INTERRUPT_CHECK (26, LABEL_10_4);
  (Wrd5.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_10_0]));
  (Wrd6.Obj) = (current_block [OBJECT_10_0]);
  (Wrd13.Obj) = ((Wrd5.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_67;

DEFLABEL (label_66)
  ((Wrd5.pObj) [0]) = (Wrd6.Obj);

DEFLABEL (label_65)
  (Wrd17.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_10_1]));
  (Wrd18.Obj) = (MAKE_OBJECT (50, 0));
  (Wrd27.Obj) = ((Wrd17.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_64;

DEFLABEL (label_63)
  ((Wrd17.pObj) [0]) = (Wrd18.Obj);

DEFLABEL (label_62)
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_10_2]));
  (Wrd32.Obj) = (MAKE_OBJECT (50, 0));
  (Wrd41.Obj) = ((Wrd31.pObj) [0]);
  (Wrd42.uLng) = (OBJECT_TYPE (Wrd41.Obj));
  if ((Wrd42.uLng) == 50)
    goto label_61;

DEFLABEL (label_60)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_59)
  (Wrd45.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_10_3]));
  (Wrd46.Obj) = (MAKE_OBJECT (50, 0));
  (Wrd55.Obj) = ((Wrd45.pObj) [0]);
  (Wrd56.uLng) = (OBJECT_TYPE (Wrd55.Obj));
  if ((Wrd56.uLng) == 50)
    goto label_58;

DEFLABEL (label_57)
  ((Wrd45.pObj) [0]) = (Wrd46.Obj);

DEFLABEL (label_56)
  (Wrd59.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_10_4]));
  (Wrd60.Obj) = (MAKE_OBJECT (50, 0));
  (Wrd69.Obj) = ((Wrd59.pObj) [0]);
  (Wrd70.uLng) = (OBJECT_TYPE (Wrd69.Obj));
  if ((Wrd70.uLng) == 50)
    goto label_55;

DEFLABEL (label_54)
  ((Wrd59.pObj) [0]) = (Wrd60.Obj);

DEFLABEL (label_53)
  (Wrd73.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_10_5]));
  (Wrd74.Obj) = (MAKE_OBJECT (50, 0));
  (Wrd83.Obj) = ((Wrd73.pObj) [0]);
  (Wrd84.uLng) = (OBJECT_TYPE (Wrd83.Obj));
  if ((Wrd84.uLng) == 50)
    goto label_52;

DEFLABEL (label_51)
  ((Wrd73.pObj) [0]) = (Wrd74.Obj);

DEFLABEL (label_50)
  (Wrd87.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_10_6]));
  (Wrd88.Obj) = (MAKE_OBJECT (50, 0));
  (Wrd97.Obj) = ((Wrd87.pObj) [0]);
  (Wrd98.uLng) = (OBJECT_TYPE (Wrd97.Obj));
  if ((Wrd98.uLng) == 50)
    goto label_49;

DEFLABEL (label_48)
  ((Wrd87.pObj) [0]) = (Wrd88.Obj);

DEFLABEL (label_47)
  (Wrd101.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_10_7]));
  (Wrd102.Obj) = (MAKE_OBJECT (50, 0));
  (Wrd111.Obj) = ((Wrd101.pObj) [0]);
  (Wrd112.uLng) = (OBJECT_TYPE (Wrd111.Obj));
  if ((Wrd112.uLng) == 50)
    goto label_46;

DEFLABEL (label_45)
  ((Wrd101.pObj) [0]) = (Wrd102.Obj);

DEFLABEL (label_44)
  (Wrd115.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_10_8]));
  (Wrd116.Obj) = (MAKE_OBJECT (50, 0));
  (Wrd125.Obj) = ((Wrd115.pObj) [0]);
  (Wrd126.uLng) = (OBJECT_TYPE (Wrd125.Obj));
  if ((Wrd126.uLng) == 50)
    goto label_43;

DEFLABEL (label_42)
  ((Wrd115.pObj) [0]) = (Wrd116.Obj);

DEFLABEL (label_41)
  (Wrd129.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_10_9]));
  (Wrd130.Obj) = (MAKE_OBJECT (50, 0));
  (Wrd139.Obj) = ((Wrd129.pObj) [0]);
  (Wrd140.uLng) = (OBJECT_TYPE (Wrd139.Obj));
  if ((Wrd140.uLng) == 50)
    goto label_40;

DEFLABEL (label_39)
  ((Wrd129.pObj) [0]) = (Wrd130.Obj);

DEFLABEL (label_38)
  (Wrd143.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_10_10]));
  (Wrd144.Obj) = (MAKE_OBJECT (50, 0));
  (Wrd153.Obj) = ((Wrd143.pObj) [0]);
  (Wrd154.uLng) = (OBJECT_TYPE (Wrd153.Obj));
  if ((Wrd154.uLng) == 50)
    goto label_37;

DEFLABEL (label_36)
  ((Wrd143.pObj) [0]) = (Wrd144.Obj);

DEFLABEL (label_35)
  (Wrd157.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_10_11]));
  (Wrd158.Obj) = (MAKE_OBJECT (50, 0));
  (Wrd167.Obj) = ((Wrd157.pObj) [0]);
  (Wrd168.uLng) = (OBJECT_TYPE (Wrd167.Obj));
  if ((Wrd168.uLng) == 50)
    goto label_34;

DEFLABEL (label_33)
  ((Wrd157.pObj) [0]) = (Wrd158.Obj);

DEFLABEL (label_32)
  (Wrd171.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_10_12]));
  (Wrd172.Obj) = (MAKE_OBJECT (50, 0));
  (Wrd181.Obj) = ((Wrd171.pObj) [0]);
  (Wrd182.uLng) = (OBJECT_TYPE (Wrd181.Obj));
  if ((Wrd182.uLng) == 50)
    goto label_31;

DEFLABEL (label_30)
  ((Wrd171.pObj) [0]) = (Wrd172.Obj);

DEFLABEL (label_29)
  (Wrd185.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_10_13]));
  (Wrd186.Obj) = (MAKE_OBJECT (50, 0));
  (Wrd195.Obj) = ((Wrd185.pObj) [0]);
  (Wrd196.uLng) = (OBJECT_TYPE (Wrd195.Obj));
  if ((Wrd196.uLng) == 50)
    goto label_28;

DEFLABEL (label_27)
  ((Wrd185.pObj) [0]) = (Wrd186.Obj);

DEFLABEL (label_26)
  (Wrd199.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_10_14]));
  (Wrd200.Obj) = (MAKE_OBJECT (50, 0));
  (Wrd209.Obj) = ((Wrd199.pObj) [0]);
  (Wrd210.uLng) = (OBJECT_TYPE (Wrd209.Obj));
  if ((Wrd210.uLng) == 50)
    goto label_25;

DEFLABEL (label_24)
  ((Wrd199.pObj) [0]) = (Wrd200.Obj);

DEFLABEL (label_23)
  (Wrd213.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_10_15]));
  (Wrd214.Obj) = (MAKE_OBJECT (50, 0));
  (Wrd223.Obj) = ((Wrd213.pObj) [0]);
  (Wrd224.uLng) = (OBJECT_TYPE (Wrd223.Obj));
  if ((Wrd224.uLng) == 50)
    goto label_22;

DEFLABEL (label_21)
  ((Wrd213.pObj) [0]) = (Wrd214.Obj);

DEFLABEL (label_20)
  Rvl = (current_block [OBJECT_10_1]);
  goto pop_return;

DEFLABEL (label_22)
  if ((Wrd223.Obj) == (Wrd214.Obj))
    goto label_21;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_10_20])), (Wrd213.pObj), (Wrd214.Obj));

DEFLABEL (label_17)
  goto label_20;

DEFLABEL (label_25)
  if ((Wrd209.Obj) == (Wrd200.Obj))
    goto label_24;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_10_19])), (Wrd199.pObj), (Wrd200.Obj));

DEFLABEL (label_16)
  goto label_23;

DEFLABEL (label_28)
  if ((Wrd195.Obj) == (Wrd186.Obj))
    goto label_27;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_10_18])), (Wrd185.pObj), (Wrd186.Obj));

DEFLABEL (label_15)
  goto label_26;

DEFLABEL (label_31)
  if ((Wrd181.Obj) == (Wrd172.Obj))
    goto label_30;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_10_17])), (Wrd171.pObj), (Wrd172.Obj));

DEFLABEL (label_14)
  goto label_29;

DEFLABEL (label_34)
  if ((Wrd167.Obj) == (Wrd158.Obj))
    goto label_33;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_10_16])), (Wrd157.pObj), (Wrd158.Obj));

DEFLABEL (label_13)
  goto label_32;

DEFLABEL (label_37)
  if ((Wrd153.Obj) == (Wrd144.Obj))
    goto label_36;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_10_15])), (Wrd143.pObj), (Wrd144.Obj));

DEFLABEL (label_12)
  goto label_35;

DEFLABEL (label_40)
  if ((Wrd139.Obj) == (Wrd130.Obj))
    goto label_39;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_10_14])), (Wrd129.pObj), (Wrd130.Obj));

DEFLABEL (label_11)
  goto label_38;

DEFLABEL (label_43)
  if ((Wrd125.Obj) == (Wrd116.Obj))
    goto label_42;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_10_13])), (Wrd115.pObj), (Wrd116.Obj));

DEFLABEL (label_10)
  goto label_41;

DEFLABEL (label_46)
  if ((Wrd111.Obj) == (Wrd102.Obj))
    goto label_45;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_10_12])), (Wrd101.pObj), (Wrd102.Obj));

DEFLABEL (label_9)
  goto label_44;

DEFLABEL (label_49)
  if ((Wrd97.Obj) == (Wrd88.Obj))
    goto label_48;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_10_11])), (Wrd87.pObj), (Wrd88.Obj));

DEFLABEL (label_8)
  goto label_47;

DEFLABEL (label_52)
  if ((Wrd83.Obj) == (Wrd74.Obj))
    goto label_51;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_10_10])), (Wrd73.pObj), (Wrd74.Obj));

DEFLABEL (label_7)
  goto label_50;

DEFLABEL (label_55)
  if ((Wrd69.Obj) == (Wrd60.Obj))
    goto label_54;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_10_9])), (Wrd59.pObj), (Wrd60.Obj));

DEFLABEL (label_6)
  goto label_53;

DEFLABEL (label_58)
  if ((Wrd55.Obj) == (Wrd46.Obj))
    goto label_57;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_10_8])), (Wrd45.pObj), (Wrd46.Obj));

DEFLABEL (label_5)
  goto label_56;

DEFLABEL (label_61)
  if ((Wrd41.Obj) == (Wrd32.Obj))
    goto label_60;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_10_7])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_4)
  goto label_59;

DEFLABEL (label_64)
  if ((Wrd27.Obj) == (Wrd18.Obj))
    goto label_63;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_10_6])), (Wrd17.pObj), (Wrd18.Obj));

DEFLABEL (label_3)
  goto label_62;

DEFLABEL (label_67)
  if ((Wrd13.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_66;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_10_5])), (Wrd5.pObj), (Wrd6.Obj));

DEFLABEL (label_2)
  goto label_65;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_11_4 3
#define LABEL_11_5 5
#define LABEL_11_6 7
#define LABEL_11_8 9
#define LABEL_11_9 11
#define LABEL_11_10 13
#define LABEL_11_11 15
#define LABEL_11_12 17
#define LABEL_11_13 19
#define LABEL_11_14 21
#define LABEL_11_15 23
#define LABEL_11_16 25
#define LABEL_11_17 27
#define ENVIRONMENT_LABEL_11_3 47
#define DEBUGGING_LABEL_11_2 46
#define OBJECT_11_2 45
#define OBJECT_11_1 44
#define OBJECT_11_0 43
#define EXECUTE_CACHE_11_7 29
#define FREE_ASSIGNMENT_11_10 32
#define FREE_ASSIGNMENT_11_9 33
#define FREE_ASSIGNMENT_11_8 34
#define FREE_ASSIGNMENT_11_7 35
#define FREE_ASSIGNMENT_11_6 36
#define FREE_ASSIGNMENT_11_5 37
#define FREE_ASSIGNMENT_11_4 38
#define FREE_ASSIGNMENT_11_3 39
#define FREE_ASSIGNMENT_11_2 40
#define FREE_ASSIGNMENT_11_1 41
#define FREE_ASSIGNMENT_11_0 42
#define FREE_REFERENCES_LABEL_11_0 28
#define NUMBER_OF_LINKER_SECTIONS_11_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
asstop_so_code_11 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd123;
  machine_word Wrd122;
  machine_word Wrd115;
  machine_word Wrd114;
  machine_word Wrd111;
  machine_word Wrd110;
  machine_word Wrd103;
  machine_word Wrd102;
  machine_word Wrd99;
  machine_word Wrd98;
  machine_word Wrd91;
  machine_word Wrd90;
  machine_word Wrd87;
  machine_word Wrd86;
  machine_word Wrd79;
  machine_word Wrd78;
  machine_word Wrd75;
  machine_word Wrd74;
  machine_word Wrd67;
  machine_word Wrd66;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_11_4);
      goto initialize_back_endB_1;

    case 1:
      current_block = (Rpc - LABEL_11_5);
      goto label_3;

    case 2:
      current_block = (Rpc - LABEL_11_6);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_11_8);
      goto label_4;

    case 4:
      current_block = (Rpc - LABEL_11_9);
      goto label_5;

    case 5:
      current_block = (Rpc - LABEL_11_10);
      goto label_6;

    case 6:
      current_block = (Rpc - LABEL_11_11);
      goto label_7;

    case 7:
      current_block = (Rpc - LABEL_11_12);
      goto label_8;

    case 8:
      current_block = (Rpc - LABEL_11_13);
      goto label_9;

    case 9:
      current_block = (Rpc - LABEL_11_14);
      goto label_10;

    case 10:
      current_block = (Rpc - LABEL_11_15);
      goto label_11;

    case 11:
      current_block = (Rpc - LABEL_11_16);
      goto label_12;

    case 12:
      current_block = (Rpc - LABEL_11_17);
      goto label_13;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (initialize_back_endB_15)
DEFLABEL (initialize_back_endB_1)
  INTERRUPT_CHECK (26, LABEL_11_4);
  (Wrd5.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_11_0]));
  (Wrd6.Obj) = (current_block [OBJECT_11_0]);
  (Wrd13.Obj) = ((Wrd5.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_48;

DEFLABEL (label_47)
  ((Wrd5.pObj) [0]) = (Wrd6.Obj);

DEFLABEL (label_46)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_6]))));
  (* (--Rsp)) = (Wrd19.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_11_6);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_11_1]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_45;

DEFLABEL (label_44)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_43)
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_11_2]));
  (Wrd19.Obj) = (current_block [OBJECT_11_0]);
  (Wrd26.Obj) = ((Wrd18.pObj) [0]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if ((Wrd27.uLng) == 50)
    goto label_42;

DEFLABEL (label_41)
  ((Wrd18.pObj) [0]) = (Wrd19.Obj);

DEFLABEL (label_40)
  (Wrd30.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_11_3]));
  (Wrd31.Obj) = (current_block [OBJECT_11_0]);
  (Wrd38.Obj) = ((Wrd30.pObj) [0]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if ((Wrd39.uLng) == 50)
    goto label_39;

DEFLABEL (label_38)
  ((Wrd30.pObj) [0]) = (Wrd31.Obj);

DEFLABEL (label_37)
  (Wrd42.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_11_4]));
  (Wrd43.Obj) = (current_block [OBJECT_11_1]);
  (Wrd50.Obj) = ((Wrd42.pObj) [0]);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if ((Wrd51.uLng) == 50)
    goto label_36;

DEFLABEL (label_35)
  ((Wrd42.pObj) [0]) = (Wrd43.Obj);

DEFLABEL (label_34)
  (Wrd54.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_11_5]));
  (Wrd55.Obj) = (current_block [OBJECT_11_0]);
  (Wrd62.Obj) = ((Wrd54.pObj) [0]);
  (Wrd63.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if ((Wrd63.uLng) == 50)
    goto label_33;

DEFLABEL (label_32)
  ((Wrd54.pObj) [0]) = (Wrd55.Obj);

DEFLABEL (label_31)
  (Wrd66.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_11_6]));
  (Wrd67.Obj) = (current_block [OBJECT_11_0]);
  (Wrd74.Obj) = ((Wrd66.pObj) [0]);
  (Wrd75.uLng) = (OBJECT_TYPE (Wrd74.Obj));
  if ((Wrd75.uLng) == 50)
    goto label_30;

DEFLABEL (label_29)
  ((Wrd66.pObj) [0]) = (Wrd67.Obj);

DEFLABEL (label_28)
  (Wrd78.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_11_7]));
  (Wrd79.Obj) = (current_block [OBJECT_11_0]);
  (Wrd86.Obj) = ((Wrd78.pObj) [0]);
  (Wrd87.uLng) = (OBJECT_TYPE (Wrd86.Obj));
  if ((Wrd87.uLng) == 50)
    goto label_27;

DEFLABEL (label_26)
  ((Wrd78.pObj) [0]) = (Wrd79.Obj);

DEFLABEL (label_25)
  (Wrd90.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_11_8]));
  (Wrd91.Obj) = (current_block [OBJECT_11_0]);
  (Wrd98.Obj) = ((Wrd90.pObj) [0]);
  (Wrd99.uLng) = (OBJECT_TYPE (Wrd98.Obj));
  if ((Wrd99.uLng) == 50)
    goto label_24;

DEFLABEL (label_23)
  ((Wrd90.pObj) [0]) = (Wrd91.Obj);

DEFLABEL (label_22)
  (Wrd102.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_11_9]));
  (Wrd103.Obj) = (current_block [OBJECT_11_0]);
  (Wrd110.Obj) = ((Wrd102.pObj) [0]);
  (Wrd111.uLng) = (OBJECT_TYPE (Wrd110.Obj));
  if ((Wrd111.uLng) == 50)
    goto label_21;

DEFLABEL (label_20)
  ((Wrd102.pObj) [0]) = (Wrd103.Obj);

DEFLABEL (label_19)
  (Wrd114.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_11_10]));
  (Wrd115.Obj) = (current_block [OBJECT_11_0]);
  (Wrd122.Obj) = ((Wrd114.pObj) [0]);
  (Wrd123.uLng) = (OBJECT_TYPE (Wrd122.Obj));
  if ((Wrd123.uLng) == 50)
    goto label_18;

DEFLABEL (label_17)
  ((Wrd114.pObj) [0]) = (Wrd115.Obj);

DEFLABEL (label_16)
  Rvl = (current_block [OBJECT_11_2]);
  goto pop_return;

DEFLABEL (label_18)
  if ((Wrd122.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_17;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_11_17])), (Wrd114.pObj), (Wrd115.Obj));

DEFLABEL (label_13)
  goto label_16;

DEFLABEL (label_21)
  if ((Wrd110.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_20;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_11_16])), (Wrd102.pObj), (Wrd103.Obj));

DEFLABEL (label_12)
  goto label_19;

DEFLABEL (label_24)
  if ((Wrd98.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_23;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_11_15])), (Wrd90.pObj), (Wrd91.Obj));

DEFLABEL (label_11)
  goto label_22;

DEFLABEL (label_27)
  if ((Wrd86.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_26;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_11_14])), (Wrd78.pObj), (Wrd79.Obj));

DEFLABEL (label_10)
  goto label_25;

DEFLABEL (label_30)
  if ((Wrd74.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_29;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_11_13])), (Wrd66.pObj), (Wrd67.Obj));

DEFLABEL (label_9)
  goto label_28;

DEFLABEL (label_33)
  if ((Wrd62.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_32;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_11_12])), (Wrd54.pObj), (Wrd55.Obj));

DEFLABEL (label_8)
  goto label_31;

DEFLABEL (label_36)
  if ((Wrd50.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_35;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_11_11])), (Wrd42.pObj), (Wrd43.Obj));

DEFLABEL (label_7)
  goto label_34;

DEFLABEL (label_39)
  if ((Wrd38.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_38;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_11_10])), (Wrd30.pObj), (Wrd31.Obj));

DEFLABEL (label_6)
  goto label_37;

DEFLABEL (label_42)
  if ((Wrd26.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_41;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_11_9])), (Wrd18.pObj), (Wrd19.Obj));

DEFLABEL (label_5)
  goto label_40;

DEFLABEL (label_45)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_44;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_11_8])), (Wrd6.pObj), Rvl);

DEFLABEL (label_4)
  goto label_43;

DEFLABEL (label_48)
  if ((Wrd13.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_47;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_11_5])), (Wrd5.pObj), (Wrd6.Obj));

DEFLABEL (label_3)
  goto label_46;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_12_4 3
#define LABEL_12_5 5
#define LABEL_12_10 7
#define LABEL_12_7 9
#define LABEL_12_12 11
#define LABEL_12_13 13
#define LABEL_12_14 15
#define LABEL_12_15 17
#define LABEL_12_8 19
#define LABEL_12_9 21
#define LABEL_12_19 23
#define LABEL_12_16 25
#define TAG_12_17 11
#define LABEL_12_21 27
#define LABEL_12_24 29
#define LABEL_12_23 31
#define LABEL_12_27 33
#define LABEL_12_26 35
#define LABEL_12_28 37
#define ENVIRONMENT_LABEL_12_3 66
#define DEBUGGING_LABEL_12_2 65
#define OBJECT_12_5 64
#define OBJECT_12_4 63
#define OBJECT_12_3 62
#define OBJECT_12_2 61
#define OBJECT_12_1 60
#define OBJECT_12_0 59
#define EXECUTE_CACHE_12_25 39
#define EXECUTE_CACHE_12_22 41
#define EXECUTE_CACHE_12_20 43
#define EXECUTE_CACHE_12_18 45
#define EXECUTE_CACHE_12_11 47
#define EXECUTE_CACHE_12_6 49
#define FREE_REFERENCE_12_2 52
#define FREE_REFERENCE_12_1 53
#define FREE_REFERENCE_12_0 54
#define FREE_ASSIGNMENT_12_2 56
#define FREE_ASSIGNMENT_12_1 57
#define FREE_ASSIGNMENT_12_0 58
#define FREE_REFERENCES_LABEL_12_0 38
#define NUMBER_OF_LINKER_SECTIONS_12_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
asstop_so_code_12 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd11;
  machine_word Wrd24;
  machine_word Wrd19;
  machine_word Wrd23;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd8;
  machine_word Wrd10;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd49;
  machine_word Wrd50;
  machine_word Wrd41;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd42;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd14;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_12_4);
      goto phase_assemble_11;

    case 1:
      current_block = (Rpc - LABEL_12_5);
      goto lambda_10;

    case 2:
      current_block = (Rpc - LABEL_12_10);
      goto label_13;

    case 3:
      current_block = (Rpc - LABEL_12_7);
      goto lambda_7;

    case 4:
      current_block = (Rpc - LABEL_12_12);
      goto label_14;

    case 5:
      current_block = (Rpc - LABEL_12_13);
      goto label_15;

    case 6:
      current_block = (Rpc - LABEL_12_14);
      goto label_16;

    case 7:
      current_block = (Rpc - LABEL_12_15);
      goto label_17;

    case 8:
      current_block = (Rpc - LABEL_12_8);
      goto continuation_9;

    case 9:
      current_block = (Rpc - LABEL_12_9);
      goto continuation_8;

    case 10:
      current_block = (Rpc - LABEL_12_19);
      goto label_18;

    case 11:
      current_block = (Rpc - LABEL_12_16);
      goto lambda_25;

    case 12:
      current_block = (Rpc - LABEL_12_21);
      goto continuation_0;

    case 13:
      current_block = (Rpc - LABEL_12_24);
      goto label_19;

    case 14:
      current_block = (Rpc - LABEL_12_23);
      goto continuation_2;

    case 15:
      current_block = (Rpc - LABEL_12_27);
      goto continuation_5;

    case 16:
      current_block = (Rpc - LABEL_12_26);
      goto continuation_3;

    case 17:
      current_block = (Rpc - LABEL_12_28);
      goto label_20;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (phase_assemble_22)
DEFLABEL (phase_assemble_11)
  INTERRUPT_CHECK (26, LABEL_12_4);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_5]))));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_12_0]);
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_6]));

DEFLABEL (lambda_23)
DEFLABEL (lambda_10)
  INTERRUPT_CHECK (26, LABEL_12_5);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_7]))));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_8]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_9]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd14.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_12_0]));
  (Wrd17.Obj) = ((Wrd14.pObj) [0]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd18.uLng) == 50)
    goto label_29;
  Wrd13 = Wrd17;

DEFLABEL (label_28)
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_11]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_12_9);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_12_2]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_27;
  Wrd5 = Wrd9;

DEFLABEL (label_26)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_20]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_12_8);
  (* (--Rsp)) = Rvl;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_27)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_12_19])), (Wrd6.pObj));

DEFLABEL (label_18)
  (Wrd5.Obj) = Rvl;
  goto label_26;

DEFLABEL (label_29)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_12_10])), (Wrd14.pObj));

DEFLABEL (label_13)
  (Wrd13.Obj) = Rvl;
  goto label_28;

DEFLABEL (lambda_24)
DEFLABEL (lambda_7)
  INTERRUPT_CHECK (26, LABEL_12_7);
  (Wrd5.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_12_0]));
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd13.Obj) = ((Wrd5.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_41;

DEFLABEL (label_40)
  ((Wrd5.pObj) [0]) = (Wrd6.Obj);

DEFLABEL (label_39)
  (Wrd17.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_12_1]));
  (Wrd18.Obj) = (Rsp [2]);
  (Wrd25.Obj) = ((Wrd17.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_38;

DEFLABEL (label_37)
  ((Wrd17.pObj) [0]) = (Wrd18.Obj);

DEFLABEL (label_36)
  (Wrd29.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_12_2]));
  (Wrd30.Obj) = (Rsp [3]);
  (Wrd37.Obj) = ((Wrd29.pObj) [0]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if ((Wrd38.uLng) == 50)
    goto label_35;

DEFLABEL (label_34)
  ((Wrd29.pObj) [0]) = (Wrd30.Obj);

DEFLABEL (label_33)
  (Wrd42.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_12_1]));
  (Wrd45.Obj) = ((Wrd42.pObj) [0]);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd45.Obj));
  if ((Wrd46.uLng) == 50)
    goto label_32;
  Wrd41 = Wrd45;

DEFLABEL (label_31)
  if ((Wrd41.Obj) == ((SCHEME_OBJECT) 0))
    goto label_30;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd50.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_12_17);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_12_16])));
  Rhp += 1;
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd50.pObj)));
  Wrd51 = Wrd50;
  (Wrd52.Obj) = (Rsp [0]);
  ((Wrd51.pObj) [2]) = (Wrd52.Obj);
  (Rsp [3]) = (Wrd49.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_18]));

DEFLABEL (label_30)
  Rvl = (current_block [OBJECT_12_1]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_32)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_12_15])), (Wrd42.pObj));

DEFLABEL (label_17)
  (Wrd41.Obj) = Rvl;
  goto label_31;

DEFLABEL (label_35)
  if ((Wrd37.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_34;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_12_14])), (Wrd29.pObj), (Wrd30.Obj));

DEFLABEL (label_16)
  goto label_33;

DEFLABEL (label_38)
  if ((Wrd25.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_37;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_12_13])), (Wrd17.pObj), (Wrd18.Obj));

DEFLABEL (label_15)
  goto label_36;

DEFLABEL (label_41)
  if ((Wrd13.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_40;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_12_12])), (Wrd5.pObj), (Wrd6.Obj));

DEFLABEL (label_14)
  goto label_39;

DEFLABEL (lambda_25)
  CLOSURE_HEADER (LABEL_12_16);

DEFLABEL (lambda_6)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_21]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_12_2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_22]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_12_21);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_23]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 26))
    goto label_46;
  (Wrd23.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  (Wrd19.Lng) = ((Wrd23.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd19.Lng)))
    goto label_46;
  (Wrd24.Obj) = (LONG_TO_FIXNUM (Wrd19.Lng));
  (* (--Rsp)) = (Wrd24.Obj);

DEFLABEL (label_45)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_25]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_12_23);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_26]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_12_3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_22]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_12_26);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd8.uLng) == 26))
    goto label_44;
  (Wrd25.Lng) = (FIXNUM_TO_LONG (Wrd7.Obj));
  if ((Wrd25.Lng) > 0)
    goto label_43;

DEFLABEL (label_42)
  (Wrd16.Obj) = (current_block [OBJECT_12_4]);
  (Rsp [0]) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_22]));

DEFLABEL (label_43)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_27]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (current_block [OBJECT_12_5]);
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_22]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_12_27);
  goto label_42;

DEFLABEL (label_44)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_28]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_INTERFACE_0 (44);

DEFLABEL (label_20)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_42;
  goto label_43;

DEFLABEL (label_46)
  (Wrd10.Obj) = (Rsp [2]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [2]);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_24]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_19)
  (* (--Rsp)) = Rvl;
  goto label_45;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_13_4 3
#define LABEL_13_5 5
#define LABEL_13_9 7
#define LABEL_13_7 9
#define LABEL_13_13 11
#define LABEL_13_15 13
#define LABEL_13_8 15
#define LABEL_13_20 17
#define LABEL_13_21 19
#define LABEL_13_22 21
#define LABEL_13_24 23
#define LABEL_13_10 25
#define LABEL_13_12 27
#define LABEL_13_29 29
#define LABEL_13_30 31
#define LABEL_13_31 33
#define LABEL_13_32 35
#define LABEL_13_33 37
#define LABEL_13_34 39
#define LABEL_13_35 41
#define LABEL_13_36 43
#define LABEL_13_14 45
#define LABEL_13_17 47
#define TAG_13_18 22
#define LABEL_13_40 49
#define LABEL_13_19 51
#define LABEL_13_41 53
#define LABEL_13_44 55
#define LABEL_13_23 57
#define LABEL_13_49 59
#define LABEL_13_50 61
#define LABEL_13_53 63
#define LABEL_13_25 65
#define LABEL_13_26 67
#define TAG_13_27 32
#define LABEL_13_54 69
#define LABEL_13_56 71
#define LABEL_13_38 73
#define LABEL_13_37 75
#define LABEL_13_42 77
#define TAG_13_43 37
#define LABEL_13_60 79
#define LABEL_13_46 81
#define TAG_13_47 39
#define LABEL_13_61 83
#define LABEL_13_48 85
#define LABEL_13_52 87
#define LABEL_13_51 89
#define LABEL_13_55 91
#define LABEL_13_66 93
#define LABEL_13_59 95
#define LABEL_13_67 97
#define LABEL_13_62 99
#define LABEL_13_63 101
#define LABEL_13_64 103
#define LABEL_13_65 105
#define LABEL_13_69 107
#define LABEL_13_71 109
#define LABEL_13_70 111
#define LABEL_13_72 113
#define ENVIRONMENT_LABEL_13_3 169
#define DEBUGGING_LABEL_13_2 168
#define OBJECT_13_12 167
#define OBJECT_13_11 166
#define OBJECT_13_10 165
#define OBJECT_13_9 164
#define OBJECT_13_8 163
#define OBJECT_13_7 162
#define OBJECT_13_6 161
#define OBJECT_13_5 160
#define OBJECT_13_4 159
#define OBJECT_13_3 158
#define OBJECT_13_2 157
#define OBJECT_13_1 156
#define OBJECT_13_0 155
#define EXECUTE_CACHE_13_68 115
#define EXECUTE_CACHE_13_58 117
#define EXECUTE_CACHE_13_45 119
#define EXECUTE_CACHE_13_39 121
#define EXECUTE_CACHE_13_28 123
#define EXECUTE_CACHE_13_57 125
#define EXECUTE_CACHE_13_16 127
#define EXECUTE_CACHE_13_11 129
#define EXECUTE_CACHE_13_6 131
#define FREE_REFERENCE_13_11 134
#define FREE_REFERENCE_13_10 135
#define FREE_REFERENCE_13_9 136
#define FREE_REFERENCE_13_8 137
#define FREE_REFERENCE_13_7 138
#define FREE_REFERENCE_13_6 139
#define FREE_REFERENCE_13_5 140
#define FREE_REFERENCE_13_4 141
#define FREE_REFERENCE_13_3 142
#define FREE_REFERENCE_13_2 143
#define FREE_REFERENCE_13_1 144
#define FREE_REFERENCE_13_0 145
#define FREE_ASSIGNMENT_13_7 147
#define FREE_ASSIGNMENT_13_6 148
#define FREE_ASSIGNMENT_13_5 149
#define FREE_ASSIGNMENT_13_4 150
#define FREE_ASSIGNMENT_13_3 151
#define FREE_ASSIGNMENT_13_2 152
#define FREE_ASSIGNMENT_13_1 153
#define FREE_ASSIGNMENT_13_0 154
#define FREE_REFERENCES_LABEL_13_0 114
#define NUMBER_OF_LINKER_SECTIONS_13_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
asstop_so_code_13 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd26;
  machine_word Wrd31;
  machine_word Wrd108;
  machine_word Wrd107;
  machine_word Wrd98;
  machine_word Wrd97;
  machine_word Wrd94;
  machine_word Wrd93;
  machine_word Wrd84;
  machine_word Wrd83;
  machine_word Wrd80;
  machine_word Wrd79;
  machine_word Wrd70;
  machine_word Wrd69;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd42;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd27;
  machine_word Wrd5;
  machine_word Wrd29;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd41;
  machine_word Wrd35;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd14;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd17;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd9;
  machine_word Wrd18;
  machine_word Wrd11;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_13_4);
      goto phase_link_44;

    case 1:
      current_block = (Rpc - LABEL_13_5);
      goto lambda_43;

    case 2:
      current_block = (Rpc - LABEL_13_9);
      goto label_46;

    case 3:
      current_block = (Rpc - LABEL_13_7);
      goto continuation_4;

    case 4:
      current_block = (Rpc - LABEL_13_13);
      goto label_47;

    case 5:
      current_block = (Rpc - LABEL_13_15);
      goto label_48;

    case 6:
      current_block = (Rpc - LABEL_13_8);
      goto continuation_13;

    case 7:
      current_block = (Rpc - LABEL_13_20);
      goto label_49;

    case 8:
      current_block = (Rpc - LABEL_13_21);
      goto label_52;

    case 9:
      current_block = (Rpc - LABEL_13_22);
      goto label_50;

    case 10:
      current_block = (Rpc - LABEL_13_24);
      goto label_51;

    case 11:
      current_block = (Rpc - LABEL_13_10);
      goto lambda_12;

    case 12:
      current_block = (Rpc - LABEL_13_12);
      goto continuation_41;

    case 13:
      current_block = (Rpc - LABEL_13_29);
      goto label_53;

    case 14:
      current_block = (Rpc - LABEL_13_30);
      goto label_54;

    case 15:
      current_block = (Rpc - LABEL_13_31);
      goto label_55;

    case 16:
      current_block = (Rpc - LABEL_13_32);
      goto label_56;

    case 17:
      current_block = (Rpc - LABEL_13_33);
      goto label_57;

    case 18:
      current_block = (Rpc - LABEL_13_34);
      goto label_58;

    case 19:
      current_block = (Rpc - LABEL_13_35);
      goto label_59;

    case 20:
      current_block = (Rpc - LABEL_13_36);
      goto label_60;

    case 21:
      current_block = (Rpc - LABEL_13_14);
      goto continuation_42;

    case 22:
      current_block = (Rpc - LABEL_13_17);
      goto lambda_17;

    case 23:
      current_block = (Rpc - LABEL_13_40);
      goto continuation_27;

    case 24:
      current_block = (Rpc - LABEL_13_19);
      goto continuation_18;

    case 25:
      current_block = (Rpc - LABEL_13_41);
      goto label_61;

    case 26:
      current_block = (Rpc - LABEL_13_44);
      goto label_62;

    case 27:
      current_block = (Rpc - LABEL_13_23);
      goto continuation_20;

    case 28:
      current_block = (Rpc - LABEL_13_49);
      goto label_63;

    case 29:
      current_block = (Rpc - LABEL_13_50);
      goto lambda_3;

    case 30:
      current_block = (Rpc - LABEL_13_53);
      goto label_64;

    case 31:
      current_block = (Rpc - LABEL_13_25);
      goto continuation_11;

    case 32:
      current_block = (Rpc - LABEL_13_26);
      goto lambda_78;

    case 33:
      current_block = (Rpc - LABEL_13_54);
      goto label_65;

    case 34:
      current_block = (Rpc - LABEL_13_56);
      goto label_66;

    case 35:
      current_block = (Rpc - LABEL_13_38);
      goto continuation_14;

    case 36:
      current_block = (Rpc - LABEL_13_37);
      goto continuation_15;

    case 37:
      current_block = (Rpc - LABEL_13_42);
      goto lambda_79;

    case 38:
      current_block = (Rpc - LABEL_13_60);
      goto label_67;

    case 39:
      current_block = (Rpc - LABEL_13_46);
      goto lambda_25;

    case 40:
      current_block = (Rpc - LABEL_13_61);
      goto label_68;

    case 41:
      current_block = (Rpc - LABEL_13_48);
      goto continuation_19;

    case 42:
      current_block = (Rpc - LABEL_13_52);
      goto continuation_0;

    case 43:
      current_block = (Rpc - LABEL_13_51);
      goto continuation_1;

    case 44:
      current_block = (Rpc - LABEL_13_55);
      goto continuation_9;

    case 45:
      current_block = (Rpc - LABEL_13_66);
      goto label_69;

    case 46:
      current_block = (Rpc - LABEL_13_59);
      goto continuation_36;

    case 47:
      current_block = (Rpc - LABEL_13_67);
      goto label_70;

    case 48:
      current_block = (Rpc - LABEL_13_62);
      goto continuation_23;

    case 49:
      current_block = (Rpc - LABEL_13_63);
      goto continuation_28;

    case 50:
      current_block = (Rpc - LABEL_13_64);
      goto continuation_8;

    case 51:
      current_block = (Rpc - LABEL_13_65);
      goto continuation_6;

    case 52:
      current_block = (Rpc - LABEL_13_69);
      goto continuation_29;

    case 53:
      current_block = (Rpc - LABEL_13_71);
      goto label_71;

    case 54:
      current_block = (Rpc - LABEL_13_70);
      goto continuation_5;

    case 55:
      current_block = (Rpc - LABEL_13_72);
      goto label_72;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (phase_link_74)
DEFLABEL (phase_link_44)
  INTERRUPT_CHECK (26, LABEL_13_4);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_5]))));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_13_0]);
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_6]));

DEFLABEL (lambda_75)
DEFLABEL (lambda_43)
  INTERRUPT_CHECK (26, LABEL_13_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_8]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_102;
  Wrd11 = Wrd15;

DEFLABEL (label_101)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_10]))));
  (* (--Rsp)) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_11]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_13_8);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_13_18);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_13_17])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  ((Wrd7.pObj) [2]) = Rvl;
  (Rsp [0]) = (Wrd6.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_19]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd14.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13_3]));
  (Wrd17.Obj) = ((Wrd14.pObj) [0]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd18.uLng) == 50)
    goto label_100;
  Wrd13 = Wrd17;

DEFLABEL (label_99)
  if ((Wrd13.Obj) == ((SCHEME_OBJECT) 0))
    goto label_96;
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13_5]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_95;
  Wrd20 = Wrd24;

DEFLABEL (label_94)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_23]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd30.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13_6]));
  (Wrd33.Obj) = ((Wrd30.pObj) [0]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if ((Wrd34.uLng) == 50)
    goto label_93;
  Wrd29 = Wrd33;

DEFLABEL (label_92)
  (* (--Rsp)) = (Wrd29.Obj);
  goto lambda_3;

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_13_23);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_13_47);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_13_46])));
  Rhp += 2;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  Wrd11 = Wrd8;
  (Wrd12.Obj) = (Rsp [1]);
  ((Wrd11.pObj) [2]) = (Wrd12.Obj);
  ((Wrd11.pObj) [3]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_48]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd17.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13_4]));
  (Wrd20.Obj) = ((Wrd17.pObj) [0]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd21.uLng) == 50)
    goto label_91;
  Wrd16 = Wrd20;

DEFLABEL (label_90)
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd22.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd22.Obj);
  goto lambda_17;

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_13_48);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_63]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_13_6]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  goto lambda_25;

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_13_63);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_69]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_13_1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  goto lambda_25;

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_13_69);
  (* (--Rsp)) = Rvl;
  (Wrd14.Obj) = (Rsp [4]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_89;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_89;
  (Wrd7.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_88)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_40]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_13_11]), 1);

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_13_40);
  (Wrd29.Obj) = (* (Rsp++));
  (Wrd30.Obj) = (* (Rsp++));
  (Wrd31.Obj) = (* (Rsp++));
  (Wrd38.Obj) = (MAKE_OBJECT (0, 4));
  (* (Rhp++)) = (Wrd38.Obj);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd31.Obj);
  (* (Rhp++)) = (Wrd30.Obj);
  (* (Rhp++)) = (Wrd29.Obj);
  (Wrd35.pObj) = (& (Rhp [-5]));
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd35.pObj)));
  (Wrd42.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd42.Obj);
  (* (Rhp++)) = (Wrd33.Obj);
  (Wrd41.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd41.pObj)));
  Rsp = (& (Rsp [4]));

DEFLABEL (label_87)
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_13_7]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_86;

DEFLABEL (label_85)
  ((Wrd6.pObj) [0]) = (Wrd5.Obj);

DEFLABEL (label_84)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd19.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_13_43);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_13_42])));
  Rhp += 1;
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd19.pObj)));
  Wrd20 = Wrd19;
  (Wrd21.Obj) = (Rsp [0]);
  ((Wrd20.pObj) [2]) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13_8]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_83;
  Wrd23 = Wrd27;

DEFLABEL (label_82)
  (Rsp [1]) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_45]));

DEFLABEL (label_83)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_13_44])), (Wrd24.pObj));

DEFLABEL (label_62)
  (Wrd23.Obj) = Rvl;
  goto label_82;

DEFLABEL (label_86)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_85;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_13_41])), (Wrd6.pObj), (Wrd5.Obj));

DEFLABEL (label_61)
  goto label_84;

DEFLABEL (label_89)
  (Wrd16.Obj) = (Rsp [4]);
  (Wrd17.Obj) = (current_block [OBJECT_13_10]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_71]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_13_5]), 2);

DEFLABEL (label_71)
  (* (--Rsp)) = Rvl;
  goto label_88;

DEFLABEL (label_91)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_13_49])), (Wrd17.pObj));

DEFLABEL (label_63)
  (Wrd16.Obj) = Rvl;
  goto label_90;

DEFLABEL (label_93)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_13_24])), (Wrd30.pObj));

DEFLABEL (label_51)
  (Wrd29.Obj) = Rvl;
  goto label_92;

DEFLABEL (label_95)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_13_22])), (Wrd21.pObj));

DEFLABEL (label_50)
  (Wrd20.Obj) = Rvl;
  goto label_94;

DEFLABEL (label_96)
  (Wrd36.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13_4]));
  (Wrd39.Obj) = ((Wrd36.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_98;
  Wrd35 = Wrd39;

DEFLABEL (label_97)
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd41.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd41.Obj);
  goto lambda_17;

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_13_19);
  (Wrd5.Obj) = Rvl;
  goto label_87;

DEFLABEL (label_98)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_13_21])), (Wrd36.pObj));

DEFLABEL (label_52)
  (Wrd35.Obj) = Rvl;
  goto label_97;

DEFLABEL (label_100)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_13_20])), (Wrd14.pObj));

DEFLABEL (label_49)
  (Wrd13.Obj) = Rvl;
  goto label_99;

DEFLABEL (label_102)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_13_9])), (Wrd12.pObj));

DEFLABEL (label_46)
  (Wrd11.Obj) = Rvl;
  goto label_101;

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_13_7);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13_1]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_130;
  Wrd8 = Wrd12;

DEFLABEL (label_129)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_14]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (current_block [OBJECT_13_1]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd19.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13_2]));
  (Wrd22.Obj) = ((Wrd19.pObj) [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd23.uLng) == 50)
    goto label_128;
  Wrd18 = Wrd22;

DEFLABEL (label_127)
  (* (--Rsp)) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_16]));

DEFLABEL (continuation_42)
  INTERRUPT_CHECK (27, LABEL_13_14);
  (* (--Rsp)) = Rvl;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_41)
  INTERRUPT_CHECK (27, LABEL_13_12);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13_7]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_126;
  Wrd5 = Wrd9;

DEFLABEL (label_125)
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_104;

DEFLABEL (label_103)
  Rvl = (current_block [OBJECT_13_2]);
  goto pop_return;

DEFLABEL (label_104)
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_13_0]));
  (Wrd14.Obj) = (MAKE_OBJECT (50, 0));
  (Wrd23.Obj) = ((Wrd13.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_124;

DEFLABEL (label_123)
  ((Wrd13.pObj) [0]) = (Wrd14.Obj);

DEFLABEL (label_122)
  (Wrd27.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_13_1]));
  (Wrd28.Obj) = (MAKE_OBJECT (50, 0));
  (Wrd37.Obj) = ((Wrd27.pObj) [0]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if ((Wrd38.uLng) == 50)
    goto label_121;

DEFLABEL (label_120)
  ((Wrd27.pObj) [0]) = (Wrd28.Obj);

DEFLABEL (label_119)
  (Wrd41.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_13_2]));
  (Wrd42.Obj) = (MAKE_OBJECT (50, 0));
  (Wrd51.Obj) = ((Wrd41.pObj) [0]);
  (Wrd52.uLng) = (OBJECT_TYPE (Wrd51.Obj));
  if ((Wrd52.uLng) == 50)
    goto label_118;

DEFLABEL (label_117)
  ((Wrd41.pObj) [0]) = (Wrd42.Obj);

DEFLABEL (label_116)
  (Wrd55.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_13_3]));
  (Wrd56.Obj) = (MAKE_OBJECT (50, 0));
  (Wrd65.Obj) = ((Wrd55.pObj) [0]);
  (Wrd66.uLng) = (OBJECT_TYPE (Wrd65.Obj));
  if ((Wrd66.uLng) == 50)
    goto label_115;

DEFLABEL (label_114)
  ((Wrd55.pObj) [0]) = (Wrd56.Obj);

DEFLABEL (label_113)
  (Wrd69.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_13_4]));
  (Wrd70.Obj) = (MAKE_OBJECT (50, 0));
  (Wrd79.Obj) = ((Wrd69.pObj) [0]);
  (Wrd80.uLng) = (OBJECT_TYPE (Wrd79.Obj));
  if ((Wrd80.uLng) == 50)
    goto label_112;

DEFLABEL (label_111)
  ((Wrd69.pObj) [0]) = (Wrd70.Obj);

DEFLABEL (label_110)
  (Wrd83.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_13_5]));
  (Wrd84.Obj) = (MAKE_OBJECT (50, 0));
  (Wrd93.Obj) = ((Wrd83.pObj) [0]);
  (Wrd94.uLng) = (OBJECT_TYPE (Wrd93.Obj));
  if ((Wrd94.uLng) == 50)
    goto label_109;

DEFLABEL (label_108)
  ((Wrd83.pObj) [0]) = (Wrd84.Obj);

DEFLABEL (label_107)
  (Wrd97.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_13_6]));
  (Wrd98.Obj) = (MAKE_OBJECT (50, 0));
  (Wrd107.Obj) = ((Wrd97.pObj) [0]);
  (Wrd108.uLng) = (OBJECT_TYPE (Wrd107.Obj));
  if ((Wrd108.uLng) == 50)
    goto label_106;

DEFLABEL (label_105)
  ((Wrd97.pObj) [0]) = (Wrd98.Obj);
  goto label_103;

DEFLABEL (label_106)
  if ((Wrd107.Obj) == (Wrd98.Obj))
    goto label_105;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_13_36])), (Wrd97.pObj), (Wrd98.Obj));

DEFLABEL (label_60)
  goto label_103;

DEFLABEL (label_109)
  if ((Wrd93.Obj) == (Wrd84.Obj))
    goto label_108;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_13_35])), (Wrd83.pObj), (Wrd84.Obj));

DEFLABEL (label_59)
  goto label_107;

DEFLABEL (label_112)
  if ((Wrd79.Obj) == (Wrd70.Obj))
    goto label_111;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_13_34])), (Wrd69.pObj), (Wrd70.Obj));

DEFLABEL (label_58)
  goto label_110;

DEFLABEL (label_115)
  if ((Wrd65.Obj) == (Wrd56.Obj))
    goto label_114;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_13_33])), (Wrd55.pObj), (Wrd56.Obj));

DEFLABEL (label_57)
  goto label_113;

DEFLABEL (label_118)
  if ((Wrd51.Obj) == (Wrd42.Obj))
    goto label_117;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_13_32])), (Wrd41.pObj), (Wrd42.Obj));

DEFLABEL (label_56)
  goto label_116;

DEFLABEL (label_121)
  if ((Wrd37.Obj) == (Wrd28.Obj))
    goto label_120;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_13_31])), (Wrd27.pObj), (Wrd28.Obj));

DEFLABEL (label_55)
  goto label_119;

DEFLABEL (label_124)
  if ((Wrd23.Obj) == (Wrd14.Obj))
    goto label_123;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_13_30])), (Wrd13.pObj), (Wrd14.Obj));

DEFLABEL (label_54)
  goto label_122;

DEFLABEL (label_126)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_13_29])), (Wrd6.pObj));

DEFLABEL (label_53)
  (Wrd5.Obj) = Rvl;
  goto label_125;

DEFLABEL (label_128)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_13_15])), (Wrd19.pObj));

DEFLABEL (label_48)
  (Wrd18.Obj) = Rvl;
  goto label_127;

DEFLABEL (label_130)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_13_13])), (Wrd9.pObj));

DEFLABEL (label_47)
  (Wrd8.Obj) = Rvl;
  goto label_129;

DEFLABEL (lambda_77)
DEFLABEL (lambda_12)
  INTERRUPT_CHECK (26, LABEL_13_10);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_25]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_13_27);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_13_26])));
  Rhp += 1;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd10 = Wrd9;
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_28]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_13_25);
  (Wrd10.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_76)
DEFLABEL (lambda_17)
  INTERRUPT_CHECK (26, LABEL_13_17);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_37]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_38]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_39]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_13_38);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_131;
  (Wrd16.Obj) = (current_block [OBJECT_13_3]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [4]);
  (Rsp [1]) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_58]));

DEFLABEL (label_131)
  (Wrd5.Obj) = Rvl;
  Rsp = (& (Rsp [2]));

DEFLABEL (label_133)
  (Rsp [1]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_132;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  Rvl = ((Wrd8.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_132)
  INVOKE_PRIMITIVE ((current_block [OBJECT_13_4]), 1);

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_13_37);
  (Wrd5.Obj) = Rvl;
  goto label_133;

DEFLABEL (lambda_81)
DEFLABEL (lambda_3)
  INTERRUPT_CHECK (26, LABEL_13_50);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_51]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_52]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13_9]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_138;
  Wrd11 = Wrd15;

DEFLABEL (label_137)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_39]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_13_52);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_134;
  (Wrd15.Obj) = (current_block [OBJECT_13_7]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [3]);
  (Rsp [1]) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_58]));

DEFLABEL (label_134)
  (Wrd5.Obj) = Rvl;
  Rsp = (& (Rsp [2]));

DEFLABEL (label_136)
  (Rsp [0]) = (Wrd5.Obj);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_135;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  Rvl = ((Wrd8.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_135)
  INVOKE_PRIMITIVE ((current_block [OBJECT_13_4]), 1);

DEFLABEL (label_138)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_13_53])), (Wrd12.pObj));

DEFLABEL (label_64)
  (Wrd11.Obj) = Rvl;
  goto label_137;

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_13_51);
  (Wrd5.Obj) = Rvl;
  goto label_136;

DEFLABEL (lambda_78)
  CLOSURE_HEADER (LABEL_13_26);

DEFLABEL (lambda_10)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13_10]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_146;
  Wrd5 = Wrd9;

DEFLABEL (label_145)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_55]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13_11]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_144;
  Wrd14 = Wrd18;

DEFLABEL (label_143)
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_57]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_13_55);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_64]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_65]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13_1]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_142;
  Wrd11 = Wrd15;

DEFLABEL (label_141)
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_13_8]), 1);

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_13_65);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_70]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [5]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  goto lambda_3;

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_13_70);
  (Wrd6.Obj) = Rvl;
  (Wrd5.Obj) = (* (Rsp++));
  (Wrd12.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd12.uLng) == 26))
    goto label_140;
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd13.uLng) == 26))
    goto label_140;
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Rvl));
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  (Wrd14.Lng) = ((Wrd15.Lng) + (Wrd16.Lng));
  if (! (LONG_TO_FIXNUM_P (Wrd14.Lng)))
    goto label_140;
  (Wrd17.Obj) = (LONG_TO_FIXNUM (Wrd14.Lng));
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_139)
  INVOKE_PRIMITIVE ((current_block [OBJECT_13_12]), 1);

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_13_64);
  (Rsp [2]) = Rvl;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_140)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_72]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_INTERFACE_0 (43);

DEFLABEL (label_72)
  (* (--Rsp)) = Rvl;
  goto label_139;

DEFLABEL (label_142)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_13_66])), (Wrd12.pObj));

DEFLABEL (label_69)
  (Wrd11.Obj) = Rvl;
  goto label_141;

DEFLABEL (label_144)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_13_56])), (Wrd15.pObj));

DEFLABEL (label_66)
  (Wrd14.Obj) = Rvl;
  goto label_143;

DEFLABEL (label_146)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_13_54])), (Wrd6.pObj));

DEFLABEL (label_65)
  (Wrd5.Obj) = Rvl;
  goto label_145;

DEFLABEL (lambda_79)
  CLOSURE_HEADER (LABEL_13_42);

DEFLABEL (lambda_37)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_59]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_150;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [1]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_149)
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [2]);
  (* (--Rsp)) = (Wrd19.Obj);
  goto lambda_17;

DEFLABEL (continuation_36)
  INTERRUPT_CHECK (27, LABEL_13_59);
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (Rsp [2]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_148;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [0]);

DEFLABEL (label_147)
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd14.Obj) = (* (Rsp++));
  (Rsp [1]) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_68]));

DEFLABEL (label_148)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_67]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_13_9]), 1);

DEFLABEL (label_70)
  (Wrd5.Obj) = Rvl;
  goto label_147;

DEFLABEL (label_150)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_60]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_13_4]), 1);

DEFLABEL (label_67)
  (* (--Rsp)) = Rvl;
  goto label_149;

DEFLABEL (lambda_80)
DEFLABEL (lambda_25)
  INTERRUPT_CHECK (26, LABEL_13_46);
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [2]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 10))
    goto label_155;
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 26))
    goto label_155;
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) (Wrd16.Lng)) < ((unsigned long) (Wrd22.Lng))))
    goto label_155;
  (Wrd6.uLng) = (OBJECT_DATUM (Wrd13.Obj));
  (Wrd11.pObj) = (& ((Wrd20.pObj) [(Wrd6.Lng)]));
  (Wrd12.Obj) = ((Wrd11.pObj) [1]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_154)
  (Wrd34.Obj) = (Rsp [0]);
  if (! ((Wrd34.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_151;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_151)
  (Wrd37.Obj) = (Rsp [1]);
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd36.Obj) = ((Wrd38.pObj) [3]);
  (Rsp [2]) = (Wrd36.Obj);
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_62]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  goto lambda_3;

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_13_62);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd8.uLng) == 26)
    goto label_153;

DEFLABEL (label_152)
  INVOKE_INTERFACE_0 (40);

DEFLABEL (label_153)
  (Wrd9.Obj) = (Rsp [1]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd10.uLng) == 26))
    goto label_152;
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd7.Obj));
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd9.Obj));
  (Wrd11.Lng) = ((Wrd13.Lng) - (Wrd15.Lng));
  if (! (LONG_TO_FIXNUM_P (Wrd11.Lng)))
    goto label_152;
  Rvl = (LONG_TO_FIXNUM (Wrd11.Lng));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_155)
  (Wrd28.Obj) = (Rsp [0]);
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd27.Obj) = ((Wrd29.pObj) [2]);
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_61]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_13_5]), 2);

DEFLABEL (label_68)
  (* (--Rsp)) = Rvl;
  goto label_154;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_14_4 3
#define LABEL_14_5 5
#define ENVIRONMENT_LABEL_14_3 12
#define DEBUGGING_LABEL_14_2 11
#define EXECUTE_CACHE_14_6 7
#define FREE_REFERENCE_14_0 10
#define FREE_REFERENCES_LABEL_14_0 6
#define NUMBER_OF_LINKER_SECTIONS_14_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
asstop_so_code_14 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_14_4);
      goto phase_info_generation_2_0;

    case 1:
      current_block = (Rpc - LABEL_14_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (phase_info_generation_2_4)
DEFLABEL (phase_info_generation_2_0)
  INTERRUPT_CHECK (26, LABEL_14_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14_0]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_6;
  Wrd7 = Wrd11;

DEFLABEL (label_5)
  (Rsp [1]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_14_5])), (Wrd8.pObj));

DEFLABEL (label_2)
  (Wrd7.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_15_4 3
#define LABEL_15_5 5
#define TAG_15_6 1
#define LABEL_15_8 7
#define LABEL_15_11 9
#define LABEL_15_13 11
#define LABEL_15_14 13
#define LABEL_15_15 15
#define LABEL_15_9 17
#define LABEL_15_16 19
#define LABEL_15_17 21
#define LABEL_15_18 23
#define LABEL_15_19 25
#define LABEL_15_20 27
#define LABEL_15_21 29
#define LABEL_15_22 31
#define LABEL_15_10 33
#define LABEL_15_27 35
#define LABEL_15_29 37
#define LABEL_15_23 39
#define LABEL_15_30 41
#define LABEL_15_24 43
#define LABEL_15_25 45
#define LABEL_15_28 47
#define LABEL_15_35 49
#define LABEL_15_32 51
#define LABEL_15_34 53
#define LABEL_15_37 55
#define LABEL_15_36 57
#define ENVIRONMENT_LABEL_15_3 95
#define DEBUGGING_LABEL_15_2 94
#define OBJECT_15_9 93
#define OBJECT_15_8 92
#define OBJECT_15_7 91
#define OBJECT_15_6 90
#define OBJECT_15_5 89
#define OBJECT_15_4 88
#define OBJECT_15_3 87
#define OBJECT_15_2 86
#define OBJECT_15_1 85
#define OBJECT_15_0 84
#define EXECUTE_CACHE_15_38 59
#define EXECUTE_CACHE_15_33 61
#define EXECUTE_CACHE_15_31 63
#define EXECUTE_CACHE_15_26 65
#define EXECUTE_CACHE_15_12 67
#define EXECUTE_CACHE_15_7 69
#define FREE_REFERENCE_15_9 72
#define FREE_REFERENCE_15_8 73
#define FREE_REFERENCE_15_7 74
#define FREE_REFERENCE_15_6 75
#define FREE_REFERENCE_15_5 76
#define FREE_REFERENCE_15_4 77
#define FREE_REFERENCE_15_3 78
#define FREE_REFERENCE_15_2 79
#define FREE_REFERENCE_15_1 80
#define FREE_REFERENCE_15_0 81
#define FREE_ASSIGNMENT_15_0 83
#define FREE_REFERENCES_LABEL_15_0 58
#define NUMBER_OF_LINKER_SECTIONS_15_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
asstop_so_code_15 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd27;
  machine_word Wrd15;
  machine_word Wrd93;
  machine_word Wrd130;
  machine_word Wrd101;
  machine_word Wrd100;
  machine_word Wrd99;
  machine_word Wrd91;
  machine_word Wrd90;
  machine_word Wrd84;
  machine_word Wrd89;
  machine_word Wrd88;
  machine_word Wrd85;
  machine_word Wrd77;
  machine_word Wrd82;
  machine_word Wrd81;
  machine_word Wrd78;
  machine_word Wrd71;
  machine_word Wrd76;
  machine_word Wrd75;
  machine_word Wrd72;
  machine_word Wrd65;
  machine_word Wrd68;
  machine_word Wrd67;
  machine_word Wrd59;
  machine_word Wrd56;
  machine_word Wrd58;
  machine_word Wrd55;
  machine_word Wrd48;
  machine_word Wrd50;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd51;
  machine_word Wrd47;
  machine_word Wrd41;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd42;
  machine_word Wrd34;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd35;
  machine_word Wrd28;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd29;
  machine_word Wrd112;
  machine_word Wrd111;
  machine_word Wrd110;
  machine_word Wrd131;
  machine_word Wrd137;
  machine_word Wrd136;
  machine_word Wrd135;
  machine_word Wrd127;
  machine_word Wrd121;
  machine_word Wrd126;
  machine_word Wrd125;
  machine_word Wrd122;
  machine_word Wrd114;
  machine_word Wrd119;
  machine_word Wrd118;
  machine_word Wrd115;
  machine_word Wrd20;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_15_4);
      goto info_generation_2_19;

    case 1:
      current_block = (Rpc - LABEL_15_5);
      goto lambda_39;

    case 2:
      current_block = (Rpc - LABEL_15_8);
      goto label_21;

    case 3:
      current_block = (Rpc - LABEL_15_11);
      goto label_22;

    case 4:
      current_block = (Rpc - LABEL_15_13);
      goto continuation_14;

    case 5:
      current_block = (Rpc - LABEL_15_14);
      goto label_32;

    case 6:
      current_block = (Rpc - LABEL_15_15);
      goto label_33;

    case 7:
      current_block = (Rpc - LABEL_15_9);
      goto continuation_4;

    case 8:
      current_block = (Rpc - LABEL_15_16);
      goto label_23;

    case 9:
      current_block = (Rpc - LABEL_15_17);
      goto label_24;

    case 10:
      current_block = (Rpc - LABEL_15_18);
      goto label_25;

    case 11:
      current_block = (Rpc - LABEL_15_19);
      goto label_26;

    case 12:
      current_block = (Rpc - LABEL_15_20);
      goto label_27;

    case 13:
      current_block = (Rpc - LABEL_15_21);
      goto label_28;

    case 14:
      current_block = (Rpc - LABEL_15_22);
      goto label_29;

    case 15:
      current_block = (Rpc - LABEL_15_10);
      goto continuation_3;

    case 16:
      current_block = (Rpc - LABEL_15_27);
      goto label_30;

    case 17:
      current_block = (Rpc - LABEL_15_29);
      goto label_31;

    case 18:
      current_block = (Rpc - LABEL_15_23);
      goto continuation_12;

    case 19:
      current_block = (Rpc - LABEL_15_30);
      goto label_34;

    case 20:
      current_block = (Rpc - LABEL_15_24);
      goto continuation_10;

    case 21:
      current_block = (Rpc - LABEL_15_25);
      goto continuation_9;

    case 22:
      current_block = (Rpc - LABEL_15_28);
      goto continuation_2;

    case 23:
      current_block = (Rpc - LABEL_15_35);
      goto label_35;

    case 24:
      current_block = (Rpc - LABEL_15_32);
      goto lambda_8;

    case 25:
      current_block = (Rpc - LABEL_15_34);
      goto continuation_1;

    case 26:
      current_block = (Rpc - LABEL_15_37);
      goto label_36;

    case 27:
      current_block = (Rpc - LABEL_15_36);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (info_generation_2_38)
DEFLABEL (info_generation_2_19)
  INTERRUPT_CHECK (26, LABEL_15_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_15_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_15_5])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_15_0]);
  (Rsp [0]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_7]));

DEFLABEL (lambda_39)
  CLOSURE_HEADER (LABEL_15_5);

DEFLABEL (lambda_18)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_77;
  Wrd5 = Wrd9;

DEFLABEL (label_76)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_9]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_10]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15_1]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_75;
  Wrd20 = Wrd24;

DEFLABEL (label_74)
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_12]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_15_10);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15_6]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_73;
  Wrd5 = Wrd9;

DEFLABEL (label_72)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_28]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15_7]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_71;
  Wrd14 = Wrd18;

DEFLABEL (label_70)
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_12]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_15_28);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_34]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15_8]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_69;
  Wrd8 = Wrd12;

DEFLABEL (label_68)
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_12]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_15_34);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_36]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15_9]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_67;
  Wrd8 = Wrd12;

DEFLABEL (label_66)
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_12]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_15_36);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_38]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_15_9);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [3]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  if ((Wrd7.Obj) == (current_block [OBJECT_15_4]))
    goto label_65;
  if ((Wrd7.Obj) == (current_block [OBJECT_15_5]))
    goto label_49;
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_13]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_23]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_24]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_25]))));
  (* (--Rsp)) = (Wrd27.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_26]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_15_25);
  (* (--Rsp)) = Rvl;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_32]))));
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_33]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_15_24);
  (Wrd9.Obj) = (Rsp [3]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_15_7]), 1);

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_15_23);
  (* (--Rsp)) = Rvl;
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15_3]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_48;
  Wrd6 = Wrd10;

DEFLABEL (label_47)
  (Wrd12.Obj) = (* (Rsp++));
  (Wrd18.Obj) = (MAKE_OBJECT (0, 4));
  (Wrd19.Obj) = (current_block [OBJECT_15_6]);
  (Wrd20.Obj) = (current_block [OBJECT_15_2]);
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd20.Obj);
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd12.Obj);
  (Wrd14.pObj) = (& (Rhp [-5]));
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd14.pObj)));
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_31]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_15_13);
  (Wrd115.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15_2]));
  (Wrd118.Obj) = ((Wrd115.pObj) [0]);
  (Wrd119.uLng) = (OBJECT_TYPE (Wrd118.Obj));
  if ((Wrd119.uLng) == 50)
    goto label_46;
  Wrd114 = Wrd118;

DEFLABEL (label_45)
  (* (--Rsp)) = (Wrd114.Obj);
  (Wrd122.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15_3]));
  (Wrd125.Obj) = ((Wrd122.pObj) [0]);
  (Wrd126.uLng) = (OBJECT_TYPE (Wrd125.Obj));
  if ((Wrd126.uLng) == 50)
    goto label_44;
  Wrd121 = Wrd125;

DEFLABEL (label_43)
  (Wrd127.Obj) = (* (Rsp++));
  (Wrd135.Obj) = (MAKE_OBJECT (0, 6));
  (Wrd136.Obj) = (current_block [OBJECT_15_1]);
  (Wrd137.Obj) = (current_block [OBJECT_15_2]);
  (* (Rhp++)) = (Wrd135.Obj);
  (* (Rhp++)) = (Wrd136.Obj);
  (* (Rhp++)) = (Wrd137.Obj);
  (* (Rhp++)) = (Wrd121.Obj);
  (Wrd131.Obj) = (current_block [OBJECT_15_3]);
  (* (Rhp++)) = (Wrd127.Obj);
  (* (Rhp++)) = (Wrd131.Obj);

DEFLABEL (label_42)
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_41)
  (Wrd130.pObj) = (& (Rhp [-7]));
  (Wrd93.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd130.pObj)));
  Rsp = (& (Rsp [1]));
  (Rsp [2]) = (Wrd93.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_44)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_15_15])), (Wrd122.pObj));

DEFLABEL (label_33)
  (Wrd121.Obj) = Rvl;
  goto label_43;

DEFLABEL (label_46)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_15_14])), (Wrd115.pObj));

DEFLABEL (label_32)
  (Wrd114.Obj) = Rvl;
  goto label_45;

DEFLABEL (label_48)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_15_30])), (Wrd7.pObj));

DEFLABEL (label_34)
  (Wrd6.Obj) = Rvl;
  goto label_47;

DEFLABEL (label_49)
  (Wrd29.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15_4]));
  (Wrd32.Obj) = ((Wrd29.pObj) [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd33.uLng) == 50)
    goto label_64;
  Wrd28 = Wrd32;

DEFLABEL (label_63)
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd35.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15_0]));
  (Wrd38.Obj) = ((Wrd35.pObj) [0]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if ((Wrd39.uLng) == 50)
    goto label_62;
  Wrd34 = Wrd38;

DEFLABEL (label_61)
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd42.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15_5]));
  (Wrd45.Obj) = ((Wrd42.pObj) [0]);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd45.Obj));
  if ((Wrd46.uLng) == 50)
    goto label_60;
  Wrd41 = Wrd45;

DEFLABEL (label_59)
  (Wrd47.Obj) = (* (Rsp++));
  (Wrd51.Obj) = ((SCHEME_OBJECT) 0);
  (Wrd53.Obj) = (MAKE_OBJECT (0, 3));
  (Wrd54.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd53.Obj);
  (* (Rhp++)) = (Wrd41.Obj);
  (* (Rhp++)) = (Wrd54.Obj);
  (* (Rhp++)) = (Wrd47.Obj);
  (Wrd50.pObj) = (& (Rhp [-4]));
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd50.pObj)));
  (Wrd55.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd48.Obj);
  (* (Rhp++)) = (Wrd55.Obj);
  (Wrd58.pObj) = (& (Rhp [-2]));
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd58.pObj)));
  (Wrd59.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_15_0]));
  (Wrd67.Obj) = ((Wrd59.pObj) [0]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if ((Wrd68.uLng) == 50)
    goto label_58;

DEFLABEL (label_57)
  ((Wrd59.pObj) [0]) = (Wrd56.Obj);

DEFLABEL (label_56)
  (Wrd72.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15_2]));
  (Wrd75.Obj) = ((Wrd72.pObj) [0]);
  (Wrd76.uLng) = (OBJECT_TYPE (Wrd75.Obj));
  if ((Wrd76.uLng) == 50)
    goto label_55;
  Wrd71 = Wrd75;

DEFLABEL (label_54)
  (* (--Rsp)) = (Wrd71.Obj);
  (Wrd78.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15_5]));
  (Wrd81.Obj) = ((Wrd78.pObj) [0]);
  (Wrd82.uLng) = (OBJECT_TYPE (Wrd81.Obj));
  if ((Wrd82.uLng) == 50)
    goto label_53;
  Wrd77 = Wrd81;

DEFLABEL (label_52)
  (* (--Rsp)) = (Wrd77.Obj);
  (Wrd85.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15_3]));
  (Wrd88.Obj) = ((Wrd85.pObj) [0]);
  (Wrd89.uLng) = (OBJECT_TYPE (Wrd88.Obj));
  if ((Wrd89.uLng) == 50)
    goto label_51;
  Wrd84 = Wrd88;

DEFLABEL (label_50)
  (Wrd90.Obj) = (* (Rsp++));
  (Wrd91.Obj) = (* (Rsp++));
  (Wrd99.Obj) = (MAKE_OBJECT (0, 6));
  (Wrd100.Obj) = (current_block [OBJECT_15_1]);
  (Wrd101.Obj) = (current_block [OBJECT_15_2]);
  (* (Rhp++)) = (Wrd99.Obj);
  (* (Rhp++)) = (Wrd100.Obj);
  (* (Rhp++)) = (Wrd101.Obj);
  (* (Rhp++)) = (Wrd84.Obj);
  (* (Rhp++)) = (Wrd91.Obj);
  (* (Rhp++)) = (Wrd90.Obj);
  goto label_42;

DEFLABEL (label_51)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_15_22])), (Wrd85.pObj));

DEFLABEL (label_29)
  (Wrd84.Obj) = Rvl;
  goto label_50;

DEFLABEL (label_53)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_15_21])), (Wrd78.pObj));

DEFLABEL (label_28)
  (Wrd77.Obj) = Rvl;
  goto label_52;

DEFLABEL (label_55)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_15_20])), (Wrd72.pObj));

DEFLABEL (label_27)
  (Wrd71.Obj) = Rvl;
  goto label_54;

DEFLABEL (label_58)
  (Wrd65.Obj) = (MAKE_OBJECT (50, (Wrd51.uLng)));
  if ((Wrd67.Obj) == (Wrd65.Obj))
    goto label_57;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_15_19])), (Wrd59.pObj), (Wrd56.Obj));

DEFLABEL (label_26)
  goto label_56;

DEFLABEL (label_60)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_15_18])), (Wrd42.pObj));

DEFLABEL (label_25)
  (Wrd41.Obj) = Rvl;
  goto label_59;

DEFLABEL (label_62)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_15_17])), (Wrd35.pObj));

DEFLABEL (label_24)
  (Wrd34.Obj) = Rvl;
  goto label_61;

DEFLABEL (label_64)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_15_16])), (Wrd29.pObj));

DEFLABEL (label_23)
  (Wrd28.Obj) = Rvl;
  goto label_63;

DEFLABEL (label_65)
  (Wrd110.Obj) = (MAKE_OBJECT (0, 6));
  (Wrd111.Obj) = (current_block [OBJECT_15_1]);
  (Wrd112.Obj) = (current_block [OBJECT_15_2]);
  (* (Rhp++)) = (Wrd110.Obj);
  (* (Rhp++)) = (Wrd111.Obj);
  (* (Rhp++)) = (Wrd112.Obj);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (* (Rhp++)) = Rvl;
  goto label_41;

DEFLABEL (label_67)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_15_37])), (Wrd9.pObj));

DEFLABEL (label_36)
  (Wrd8.Obj) = Rvl;
  goto label_66;

DEFLABEL (label_69)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_15_35])), (Wrd9.pObj));

DEFLABEL (label_35)
  (Wrd8.Obj) = Rvl;
  goto label_68;

DEFLABEL (label_71)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_15_29])), (Wrd15.pObj));

DEFLABEL (label_31)
  (Wrd14.Obj) = Rvl;
  goto label_70;

DEFLABEL (label_73)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_15_27])), (Wrd6.pObj));

DEFLABEL (label_30)
  (Wrd5.Obj) = Rvl;
  goto label_72;

DEFLABEL (label_75)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_15_11])), (Wrd21.pObj));

DEFLABEL (label_22)
  (Wrd20.Obj) = Rvl;
  goto label_74;

DEFLABEL (label_77)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_15_8])), (Wrd6.pObj));

DEFLABEL (label_21)
  (Wrd5.Obj) = Rvl;
  goto label_76;

DEFLABEL (lambda_40)
DEFLABEL (lambda_8)
  INTERRUPT_CHECK (26, LABEL_15_32);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_15_8]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_79;

DEFLABEL (label_78)
  INVOKE_PRIMITIVE ((current_block [OBJECT_15_9]), 2);

DEFLABEL (label_79)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_78;
  Rvl = ((Wrd14.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_16_4 3
#define LABEL_16_6 5
#define LABEL_16_5 7
#define LABEL_16_8 9
#define LABEL_16_9 11
#define ENVIRONMENT_LABEL_16_3 21
#define DEBUGGING_LABEL_16_2 20
#define OBJECT_16_2 19
#define OBJECT_16_1 18
#define OBJECT_16_0 17
#define EXECUTE_CACHE_16_7 13
#define FREE_REFERENCE_16_0 16
#define FREE_REFERENCES_LABEL_16_0 12
#define NUMBER_OF_LINKER_SECTIONS_16_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
asstop_so_code_16 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd21;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd7;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_16_4);
      goto recursive_compilation_results_3;

    case 1:
      current_block = (Rpc - LABEL_16_6);
      goto label_5;

    case 2:
      current_block = (Rpc - LABEL_16_5);
      goto lambda_2;

    case 3:
      current_block = (Rpc - LABEL_16_8);
      goto label_6;

    case 4:
      current_block = (Rpc - LABEL_16_9);
      goto label_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (recursive_compilation_results_9)
DEFLABEL (recursive_compilation_results_3)
  INTERRUPT_CHECK (26, LABEL_16_4);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_5]))));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_16_0]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_12;
  Wrd7 = Wrd11;

DEFLABEL (label_11)
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_7]));

DEFLABEL (label_12)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_16_6])), (Wrd8.pObj));

DEFLABEL (label_5)
  (Wrd7.Obj) = Rvl;
  goto label_11;

DEFLABEL (lambda_10)
DEFLABEL (lambda_2)
  INTERRUPT_CHECK (26, LABEL_16_5);
  (Wrd14.Obj) = (Rsp [1]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_19;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd13.Lng))))
    goto label_19;
  (Wrd7.Obj) = ((Wrd11.pObj) [1]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_18)
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_17;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd29.Lng))))
    goto label_17;
  (Wrd21.Obj) = ((Wrd27.pObj) [1]);

DEFLABEL (label_16)
  (Wrd37.Obj) = (* (Rsp++));
  (Wrd39.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  (Wrd40.Lng) = (FIXNUM_TO_LONG (Wrd37.Obj));
  if ((Wrd39.Lng) < (Wrd40.Lng))
    goto label_14;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_13;

DEFLABEL (label_14)
  Rvl = (current_block [OBJECT_16_2]);

DEFLABEL (label_13)
DEFLABEL (label_15)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_17)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.Obj) = (current_block [OBJECT_16_0]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_9]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_16_1]), 2);

DEFLABEL (label_7)
  (Wrd21.Obj) = Rvl;
  goto label_16;

DEFLABEL (label_19)
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.Obj) = (current_block [OBJECT_16_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_8]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_16_1]), 2);

DEFLABEL (label_6)
  (* (--Rsp)) = Rvl;
  goto label_18;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_17_4 3
#define ENVIRONMENT_LABEL_17_3 8
#define DEBUGGING_LABEL_17_2 7
#define EXECUTE_CACHE_17_5 5
#define FREE_REFERENCES_LABEL_17_0 4
#define NUMBER_OF_LINKER_SECTIONS_17_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
asstop_so_code_17 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_17_4);
      goto compiler_dump_inf_file_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (compiler_dump_inf_file_3)
DEFLABEL (compiler_dump_inf_file_0)
  INTERRUPT_CHECK (26, LABEL_17_4);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_18_4 3
#define LABEL_18_5 5
#define LABEL_18_7 7
#define LABEL_18_8 9
#define LABEL_18_10 11
#define ENVIRONMENT_LABEL_18_3 22
#define DEBUGGING_LABEL_18_2 21
#define OBJECT_18_1 20
#define OBJECT_18_0 19
#define EXECUTE_CACHE_18_11 13
#define EXECUTE_CACHE_18_9 15
#define EXECUTE_CACHE_18_6 17
#define FREE_REFERENCES_LABEL_18_0 12
#define NUMBER_OF_LINKER_SECTIONS_18_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
asstop_so_code_18 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_18_4);
      goto compiler_dump_bif_bsm_files_6;

    case 1:
      current_block = (Rpc - LABEL_18_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_18_7);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_18_8);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_18_10);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (compiler_dump_bif_bsm_files_9)
DEFLABEL (compiler_dump_bif_bsm_files_6)
  INTERRUPT_CHECK (26, LABEL_18_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_18_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_6]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_18_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_18_1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_18_7);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_18_8);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_18_10);
  (Wrd5.Obj) = (Rsp [0]);
  (Rsp [3]) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [2]);
  (Rsp [4]) = (Wrd6.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_11]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_19_4 3
#define LABEL_19_5 5
#define LABEL_19_7 7
#define LABEL_19_8 9
#define LABEL_19_10 11
#define ENVIRONMENT_LABEL_19_3 22
#define DEBUGGING_LABEL_19_2 21
#define OBJECT_19_1 20
#define OBJECT_19_0 19
#define EXECUTE_CACHE_19_11 13
#define EXECUTE_CACHE_19_9 15
#define EXECUTE_CACHE_19_6 17
#define FREE_REFERENCES_LABEL_19_0 12
#define NUMBER_OF_LINKER_SECTIONS_19_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
asstop_so_code_19 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_19_4);
      goto compiler_dump_bci_bcs_files_6;

    case 1:
      current_block = (Rpc - LABEL_19_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_19_7);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_19_8);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_19_10);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (compiler_dump_bci_bcs_files_9)
DEFLABEL (compiler_dump_bci_bcs_files_6)
  INTERRUPT_CHECK (26, LABEL_19_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_19_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_6]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_19_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_19_1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_19_7);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_19_8);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_19_10);
  (Wrd5.Obj) = (Rsp [0]);
  (Rsp [3]) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [2]);
  (Rsp [4]) = (Wrd6.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_11]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_20_4 3
#define LABEL_20_5 5
#define LABEL_20_7 7
#define ENVIRONMENT_LABEL_20_3 17
#define DEBUGGING_LABEL_20_2 16
#define OBJECT_20_0 15
#define EXECUTE_CACHE_20_9 9
#define EXECUTE_CACHE_20_8 11
#define EXECUTE_CACHE_20_6 13
#define FREE_REFERENCES_LABEL_20_0 8
#define NUMBER_OF_LINKER_SECTIONS_20_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
asstop_so_code_20 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_20_4);
      goto compiler_dump_bci_file_3;

    case 1:
      current_block = (Rpc - LABEL_20_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_20_7);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (compiler_dump_bci_file_6)
DEFLABEL (compiler_dump_bci_file_3)
  INTERRUPT_CHECK (26, LABEL_20_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_20_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_20_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_20_7);
  (Wrd5.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_9]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_21_4 3
#define LABEL_21_5 5
#define TAG_21_6 1
#define LABEL_21_8 7
#define ENVIRONMENT_LABEL_21_3 16
#define DEBUGGING_LABEL_21_2 15
#define EXECUTE_CACHE_21_10 9
#define EXECUTE_CACHE_21_9 11
#define EXECUTE_CACHE_21_7 13
#define FREE_REFERENCES_LABEL_21_0 8
#define NUMBER_OF_LINKER_SECTIONS_21_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
asstop_so_code_21 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_21_4);
      goto dump_compressed_2;

    case 1:
      current_block = (Rpc - LABEL_21_5);
      goto lambda_6;

    case 2:
      current_block = (Rpc - LABEL_21_8);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (dump_compressed_5)
DEFLABEL (dump_compressed_2)
  INTERRUPT_CHECK (26, LABEL_21_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_21_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_21_5])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_7]));

DEFLABEL (lambda_6)
  CLOSURE_HEADER (LABEL_21_5);

DEFLABEL (lambda_1)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_9]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_21_8);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Wrd8.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd8.Obj);
  (Rsp [1]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_10]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_22_4 3
#define ENVIRONMENT_LABEL_22_3 10
#define DEBUGGING_LABEL_22_2 9
#define OBJECT_22_1 8
#define OBJECT_22_0 7
#define EXECUTE_CACHE_22_5 5
#define FREE_REFERENCES_LABEL_22_0 4
#define NUMBER_OF_LINKER_SECTIONS_22_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
asstop_so_code_22 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_22_4);
      goto compile_data_from_file_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (compile_data_from_file_3)
DEFLABEL (compile_data_from_file_0)
  INTERRUPT_CHECK (26, LABEL_22_4);
  (Wrd5.Obj) = (current_block [OBJECT_22_0]);
  (Rsp [0]) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_22_1]);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_23_4 3
#define LABEL_23_5 5
#define TAG_23_6 1
#define LABEL_23_8 7
#define LABEL_23_9 9
#define LABEL_23_10 11
#define LABEL_23_11 13
#define LABEL_23_12 15
#define LABEL_23_13 17
#define LABEL_23_14 19
#define LABEL_23_15 21
#define LABEL_23_16 23
#define LABEL_23_17 25
#define LABEL_23_18 27
#define LABEL_23_20 29
#define LABEL_23_21 31
#define LABEL_23_22 33
#define LABEL_23_23 35
#define LABEL_23_25 37
#define LABEL_23_27 39
#define ENVIRONMENT_LABEL_23_3 68
#define DEBUGGING_LABEL_23_2 67
#define OBJECT_23_1 66
#define OBJECT_23_0 65
#define EXECUTE_CACHE_23_26 41
#define EXECUTE_CACHE_23_24 43
#define EXECUTE_CACHE_23_19 45
#define EXECUTE_CACHE_23_7 47
#define FREE_REFERENCE_23_0 50
#define FREE_ASSIGNMENT_23_12 52
#define FREE_ASSIGNMENT_23_11 53
#define FREE_ASSIGNMENT_23_10 54
#define FREE_ASSIGNMENT_23_9 55
#define FREE_ASSIGNMENT_23_8 56
#define FREE_ASSIGNMENT_23_7 57
#define FREE_ASSIGNMENT_23_6 58
#define FREE_ASSIGNMENT_23_5 59
#define FREE_ASSIGNMENT_23_4 60
#define FREE_ASSIGNMENT_23_3 61
#define FREE_ASSIGNMENT_23_2 62
#define FREE_ASSIGNMENT_23_1 63
#define FREE_ASSIGNMENT_23_0 64
#define FREE_REFERENCES_LABEL_23_0 40
#define NUMBER_OF_LINKER_SECTIONS_23_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
asstop_so_code_23 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd44;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd31;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd18;
  machine_word Wrd14;
  machine_word Wrd131;
  machine_word Wrd126;
  machine_word Wrd125;
  machine_word Wrd118;
  machine_word Wrd117;
  machine_word Wrd114;
  machine_word Wrd113;
  machine_word Wrd106;
  machine_word Wrd105;
  machine_word Wrd102;
  machine_word Wrd101;
  machine_word Wrd94;
  machine_word Wrd93;
  machine_word Wrd90;
  machine_word Wrd89;
  machine_word Wrd82;
  machine_word Wrd81;
  machine_word Wrd78;
  machine_word Wrd77;
  machine_word Wrd70;
  machine_word Wrd69;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd8;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_23_4);
      goto lap__code_4;

    case 1:
      current_block = (Rpc - LABEL_23_5);
      goto lambda_22;

    case 2:
      current_block = (Rpc - LABEL_23_8);
      goto label_6;

    case 3:
      current_block = (Rpc - LABEL_23_9);
      goto label_7;

    case 4:
      current_block = (Rpc - LABEL_23_10);
      goto label_8;

    case 5:
      current_block = (Rpc - LABEL_23_11);
      goto label_9;

    case 6:
      current_block = (Rpc - LABEL_23_12);
      goto label_10;

    case 7:
      current_block = (Rpc - LABEL_23_13);
      goto label_11;

    case 8:
      current_block = (Rpc - LABEL_23_14);
      goto label_12;

    case 9:
      current_block = (Rpc - LABEL_23_15);
      goto label_13;

    case 10:
      current_block = (Rpc - LABEL_23_16);
      goto label_14;

    case 11:
      current_block = (Rpc - LABEL_23_17);
      goto label_15;

    case 12:
      current_block = (Rpc - LABEL_23_18);
      goto continuation_0;

    case 13:
      current_block = (Rpc - LABEL_23_20);
      goto label_16;

    case 14:
      current_block = (Rpc - LABEL_23_21);
      goto label_17;

    case 15:
      current_block = (Rpc - LABEL_23_22);
      goto label_18;

    case 16:
      current_block = (Rpc - LABEL_23_23);
      goto continuation_1;

    case 17:
      current_block = (Rpc - LABEL_23_25);
      goto continuation_2;

    case 18:
      current_block = (Rpc - LABEL_23_27);
      goto label_19;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lap__code_21)
DEFLABEL (lap__code_4)
  INTERRUPT_CHECK (26, LABEL_23_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_23_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_23_5])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_7]));

DEFLABEL (lambda_22)
  CLOSURE_HEADER (LABEL_23_5);

DEFLABEL (lambda_3)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_23_0]));
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Wrd15.Obj) = ((Wrd5.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_63;

DEFLABEL (label_62)
  ((Wrd5.pObj) [0]) = (Wrd6.Obj);

DEFLABEL (label_61)
  (Wrd19.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_23_1]));
  (Wrd21.Obj) = (Rsp [0]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [3]);
  (Wrd29.Obj) = ((Wrd19.pObj) [0]);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if ((Wrd30.uLng) == 50)
    goto label_60;

DEFLABEL (label_59)
  ((Wrd19.pObj) [0]) = (Wrd20.Obj);

DEFLABEL (label_58)
  (Wrd33.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_23_2]));
  (Wrd34.Obj) = (current_block [OBJECT_23_0]);
  (Wrd41.Obj) = ((Wrd33.pObj) [0]);
  (Wrd42.uLng) = (OBJECT_TYPE (Wrd41.Obj));
  if ((Wrd42.uLng) == 50)
    goto label_57;

DEFLABEL (label_56)
  ((Wrd33.pObj) [0]) = (Wrd34.Obj);

DEFLABEL (label_55)
  (Wrd45.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_23_3]));
  (Wrd46.Obj) = (current_block [OBJECT_23_0]);
  (Wrd53.Obj) = ((Wrd45.pObj) [0]);
  (Wrd54.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if ((Wrd54.uLng) == 50)
    goto label_54;

DEFLABEL (label_53)
  ((Wrd45.pObj) [0]) = (Wrd46.Obj);

DEFLABEL (label_52)
  (Wrd57.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_23_4]));
  (Wrd58.Obj) = (current_block [OBJECT_23_1]);
  (Wrd65.Obj) = ((Wrd57.pObj) [0]);
  (Wrd66.uLng) = (OBJECT_TYPE (Wrd65.Obj));
  if ((Wrd66.uLng) == 50)
    goto label_51;

DEFLABEL (label_50)
  ((Wrd57.pObj) [0]) = (Wrd58.Obj);

DEFLABEL (label_49)
  (Wrd69.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_23_5]));
  (Wrd70.Obj) = (current_block [OBJECT_23_1]);
  (Wrd77.Obj) = ((Wrd69.pObj) [0]);
  (Wrd78.uLng) = (OBJECT_TYPE (Wrd77.Obj));
  if ((Wrd78.uLng) == 50)
    goto label_48;

DEFLABEL (label_47)
  ((Wrd69.pObj) [0]) = (Wrd70.Obj);

DEFLABEL (label_46)
  (Wrd81.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_23_6]));
  (Wrd82.Obj) = (current_block [OBJECT_23_1]);
  (Wrd89.Obj) = ((Wrd81.pObj) [0]);
  (Wrd90.uLng) = (OBJECT_TYPE (Wrd89.Obj));
  if ((Wrd90.uLng) == 50)
    goto label_45;

DEFLABEL (label_44)
  ((Wrd81.pObj) [0]) = (Wrd82.Obj);

DEFLABEL (label_43)
  (Wrd93.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_23_7]));
  (Wrd94.Obj) = (current_block [OBJECT_23_1]);
  (Wrd101.Obj) = ((Wrd93.pObj) [0]);
  (Wrd102.uLng) = (OBJECT_TYPE (Wrd101.Obj));
  if ((Wrd102.uLng) == 50)
    goto label_42;

DEFLABEL (label_41)
  ((Wrd93.pObj) [0]) = (Wrd94.Obj);

DEFLABEL (label_40)
  (Wrd105.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_23_8]));
  (Wrd106.Obj) = (current_block [OBJECT_23_1]);
  (Wrd113.Obj) = ((Wrd105.pObj) [0]);
  (Wrd114.uLng) = (OBJECT_TYPE (Wrd113.Obj));
  if ((Wrd114.uLng) == 50)
    goto label_39;

DEFLABEL (label_38)
  ((Wrd105.pObj) [0]) = (Wrd106.Obj);

DEFLABEL (label_37)
  (Wrd117.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_23_9]));
  (Wrd118.Obj) = (current_block [OBJECT_23_1]);
  (Wrd125.Obj) = ((Wrd117.pObj) [0]);
  (Wrd126.uLng) = (OBJECT_TYPE (Wrd125.Obj));
  if ((Wrd126.uLng) == 50)
    goto label_36;

DEFLABEL (label_35)
  ((Wrd117.pObj) [0]) = (Wrd118.Obj);

DEFLABEL (label_34)
  (Wrd131.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_18]))));
  (* (--Rsp)) = (Wrd131.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_19]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_23_18);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_23_10]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_33;

DEFLABEL (label_32)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_31)
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_23_11]));
  (Wrd19.Obj) = (current_block [OBJECT_23_1]);
  (Wrd26.Obj) = ((Wrd18.pObj) [0]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if ((Wrd27.uLng) == 50)
    goto label_30;

DEFLABEL (label_29)
  ((Wrd18.pObj) [0]) = (Wrd19.Obj);

DEFLABEL (label_28)
  (Wrd30.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_23_12]));
  (Wrd31.Obj) = (current_block [OBJECT_23_1]);
  (Wrd38.Obj) = ((Wrd30.pObj) [0]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if ((Wrd39.uLng) == 50)
    goto label_27;

DEFLABEL (label_26)
  ((Wrd30.pObj) [0]) = (Wrd31.Obj);

DEFLABEL (label_25)
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_23]))));
  (* (--Rsp)) = (Wrd44.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_24]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_23_23);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_25]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_26]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_23_25);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_23_0]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_24;
  Wrd6 = Wrd10;

DEFLABEL (label_23)
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_24)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_23_27])), (Wrd7.pObj));

DEFLABEL (label_19)
  (Wrd6.Obj) = Rvl;
  goto label_23;

DEFLABEL (label_27)
  if ((Wrd38.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_26;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_23_22])), (Wrd30.pObj), (Wrd31.Obj));

DEFLABEL (label_18)
  goto label_25;

DEFLABEL (label_30)
  if ((Wrd26.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_29;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_23_21])), (Wrd18.pObj), (Wrd19.Obj));

DEFLABEL (label_17)
  goto label_28;

DEFLABEL (label_33)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_32;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_23_20])), (Wrd6.pObj), Rvl);

DEFLABEL (label_16)
  goto label_31;

DEFLABEL (label_36)
  if ((Wrd125.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_35;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_23_17])), (Wrd117.pObj), (Wrd118.Obj));

DEFLABEL (label_15)
  goto label_34;

DEFLABEL (label_39)
  if ((Wrd113.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_38;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_23_16])), (Wrd105.pObj), (Wrd106.Obj));

DEFLABEL (label_14)
  goto label_37;

DEFLABEL (label_42)
  if ((Wrd101.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_41;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_23_15])), (Wrd93.pObj), (Wrd94.Obj));

DEFLABEL (label_13)
  goto label_40;

DEFLABEL (label_45)
  if ((Wrd89.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_44;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_23_14])), (Wrd81.pObj), (Wrd82.Obj));

DEFLABEL (label_12)
  goto label_43;

DEFLABEL (label_48)
  if ((Wrd77.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_47;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_23_13])), (Wrd69.pObj), (Wrd70.Obj));

DEFLABEL (label_11)
  goto label_46;

DEFLABEL (label_51)
  if ((Wrd65.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_50;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_23_12])), (Wrd57.pObj), (Wrd58.Obj));

DEFLABEL (label_10)
  goto label_49;

DEFLABEL (label_54)
  if ((Wrd53.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_53;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_23_11])), (Wrd45.pObj), (Wrd46.Obj));

DEFLABEL (label_9)
  goto label_52;

DEFLABEL (label_57)
  if ((Wrd41.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_56;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_23_10])), (Wrd33.pObj), (Wrd34.Obj));

DEFLABEL (label_8)
  goto label_55;

DEFLABEL (label_60)
  if ((Wrd29.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_59;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_23_9])), (Wrd19.pObj), (Wrd20.Obj));

DEFLABEL (label_7)
  goto label_58;

DEFLABEL (label_63)
  if ((Wrd15.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_62;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_23_8])), (Wrd5.pObj), (Wrd6.Obj));

DEFLABEL (label_6)
  goto label_61;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_24_4 3
#define ENVIRONMENT_LABEL_24_3 5
#define DEBUGGING_LABEL_24_2 4
#define FREE_REFERENCES_LABEL_24_0 4
#define NUMBER_OF_LINKER_SECTIONS_24_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
asstop_so_code_24 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_24_4);
      goto canonicalize_label_name_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (canonicalize_label_name_3)
DEFLABEL (canonicalize_label_name_0)
  INTERRUPT_CHECK (26, LABEL_24_4);
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4 3
#define LABEL_7 5
#define LABEL_6 7
#define LABEL_8 9
#define LABEL_9 11
#define LABEL_10 13
#define ENVIRONMENT_LABEL_3 28
#define DEBUGGING_LABEL_2 27
#define PURIFICATION_ROOT 26
#define OBJECT_6 25
#define OBJECT_5 24
#define OBJECT_4 23
#define OBJECT_3 22
#define OBJECT_2 21
#define OBJECT_1 20
#define OBJECT_0 19
#define FREE_REFERENCE_0 15
#define GLOBAL_EXECUTE_CACHE_5 17
#define FREE_REFERENCES_LABEL_0 14
#define NUMBER_OF_LINKER_SECTIONS_1 2

#ifndef WANT_ONLY_DATA

SCHEME_OBJECT *
asstop_so_06286df60b91c26b (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_7);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_6);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_8);
      goto label_7;

    case 4:
      current_block = (Rpc - LABEL_9);
      goto label_8;

    case 5:
      current_block = (Rpc - LABEL_10);
      goto expression_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_3)
  (current_block [ENVIRONMENT_LABEL_3]) = (Rrb [REGBLOCK_ENV]);
  INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_9])), current_block, (& (current_block [FREE_REFERENCES_LABEL_0])), NUMBER_OF_LINKER_SECTIONS_1);

DEFLABEL (label_8)
  (* (--Rsp)) = (ULONG_TO_FIXNUM (1UL));

DEFLABEL (label_7)
  {
    static const short sections [] =
      {
	0,
	0,
	3,
	1,
	1,
	1,
	1,
	1,
	1,
	2,
	3,
	2,
	3,
	3,
	2,
	1,
	3,
	3,
	2,
	2,
	0,
	0,
	1,
	1,
	1
      };
    unsigned long counter = (OBJECT_DATUM (* Rsp));
    SCHEME_OBJECT blocks;
    SCHEME_OBJECT * sub_block;
    short section;
    if (counter > 24)
      goto label_6;
    blocks = (current_block [OBJECT_6]);
    sub_block = (OBJECT_ADDRESS (MEMORY_REF (blocks, counter)));
    (sub_block [(OBJECT_DATUM (sub_block [0]))]) = (Rrb [REGBLOCK_ENV]);
    section = (sections [counter]);
    (* Rsp) = (ULONG_TO_FIXNUM (counter + 1));
    INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_8])), sub_block, (sub_block + (2 + (OBJECT_DATUM (sub_block [1])))), section);
  }

DEFLABEL (label_6)
  Rsp += 1;
  (Wrd5.Obj) = (Rrb [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_1]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_10;
  Wrd8 = Wrd12;

DEFLABEL (label_9)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_2]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3]), 3);

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_6);
  (Wrd5.Obj) = (current_block [OBJECT_4]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_5]);
  (Rsp [2]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (label_10)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_7])), (Wrd9.pObj));

DEFLABEL (label_4)
  (Wrd8.Obj) = Rvl;
  goto label_9;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

static const struct liarc_code_S arr_decl_asstop_so_06286df60b91c26b [24] =
  {
    { "asstop_so_code_1", 2, asstop_so_code_1 },
    { "asstop_so_code_2", 1, asstop_so_code_2 },
    { "asstop_so_code_3", 1, asstop_so_code_3 },
    { "asstop_so_code_4", 1, asstop_so_code_4 },
    { "asstop_so_code_5", 1, asstop_so_code_5 },
    { "asstop_so_code_6", 5, asstop_so_code_6 },
    { "asstop_so_code_7", 8, asstop_so_code_7 },
    { "asstop_so_code_8", 8, asstop_so_code_8 },
    { "asstop_so_code_9", 64, asstop_so_code_9 },
    { "asstop_so_code_10", 17, asstop_so_code_10 },
    { "asstop_so_code_11", 13, asstop_so_code_11 },
    { "asstop_so_code_12", 18, asstop_so_code_12 },
    { "asstop_so_code_13", 56, asstop_so_code_13 },
    { "asstop_so_code_14", 2, asstop_so_code_14 },
    { "asstop_so_code_15", 28, asstop_so_code_15 },
    { "asstop_so_code_16", 5, asstop_so_code_16 },
    { "asstop_so_code_17", 1, asstop_so_code_17 },
    { "asstop_so_code_18", 5, asstop_so_code_18 },
    { "asstop_so_code_19", 5, asstop_so_code_19 },
    { "asstop_so_code_20", 3, asstop_so_code_20 },
    { "asstop_so_code_21", 3, asstop_so_code_21 },
    { "asstop_so_code_22", 1, asstop_so_code_22 },
    { "asstop_so_code_23", 19, asstop_so_code_23 },
    { "asstop_so_code_24", 1, asstop_so_code_24 }
  };

int
decl_asstop_so_06286df60b91c26b (void)
{
  DECLARE_SUBCODE_MULTIPLE (arr_decl_asstop_so_06286df60b91c26b);
  return (0);
}

DECLARE_COMPILED_CODE ("asstop.so", 6, decl_asstop_so_06286df60b91c26b, asstop_so_06286df60b91c26b)

#endif /* !WANT_ONLY_DATA */

#ifndef WANT_ONLY_CODE

static const unsigned char prog_asstop_so_data_06286df60b91c26b [5391] =
  "\xb9\x01\x33\xb6\x09\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0c\x0c\x0d"
  "\x24\x22\x29\x22\x29\x21\x17\x2b\xb9\x1d\xb0\x82\x88\x07\x28\x0d"
  "\x23\x22\x29\x21\x17\x2b\xba\x1d\xb0\x83\x88\x28\x0d\x23\x22\x29"
  "\x21\x9f\x2b\xbb\x1d\xb0\x84\x88\x22\x29\x21\x9c\x2b\xbc\x1d\xb0"
  "\x85\x88\x22\x29\x21\x9c\x2b\xbd\x1d\xb0\x86\x88\x0d\xbe\x24\x28"
  "\x0d\xbf\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x0d\x1c\x24"
  "\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x1c\x28\x1b\x28\x0d\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x1d\x08\x0d\x1c\x25\x1b\x24\x28\x0d\x1c"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\x0d\x1c\x1b\x0d\x1c\x0d"
  "\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d"
  "\x1c\x0d\x1c\x0d\x1c\xb6\x25\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b"
  "\x1b\x1b\x1b\x1b\x1b\xb6\x24\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x1d\x08\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b"
  "\x1b\x1b\x1b\xb6\x25\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d"
  "\x80\x08\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x25\x28\x0d"
  "\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x0c\x0c\x0c\x0c\x1d\x0c\x1b\x1b\x1b\x25\x0d\x1c"
  "\x0d\x1b\x24\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x28\x0d\x28\x0d\x28"
  "\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xc1\xc1"
  "\x82\xc1\xc1\x0c\x80\xc2\x1c\xc1\x0c\x1d\x81\x0c\x1b\x1b\x0d\x1c"
  "\x1b\x1b\x0d\x1c\x0d\x1c\xb6\x25\x1b\x1b\x0d\x1b\x1b\x1b\x1b\x0d"
  "\x1b\x1b\x0d\x0d\x24\x28\x1b\x28\x0d\x1c\x28\x0d\x1c\x28\x1b\x28"
  "\x0d\x28\x0d\x28\x0d\x28\x0d\x1c\x28\x0d\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x0d\x24\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x1b\x81\xc1\x0d\x0d\x0d\x80\x82\x0d\x0c\x1b"
  "\x25\x1b\x1b\x0d\x0d\x1b\x0d\x1b\x0d\x0d\x0d\x24\x28\x1b\x28\x1b"
  "\x28\x0d\x1c\x28\x0d\x1c\x28\x1b\x28\x0d\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x07\x1b\x80\x1b\x24"
  "\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x28\x0d\x1c\x23\x22\x29\x21\x9f\x2b\x1c\x1d"
  "\xb0\x02\x88\x0c\x0c\x28\x0d\x1c\x28\x0d\x1c\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x0c\x0c\x28\x1b\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x28\x1b\x28"
  "\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x28\x0d\x28\x1b\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x0c\x28\x1b\x23\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x08\x80\x1b\x1b\x0d\x1b\x1b\x1b\x1b"
  "\x1b\x1b\x1b\x1b\x1b\x1b\x25\xb6\x24\x28\x0d\x28\x1b\x28\xb7\x28"
  "\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x22\x29\x21\x9c\x2b\x1c\x17\x1c\x88\x1b\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x9a\x0d\x0d\x1b\x9a\xc3\x1b\x1b\x0d\x1c\x0d\x0d\x0d\x1b\x1b\x1b"
  "\x1b\xb7\x0d\x0d\x0d\x0d\x0d\x0d\xb6\x1b\x1b\x1b\x1b\x1b\x1b\x0d"
  "\x0d\x0d\x1b\x0d\x17\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1e\x1e\x1e\x1e\x1e\x1e\x1e\xb5\x2a\xb4\x2a"
  "\xb3\x2a\xb2\x2a\xb1\x2a\x17\x28\x0d\x26\x1b\x24\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x02\x7e\x2f\x61\x66\x73"
  "\x2f\x63\x73\x61\x69\x6c\x2e\x6d\x69\x74\x2e\x65\x64\x75\x2f\x67"
  "\x72\x6f\x75\x70\x2f\x6d\x61\x63\x2f\x70\x72\x6f\x6a\x65\x63\x74"
  "\x73\x2f\x73\x63\x68\x65\x6d\x65\x2f\x76\x37\x2f\x64\x69\x73\x74"
  "\x2f\x73\x6e\x61\x70\x73\x68\x6f\x74\x2e\x70\x6b\x67\x2f\x32\x30"
  "\x30\x37\x30\x39\x30\x39\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d"
  "\x65\x2d\x63\x2d\x32\x30\x30\x37\x30\x39\x30\x39\x2f\x73\x72\x63"
  "\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2f\x62\x61\x73\x65\x2f\x61"
  "\x73\x73\x74\x6f\x70\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69"
  "\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x04"
  "\x6d\x6f\x63\x04\x63\x6f\x6d\x1a\x63\x6f\x6d\x70\x69\x6c\x65\x72"
  "\x3a\x63\x72\x6f\x73\x73\x2d\x63\x6f\x6d\x70\x69\x6c\x69\x6e\x67"
  "\x3f\x02\x08\x06\x81\x81\x02\x07\x04\x82\x02\x05\x0c\x02\x05\x08"
  "\x66\x61\x73\x64\x75\x6d\x70\x02\x09\x04\x84\x06\x03\x0a\x02\x04"
  "\x0b\x73\x63\x6f\x64\x65\x2d\x65\x76\x61\x6c\x02\x0a\x04\x84\x06"
  "\x03\x02\x0b\x04\x83\x04\x03\x02\x0c\x04\x83\x04\x03\x02\x09\x2a"
  "\x72\x65\x73\x75\x6c\x74\x2a\x02\x02\x0f\x70\x68\x61\x73\x65\x2f"
  "\x61\x73\x73\x65\x6d\x62\x6c\x65\x02\x0b\x70\x68\x61\x73\x65\x2f"
  "\x6c\x69\x6e\x6b\x09\x03\x18\x70\x68\x61\x73\x65\x2f\x69\x6e\x66"
  "\x6f\x2d\x67\x65\x6e\x65\x72\x61\x74\x69\x6f\x6e\x2d\x32\x0a\x04"
  "\x11\x0c\x81\x83\x02\x10\x0a\x81\x83\x02\x0f\x08\x81\x83\x02\x0e"
  "\x06\x81\x83\x02\x0d\x04\x83\x04\x0b\x17\x0b\x02\x08\x14\x2a\x70"
  "\x72\x6f\x63\x65\x64\x75\x72\x65\x2d\x72\x65\x73\x75\x6c\x74\x3f"
  "\x2a\x0c\x0e\x2a\x62\x6c\x6f\x63\x6b\x2d\x6c\x61\x62\x65\x6c\x2a"
  "\x0d\x03\x04\x15\x6c\x61\x70\x3a\x6d\x61\x6b\x65\x2d\x65\x6e\x74"
  "\x72\x79\x2d\x70\x6f\x69\x6e\x74\x03\x08\x75\x6e\x71\x75\x6f\x74"
  "\x65\x03\x11\x75\x6e\x71\x75\x6f\x74\x65\x2d\x73\x70\x6c\x69\x63"
  "\x69\x6e\x67\x03\x04\x6c\x61\x70\x0e\x04\x0e\x03\x0c\x65\x6e\x74"
  "\x72\x79\x2d\x70\x6f\x69\x6e\x74\x07\x19\x12\x81\x85\x02\x18\x10"
  "\x81\x8b\x02\x17\x0e\x81\x89\x02\x16\x0c\x81\x87\x02\x15\x0a\x81"
  "\x85\x02\x14\x08\x81\x89\x02\x13\x06\x81\x89\x02\x12\x04\x84\x06"
  "\x11\x24\x0e\x02\x09\x02\x20\x2a\x72\x65\x63\x75\x72\x73\x69\x76"
  "\x65\x2d\x63\x6f\x6d\x70\x69\x6c\x61\x74\x69\x6f\x6e\x2d\x72\x65"
  "\x73\x75\x6c\x74\x73\x2a\x0f\x02\x0f\x02\x05\x13\x73\x68\x61\x6c"
  "\x6c\x6f\x77\x2d\x66\x6c\x75\x69\x64\x2d\x62\x69\x6e\x64\x10\x02"
  "\x21\x12\x81\x87\x02\x20\x10\x81\x85\x02\x1f\x0e\x81\x83\x02\x1e"
  "\x0c\x81\x83\x02\x1d\x0a\x81\x87\x02\x1c\x08\x81\x85\x02\x1b\x06"
  "\x81\x83\x02\x1a\x04\x83\x04\x11\x1d\x11\x02\x0a\x02\x15\x2a\x62"
  "\x6c\x6f\x63\x6b\x2d\x61\x73\x73\x6f\x63\x69\x61\x74\x69\x6f\x6e"
  "\x73\x2a\x12\x0d\x12\x2a\x65\x78\x74\x65\x72\x6e\x61\x6c\x2d\x6c"
  "\x61\x62\x65\x6c\x73\x2a\x13\x14\x2a\x65\x6e\x64\x2d\x6f\x66\x2d"
  "\x62\x6c\x6f\x63\x6b\x2d\x63\x6f\x64\x65\x2a\x14\x10\x2a\x6e\x65"
  "\x78\x74\x2d\x63\x6f\x6e\x73\x74\x61\x6e\x74\x2a\x15\x17\x2a\x69"
  "\x6e\x74\x65\x72\x6e\x65\x64\x2d\x61\x73\x73\x69\x67\x6e\x6d\x65"
  "\x6e\x74\x73\x2a\x16\x15\x2a\x69\x6e\x74\x65\x72\x6e\x65\x64\x2d"
  "\x63\x6f\x6e\x73\x74\x61\x6e\x74\x73\x2a\x17\x18\x2a\x69\x6e\x74"
  "\x65\x72\x6e\x65\x64\x2d\x67\x6c\x6f\x62\x61\x6c\x2d\x6c\x69\x6e"
  "\x6b\x73\x2a\x18\x1c\x2a\x69\x6e\x74\x65\x72\x6e\x65\x64\x2d\x73"
  "\x74\x61\x74\x69\x63\x2d\x76\x61\x72\x69\x61\x62\x6c\x65\x73\x2a"
  "\x19\x15\x2a\x69\x6e\x74\x65\x72\x6e\x65\x64\x2d\x75\x75\x6f\x2d"
  "\x6c\x69\x6e\x6b\x73\x2a\x1a\x15\x2a\x69\x6e\x74\x65\x72\x6e\x65"
  "\x64\x2d\x76\x61\x72\x69\x61\x62\x6c\x65\x73\x2a\x1b\x11\x2a\x6c"
  "\x61\x62\x65\x6c\x2d\x62\x69\x6e\x64\x69\x6e\x67\x73\x2a\x1c\x0e"
  "\x2a\x63\x6f\x64\x65\x2d\x76\x65\x63\x74\x6f\x72\x2a\x1d\x0f\x2a"
  "\x65\x6e\x74\x72\x79\x2d\x70\x6f\x69\x6e\x74\x73\x2a\x1e\x10\x12"
  "\x0d\x13\x14\x15\x16\x17\x18\x19\x1a\x1b\x1c\x1d\x1e\x10\x05\x10"
  "\x02\x61\x82\x01\x81\x87\x02\x60\x80\x01\x81\x85\x02\x5f\x7e\x81"
  "\x87\x02\x5e\x7c\x81\x85\x02\x5d\x7a\x81\x87\x02\x5c\x78\x81\x85"
  "\x02\x5b\x76\x81\x87\x02\x5a\x74\x81\x85\x02\x59\x72\x81\x87\x02"
  "\x58\x70\x81\x85\x02\x57\x6e\x81\x87\x02\x56\x6c\x81\x85\x02\x55"
  "\x6a\x81\x87\x02\x54\x68\x81\x85\x02\x53\x66\x81\x87\x02\x52\x64"
  "\x81\x85\x02\x51\x62\x81\x87\x02\x50\x60\x81\x85\x02\x4f\x5e\x81"
  "\x87\x02\x4e\x5c\x81\x85\x02\x4d\x5a\x81\x87\x02\x4c\x58\x81\x85"
  "\x02\x4b\x56\x81\x87\x02\x4a\x54\x81\x85\x02\x49\x52\x81\x87\x02"
  "\x48\x50\x81\x85\x02\x47\x4e\x81\x87\x02\x46\x4c\x81\x85\x02\x45"
  "\x4a\x81\x87\x02\x44\x48\x81\x85\x02\x43\x46\x81\x83\x02\x42\x44"
  "\x81\x83\x02\x41\x42\x81\x87\x02\x40\x40\x81\x85\x02\x3f\x3e\x81"
  "\x87\x02\x3e\x3c\x81\x85\x02\x3d\x3a\x81\x87\x02\x3c\x38\x81\x85"
  "\x02\x3b\x36\x81\x87\x02\x3a\x34\x81\x85\x02\x39\x32\x81\x87\x02"
  "\x38\x30\x81\x85\x02\x37\x2e\x81\x87\x02\x36\x2c\x81\x85\x02\x35"
  "\x2a\x81\x87\x02\x34\x28\x81\x85\x02\x33\x26\x81\x87\x02\x32\x24"
  "\x81\x85\x02\x31\x22\x81\x87\x02\x30\x20\x81\x85\x02\x2f\x1e\x81"
  "\x87\x02\x2e\x1c\x81\x85\x02\x2d\x1a\x81\x87\x02\x2c\x18\x81\x85"
  "\x02\x2b\x16\x81\x87\x02\x2a\x14\x81\x85\x02\x29\x12\x81\x87\x02"
  "\x28\x10\x81\x85\x02\x27\x0e\x81\x87\x02\x26\x0c\x81\x85\x02\x25"
  "\x0a\x81\x87\x02\x24\x08\x81\x85\x02\x23\x06\x81\x83\x02\x22\x04"
  "\x83\x04\x81\x01\xa8\x01\x10\x02\x0b\x02\x0f\x12\x0d\x13\x14\x15"
  "\x16\x17\x18\x19\x1a\x1b\x1c\x1d\x1e\x11\x72\x24\x81\x81\x02\x71"
  "\x22\x81\x81\x02\x70\x20\x81\x81\x02\x6f\x1e\x81\x81\x02\x6e\x1c"
  "\x81\x81\x02\x6d\x1a\x81\x81\x02\x6c\x18\x81\x81\x02\x6b\x16\x81"
  "\x81\x02\x6a\x14\x81\x81\x02\x69\x12\x81\x81\x02\x68\x10\x81\x81"
  "\x02\x67\x0e\x81\x81\x02\x66\x0c\x81\x81\x02\x65\x0a\x81\x81\x02"
  "\x64\x08\x81\x81\x02\x63\x06\x81\x81\x02\x62\x04\x82\x02\x23\x39"
  "\x1f\x02\x0c\x02\x12\x0d\x13\x14\x15\x16\x17\x18\x19\x1a\x1b\x0c"
  "\x02\x0f\x67\x65\x6e\x65\x72\x61\x74\x65\x2d\x6c\x61\x62\x65\x6c"
  "\x14\x02\x7f\x1c\x81\x81\x02\x7e\x1a\x81\x81\x02\x7d\x18\x81\x81"
  "\x02\x7c\x16\x81\x81\x02\x7b\x14\x81\x81\x02\x7a\x12\x81\x81\x02"
  "\x79\x10\x81\x81\x02\x78\x0e\x81\x81\x02\x77\x0c\x81\x81\x02\x76"
  "\x0a\x81\x81\x02\x75\x08\x81\x81\x02\x74\x06\x81\x81\x02\x73\x04"
  "\x82\x02\x1b\x30\x12\x02\x0d\x02\x73\x02\x2e\x0b\x20\x69\x74\x65"
  "\x72\x61\x74\x69\x6f\x6e\x1b\x42\x72\x61\x6e\x63\x68\x20\x74\x65"
  "\x6e\x73\x69\x6f\x6e\x69\x6e\x67\x20\x64\x6f\x6e\x65\x20\x69\x6e"
  "\x20\x02\x09\x41\x73\x73\x65\x6d\x62\x6c\x79\x1d\x1e\x1c\x04\x06"
  "\x2a\x6c\x61\x70\x2a\x20\x16\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a"
  "\x73\x68\x6f\x77\x2d\x70\x68\x61\x73\x65\x73\x3f\x0d\x04\x04\x0f"
  "\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2d\x70\x68\x61\x73\x65\x21\x03"
  "\x0f\x6c\x61\x73\x74\x2d\x72\x65\x66\x65\x72\x65\x6e\x63\x65\x22"
  "\x03\x18\x77\x72\x69\x74\x65\x2d\x6e\x6f\x74\x69\x66\x69\x63\x61"
  "\x74\x69\x6f\x6e\x2d\x6c\x69\x6e\x65\x04\x09\x61\x73\x73\x65\x6d"
  "\x62\x6c\x65\x04\x0d\x77\x72\x69\x74\x65\x2d\x73\x74\x72\x69\x6e"
  "\x67\x04\x06\x77\x72\x69\x74\x65\x07\x91\x01\x26\x81\x85\x02\x90"
  "\x01\x24\x81\x85\x02\x8f\x01\x22\x81\x85\x02\x8e\x01\x20\x81\x85"
  "\x02\x8d\x01\x1e\x81\x89\x02\x8c\x01\x1c\x81\x85\x02\x8b\x01\x1a"
  "\x81\x85\x02\x8a\x01\x18\x81\x87\x02\x89\x01\x16\x81\x85\x02\x88"
  "\x01\x14\x81\x83\x02\x87\x01\x12\x81\x89\x02\x86\x01\x10\x81\x89"
  "\x02\x85\x01\x0e\x81\x89\x02\x84\x01\x0c\x81\x89\x02\x83\x01\x0a"
  "\x86\x0a\x82\x01\x08\x81\x87\x02\x81\x01\x06\x82\x02\x80\x01\x04"
  "\x82\x02\x25\x43\x23\x02\x0e\x18\x6d\x61\x6b\x65\x2d\x6e\x6f\x6e"
  "\x2d\x70\x6f\x69\x6e\x74\x65\x72\x2d\x6f\x62\x6a\x65\x63\x74\x1d"
  "\x63\x6f\x6d\x70\x69\x6c\x65\x64\x2d\x63\x6f\x64\x65\x2d\x61\x64"
  "\x64\x72\x65\x73\x73\x2d\x3e\x62\x6c\x6f\x63\x6b\x04\x63\x61\x72"
  "\x0d\x6f\x62\x6a\x65\x63\x74\x2d\x64\x61\x74\x75\x6d\x14\x4d\x69"
  "\x73\x73\x69\x6e\x67\x20\x65\x6e\x74\x72\x79\x20\x70\x6f\x69\x6e"
  "\x74\x0b\x76\x65\x63\x74\x6f\x72\x2d\x72\x65\x66\x24\x04\x63\x64"
  "\x72\x21\x4c\x61\x62\x65\x6c\x20\x6e\x6f\x74\x20\x64\x65\x66\x69"
  "\x6e\x65\x64\x20\x61\x73\x20\x65\x6e\x74\x72\x79\x20\x70\x6f\x69"
  "\x6e\x74\x02\x0e\x4c\x69\x6e\x6b\x69\x66\x69\x63\x61\x74\x69\x6f"
  "\x6e\x1d\x1e\x1c\x2a\x73\x75\x62\x70\x72\x6f\x63\x65\x64\x75\x72"
  "\x65\x2d\x6c\x69\x6e\x6b\x69\x6e\x67\x2d\x69\x6e\x66\x6f\x2a\x25"
  "\x1c\x0d\x0e\x2a\x65\x6e\x74\x72\x79\x2d\x6c\x61\x62\x65\x6c\x2a"
  "\x26\x17\x2a\x69\x63\x2d\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x2d"
  "\x68\x65\x61\x64\x65\x72\x73\x2a\x27\x09\x1e\x1d\x1c\x64\x65\x63"
  "\x6c\x61\x72\x65\x2d\x63\x6f\x6d\x70\x69\x6c\x65\x64\x2d\x63\x6f"
  "\x64\x65\x2d\x62\x6c\x6f\x63\x6b\x0c\x26\x25\x0d\x23\x63\x6f\x6d"
  "\x70\x69\x6c\x65\x72\x3a\x70\x72\x65\x73\x65\x72\x76\x65\x2d\x64"
  "\x61\x74\x61\x2d\x73\x74\x72\x75\x63\x74\x75\x72\x65\x73\x3f\x27"
  "\x1c\x19\x74\x79\x70\x65\x2d\x63\x6f\x64\x65\x3a\x63\x6f\x6d\x70"
  "\x69\x6c\x65\x64\x2d\x65\x6e\x74\x72\x79\x1a\x70\x72\x69\x6d\x69"
  "\x74\x69\x76\x65\x2d\x6f\x62\x6a\x65\x63\x74\x2d\x73\x65\x74\x2d"
  "\x74\x79\x70\x65\x0d\x04\x21\x04\x04\x6d\x61\x70\x25\x04\x10\x75"
  "\x63\x6f\x64\x65\x2d\x70\x72\x69\x6d\x69\x74\x69\x76\x65\x0c\x03"
  "\x0c\x03\x1e\x77\x69\x74\x68\x2d\x61\x62\x73\x6f\x6c\x75\x74\x65"
  "\x6c\x79\x2d\x6e\x6f\x2d\x69\x6e\x74\x65\x72\x72\x75\x70\x74\x73"
  "\x04\x05\x61\x73\x73\x71\x04\x09\x66\x6f\x72\x2d\x65\x61\x63\x68"
  "\x04\x06\x65\x72\x72\x6f\x72\x0c\x04\x11\x73\x65\x74\x2d\x6c\x61"
  "\x6d\x62\x64\x61\x2d\x62\x6f\x64\x79\x21\x0a\xc9\x01\x72\x81\x89"
  "\x02\xc8\x01\x70\x81\x8b\x02\xc7\x01\x6e\x81\x8b\x02\xc6\x01\x6c"
  "\x81\x89\x02\xc5\x01\x6a\x81\x89\x02\xc4\x01\x68\x81\x87\x02\xc3"
  "\x01\x66\x81\x87\x02\xc2\x01\x64\x81\x87\x02\xc1\x01\x62\x81\x87"
  "\x02\xc0\x01\x60\x81\x85\x02\xbf\x01\x5e\x81\x8b\x02\xbe\x01\x5c"
  "\x81\x85\x02\xbd\x01\x5a\x81\x83\x02\xbc\x01\x58\x81\x85\x02\xbb"
  "\x01\x56\x81\x85\x02\xba\x01\x54\x81\x85\x02\xb9\x01\x52\x81\x85"
  "\x02\xb8\x01\x50\x81\x87\x02\xb7\x01\x4e\x81\x85\x02\xb6\x01\x4c"
  "\x81\x85\x02\xb5\x01\x4a\x81\x87\x02\xb4\x01\x48\x81\x87\x02\xb3"
  "\x01\x46\x81\x83\x02\xb2\x01\x44\x81\x83\x02\xb1\x01\x42\x81\x83"
  "\x02\xb0\x01\x40\x81\x87\x02\xaf\x01\x3e\x81\x83\x02\xae\x01\x3c"
  "\x81\x87\x02\xad\x01\x3a\x81\x83\x02\xac\x01\x38\x81\x85\x02\xab"
  "\x01\x36\x81\x83\x02\xaa\x01\x34\x81\x83\x02\xa9\x01\x32\x81\x8d"
  "\x02\xa8\x01\x30\x81\x85\x02\xa7\x01\x2e\x81\x85\x02\xa6\x01\x2c"
  "\x81\x81\x02\xa5\x01\x2a\x81\x81\x02\xa4\x01\x28\x81\x81\x02\xa3"
  "\x01\x26\x81\x81\x02\xa2\x01\x24\x81\x81\x02\xa1\x01\x22\x81\x81"
  "\x02\xa0\x01\x20\x81\x81\x02\x9f\x01\x1e\x81\x81\x02\x9e\x01\x1c"
  "\x81\x81\x02\x9d\x01\x1a\x83\x04\x9c\x01\x18\x81\x85\x02\x9b\x01"
  "\x16\x81\x85\x02\x9a\x01\x14\x81\x85\x02\x99\x01\x12\x81\x85\x02"
  "\x98\x01\x10\x81\x81\x02\x97\x01\x0e\x81\x89\x02\x96\x01\x0c\x81"
  "\x83\x02\x95\x01\x0a\x81\x81\x02\x94\x01\x08\x81\x83\x02\x93\x01"
  "\x06\x82\x02\x92\x01\x04\x82\x02\x71\xaa\x01\x28\x02\x0f\x28\x73"
  "\x65\x74\x2d\x63\x6f\x6d\x70\x69\x6c\x65\x64\x2d\x63\x6f\x64\x65"
  "\x2d\x62\x6c\x6f\x63\x6b\x2f\x64\x65\x62\x75\x67\x67\x69\x6e\x67"
  "\x2d\x69\x6e\x66\x6f\x21\x02\x04\x12\x69\x6e\x66\x6f\x2d\x67\x65"
  "\x6e\x65\x72\x61\x74\x69\x6f\x6e\x2d\x32\x29\x02\xcb\x01\x06\x81"
  "\x85\x02\xca\x01\x04\x83\x04\x05\x0d\x2a\x02\x10\x24\x0d\x6c\x69"
  "\x73\x74\x2d\x3e\x76\x65\x63\x74\x6f\x72\x17\x64\x65\x62\x75\x67"
  "\x67\x69\x6e\x67\x2d\x66\x69\x6c\x65\x2d\x77\x72\x61\x70\x70\x65"
  "\x72\x0a\x72\x65\x63\x75\x72\x73\x69\x76\x65\x05\x6b\x65\x65\x70"
  "\x17\x64\x65\x62\x75\x67\x67\x69\x6e\x67\x2d\x69\x6e\x66\x6f\x2d"
  "\x77\x72\x61\x70\x70\x65\x72\x21\x44\x65\x62\x75\x67\x67\x69\x6e"
  "\x67\x20\x49\x6e\x66\x6f\x72\x6d\x61\x74\x69\x6f\x6e\x20\x47\x65"
  "\x6e\x65\x72\x61\x74\x69\x6f\x6e\x0f\x02\x1d\x13\x17\x2a\x69\x6e"
  "\x66\x6f\x2d\x6f\x75\x74\x70\x75\x74\x2d\x66\x69\x6c\x65\x6e\x61"
  "\x6d\x65\x2a\x10\x2a\x64\x65\x62\x75\x67\x67\x69\x6e\x67\x2d\x6b"
  "\x65\x79\x2a\x0f\x1f\x2a\x72\x65\x63\x75\x72\x73\x69\x76\x65\x2d"
  "\x63\x6f\x6d\x70\x69\x6c\x61\x74\x69\x6f\x6e\x2d\x6e\x75\x6d\x62"
  "\x65\x72\x2a\x1c\x14\x2a\x64\x62\x67\x2d\x63\x6f\x6e\x74\x69\x6e"
  "\x75\x61\x74\x69\x6f\x6e\x73\x2a\x11\x2a\x64\x62\x67\x2d\x70\x72"
  "\x6f\x63\x65\x64\x75\x72\x65\x73\x2a\x11\x2a\x64\x62\x67\x2d\x65"
  "\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x2a\x0b\x04\x21\x03\x22\x02"
  "\x1e\x72\x65\x63\x75\x72\x73\x69\x76\x65\x2d\x63\x6f\x6d\x70\x69"
  "\x6c\x61\x74\x69\x6f\x6e\x2d\x72\x65\x73\x75\x6c\x74\x73\x22\x04"
  "\x18\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x64\x75\x6d\x70\x2d\x69"
  "\x6e\x66\x6f\x2d\x66\x69\x6c\x65\x21\x04\x25\x07\x18\x69\x6e\x66"
  "\x6f\x2d\x67\x65\x6e\x65\x72\x61\x74\x69\x6f\x6e\x2d\x70\x68\x61"
  "\x73\x65\x2d\x33\x07\xe7\x01\x3a\x81\x91\x02\xe6\x01\x38\x81\x93"
  "\x02\xe5\x01\x36\x81\x8f\x02\xe4\x01\x34\x83\x04\xe3\x01\x32\x81"
  "\x91\x02\xe2\x01\x30\x81\x8d\x02\xe1\x01\x2e\x81\x91\x02\xe0\x01"
  "\x2c\x81\x8f\x02\xdf\x01\x2a\x81\x8f\x02\xde\x01\x28\x81\x8d\x02"
  "\xdd\x01\x26\x81\x8f\x02\xdc\x01\x24\x81\x8b\x02\xdb\x01\x22\x81"
  "\x89\x02\xda\x01\x20\x81\x8d\x02\xd9\x01\x1e\x81\x8b\x02\xd8\x01"
  "\x1c\x81\x89\x02\xd7\x01\x1a\x81\x89\x02\xd6\x01\x18\x81\x8d\x02"
  "\xd5\x01\x16\x81\x8b\x02\xd4\x01\x14\x81\x89\x02\xd3\x01\x12\x81"
  "\x87\x02\xd2\x01\x10\x81\x8b\x02\xd1\x01\x0e\x81\x89\x02\xd0\x01"
  "\x0c\x81\x89\x02\xcf\x01\x0a\x81\x8b\x02\xce\x01\x08\x81\x83\x02"
  "\xcd\x01\x06\x81\x83\x02\xcc\x01\x04\x84\x06\x39\x60\x25\x02\x11"
  "\x24\x0f\x02\x04\x05\x73\x6f\x72\x74\x02\xec\x01\x0c\x81\x87\x02"
  "\xeb\x01\x0a\x81\x85\x02\xea\x01\x08\x84\x06\xe9\x01\x06\x81\x83"
  "\x02\xe8\x01\x04\x82\x02\x0b\x16\x24\x02\x12\x04\x15\x63\x6f\x6d"
  "\x70\x69\x6c\x65\x72\x2d\x66\x69\x6c\x65\x2d\x6f\x75\x74\x70\x75"
  "\x74\x2b\x02\xed\x01\x04\x84\x06\x03\x2c\x02\x13\x04\x62\x69\x66"
  "\x04\x62\x73\x6d\x04\x12\x70\x61\x74\x68\x6e\x61\x6d\x65\x2d\x6e"
  "\x65\x77\x2d\x74\x79\x70\x65\x2d\x04\x15\x73\x70\x6c\x69\x74\x2d"
  "\x69\x6e\x66\x2d\x73\x74\x72\x75\x63\x74\x75\x72\x65\x21\x2e\x04"
  "\x2b\x04\xf2\x01\x0c\x81\x8b\x02\xf1\x01\x0a\x81\x89\x02\xf0\x01"
  "\x08\x81\x87\x02\xef\x01\x06\x81\x85\x02\xee\x01\x04\x84\x06\x0b"
  "\x17\x2f\x02\x14\x04\x62\x63\x69\x04\x62\x63\x73\x04\x2d\x04\x2e"
  "\x04\x10\x64\x75\x6d\x70\x2d\x63\x6f\x6d\x70\x72\x65\x73\x73\x65"
  "\x64\x30\x04\xf7\x01\x0c\x81\x8b\x02\xf6\x01\x0a\x81\x89\x02\xf5"
  "\x01\x08\x81\x87\x02\xf4\x01\x06\x81\x85\x02\xf3\x01\x04\x84\x06"
  "\x0b\x17\x31\x02\x15\x04\x62\x63\x69\x04\x2d\x04\x2e\x04\x30\x04"
  "\xfa\x01\x08\x81\x87\x02\xf9\x01\x06\x81\x85\x02\xf8\x01\x04\x84"
  "\x06\x07\x12\x2e\x02\x16\x03\x1d\x63\x61\x6c\x6c\x2d\x77\x69\x74"
  "\x68\x2d\x74\x65\x6d\x70\x6f\x72\x61\x72\x79\x2d\x66\x69\x6c\x65"
  "\x6e\x61\x6d\x65\x04\x2b\x04\x09\x63\x6f\x6d\x70\x72\x65\x73\x73"
  "\x04\xfd\x01\x08\x81\x85\x02\xfc\x01\x06\x81\x85\x02\xfb\x01\x04"
  "\x84\x06\x07\x11\x2d\x02\x17\x17\x63\x6f\x6d\x70\x69\x6c\x65\x2d"
  "\x64\x61\x74\x61\x2d\x66\x72\x6f\x6d\x2d\x66\x69\x6c\x65\x32\x13"
  "\x49\x6c\x6c\x65\x67\x61\x6c\x20\x6f\x70\x65\x72\x61\x74\x69\x6f"
  "\x6e\x3a\x04\x0c\x02\xfe\x01\x04\x84\x06\x03\x0b\x0c\x02\x18\x20"
  "\x26\x17\x2a\x63\x75\x72\x72\x65\x6e\x74\x2d\x6c\x61\x62\x65\x6c"
  "\x2d\x6e\x75\x6d\x62\x65\x72\x2a\x15\x16\x17\x18\x19\x1a\x1b\x0d"
  "\x13\x27\x0e\x02\x03\x0c\x69\x6e\x2d\x63\x6f\x6d\x70\x69\x6c\x65"
  "\x72\x02\x14\x02\x02\x09\x05\x91\x02\x28\x81\x83\x02\x90\x02\x26"
  "\x81\x83\x02\x8f\x02\x24\x81\x83\x02\x8e\x02\x22\x81\x83\x02\x8d"
  "\x02\x20\x81\x83\x02\x8c\x02\x1e\x81\x83\x02\x8b\x02\x1c\x81\x83"
  "\x02\x8a\x02\x1a\x81\x83\x02\x89\x02\x18\x81\x83\x02\x88\x02\x16"
  "\x81\x83\x02\x87\x02\x14\x81\x83\x02\x86\x02\x12\x81\x83\x02\x85"
  "\x02\x10\x81\x83\x02\x84\x02\x0e\x81\x83\x02\x83\x02\x0c\x81\x83"
  "\x02\x82\x02\x0a\x81\x83\x02\x81\x02\x08\x81\x83\x02\x80\x02\x06"
  "\x81\x83\x02\xff\x01\x04\x84\x06\x27\x45\x27\x02\x19\x92\x02\x04"
  "\x83\x04\x03\x26\x19\x20\x20\x26\x04\x27\x04\x0c\x04\x18\x63\x61"
  "\x6e\x6f\x6e\x69\x63\x61\x6c\x69\x7a\x65\x2d\x6c\x61\x62\x65\x6c"
  "\x2d\x6e\x61\x6d\x65\x0a\x6c\x61\x70\x2d\x3e\x63\x6f\x64\x65\x32"
  "\x11\x6c\x6f\x63\x61\x6c\x2d\x61\x73\x73\x69\x67\x6e\x6d\x65\x6e"
  "\x74\x21\x30\x17\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x64\x75\x6d"
  "\x70\x2d\x62\x63\x69\x2d\x66\x69\x6c\x65\x32\x1c\x63\x6f\x6d\x70"
  "\x69\x6c\x65\x72\x3a\x64\x75\x6d\x70\x2d\x62\x63\x69\x2f\x62\x63"
  "\x73\x2d\x66\x69\x6c\x65\x73\x1c\x63\x6f\x6d\x70\x69\x6c\x65\x72"
  "\x3a\x64\x75\x6d\x70\x2d\x62\x69\x66\x2f\x62\x73\x6d\x2d\x66\x69"
  "\x6c\x65\x73\x17\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x64\x75\x6d"
  "\x70\x2d\x69\x6e\x66\x2d\x66\x69\x6c\x65\x22\x29\x0a\x09\x15\x69"
  "\x6e\x69\x74\x69\x61\x6c\x69\x7a\x65\x2d\x62\x61\x63\x6b\x2d\x65"
  "\x6e\x64\x21\x18\x61\x73\x73\x65\x6d\x62\x6c\x65\x72\x26\x6c\x69"
  "\x6e\x6b\x65\x72\x2d\x72\x65\x73\x65\x74\x21\x20\x62\x69\x6e\x64"
  "\x2d\x61\x73\x73\x65\x6d\x62\x6c\x65\x72\x26\x6c\x69\x6e\x6b\x65"
  "\x72\x2d\x76\x61\x72\x69\x61\x62\x6c\x65\x73\x2a\x62\x69\x6e\x64"
  "\x2d\x61\x73\x73\x65\x6d\x62\x6c\x65\x72\x26\x6c\x69\x6e\x6b\x65"
  "\x72\x2d\x74\x6f\x70\x2d\x6c\x65\x76\x65\x6c\x2d\x76\x61\x72\x69"
  "\x61\x62\x6c\x65\x73\x09\x77\x72\x61\x70\x2d\x6c\x61\x70\x0e\x61"
  "\x73\x73\x65\x6d\x62\x6c\x65\x26\x6c\x69\x6e\x6b\x1e\x1d\x1c\x13"
  "\x0d\x0f\x1c\x63\x6f\x6d\x70\x69\x6c\x65\x2d\x73\x63\x6f\x64\x65"
  "\x2f\x69\x6e\x74\x65\x72\x6e\x61\x6c\x2f\x68\x6f\x6f\x6b\x25\x63"
  "\x6f\x6d\x70\x69\x6c\x65\x72\x2d\x6f\x75\x74\x70\x75\x74\x2d\x3e"
  "\x63\x6f\x6d\x70\x69\x6c\x65\x64\x2d\x65\x78\x70\x72\x65\x73\x73"
  "\x69\x6f\x6e\x1b\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2d\x6f\x75\x74"
  "\x70\x75\x74\x2d\x3e\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x2b\x25"
  "\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x63\x6f\x6d\x70\x69\x6c\x65"
  "\x64\x2d\x63\x6f\x64\x65\x2d\x70\x61\x74\x68\x6e\x61\x6d\x65\x2d"
  "\x74\x79\x70\x65\x1d\x2d\x04\x2e\x04\x31\x04\x2f\x04\x2c\x04\x24"
  "\x04\x25\x04\x2a\x04\x28\x04\x23\x04\x12\x04\x1f\x04\x10\x04\x11"
  "\x04\x0e\x04\x0b\x04\x04\x04\x04\x04\x04\x1d\x05\x10\x64\x65\x66"
  "\x69\x6e\x65\x2d\x6d\x75\x6c\x74\x69\x70\x6c\x65\x02\x32\x02\x06"
  "\x0e\x80\x80\x04\x05\x0c\x81\x81\x02\x04\x0a\x81\x81\x02\x03\x08"
  "\x81\x83\x02\x02\x06\x81\x85\x02\x01\x04\x81\x83\x02\x0d\x1d";

SCHEME_OBJECT *
asstop_so_data_06286df60b91c26b (entry_count_t dispatch_base)
{
  SCHEME_OBJECT ccb;
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES_FOR_DATA ();

  ccb = (unstackify (((unsigned char *) (& (prog_asstop_so_data_06286df60b91c26b [0]))), (sizeof (prog_asstop_so_data_06286df60b91c26b)), dispatch_base));
  current_block = (OBJECT_ADDRESS (ccb));
  return (& (current_block [LABEL_10]));
}

DECLARE_COMPILED_DATA_NS ("asstop.so", asstop_so_data_06286df60b91c26b)

#endif /* !WANT_ONLY_CODE */

DECLARE_DYNAMIC_INITIALIZATION ("asstop.so", "00d7c9423676dafb")
