/* Emacs: this is -*- C -*- code, */
/* generated 2007-09-09T13:50:10-0400 by Liar version UNKNOWN. */

#include "liarc.h"

#define LABEL_1_4 3
#define LABEL_1_5 5
#define LABEL_1_7 7
#define TAG_1_8 2
#define LABEL_1_14 9
#define LABEL_1_15 11
#define LABEL_1_9 13
#define TAG_1_10 5
#define LABEL_1_16 15
#define LABEL_1_17 17
#define LABEL_1_11 19
#define TAG_1_12 8
#define LABEL_1_18 21
#define LABEL_1_19 23
#define ENVIRONMENT_LABEL_1_3 38
#define DEBUGGING_LABEL_1_2 37
#define OBJECT_1_2 36
#define OBJECT_1_1 35
#define OBJECT_1_0 34
#define EXECUTE_CACHE_1_13 25
#define EXECUTE_CACHE_1_6 27
#define FREE_REFERENCE_1_1 30
#define FREE_REFERENCE_1_0 31
#define FREE_ASSIGNMENT_1_0 33
#define FREE_REFERENCES_LABEL_1_0 24
#define NUMBER_OF_LINKER_SECTIONS_1_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcompr_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd34;
  machine_word Wrd30;
  machine_word Wrd11;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd31;
  machine_word Wrd19;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  machine_word Wrd32;
  machine_word Wrd28;
  machine_word Wrd29;
  machine_word Wrd23;
  machine_word Wrd24;
  machine_word Wrd20;
  machine_word Wrd16;
  machine_word Wrd17;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd14;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_1_4);
      goto code_compression_18;

    case 1:
      current_block = (Rpc - LABEL_1_5);
      goto lambda_17;

    case 2:
      current_block = (Rpc - LABEL_1_7);
      goto lambda_29;

    case 3:
      current_block = (Rpc - LABEL_1_14);
      goto label_20;

    case 4:
      current_block = (Rpc - LABEL_1_15);
      goto label_21;

    case 5:
      current_block = (Rpc - LABEL_1_9);
      goto lambda_30;

    case 6:
      current_block = (Rpc - LABEL_1_16);
      goto label_22;

    case 7:
      current_block = (Rpc - LABEL_1_17);
      goto label_23;

    case 8:
      current_block = (Rpc - LABEL_1_11);
      goto lambda_31;

    case 9:
      current_block = (Rpc - LABEL_1_18);
      goto label_24;

    case 10:
      current_block = (Rpc - LABEL_1_19);
      goto label_25;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (code_compression_27)
DEFLABEL (code_compression_18)
  INTERRUPT_CHECK (26, LABEL_1_4);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_5]))));
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_6]));

DEFLABEL (lambda_28)
DEFLABEL (lambda_17)
  INTERRUPT_CHECK (26, LABEL_1_5);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd14.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd12.pObj) = (& (Rhp [-1]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd17.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_7])));
  Rhp += 2;
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd17.pObj)));
  Wrd20 = Wrd17;
  ((Wrd20.pObj) [2]) = (Wrd7.Obj);
  ((Wrd20.pObj) [3]) = (Wrd13.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd24.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_9])));
  Rhp += 1;
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd24.pObj)));
  ((Wrd24.pObj) [2]) = (Wrd14.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd29.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_12);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_11])));
  Rhp += 2;
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd29.pObj)));
  Wrd32 = Wrd29;
  ((Wrd32.pObj) [2]) = (Wrd7.Obj);
  ((Wrd32.pObj) [3]) = (Wrd13.Obj);
  (Rsp [2]) = (Wrd28.Obj);
  (Rsp [1]) = (Wrd23.Obj);
  (Rsp [0]) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_13]));

DEFLABEL (lambda_29)
  CLOSURE_HEADER (LABEL_1_7);

DEFLABEL (lambda_6)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_37;

DEFLABEL (label_36)
  Wrd19 = Wrd23;

DEFLABEL (label_35)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_34;

DEFLABEL (label_33)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_32)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [2]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_1_0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_34)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_33;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_15])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_21)
  goto label_32;

DEFLABEL (label_37)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_36;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_1_14])), (Wrd20.pObj));

DEFLABEL (label_20)
  (Wrd19.Obj) = Rvl;
  goto label_35;

DEFLABEL (lambda_30)
  CLOSURE_HEADER (LABEL_1_9);

DEFLABEL (lambda_8)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_1]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_41;
  Wrd5 = Wrd9;

DEFLABEL (label_40)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd24.Obj) = (Rsp [1]);
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [2]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd27.uLng) == 10))
    goto label_39;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [0]);
  (Wrd23.Lng) = (FIXNUM_TO_LONG (Wrd22.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd23.Lng))))
    goto label_39;
  (Wrd11.Obj) = ((Wrd21.pObj) [3]);

DEFLABEL (label_38)
  (Rsp [1]) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_6]));

DEFLABEL (label_39)
  (Wrd29.Obj) = (Rsp [1]);
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd28.Obj) = ((Wrd30.pObj) [2]);
  (Wrd31.Obj) = (current_block [OBJECT_1_1]);
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_17]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_2]), 2);

DEFLABEL (label_23)
  (Wrd11.Obj) = Rvl;
  goto label_38;

DEFLABEL (label_41)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_16])), (Wrd6.pObj));

DEFLABEL (label_22)
  (Wrd5.Obj) = Rvl;
  goto label_40;

DEFLABEL (lambda_31)
  CLOSURE_HEADER (LABEL_1_11);

DEFLABEL (lambda_15)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_47;

DEFLABEL (label_46)
  Wrd19 = Wrd23;

DEFLABEL (label_45)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_44;

DEFLABEL (label_43)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_42)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_1_0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_44)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_43;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_19])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_25)
  goto label_42;

DEFLABEL (label_47)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_46;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_1_18])), (Wrd20.pObj));

DEFLABEL (label_24)
  (Wrd19.Obj) = Rvl;
  goto label_45;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_2_4 3
#define LABEL_2_5 5
#define LABEL_2_6 7
#define LABEL_2_9 9
#define LABEL_2_10 11
#define LABEL_2_7 13
#define LABEL_2_8 15
#define LABEL_2_14 17
#define LABEL_2_13 19
#define LABEL_2_16 21
#define TAG_2_17 9
#define LABEL_2_19 23
#define LABEL_2_20 25
#define LABEL_2_21 27
#define LABEL_2_23 29
#define LABEL_2_24 31
#define LABEL_2_27 33
#define LABEL_2_26 35
#define LABEL_2_28 37
#define TAG_2_29 17
#define ENVIRONMENT_LABEL_2_3 66
#define DEBUGGING_LABEL_2_2 65
#define OBJECT_2_9 64
#define OBJECT_2_8 63
#define OBJECT_2_7 62
#define OBJECT_2_6 61
#define OBJECT_2_5 60
#define OBJECT_2_4 59
#define OBJECT_2_3 58
#define OBJECT_2_2 57
#define OBJECT_2_1 56
#define OBJECT_2_0 55
#define EXECUTE_CACHE_2_30 39
#define EXECUTE_CACHE_2_25 41
#define EXECUTE_CACHE_2_22 43
#define EXECUTE_CACHE_2_18 45
#define EXECUTE_CACHE_2_15 47
#define EXECUTE_CACHE_2_12 49
#define EXECUTE_CACHE_2_11 51
#define FREE_REFERENCE_2_0 54
#define FREE_REFERENCES_LABEL_2_0 38
#define NUMBER_OF_LINKER_SECTIONS_2_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcompr_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd27;
  machine_word Wrd24;
  machine_word Wrd25;
  machine_word Wrd9;
  machine_word Wrd37;
  machine_word Wrd32;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd21;
  machine_word Wrd50;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd6;
  machine_word Wrd23;
  machine_word Wrd19;
  machine_word Wrd10;
  machine_word Wrd18;
  machine_word Wrd7;
  machine_word Wrd52;
  machine_word Wrd49;
  machine_word Wrd41;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd47;
  machine_word Wrd33;
  machine_word Wrd34;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd35;
  machine_word Wrd31;
  machine_word Wrd28;
  machine_word Wrd63;
  machine_word Wrd60;
  machine_word Wrd22;
  machine_word Wrd57;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd58;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_2_4);
      goto walk_bblock_18;

    case 1:
      current_block = (Rpc - LABEL_2_5);
      goto label_20;

    case 2:
      current_block = (Rpc - LABEL_2_6);
      goto label_23;

    case 3:
      current_block = (Rpc - LABEL_2_9);
      goto label_21;

    case 4:
      current_block = (Rpc - LABEL_2_10);
      goto label_22;

    case 5:
      current_block = (Rpc - LABEL_2_7);
      goto continuation_6;

    case 6:
      current_block = (Rpc - LABEL_2_8);
      goto continuation_5;

    case 7:
      current_block = (Rpc - LABEL_2_14);
      goto label_24;

    case 8:
      current_block = (Rpc - LABEL_2_13);
      goto continuation_3;

    case 9:
      current_block = (Rpc - LABEL_2_16);
      goto lambda_30;

    case 10:
      current_block = (Rpc - LABEL_2_19);
      goto label_26;

    case 11:
      current_block = (Rpc - LABEL_2_20);
      goto label_25;

    case 12:
      current_block = (Rpc - LABEL_2_21);
      goto continuation_9;

    case 13:
      current_block = (Rpc - LABEL_2_23);
      goto continuation_10;

    case 14:
      current_block = (Rpc - LABEL_2_24);
      goto continuation_11;

    case 15:
      current_block = (Rpc - LABEL_2_27);
      goto label_27;

    case 16:
      current_block = (Rpc - LABEL_2_26);
      goto continuation_14;

    case 17:
      current_block = (Rpc - LABEL_2_28);
      goto lambda_31;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (walk_bblock_29)
DEFLABEL (walk_bblock_18)
  INTERRUPT_CHECK (26, LABEL_2_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_42;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd13.Lng))))
    goto label_42;
  (Wrd5.Obj) = ((Wrd11.pObj) [7]);

DEFLABEL (label_41)
  (Wrd58.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd58.uLng) == 10))
    goto label_40;
  (Wrd55.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd56.Obj) = ((Wrd55.pObj) [0]);
  (Wrd57.Lng) = (FIXNUM_TO_LONG (Wrd56.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd57.Lng))))
    goto label_40;
  (Wrd22.Obj) = ((Wrd55.pObj) [3]);
  if (! ((Wrd22.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_33;

DEFLABEL (label_32)
  Rvl = (current_block [OBJECT_2_3]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_33)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_7]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_8]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd35.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_0]));
  (Wrd38.Obj) = ((Wrd35.pObj) [0]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if ((Wrd39.uLng) == 50)
    goto label_39;
  Wrd34 = Wrd38;

DEFLABEL (label_38)
  Wrd33 = Wrd34;
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd47.uLng) == 10))
    goto label_37;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd45.Obj) = ((Wrd44.pObj) [0]);
  (Wrd46.Lng) = (FIXNUM_TO_LONG (Wrd45.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd46.Lng))))
    goto label_37;
  (Wrd41.Obj) = ((Wrd44.pObj) [1]);
  (* (--Rsp)) = (Wrd41.Obj);

DEFLABEL (label_36)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_11]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_2_8);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_35;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd16.Lng))))
    goto label_35;
  (Wrd10.Obj) = ((Wrd14.pObj) [8]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_34)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_15]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_2_13);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_2_17);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_2_16])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd12 = Wrd7;
  (Wrd13.Obj) = (Rsp [3]);
  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  ((Wrd12.pObj) [4]) = Rvl;
  (Rsp [1]) = (Wrd6.Obj);
  (Rsp [0]) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_18]));

DEFLABEL (label_35)
  (Wrd19.Obj) = (Rsp [3]);
  (Wrd20.Obj) = (current_block [OBJECT_2_5]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_14]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_1]), 2);

DEFLABEL (label_24)
  (* (--Rsp)) = Rvl;
  goto label_34;

DEFLABEL (label_37)
  (Wrd49.Obj) = (current_block [OBJECT_2_4]);
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_10]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_1]), 2);

DEFLABEL (label_22)
  (* (--Rsp)) = Rvl;
  goto label_36;

DEFLABEL (label_39)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_9])), (Wrd35.pObj));

DEFLABEL (label_21)
  (Wrd34.Obj) = Rvl;
  goto label_38;

DEFLABEL (label_40)
  (Wrd60.Obj) = (current_block [OBJECT_2_2]);
  (Wrd63.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_6]))));
  (* (--Rsp)) = (Wrd63.Obj);
  (* (--Rsp)) = (Wrd60.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_1]), 2);

DEFLABEL (label_23)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_32;
  goto label_33;

DEFLABEL (label_42)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_2_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_1]), 2);

DEFLABEL (label_20)
  (Wrd5.Obj) = Rvl;
  goto label_41;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_2_7);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_12]));

DEFLABEL (lambda_30)
  CLOSURE_HEADER (LABEL_2_16);

DEFLABEL (lambda_16)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd44.Obj) = (Rsp [1]);
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if (! ((Wrd45.uLng) == 10))
    goto label_49;
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd42.Obj) = ((Wrd41.pObj) [0]);
  (Wrd43.Lng) = (FIXNUM_TO_LONG (Wrd42.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd43.Lng))))
    goto label_49;
  (Wrd7.Obj) = ((Wrd41.pObj) [3]);
  if (! ((Wrd7.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_44;

DEFLABEL (label_43)
  Rvl = (current_block [OBJECT_2_3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_44)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 10))
    goto label_48;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd19.Lng))))
    goto label_48;
  (Wrd13.Obj) = ((Wrd17.pObj) [1]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_47)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_21]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd31.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd32.Obj) = (Rsp [4]);
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [4]);
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd37.Obj) = ((Wrd33.pObj) [2]);
  (* (--Rsp)) = (Wrd37.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_22]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_2_21);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_23]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd9.Obj) = (Rsp [3]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_6]), 2);

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_2_23);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_24]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [4]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd15.Obj) = ((Wrd11.pObj) [4]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_25]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_2_24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_26]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_46;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_46;
  (Wrd10.Obj) = ((Wrd14.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_45)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd25.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_2_29);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_2_28])));
  Rhp += 1;
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd25.pObj)));
  Wrd26 = Wrd25;
  (Wrd27.Obj) = (Rsp [3]);
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [4]);
  ((Wrd26.pObj) [2]) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_30]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_2_26);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [3]);
  (Rsp [2]) = (Wrd5.Obj);
  (Wrd8.Obj) = ((Wrd7.pObj) [4]);
  (Rsp [1]) = (Wrd8.Obj);
  Rsp = (& (Rsp [1]));
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_8]), 2);

DEFLABEL (label_46)
  (Wrd19.Obj) = (Rsp [3]);
  (Wrd20.Obj) = (current_block [OBJECT_2_7]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_27]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_1]), 2);

DEFLABEL (label_27)
  (* (--Rsp)) = Rvl;
  goto label_45;

DEFLABEL (label_48)
  (Wrd22.Obj) = (Rsp [1]);
  (Wrd23.Obj) = (current_block [OBJECT_2_4]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_20]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_1]), 2);

DEFLABEL (label_25)
  (* (--Rsp)) = Rvl;
  goto label_47;

DEFLABEL (label_49)
  (Wrd46.Obj) = (Rsp [1]);
  (Wrd47.Obj) = (current_block [OBJECT_2_2]);
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_19]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd46.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_1]), 2);

DEFLABEL (label_26)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_43;
  goto label_44;

DEFLABEL (lambda_31)
  CLOSURE_HEADER (LABEL_2_28);

DEFLABEL (lambda_12)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_9]), 2);

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_3_5 3
#define LABEL_3_4 5
#define LABEL_3_6 7
#define LABEL_3_7 9
#define LABEL_3_8 11
#define LABEL_3_9 13
#define LABEL_3_10 15
#define LABEL_3_11 17
#define LABEL_3_12 19
#define LABEL_3_13 21
#define LABEL_3_14 23
#define LABEL_3_15 25
#define LABEL_3_16 27
#define LABEL_3_17 29
#define LABEL_3_18 31
#define LABEL_3_19 33
#define LABEL_3_20 35
#define LABEL_3_21 37
#define LABEL_3_23 39
#define LABEL_3_22 41
#define LABEL_3_28 43
#define LABEL_3_30 45
#define LABEL_3_25 47
#define TAG_3_26 22
#define LABEL_3_29 49
#define LABEL_3_27 51
#define LABEL_3_34 53
#define TAG_3_35 25
#define ENVIRONMENT_LABEL_3_3 78
#define DEBUGGING_LABEL_3_2 77
#define OBJECT_3_10 76
#define OBJECT_3_9 75
#define OBJECT_3_8 74
#define OBJECT_3_7 73
#define OBJECT_3_6 72
#define OBJECT_3_5 71
#define OBJECT_3_4 70
#define OBJECT_3_3 69
#define OBJECT_3_2 68
#define OBJECT_3_1 67
#define OBJECT_3_0 66
#define EXECUTE_CACHE_3_33 55
#define EXECUTE_CACHE_3_32 57
#define EXECUTE_CACHE_3_31 59
#define EXECUTE_CACHE_3_24 61
#define FREE_REFERENCE_3_1 64
#define FREE_REFERENCE_3_0 65
#define FREE_REFERENCES_LABEL_3_0 54
#define NUMBER_OF_LINKER_SECTIONS_3_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcompr_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd9;
  machine_word Wrd5;
  machine_word Wrd55;
  machine_word Wrd51;
  machine_word Wrd46;
  machine_word Wrd49;
  machine_word Wrd36;
  machine_word Wrd32;
  machine_word Wrd27;
  machine_word Wrd31;
  machine_word Wrd13;
  machine_word Wrd15;
  machine_word Wrd17;
  machine_word Wrd146;
  machine_word Wrd140;
  machine_word Wrd145;
  machine_word Wrd144;
  machine_word Wrd141;
  machine_word Wrd139;
  machine_word Wrd136;
  machine_word Wrd131;
  machine_word Wrd130;
  machine_word Wrd132;
  machine_word Wrd129;
  machine_word Wrd123;
  machine_word Wrd124;
  machine_word Wrd125;
  machine_word Wrd122;
  machine_word Wrd114;
  machine_word Wrd116;
  machine_word Wrd118;
  machine_word Wrd117;
  machine_word Wrd112;
  machine_word Wrd108;
  machine_word Wrd107;
  machine_word Wrd106;
  machine_word Wrd103;
  machine_word Wrd89;
  machine_word Wrd93;
  machine_word Wrd91;
  machine_word Wrd100;
  machine_word Wrd99;
  machine_word Wrd98;
  machine_word Wrd97;
  machine_word Wrd95;
  machine_word Wrd94;
  machine_word Wrd101;
  machine_word Wrd88;
  machine_word Wrd85;
  machine_word Wrd76;
  machine_word Wrd82;
  machine_word Wrd81;
  machine_word Wrd80;
  machine_word Wrd83;
  machine_word Wrd69;
  machine_word Wrd70;
  machine_word Wrd75;
  machine_word Wrd74;
  machine_word Wrd71;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd62;
  machine_word Wrd48;
  machine_word Wrd52;
  machine_word Wrd50;
  machine_word Wrd59;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd56;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd60;
  machine_word Wrd47;
  machine_word Wrd44;
  machine_word Wrd35;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd42;
  machine_word Wrd28;
  machine_word Wrd29;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd152;
  machine_word Wrd149;
  machine_word Wrd25;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd192;
  machine_word Wrd194;
  machine_word Wrd196;
  machine_word Wrd190;
  machine_word Wrd182;
  machine_word Wrd184;
  machine_word Wrd186;
  machine_word Wrd185;
  machine_word Wrd178;
  machine_word Wrd170;
  machine_word Wrd172;
  machine_word Wrd174;
  machine_word Wrd173;
  machine_word Wrd169;
  machine_word Wrd164;
  machine_word Wrd163;
  machine_word Wrd165;
  machine_word Wrd162;
  machine_word Wrd154;
  machine_word Wrd156;
  machine_word Wrd158;
  machine_word Wrd157;
  machine_word Wrd16;
  machine_word Wrd8;
  machine_word Wrd10;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_3_5);
      goto continuation_2;

    case 1:
      current_block = (Rpc - LABEL_3_4);
      goto optimize_rtl_30;

    case 2:
      current_block = (Rpc - LABEL_3_6);
      goto label_32;

    case 3:
      current_block = (Rpc - LABEL_3_7);
      goto label_45;

    case 4:
      current_block = (Rpc - LABEL_3_8);
      goto label_46;

    case 5:
      current_block = (Rpc - LABEL_3_9);
      goto label_47;

    case 6:
      current_block = (Rpc - LABEL_3_10);
      goto label_48;

    case 7:
      current_block = (Rpc - LABEL_3_11);
      goto label_44;

    case 8:
      current_block = (Rpc - LABEL_3_12);
      goto label_33;

    case 9:
      current_block = (Rpc - LABEL_3_13);
      goto label_34;

    case 10:
      current_block = (Rpc - LABEL_3_14);
      goto label_35;

    case 11:
      current_block = (Rpc - LABEL_3_15);
      goto label_36;

    case 12:
      current_block = (Rpc - LABEL_3_16);
      goto label_37;

    case 13:
      current_block = (Rpc - LABEL_3_17);
      goto label_38;

    case 14:
      current_block = (Rpc - LABEL_3_18);
      goto label_39;

    case 15:
      current_block = (Rpc - LABEL_3_19);
      goto label_40;

    case 16:
      current_block = (Rpc - LABEL_3_20);
      goto label_41;

    case 17:
      current_block = (Rpc - LABEL_3_21);
      goto label_42;

    case 18:
      current_block = (Rpc - LABEL_3_23);
      goto label_43;

    case 19:
      current_block = (Rpc - LABEL_3_22);
      goto continuation_19;

    case 20:
      current_block = (Rpc - LABEL_3_28);
      goto label_49;

    case 21:
      current_block = (Rpc - LABEL_3_30);
      goto label_50;

    case 22:
      current_block = (Rpc - LABEL_3_25);
      goto lambda_53;

    case 23:
      current_block = (Rpc - LABEL_3_29);
      goto continuation_24;

    case 24:
      current_block = (Rpc - LABEL_3_27);
      goto continuation_22;

    case 25:
      current_block = (Rpc - LABEL_3_34);
      goto lambda_54;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (optimize_rtl_52)
DEFLABEL (optimize_rtl_30)
  INTERRUPT_CHECK (26, LABEL_3_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_102;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd8.Obj) = ((Wrd10.pObj) [0]);

DEFLABEL (label_101)
  if ((Wrd8.Obj) == (current_block [OBJECT_3_1]))
    goto label_90;
  Rsp = (& (Rsp [1]));

DEFLABEL (label_89)
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_88)
  (Wrd20.Obj) = (Rsp [0]);
  if (! ((Wrd20.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_56;

DEFLABEL (label_55)
  Rvl = (current_block [OBJECT_3_9]);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_56)
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd23.uLng) == 26))
    goto label_87;
  (Wrd25.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if ((Wrd25.Lng) < 5L)
    goto label_55;

DEFLABEL (label_86)
  (Wrd30.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3_0]));
  (Wrd33.Obj) = ((Wrd30.pObj) [0]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if ((Wrd34.uLng) == 50)
    goto label_85;
  Wrd29 = Wrd33;

DEFLABEL (label_84)
  Wrd28 = Wrd29;
  (Wrd42.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if (! ((Wrd42.uLng) == 10))
    goto label_83;
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd40.Obj) = ((Wrd39.pObj) [0]);
  (Wrd41.Lng) = (FIXNUM_TO_LONG (Wrd40.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd41.Lng))))
    goto label_83;
  (Wrd35.Obj) = ((Wrd39.pObj) [4]);

DEFLABEL (label_82)
  (Wrd60.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd60.uLng) == 10))
    goto label_81;
  (Wrd53.Obj) = (Rsp [0]);
  (Wrd54.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if (! ((Wrd54.uLng) == 26))
    goto label_81;
  (Wrd56.Lng) = (FIXNUM_TO_LONG (Wrd53.Obj));
  (Wrd57.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd58.Obj) = ((Wrd57.pObj) [0]);
  (Wrd59.Lng) = (FIXNUM_TO_LONG (Wrd58.Obj));
  if (! (((unsigned long) (Wrd56.Lng)) < ((unsigned long) (Wrd59.Lng))))
    goto label_81;
  (Wrd50.uLng) = (OBJECT_DATUM (Wrd53.Obj));
  (Wrd52.pObj) = (& ((Wrd57.pObj) [(Wrd50.Lng)]));
  (Wrd48.Obj) = ((Wrd52.pObj) [1]);

DEFLABEL (label_80)
  (Wrd66.Obj) = (Rsp [1]);
  if (! ((Wrd48.Obj) == (Wrd66.Obj)))
    goto label_55;
  (Wrd71.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3_0]));
  (Wrd74.Obj) = ((Wrd71.pObj) [0]);
  (Wrd75.uLng) = (OBJECT_TYPE (Wrd74.Obj));
  if ((Wrd75.uLng) == 50)
    goto label_79;
  Wrd70 = Wrd74;

DEFLABEL (label_78)
  Wrd69 = Wrd70;
  (Wrd83.uLng) = (OBJECT_TYPE (Wrd70.Obj));
  if (! ((Wrd83.uLng) == 10))
    goto label_77;
  (Wrd80.pObj) = (OBJECT_ADDRESS (Wrd70.Obj));
  (Wrd81.Obj) = ((Wrd80.pObj) [0]);
  (Wrd82.Lng) = (FIXNUM_TO_LONG (Wrd81.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd82.Lng))))
    goto label_77;
  (Wrd76.Obj) = ((Wrd80.pObj) [5]);

DEFLABEL (label_76)
  (Wrd101.uLng) = (OBJECT_TYPE (Wrd76.Obj));
  if (! ((Wrd101.uLng) == 10))
    goto label_75;
  (Wrd94.Obj) = (Rsp [0]);
  (Wrd95.uLng) = (OBJECT_TYPE (Wrd94.Obj));
  if (! ((Wrd95.uLng) == 26))
    goto label_75;
  (Wrd97.Lng) = (FIXNUM_TO_LONG (Wrd94.Obj));
  (Wrd98.pObj) = (OBJECT_ADDRESS (Wrd76.Obj));
  (Wrd99.Obj) = ((Wrd98.pObj) [0]);
  (Wrd100.Lng) = (FIXNUM_TO_LONG (Wrd99.Obj));
  if (! (((unsigned long) (Wrd97.Lng)) < ((unsigned long) (Wrd100.Lng))))
    goto label_75;
  (Wrd91.uLng) = (OBJECT_DATUM (Wrd94.Obj));
  (Wrd93.pObj) = (& ((Wrd98.pObj) [(Wrd91.Lng)]));
  (Wrd89.Obj) = ((Wrd93.pObj) [1]);

DEFLABEL (label_74)
  (Wrd107.uLng) = (OBJECT_TYPE (Wrd89.Obj));
  if (! ((Wrd107.uLng) == 26))
    goto label_73;
  if (! ((Wrd89.Obj) == (current_block [OBJECT_3_8])))
    goto label_55;

DEFLABEL (label_72)
  (Wrd117.Obj) = (Rsp [4]);
  (Wrd118.uLng) = (OBJECT_TYPE (Wrd117.Obj));
  if (! ((Wrd118.uLng) == 1))
    goto label_71;
  (Wrd116.pObj) = (OBJECT_ADDRESS (Wrd117.Obj));
  (Wrd114.Obj) = ((Wrd116.pObj) [1]);

DEFLABEL (label_70)
  (Wrd125.uLng) = (OBJECT_TYPE (Wrd114.Obj));
  if (! ((Wrd125.uLng) == 1))
    goto label_69;
  (Wrd124.pObj) = (OBJECT_ADDRESS (Wrd114.Obj));
  (Wrd123.Obj) = ((Wrd124.pObj) [1]);

DEFLABEL (label_68)
  (Wrd132.uLng) = (OBJECT_TYPE (Wrd123.Obj));
  if (! ((Wrd132.uLng) == 1))
    goto label_67;
  (Wrd130.pObj) = (OBJECT_ADDRESS (Wrd123.Obj));
  (Wrd131.Obj) = ((Wrd130.pObj) [0]);
  (* (--Rsp)) = (Wrd131.Obj);

DEFLABEL (label_66)
  (Wrd139.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_22]))));
  (* (--Rsp)) = (Wrd139.Obj);
  (Wrd141.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3_1]));
  (Wrd144.Obj) = ((Wrd141.pObj) [0]);
  (Wrd145.uLng) = (OBJECT_TYPE (Wrd144.Obj));
  if ((Wrd145.uLng) == 50)
    goto label_65;
  Wrd140 = Wrd144;

DEFLABEL (label_64)
  (* (--Rsp)) = (Wrd140.Obj);
  (Wrd146.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd146.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_24]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_3_22);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_57;
  Rvl = (current_block [OBJECT_3_9]);
  Rsp = (& (Rsp [6]));
  goto pop_return;

DEFLABEL (label_57)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd11.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_3_26);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_3_25])));
  Rhp += 3;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd11.pObj)));
  Wrd16 = Wrd11;
  (Wrd17.Obj) = (Rsp [4]);
  ((Wrd16.pObj) [2]) = (Wrd17.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  ((Wrd16.pObj) [3]) = (Wrd15.Obj);
  (Wrd13.Obj) = (Rsp [1]);
  ((Wrd16.pObj) [4]) = (Wrd13.Obj);
  (Rsp [5]) = (Wrd10.Obj);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_27]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_63;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd29.Lng))))
    goto label_63;
  (Wrd23.Obj) = ((Wrd27.pObj) [3]);
  (* (--Rsp)) = (Wrd23.Obj);

DEFLABEL (label_62)
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_29]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd49.Obj) = (Rsp [1]);
  (Wrd50.uLng) = (OBJECT_TYPE (Wrd49.Obj));
  if (! ((Wrd50.uLng) == 10))
    goto label_61;
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd49.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [0]);
  (Wrd48.Lng) = (FIXNUM_TO_LONG (Wrd47.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd48.Lng))))
    goto label_61;
  (Wrd42.Obj) = ((Wrd46.pObj) [2]);
  (* (--Rsp)) = (Wrd42.Obj);

DEFLABEL (label_60)
  (Wrd56.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd56.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_31]));

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_3_29);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_58;
  (Wrd18.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [4]);
  (Rsp [2]) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_33]));

DEFLABEL (label_58)
  (Wrd9.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (Rsp [1]) = (Wrd10.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd13.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_3_35);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_3_34])));
  Rhp += 2;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd13.pObj)));
  Wrd16 = Wrd13;
  ((Wrd16.pObj) [2]) = (Wrd10.Obj);
  ((Wrd16.pObj) [3]) = (Wrd9.Obj);
  Wrd5 = Wrd12;
  Rsp = (& (Rsp [3]));

DEFLABEL (label_59)
  (Rsp [4]) = (Wrd5.Obj);
  Rsp = (& (Rsp [4]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_61)
  (Wrd51.Obj) = (Rsp [1]);
  (Wrd52.Obj) = (current_block [OBJECT_3_10]);
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_30]))));
  (* (--Rsp)) = (Wrd55.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_6]), 2);

DEFLABEL (label_50)
  (* (--Rsp)) = Rvl;
  goto label_60;

DEFLABEL (label_63)
  (Wrd32.Obj) = (Rsp [5]);
  (Wrd33.Obj) = (current_block [OBJECT_3_8]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_28]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_6]), 2);

DEFLABEL (label_49)
  (* (--Rsp)) = Rvl;
  goto label_62;

DEFLABEL (label_65)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_3_23])), (Wrd141.pObj));

DEFLABEL (label_43)
  (Wrd140.Obj) = Rvl;
  goto label_64;

DEFLABEL (label_67)
  (Wrd136.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_21]))));
  (* (--Rsp)) = (Wrd136.Obj);
  (* (--Rsp)) = (Wrd123.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_0]), 1);

DEFLABEL (label_42)
  (* (--Rsp)) = Rvl;
  goto label_66;

DEFLABEL (label_69)
  (Wrd129.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_20]))));
  (* (--Rsp)) = (Wrd129.Obj);
  (* (--Rsp)) = (Wrd114.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_2]), 1);

DEFLABEL (label_41)
  (Wrd123.Obj) = Rvl;
  goto label_68;

DEFLABEL (label_71)
  (Wrd122.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_19]))));
  (* (--Rsp)) = (Wrd122.Obj);
  (* (--Rsp)) = (Wrd117.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_2]), 1);

DEFLABEL (label_40)
  (Wrd114.Obj) = Rvl;
  goto label_70;

DEFLABEL (label_73)
  (Wrd108.Obj) = (current_block [OBJECT_3_8]);
  (Wrd112.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_18]))));
  (* (--Rsp)) = (Wrd112.Obj);
  (* (--Rsp)) = (Wrd89.Obj);
  (* (--Rsp)) = (Wrd108.Obj);
  INVOKE_INTERFACE_0 (36);

DEFLABEL (label_39)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_55;
  goto label_72;

DEFLABEL (label_75)
  (Wrd103.Obj) = (Rsp [0]);
  (Wrd106.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_17]))));
  (* (--Rsp)) = (Wrd106.Obj);
  (* (--Rsp)) = (Wrd103.Obj);
  (* (--Rsp)) = (Wrd76.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_6]), 2);

DEFLABEL (label_38)
  (Wrd89.Obj) = Rvl;
  goto label_74;

DEFLABEL (label_77)
  (Wrd85.Obj) = (current_block [OBJECT_3_7]);
  (Wrd88.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_16]))));
  (* (--Rsp)) = (Wrd88.Obj);
  (* (--Rsp)) = (Wrd85.Obj);
  (* (--Rsp)) = (Wrd69.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_6]), 2);

DEFLABEL (label_37)
  (Wrd76.Obj) = Rvl;
  goto label_76;

DEFLABEL (label_79)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_3_15])), (Wrd71.pObj));

DEFLABEL (label_36)
  (Wrd70.Obj) = Rvl;
  goto label_78;

DEFLABEL (label_81)
  (Wrd62.Obj) = (Rsp [0]);
  (Wrd65.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_14]))));
  (* (--Rsp)) = (Wrd65.Obj);
  (* (--Rsp)) = (Wrd62.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_6]), 2);

DEFLABEL (label_35)
  (Wrd48.Obj) = Rvl;
  goto label_80;

DEFLABEL (label_83)
  (Wrd44.Obj) = (current_block [OBJECT_3_5]);
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_13]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_6]), 2);

DEFLABEL (label_34)
  (Wrd35.Obj) = Rvl;
  goto label_82;

DEFLABEL (label_85)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_3_12])), (Wrd30.pObj));

DEFLABEL (label_33)
  (Wrd29.Obj) = Rvl;
  goto label_84;

DEFLABEL (label_87)
  (Wrd149.Obj) = (current_block [OBJECT_3_4]);
  (Wrd152.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_11]))));
  (* (--Rsp)) = (Wrd152.Obj);
  (* (--Rsp)) = (Wrd149.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_44)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_86;
  goto label_55;

DEFLABEL (label_90)
  (Wrd157.Obj) = (Rsp [4]);
  (Wrd158.uLng) = (OBJECT_TYPE (Wrd157.Obj));
  if (! ((Wrd158.uLng) == 1))
    goto label_100;
  (Wrd156.pObj) = (OBJECT_ADDRESS (Wrd157.Obj));
  (Wrd154.Obj) = ((Wrd156.pObj) [1]);

DEFLABEL (label_99)
  (Wrd165.uLng) = (OBJECT_TYPE (Wrd154.Obj));
  if (! ((Wrd165.uLng) == 1))
    goto label_98;
  (Wrd163.pObj) = (OBJECT_ADDRESS (Wrd154.Obj));
  (Wrd164.Obj) = ((Wrd163.pObj) [0]);
  (* (--Rsp)) = (Wrd164.Obj);

DEFLABEL (label_97)
  (Wrd173.Obj) = (Rsp [0]);
  (Wrd174.uLng) = (OBJECT_TYPE (Wrd173.Obj));
  if (! ((Wrd174.uLng) == 1))
    goto label_96;
  (Wrd172.pObj) = (OBJECT_ADDRESS (Wrd173.Obj));
  (Wrd170.Obj) = ((Wrd172.pObj) [0]);

DEFLABEL (label_95)
  if ((Wrd170.Obj) == (current_block [OBJECT_3_3]))
    goto label_91;
  Rsp = (& (Rsp [2]));
  goto label_89;

DEFLABEL (label_91)
  (Wrd185.Obj) = (Rsp [0]);
  (Wrd186.uLng) = (OBJECT_TYPE (Wrd185.Obj));
  if (! ((Wrd186.uLng) == 1))
    goto label_94;
  (Wrd184.pObj) = (OBJECT_ADDRESS (Wrd185.Obj));
  (Wrd182.Obj) = ((Wrd184.pObj) [1]);

DEFLABEL (label_93)
  (Rsp [0]) = (Wrd182.Obj);
  (Wrd196.uLng) = (OBJECT_TYPE (Wrd182.Obj));
  if ((Wrd196.uLng) == 1)
    goto label_92;
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_0]), 1);

DEFLABEL (label_92)
  (Wrd194.pObj) = (OBJECT_ADDRESS (Wrd182.Obj));
  (Wrd192.Obj) = ((Wrd194.pObj) [0]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd192.Obj);
  goto label_88;

DEFLABEL (label_94)
  (Wrd190.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_10]))));
  (* (--Rsp)) = (Wrd190.Obj);
  (* (--Rsp)) = (Wrd185.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_2]), 1);

DEFLABEL (label_48)
  (Wrd182.Obj) = Rvl;
  goto label_93;

DEFLABEL (label_96)
  (Wrd178.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_9]))));
  (* (--Rsp)) = (Wrd178.Obj);
  (* (--Rsp)) = (Wrd173.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_0]), 1);

DEFLABEL (label_47)
  (Wrd170.Obj) = Rvl;
  goto label_95;

DEFLABEL (label_98)
  (Wrd169.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_8]))));
  (* (--Rsp)) = (Wrd169.Obj);
  (* (--Rsp)) = (Wrd154.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_0]), 1);

DEFLABEL (label_46)
  (* (--Rsp)) = Rvl;
  goto label_97;

DEFLABEL (label_100)
  (Wrd162.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_7]))));
  (* (--Rsp)) = (Wrd162.Obj);
  (* (--Rsp)) = (Wrd157.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_2]), 1);

DEFLABEL (label_45)
  (Wrd154.Obj) = Rvl;
  goto label_99;

DEFLABEL (label_102)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_6]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_0]), 1);

DEFLABEL (label_32)
  (Wrd8.Obj) = Rvl;
  goto label_101;

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_3_27);
  (Wrd5.Obj) = Rvl;
  goto label_59;

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_3_5);
  (* (--Rsp)) = Rvl;
  goto label_88;

DEFLABEL (lambda_53)
  CLOSURE_HEADER (LABEL_3_25);

DEFLABEL (lambda_20)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_103;
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = ((Wrd8.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = ((Wrd8.pObj) [4]);
  (Rsp [2]) = (Wrd5.Obj);
  (Rsp [3]) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_32]));

DEFLABEL (label_103)
  Rvl = (current_block [OBJECT_3_9]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (lambda_54)
  CLOSURE_HEADER (LABEL_3_34);

DEFLABEL (lambda_25)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd9.Obj) = ((Wrd8.pObj) [3]);
  (Rsp [1]) = (Wrd9.Obj);
  goto lambda_20;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4_4 3
#define LABEL_4_5 5
#define TAG_4_6 1
#define LABEL_4_7 7
#define TAG_4_8 2
#define LABEL_4_9 9
#define TAG_4_10 3
#define LABEL_4_15 11
#define LABEL_4_16 13
#define LABEL_4_17 15
#define LABEL_4_18 17
#define LABEL_4_19 19
#define LABEL_4_20 21
#define LABEL_4_21 23
#define LABEL_4_22 25
#define LABEL_4_23 27
#define LABEL_4_24 29
#define LABEL_4_25 31
#define LABEL_4_26 33
#define LABEL_4_11 35
#define LABEL_4_27 37
#define LABEL_4_28 39
#define LABEL_4_29 41
#define LABEL_4_30 43
#define LABEL_4_31 45
#define LABEL_4_32 47
#define LABEL_4_13 49
#define LABEL_4_14 51
#define LABEL_4_39 53
#define LABEL_4_41 55
#define LABEL_4_42 57
#define LABEL_4_43 59
#define LABEL_4_44 61
#define LABEL_4_45 63
#define LABEL_4_46 65
#define LABEL_4_47 67
#define LABEL_4_48 69
#define LABEL_4_40 71
#define LABEL_4_36 73
#define LABEL_4_51 75
#define LABEL_4_52 77
#define LABEL_4_53 79
#define LABEL_4_54 81
#define LABEL_4_56 83
#define LABEL_4_34 85
#define LABEL_4_58 87
#define LABEL_4_59 89
#define LABEL_4_60 91
#define LABEL_4_61 93
#define LABEL_4_62 95
#define LABEL_4_63 97
#define LABEL_4_64 99
#define LABEL_4_65 101
#define LABEL_4_68 103
#define LABEL_4_69 105
#define LABEL_4_70 107
#define LABEL_4_71 109
#define LABEL_4_72 111
#define LABEL_4_75 113
#define LABEL_4_76 115
#define LABEL_4_77 117
#define LABEL_4_78 119
#define LABEL_4_79 121
#define LABEL_4_80 123
#define LABEL_4_81 125
#define LABEL_4_82 127
#define LABEL_4_83 129
#define LABEL_4_84 131
#define LABEL_4_85 133
#define LABEL_4_86 135
#define LABEL_4_87 137
#define LABEL_4_88 139
#define LABEL_4_89 141
#define LABEL_4_91 143
#define LABEL_4_37 145
#define TAG_4_38 71
#define LABEL_4_55 147
#define LABEL_4_92 149
#define TAG_4_93 73
#define LABEL_4_99 151
#define LABEL_4_90 153
#define LABEL_4_100 155
#define LABEL_4_95 157
#define LABEL_4_66 159
#define TAG_4_67 78
#define LABEL_4_102 161
#define LABEL_4_103 163
#define LABEL_4_73 165
#define TAG_4_74 81
#define LABEL_4_104 167
#define LABEL_4_105 169
#define LABEL_4_108 171
#define LABEL_4_109 173
#define LABEL_4_94 175
#define LABEL_4_50 177
#define LABEL_4_96 179
#define TAG_4_97 88
#define LABEL_4_98 181
#define LABEL_4_112 183
#define LABEL_4_101 185
#define LABEL_4_106 187
#define TAG_4_107 92
#define LABEL_4_117 189
#define LABEL_4_118 191
#define LABEL_4_119 193
#define LABEL_4_110 195
#define LABEL_4_121 197
#define LABEL_4_122 199
#define LABEL_4_123 201
#define LABEL_4_125 203
#define LABEL_4_126 205
#define LABEL_4_113 207
#define TAG_4_114 102
#define LABEL_4_115 209
#define TAG_4_116 103
#define LABEL_4_129 211
#define LABEL_4_131 213
#define LABEL_4_127 215
#define TAG_4_128 106
#define LABEL_4_130 217
#define LABEL_4_132 219
#define LABEL_4_133 221
#define LABEL_4_120 223
#define LABEL_4_134 225
#define TAG_4_135 111
#define ENVIRONMENT_LABEL_4_3 277
#define DEBUGGING_LABEL_4_2 276
#define OBJECT_4_20 275
#define OBJECT_4_19 274
#define OBJECT_4_18 273
#define OBJECT_4_17 272
#define OBJECT_4_16 271
#define OBJECT_4_15 270
#define OBJECT_4_14 269
#define OBJECT_4_13 268
#define OBJECT_4_12 267
#define OBJECT_4_11 266
#define OBJECT_4_10 265
#define OBJECT_4_9 264
#define OBJECT_4_8 263
#define OBJECT_4_7 262
#define OBJECT_4_6 261
#define OBJECT_4_5 260
#define OBJECT_4_4 259
#define OBJECT_4_3 258
#define OBJECT_4_2 257
#define OBJECT_4_1 256
#define OBJECT_4_0 255
#define EXECUTE_CACHE_4_124 227
#define EXECUTE_CACHE_4_111 229
#define EXECUTE_CACHE_4_57 231
#define EXECUTE_CACHE_4_49 233
#define EXECUTE_CACHE_4_35 235
#define EXECUTE_CACHE_4_33 237
#define EXECUTE_CACHE_4_12 239
#define FREE_REFERENCE_4_12 242
#define FREE_REFERENCE_4_11 243
#define FREE_REFERENCE_4_10 244
#define FREE_REFERENCE_4_9 245
#define FREE_REFERENCE_4_8 246
#define FREE_REFERENCE_4_7 247
#define FREE_REFERENCE_4_6 248
#define FREE_REFERENCE_4_5 249
#define FREE_REFERENCE_4_4 250
#define FREE_REFERENCE_4_3 251
#define FREE_REFERENCE_4_2 252
#define FREE_REFERENCE_4_1 253
#define FREE_REFERENCE_4_0 254
#define FREE_REFERENCES_LABEL_4_0 226
#define NUMBER_OF_LINKER_SECTIONS_4_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcompr_so_code_4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd32;
  machine_word Wrd29;
  machine_word Wrd70;
  machine_word Wrd72;
  machine_word Wrd74;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd40;
  machine_word Wrd44;
  machine_word Wrd21;
  machine_word Wrd161;
  machine_word Wrd160;
  machine_word Wrd154;
  machine_word Wrd153;
  machine_word Wrd139;
  machine_word Wrd138;
  machine_word Wrd171;
  machine_word Wrd176;
  machine_word Wrd175;
  machine_word Wrd172;
  machine_word Wrd164;
  machine_word Wrd169;
  machine_word Wrd168;
  machine_word Wrd165;
  machine_word Wrd133;
  machine_word Wrd125;
  machine_word Wrd184;
  machine_word Wrd189;
  machine_word Wrd188;
  machine_word Wrd185;
  machine_word Wrd178;
  machine_word Wrd183;
  machine_word Wrd182;
  machine_word Wrd179;
  machine_word Wrd118;
  machine_word Wrd196;
  machine_word Wrd201;
  machine_word Wrd200;
  machine_word Wrd197;
  machine_word Wrd190;
  machine_word Wrd195;
  machine_word Wrd194;
  machine_word Wrd191;
  machine_word Wrd109;
  machine_word Wrd210;
  machine_word Wrd215;
  machine_word Wrd214;
  machine_word Wrd211;
  machine_word Wrd203;
  machine_word Wrd208;
  machine_word Wrd207;
  machine_word Wrd204;
  machine_word Wrd95;
  machine_word Wrd252;
  machine_word Wrd251;
  machine_word Wrd249;
  machine_word Wrd250;
  machine_word Wrd242;
  machine_word Wrd247;
  machine_word Wrd246;
  machine_word Wrd243;
  machine_word Wrd239;
  machine_word Wrd233;
  machine_word Wrd234;
  machine_word Wrd235;
  machine_word Wrd232;
  machine_word Wrd226;
  machine_word Wrd227;
  machine_word Wrd228;
  machine_word Wrd225;
  machine_word Wrd217;
  machine_word Wrd219;
  machine_word Wrd221;
  machine_word Wrd220;
  machine_word Wrd93;
  machine_word Wrd85;
  machine_word Wrd87;
  machine_word Wrd89;
  machine_word Wrd289;
  machine_word Wrd288;
  machine_word Wrd286;
  machine_word Wrd287;
  machine_word Wrd279;
  machine_word Wrd284;
  machine_word Wrd283;
  machine_word Wrd280;
  machine_word Wrd276;
  machine_word Wrd270;
  machine_word Wrd271;
  machine_word Wrd272;
  machine_word Wrd269;
  machine_word Wrd263;
  machine_word Wrd264;
  machine_word Wrd265;
  machine_word Wrd262;
  machine_word Wrd254;
  machine_word Wrd256;
  machine_word Wrd258;
  machine_word Wrd257;
  machine_word Wrd75;
  machine_word Wrd294;
  machine_word Wrd292;
  machine_word Wrd291;
  machine_word Wrd55;
  machine_word Wrd59;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd46;
  machine_word Wrd37;
  machine_word Wrd45;
  machine_word Wrd31;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd63;
  machine_word Wrd64;
  machine_word Wrd65;
  machine_word Wrd56;
  machine_word Wrd114;
  machine_word Wrd115;
  machine_word Wrd107;
  machine_word Wrd108;
  machine_word Wrd101;
  machine_word Wrd100;
  machine_word Wrd86;
  machine_word Wrd80;
  machine_word Wrd81;
  machine_word Wrd77;
  machine_word Wrd18;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd54;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd50;
  machine_word Wrd47;
  machine_word Wrd39;
  machine_word Wrd41;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd38;
  machine_word Wrd30;
  machine_word Wrd22;
  machine_word Wrd24;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd73;
  machine_word Wrd68;
  machine_word Wrd67;
  machine_word Wrd69;
  machine_word Wrd66;
  machine_word Wrd58;
  machine_word Wrd60;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd57;
  machine_word Wrd84;
  machine_word Wrd78;
  machine_word Wrd83;
  machine_word Wrd82;
  machine_word Wrd79;
  machine_word Wrd76;
  machine_word Wrd158;
  machine_word Wrd157;
  machine_word Wrd156;
  machine_word Wrd155;
  machine_word Wrd150;
  machine_word Wrd149;
  machine_word Wrd151;
  machine_word Wrd148;
  machine_word Wrd142;
  machine_word Wrd143;
  machine_word Wrd144;
  machine_word Wrd141;
  machine_word Wrd135;
  machine_word Wrd136;
  machine_word Wrd137;
  machine_word Wrd134;
  machine_word Wrd128;
  machine_word Wrd129;
  machine_word Wrd130;
  machine_word Wrd127;
  machine_word Wrd119;
  machine_word Wrd121;
  machine_word Wrd123;
  machine_word Wrd122;
  machine_word Wrd117;
  machine_word Wrd111;
  machine_word Wrd112;
  machine_word Wrd113;
  machine_word Wrd110;
  machine_word Wrd104;
  machine_word Wrd105;
  machine_word Wrd106;
  machine_word Wrd103;
  machine_word Wrd97;
  machine_word Wrd98;
  machine_word Wrd99;
  machine_word Wrd96;
  machine_word Wrd88;
  machine_word Wrd90;
  machine_word Wrd92;
  machine_word Wrd91;
  machine_word Wrd7;
  machine_word Wrd23;
  machine_word Wrd16;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd17;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd10;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4_4);
      goto find_reference_instruction_144;

    case 1:
      current_block = (Rpc - LABEL_4_5);
      goto loop_142;

    case 2:
      current_block = (Rpc - LABEL_4_7);
      goto lambda_21;

    case 3:
      current_block = (Rpc - LABEL_4_9);
      goto lambda_12;

    case 4:
      current_block = (Rpc - LABEL_4_15);
      goto continuation_33;

    case 5:
      current_block = (Rpc - LABEL_4_16);
      goto label_188;

    case 6:
      current_block = (Rpc - LABEL_4_17);
      goto label_189;

    case 7:
      current_block = (Rpc - LABEL_4_18);
      goto label_190;

    case 8:
      current_block = (Rpc - LABEL_4_19);
      goto label_191;

    case 9:
      current_block = (Rpc - LABEL_4_20);
      goto label_192;

    case 10:
      current_block = (Rpc - LABEL_4_21);
      goto label_193;

    case 11:
      current_block = (Rpc - LABEL_4_22);
      goto label_194;

    case 12:
      current_block = (Rpc - LABEL_4_23);
      goto label_195;

    case 13:
      current_block = (Rpc - LABEL_4_24);
      goto label_196;

    case 14:
      current_block = (Rpc - LABEL_4_25);
      goto continuation_43;

    case 15:
      current_block = (Rpc - LABEL_4_26);
      goto label_187;

    case 16:
      current_block = (Rpc - LABEL_4_11);
      goto continuation_28;

    case 17:
      current_block = (Rpc - LABEL_4_27);
      goto label_146;

    case 18:
      current_block = (Rpc - LABEL_4_28);
      goto label_150;

    case 19:
      current_block = (Rpc - LABEL_4_29);
      goto label_151;

    case 20:
      current_block = (Rpc - LABEL_4_30);
      goto label_147;

    case 21:
      current_block = (Rpc - LABEL_4_31);
      goto label_148;

    case 22:
      current_block = (Rpc - LABEL_4_32);
      goto label_149;

    case 23:
      current_block = (Rpc - LABEL_4_13);
      goto continuation_20;

    case 24:
      current_block = (Rpc - LABEL_4_14);
      goto continuation_19;

    case 25:
      current_block = (Rpc - LABEL_4_39);
      goto phi_1_6;

    case 26:
      current_block = (Rpc - LABEL_4_41);
      goto label_152;

    case 27:
      current_block = (Rpc - LABEL_4_42);
      goto lambda_22;

    case 28:
      current_block = (Rpc - LABEL_4_43);
      goto continuation_87;

    case 29:
      current_block = (Rpc - LABEL_4_44);
      goto lambda_92;

    case 30:
      current_block = (Rpc - LABEL_4_45);
      goto label_202;

    case 31:
      current_block = (Rpc - LABEL_4_46);
      goto label_203;

    case 32:
      current_block = (Rpc - LABEL_4_47);
      goto label_204;

    case 33:
      current_block = (Rpc - LABEL_4_48);
      goto label_205;

    case 34:
      current_block = (Rpc - LABEL_4_40);
      goto continuation_2;

    case 35:
      current_block = (Rpc - LABEL_4_36);
      goto lambda_139;

    case 36:
      current_block = (Rpc - LABEL_4_51);
      goto label_153;

    case 37:
      current_block = (Rpc - LABEL_4_52);
      goto label_156;

    case 38:
      current_block = (Rpc - LABEL_4_53);
      goto label_157;

    case 39:
      current_block = (Rpc - LABEL_4_54);
      goto label_154;

    case 40:
      current_block = (Rpc - LABEL_4_56);
      goto label_155;

    case 41:
      current_block = (Rpc - LABEL_4_34);
      goto continuation_44;

    case 42:
      current_block = (Rpc - LABEL_4_58);
      goto label_159;

    case 43:
      current_block = (Rpc - LABEL_4_59);
      goto label_160;

    case 44:
      current_block = (Rpc - LABEL_4_60);
      goto label_161;

    case 45:
      current_block = (Rpc - LABEL_4_61);
      goto label_162;

    case 46:
      current_block = (Rpc - LABEL_4_62);
      goto label_183;

    case 47:
      current_block = (Rpc - LABEL_4_63);
      goto label_184;

    case 48:
      current_block = (Rpc - LABEL_4_64);
      goto label_185;

    case 49:
      current_block = (Rpc - LABEL_4_65);
      goto label_186;

    case 50:
      current_block = (Rpc - LABEL_4_68);
      goto label_163;

    case 51:
      current_block = (Rpc - LABEL_4_69);
      goto label_179;

    case 52:
      current_block = (Rpc - LABEL_4_70);
      goto label_180;

    case 53:
      current_block = (Rpc - LABEL_4_71);
      goto label_181;

    case 54:
      current_block = (Rpc - LABEL_4_72);
      goto label_182;

    case 55:
      current_block = (Rpc - LABEL_4_75);
      goto label_164;

    case 56:
      current_block = (Rpc - LABEL_4_76);
      goto label_177;

    case 57:
      current_block = (Rpc - LABEL_4_77);
      goto label_178;

    case 58:
      current_block = (Rpc - LABEL_4_78);
      goto label_165;

    case 59:
      current_block = (Rpc - LABEL_4_79);
      goto label_175;

    case 60:
      current_block = (Rpc - LABEL_4_80);
      goto label_176;

    case 61:
      current_block = (Rpc - LABEL_4_81);
      goto label_166;

    case 62:
      current_block = (Rpc - LABEL_4_82);
      goto label_173;

    case 63:
      current_block = (Rpc - LABEL_4_83);
      goto label_174;

    case 64:
      current_block = (Rpc - LABEL_4_84);
      goto label_167;

    case 65:
      current_block = (Rpc - LABEL_4_85);
      goto label_171;

    case 66:
      current_block = (Rpc - LABEL_4_86);
      goto label_172;

    case 67:
      current_block = (Rpc - LABEL_4_87);
      goto label_168;

    case 68:
      current_block = (Rpc - LABEL_4_88);
      goto label_169;

    case 69:
      current_block = (Rpc - LABEL_4_89);
      goto label_170;

    case 70:
      current_block = (Rpc - LABEL_4_91);
      goto label_158;

    case 71:
      current_block = (Rpc - LABEL_4_37);
      goto lambda_222;

    case 72:
      current_block = (Rpc - LABEL_4_55);
      goto continuation_8;

    case 73:
      current_block = (Rpc - LABEL_4_92);
      goto loop_100;

    case 74:
      current_block = (Rpc - LABEL_4_99);
      goto label_197;

    case 75:
      current_block = (Rpc - LABEL_4_90);
      goto lambda_73;

    case 76:
      current_block = (Rpc - LABEL_4_100);
      goto lambda_27;

    case 77:
      current_block = (Rpc - LABEL_4_95);
      goto continuation_15;

    case 78:
      current_block = (Rpc - LABEL_4_66);
      goto lambda_227;

    case 79:
      current_block = (Rpc - LABEL_4_102);
      goto label_200;

    case 80:
      current_block = (Rpc - LABEL_4_103);
      goto label_201;

    case 81:
      current_block = (Rpc - LABEL_4_73);
      goto lambda_228;

    case 82:
      current_block = (Rpc - LABEL_4_104);
      goto label_198;

    case 83:
      current_block = (Rpc - LABEL_4_105);
      goto label_199;

    case 84:
      current_block = (Rpc - LABEL_4_108);
      goto phi_1_121;

    case 85:
      current_block = (Rpc - LABEL_4_109);
      goto label_206;

    case 86:
      current_block = (Rpc - LABEL_4_94);
      goto lambda_13;

    case 87:
      current_block = (Rpc - LABEL_4_50);
      goto lambda_4;

    case 88:
      current_block = (Rpc - LABEL_4_96);
      goto lambda_230;

    case 89:
      current_block = (Rpc - LABEL_4_98);
      goto continuation_96;

    case 90:
      current_block = (Rpc - LABEL_4_112);
      goto label_207;

    case 91:
      current_block = (Rpc - LABEL_4_101);
      goto continuation_26;

    case 92:
      current_block = (Rpc - LABEL_4_106);
      goto lambda_233;

    case 93:
      current_block = (Rpc - LABEL_4_117);
      goto continuation_113;

    case 94:
      current_block = (Rpc - LABEL_4_118);
      goto continuation_114;

    case 95:
      current_block = (Rpc - LABEL_4_119);
      goto label_214;

    case 96:
      current_block = (Rpc - LABEL_4_110);
      goto continuation_108;

    case 97:
      current_block = (Rpc - LABEL_4_121);
      goto label_210;

    case 98:
      current_block = (Rpc - LABEL_4_122);
      goto label_211;

    case 99:
      current_block = (Rpc - LABEL_4_123);
      goto label_212;

    case 100:
      current_block = (Rpc - LABEL_4_125);
      goto label_208;

    case 101:
      current_block = (Rpc - LABEL_4_126);
      goto label_209;

    case 102:
      current_block = (Rpc - LABEL_4_113);
      goto lambda_237;

    case 103:
      current_block = (Rpc - LABEL_4_115);
      goto lambda_238;

    case 104:
      current_block = (Rpc - LABEL_4_129);
      goto phi_2_133;

    case 105:
      current_block = (Rpc - LABEL_4_131);
      goto label_213;

    case 106:
      current_block = (Rpc - LABEL_4_127);
      goto lambda_239;

    case 107:
      current_block = (Rpc - LABEL_4_130);
      goto continuation_123;

    case 108:
      current_block = (Rpc - LABEL_4_132);
      goto label_215;

    case 109:
      current_block = (Rpc - LABEL_4_133);
      goto label_216;

    case 110:
      current_block = (Rpc - LABEL_4_120);
      goto lambda_116;

    case 111:
      current_block = (Rpc - LABEL_4_134);
      goto lambda_241;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (find_reference_instruction_218)
DEFLABEL (find_reference_instruction_144)
  INTERRUPT_CHECK (26, LABEL_4_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd14.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_4_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_4_5])));
  Rhp += 2;
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd14.pObj)));
  (* (--Rsp)) = (Wrd15.Obj);
  Wrd12 = Wrd14;
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  ((Wrd12.pObj) [3]) = (Wrd10.Obj);
  Rsp = (& (Rsp [1]));
  (Rsp [1]) = (Wrd15.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_142;

DEFLABEL (loop_219)
DEFLABEL (loop_142)
  INTERRUPT_CHECK (26, LABEL_4_5);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_4_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_4_7])));
  Rhp += 2;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd9 = Wrd6;
  (Wrd10.Obj) = (Rsp [0]);
  ((Wrd9.pObj) [2]) = (Wrd10.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  ((Wrd9.pObj) [3]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd12.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_4_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_4_9])));
  Rhp += 2;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd12.pObj)));
  Wrd17 = Wrd12;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [2]);
  ((Wrd17.pObj) [2]) = (Wrd20.Obj);
  (Wrd16.Obj) = ((Wrd19.pObj) [3]);
  ((Wrd17.pObj) [3]) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_11]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_12]));

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_4_11);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_244;
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd7.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_36]))));
  (Wrd10.Obj) = (Rsp [3]);
  (Rsp [2]) = (Wrd10.Obj);
  (Rsp [3]) = (Wrd8.Obj);

DEFLABEL (label_243)
  Rsp = (& (Rsp [1]));
  goto lambda_12;

DEFLABEL (label_244)
  (Wrd15.Obj) = (Rsp [3]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_331;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd12.Obj) = ((Wrd14.pObj) [0]);

DEFLABEL (label_330)
  if ((Wrd12.Obj) == (current_block [OBJECT_4_3]))
    goto label_326;

DEFLABEL (label_325)
  (Wrd25.Obj) = (Rsp [3]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 1))
    goto label_324;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd22.Obj) = ((Wrd24.pObj) [0]);

DEFLABEL (label_323)
  if ((Wrd22.Obj) == (current_block [OBJECT_4_4]))
    goto label_317;

DEFLABEL (label_316)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_34]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd35.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd35.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_35]));

DEFLABEL (continuation_44)
  INTERRUPT_CHECK (27, LABEL_4_34);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_247;
  (Wrd20.Obj) = (Rsp [2]);
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [3]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd23.uLng) == 10))
    goto label_246;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd19.Lng))))
    goto label_246;
  (Wrd11.Obj) = ((Wrd17.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_245)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd43.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_4_93);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_4_92])));
  Rhp += 2;
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd43.pObj)));
  (* (--Rsp)) = (Wrd44.Obj);
  Wrd39 = Wrd43;
  (Wrd40.Obj) = (Rsp [4]);
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  (Wrd42.Obj) = ((Wrd41.pObj) [2]);
  ((Wrd39.pObj) [2]) = (Wrd42.Obj);
  (Wrd37.Obj) = (Rsp [5]);
  ((Wrd39.pObj) [3]) = (Wrd37.Obj);
  Rsp = (& (Rsp [1]));
  (Rsp [3]) = (Wrd44.Obj);
  (Wrd33.Obj) = (* (Rsp++));
  (Rsp [3]) = (Wrd33.Obj);
  Rsp = (& (Rsp [2]));
  goto loop_100;

DEFLABEL (label_246)
  (Wrd25.Obj) = (Rsp [2]);
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd24.Obj) = ((Wrd26.pObj) [3]);
  (Wrd27.Obj) = (current_block [OBJECT_4_9]);
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_91]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_6]), 2);

DEFLABEL (label_158)
  (* (--Rsp)) = Rvl;
  goto label_245;

DEFLABEL (label_247)
  (Wrd48.Obj) = (Rsp [3]);
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if (! ((Wrd49.uLng) == 1))
    goto label_315;
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd45.Obj) = ((Wrd47.pObj) [0]);

DEFLABEL (label_314)
  if (! ((Wrd45.Obj) == (current_block [OBJECT_4_3])))
    goto label_249;

DEFLABEL (label_248)
  (Wrd291.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd291.Obj);
  (Wrd292.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_44]))));
  (Wrd294.Obj) = (Rsp [3]);
  (Rsp [2]) = (Wrd294.Obj);
  (Rsp [3]) = (Wrd292.Obj);
  Rsp = (& (Rsp [1]));
  goto lambda_12;

DEFLABEL (label_249)
  (Wrd58.Obj) = (Rsp [3]);
  (Wrd59.uLng) = (OBJECT_TYPE (Wrd58.Obj));
  if (! ((Wrd59.uLng) == 1))
    goto label_313;
  (Wrd57.pObj) = (OBJECT_ADDRESS (Wrd58.Obj));
  (Wrd55.Obj) = ((Wrd57.pObj) [0]);

DEFLABEL (label_312)
  if ((Wrd55.Obj) == (current_block [OBJECT_4_11]))
    goto label_248;
  (Wrd68.Obj) = (Rsp [3]);
  (Wrd69.uLng) = (OBJECT_TYPE (Wrd68.Obj));
  if (! ((Wrd69.uLng) == 1))
    goto label_311;
  (Wrd67.pObj) = (OBJECT_ADDRESS (Wrd68.Obj));
  (Wrd65.Obj) = ((Wrd67.pObj) [0]);

DEFLABEL (label_310)
  if ((Wrd65.Obj) == (current_block [OBJECT_4_12]))
    goto label_248;
  (Wrd78.Obj) = (Rsp [3]);
  (Wrd79.uLng) = (OBJECT_TYPE (Wrd78.Obj));
  if (! ((Wrd79.uLng) == 1))
    goto label_309;
  (Wrd77.pObj) = (OBJECT_ADDRESS (Wrd78.Obj));
  (Wrd75.Obj) = ((Wrd77.pObj) [0]);

DEFLABEL (label_308)
  if ((Wrd75.Obj) == (current_block [OBJECT_4_13]))
    goto label_299;

DEFLABEL (label_298)
  (Wrd88.Obj) = (Rsp [3]);
  (Wrd89.uLng) = (OBJECT_TYPE (Wrd88.Obj));
  if (! ((Wrd89.uLng) == 1))
    goto label_297;
  (Wrd87.pObj) = (OBJECT_ADDRESS (Wrd88.Obj));
  (Wrd85.Obj) = ((Wrd87.pObj) [0]);

DEFLABEL (label_296)
  if ((Wrd85.Obj) == (current_block [OBJECT_4_14]))
    goto label_287;

DEFLABEL (label_286)
  (Wrd98.Obj) = (Rsp [3]);
  (Wrd99.uLng) = (OBJECT_TYPE (Wrd98.Obj));
  if (! ((Wrd99.uLng) == 1))
    goto label_285;
  (Wrd97.pObj) = (OBJECT_ADDRESS (Wrd98.Obj));
  (Wrd95.Obj) = ((Wrd97.pObj) [0]);

DEFLABEL (label_284)
  if ((Wrd95.Obj) == (current_block [OBJECT_4_15]))
    goto label_279;
  (Wrd108.Obj) = (Rsp [3]);
  (Wrd109.uLng) = (OBJECT_TYPE (Wrd108.Obj));
  if (! ((Wrd109.uLng) == 1))
    goto label_278;
  (Wrd107.pObj) = (OBJECT_ADDRESS (Wrd108.Obj));
  (Wrd105.Obj) = ((Wrd107.pObj) [0]);

DEFLABEL (label_277)
  if ((Wrd105.Obj) == (current_block [OBJECT_4_16]))
    goto label_272;
  (Wrd118.Obj) = (Rsp [3]);
  (Wrd119.uLng) = (OBJECT_TYPE (Wrd118.Obj));
  if (! ((Wrd119.uLng) == 1))
    goto label_271;
  (Wrd117.pObj) = (OBJECT_ADDRESS (Wrd118.Obj));
  (Wrd115.Obj) = ((Wrd117.pObj) [0]);

DEFLABEL (label_270)
  if ((Wrd115.Obj) == (current_block [OBJECT_4_17]))
    goto label_265;
  (Wrd128.Obj) = (Rsp [3]);
  (Wrd129.uLng) = (OBJECT_TYPE (Wrd128.Obj));
  if (! ((Wrd129.uLng) == 1))
    goto label_264;
  (Wrd127.pObj) = (OBJECT_ADDRESS (Wrd128.Obj));
  (Wrd125.Obj) = ((Wrd127.pObj) [0]);

DEFLABEL (label_263)
  if ((Wrd125.Obj) == (current_block [OBJECT_4_18]))
    goto label_258;
  (Wrd138.Obj) = (Rsp [3]);
  (Wrd139.uLng) = (OBJECT_TYPE (Wrd138.Obj));
  if (! ((Wrd139.uLng) == 1))
    goto label_257;
  (Wrd137.pObj) = (OBJECT_ADDRESS (Wrd138.Obj));
  (Wrd135.Obj) = ((Wrd137.pObj) [0]);

DEFLABEL (label_256)
  if ((Wrd135.Obj) == (current_block [OBJECT_4_19]))
    goto label_250;
  Rvl = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_90]))));
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_250)
  (Wrd150.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_11]));
  (Wrd153.Obj) = ((Wrd150.pObj) [0]);
  (Wrd154.uLng) = (OBJECT_TYPE (Wrd153.Obj));
  if ((Wrd154.uLng) == 50)
    goto label_255;
  Wrd149 = Wrd153;

DEFLABEL (label_254)
  (Rsp [3]) = (Wrd149.Obj);
  (Wrd157.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_12]));
  (Wrd160.Obj) = ((Wrd157.pObj) [0]);
  (Wrd161.uLng) = (OBJECT_TYPE (Wrd160.Obj));
  if ((Wrd161.uLng) == 50)
    goto label_253;
  Wrd156 = Wrd160;

DEFLABEL (label_252)
  (Rsp [2]) = (Wrd156.Obj);

DEFLABEL (label_251)
  Rsp = (& (Rsp [1]));
  goto lambda_21;

DEFLABEL (label_253)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_89])), (Wrd157.pObj));

DEFLABEL (label_170)
  (Wrd156.Obj) = Rvl;
  goto label_252;

DEFLABEL (label_255)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_88])), (Wrd150.pObj));

DEFLABEL (label_169)
  (Wrd149.Obj) = Rvl;
  goto label_254;

DEFLABEL (label_257)
  (Wrd143.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_87]))));
  (* (--Rsp)) = (Wrd143.Obj);
  (* (--Rsp)) = (Wrd138.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_168)
  (Wrd135.Obj) = Rvl;
  goto label_256;

DEFLABEL (label_258)
  (Wrd165.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_9]));
  (Wrd168.Obj) = ((Wrd165.pObj) [0]);
  (Wrd169.uLng) = (OBJECT_TYPE (Wrd168.Obj));
  if ((Wrd169.uLng) == 50)
    goto label_262;
  Wrd164 = Wrd168;

DEFLABEL (label_261)
  (Rsp [3]) = (Wrd164.Obj);
  (Wrd172.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_10]));
  (Wrd175.Obj) = ((Wrd172.pObj) [0]);
  (Wrd176.uLng) = (OBJECT_TYPE (Wrd175.Obj));
  if ((Wrd176.uLng) == 50)
    goto label_260;
  Wrd171 = Wrd175;

DEFLABEL (label_259)
  (Rsp [2]) = (Wrd171.Obj);
  goto label_251;

DEFLABEL (label_260)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_86])), (Wrd172.pObj));

DEFLABEL (label_172)
  (Wrd171.Obj) = Rvl;
  goto label_259;

DEFLABEL (label_262)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_85])), (Wrd165.pObj));

DEFLABEL (label_171)
  (Wrd164.Obj) = Rvl;
  goto label_261;

DEFLABEL (label_264)
  (Wrd133.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_84]))));
  (* (--Rsp)) = (Wrd133.Obj);
  (* (--Rsp)) = (Wrd128.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_167)
  (Wrd125.Obj) = Rvl;
  goto label_263;

DEFLABEL (label_265)
  (Wrd179.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_7]));
  (Wrd182.Obj) = ((Wrd179.pObj) [0]);
  (Wrd183.uLng) = (OBJECT_TYPE (Wrd182.Obj));
  if ((Wrd183.uLng) == 50)
    goto label_269;
  Wrd178 = Wrd182;

DEFLABEL (label_268)
  (* (--Rsp)) = (Wrd178.Obj);
  (Wrd185.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_8]));
  (Wrd188.Obj) = ((Wrd185.pObj) [0]);
  (Wrd189.uLng) = (OBJECT_TYPE (Wrd188.Obj));
  if ((Wrd189.uLng) == 50)
    goto label_267;
  Wrd184 = Wrd188;

DEFLABEL (label_266)
  (* (--Rsp)) = (Wrd184.Obj);
  goto lambda_27;

DEFLABEL (label_267)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_83])), (Wrd185.pObj));

DEFLABEL (label_174)
  (Wrd184.Obj) = Rvl;
  goto label_266;

DEFLABEL (label_269)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_82])), (Wrd179.pObj));

DEFLABEL (label_173)
  (Wrd178.Obj) = Rvl;
  goto label_268;

DEFLABEL (label_271)
  (Wrd123.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_81]))));
  (* (--Rsp)) = (Wrd123.Obj);
  (* (--Rsp)) = (Wrd118.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_166)
  (Wrd115.Obj) = Rvl;
  goto label_270;

DEFLABEL (label_272)
  (Wrd191.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_5]));
  (Wrd194.Obj) = ((Wrd191.pObj) [0]);
  (Wrd195.uLng) = (OBJECT_TYPE (Wrd194.Obj));
  if ((Wrd195.uLng) == 50)
    goto label_276;
  Wrd190 = Wrd194;

DEFLABEL (label_275)
  (* (--Rsp)) = (Wrd190.Obj);
  (Wrd197.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_6]));
  (Wrd200.Obj) = ((Wrd197.pObj) [0]);
  (Wrd201.uLng) = (OBJECT_TYPE (Wrd200.Obj));
  if ((Wrd201.uLng) == 50)
    goto label_274;
  Wrd196 = Wrd200;

DEFLABEL (label_273)
  (* (--Rsp)) = (Wrd196.Obj);
  goto lambda_27;

DEFLABEL (label_274)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_80])), (Wrd197.pObj));

DEFLABEL (label_176)
  (Wrd196.Obj) = Rvl;
  goto label_273;

DEFLABEL (label_276)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_79])), (Wrd191.pObj));

DEFLABEL (label_175)
  (Wrd190.Obj) = Rvl;
  goto label_275;

DEFLABEL (label_278)
  (Wrd113.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_78]))));
  (* (--Rsp)) = (Wrd113.Obj);
  (* (--Rsp)) = (Wrd108.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_165)
  (Wrd105.Obj) = Rvl;
  goto label_277;

DEFLABEL (label_279)
  (Wrd204.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_3]));
  (Wrd207.Obj) = ((Wrd204.pObj) [0]);
  (Wrd208.uLng) = (OBJECT_TYPE (Wrd207.Obj));
  if ((Wrd208.uLng) == 50)
    goto label_283;
  Wrd203 = Wrd207;

DEFLABEL (label_282)
  (Rsp [3]) = (Wrd203.Obj);
  (Wrd211.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_4]));
  (Wrd214.Obj) = ((Wrd211.pObj) [0]);
  (Wrd215.uLng) = (OBJECT_TYPE (Wrd214.Obj));
  if ((Wrd215.uLng) == 50)
    goto label_281;
  Wrd210 = Wrd214;

DEFLABEL (label_280)
  (Rsp [2]) = (Wrd210.Obj);
  goto label_251;

DEFLABEL (label_281)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_77])), (Wrd211.pObj));

DEFLABEL (label_178)
  (Wrd210.Obj) = Rvl;
  goto label_280;

DEFLABEL (label_283)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_76])), (Wrd204.pObj));

DEFLABEL (label_177)
  (Wrd203.Obj) = Rvl;
  goto label_282;

DEFLABEL (label_285)
  (Wrd103.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_75]))));
  (* (--Rsp)) = (Wrd103.Obj);
  (* (--Rsp)) = (Wrd98.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_164)
  (Wrd95.Obj) = Rvl;
  goto label_284;

DEFLABEL (label_287)
  (Wrd220.Obj) = (Rsp [3]);
  (Wrd221.uLng) = (OBJECT_TYPE (Wrd220.Obj));
  if (! ((Wrd221.uLng) == 1))
    goto label_295;
  (Wrd219.pObj) = (OBJECT_ADDRESS (Wrd220.Obj));
  (Wrd217.Obj) = ((Wrd219.pObj) [1]);

DEFLABEL (label_294)
  (Wrd228.uLng) = (OBJECT_TYPE (Wrd217.Obj));
  if (! ((Wrd228.uLng) == 1))
    goto label_293;
  (Wrd227.pObj) = (OBJECT_ADDRESS (Wrd217.Obj));
  (Wrd226.Obj) = ((Wrd227.pObj) [0]);

DEFLABEL (label_292)
  (Wrd235.uLng) = (OBJECT_TYPE (Wrd226.Obj));
  if (! ((Wrd235.uLng) == 1))
    goto label_291;
  (Wrd234.pObj) = (OBJECT_ADDRESS (Wrd226.Obj));
  (Wrd233.Obj) = ((Wrd234.pObj) [0]);

DEFLABEL (label_290)
  if (! ((Wrd233.Obj) == (current_block [OBJECT_4_2])))
    goto label_286;
  (Wrd243.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_2]));
  (Wrd246.Obj) = ((Wrd243.pObj) [0]);
  (Wrd247.uLng) = (OBJECT_TYPE (Wrd246.Obj));
  if ((Wrd247.uLng) == 50)
    goto label_289;
  Wrd242 = Wrd246;

DEFLABEL (label_288)
  (Rsp [2]) = (Wrd242.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd250.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_4_74);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_4_73])));
  Rhp += 1;
  (Wrd249.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd250.pObj)));
  Wrd251 = Wrd250;
  (Wrd252.Obj) = (Rsp [3]);
  ((Wrd251.pObj) [2]) = (Wrd252.Obj);
  (Rsp [3]) = (Wrd249.Obj);
  goto label_251;

DEFLABEL (label_289)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_72])), (Wrd243.pObj));

DEFLABEL (label_182)
  (Wrd242.Obj) = Rvl;
  goto label_288;

DEFLABEL (label_291)
  (Wrd239.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_71]))));
  (* (--Rsp)) = (Wrd239.Obj);
  (* (--Rsp)) = (Wrd226.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_181)
  (Wrd233.Obj) = Rvl;
  goto label_290;

DEFLABEL (label_293)
  (Wrd232.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_70]))));
  (* (--Rsp)) = (Wrd232.Obj);
  (* (--Rsp)) = (Wrd217.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_180)
  (Wrd226.Obj) = Rvl;
  goto label_292;

DEFLABEL (label_295)
  (Wrd225.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_69]))));
  (* (--Rsp)) = (Wrd225.Obj);
  (* (--Rsp)) = (Wrd220.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_0]), 1);

DEFLABEL (label_179)
  (Wrd217.Obj) = Rvl;
  goto label_294;

DEFLABEL (label_297)
  (Wrd93.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_68]))));
  (* (--Rsp)) = (Wrd93.Obj);
  (* (--Rsp)) = (Wrd88.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_163)
  (Wrd85.Obj) = Rvl;
  goto label_296;

DEFLABEL (label_299)
  (Wrd257.Obj) = (Rsp [3]);
  (Wrd258.uLng) = (OBJECT_TYPE (Wrd257.Obj));
  if (! ((Wrd258.uLng) == 1))
    goto label_307;
  (Wrd256.pObj) = (OBJECT_ADDRESS (Wrd257.Obj));
  (Wrd254.Obj) = ((Wrd256.pObj) [1]);

DEFLABEL (label_306)
  (Wrd265.uLng) = (OBJECT_TYPE (Wrd254.Obj));
  if (! ((Wrd265.uLng) == 1))
    goto label_305;
  (Wrd264.pObj) = (OBJECT_ADDRESS (Wrd254.Obj));
  (Wrd263.Obj) = ((Wrd264.pObj) [0]);

DEFLABEL (label_304)
  (Wrd272.uLng) = (OBJECT_TYPE (Wrd263.Obj));
  if (! ((Wrd272.uLng) == 1))
    goto label_303;
  (Wrd271.pObj) = (OBJECT_ADDRESS (Wrd263.Obj));
  (Wrd270.Obj) = ((Wrd271.pObj) [0]);

DEFLABEL (label_302)
  if (! ((Wrd270.Obj) == (current_block [OBJECT_4_2])))
    goto label_298;
  (Wrd280.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_1]));
  (Wrd283.Obj) = ((Wrd280.pObj) [0]);
  (Wrd284.uLng) = (OBJECT_TYPE (Wrd283.Obj));
  if ((Wrd284.uLng) == 50)
    goto label_301;
  Wrd279 = Wrd283;

DEFLABEL (label_300)
  (Rsp [2]) = (Wrd279.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd287.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_4_67);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_4_66])));
  Rhp += 1;
  (Wrd286.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd287.pObj)));
  Wrd288 = Wrd287;
  (Wrd289.Obj) = (Rsp [3]);
  ((Wrd288.pObj) [2]) = (Wrd289.Obj);
  (Rsp [3]) = (Wrd286.Obj);
  goto label_251;

DEFLABEL (label_301)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_65])), (Wrd280.pObj));

DEFLABEL (label_186)
  (Wrd279.Obj) = Rvl;
  goto label_300;

DEFLABEL (label_303)
  (Wrd276.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_64]))));
  (* (--Rsp)) = (Wrd276.Obj);
  (* (--Rsp)) = (Wrd263.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_185)
  (Wrd270.Obj) = Rvl;
  goto label_302;

DEFLABEL (label_305)
  (Wrd269.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_63]))));
  (* (--Rsp)) = (Wrd269.Obj);
  (* (--Rsp)) = (Wrd254.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_184)
  (Wrd263.Obj) = Rvl;
  goto label_304;

DEFLABEL (label_307)
  (Wrd262.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_62]))));
  (* (--Rsp)) = (Wrd262.Obj);
  (* (--Rsp)) = (Wrd257.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_0]), 1);

DEFLABEL (label_183)
  (Wrd254.Obj) = Rvl;
  goto label_306;

DEFLABEL (label_309)
  (Wrd83.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_61]))));
  (* (--Rsp)) = (Wrd83.Obj);
  (* (--Rsp)) = (Wrd78.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_162)
  (Wrd75.Obj) = Rvl;
  goto label_308;

DEFLABEL (label_311)
  (Wrd73.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_60]))));
  (* (--Rsp)) = (Wrd73.Obj);
  (* (--Rsp)) = (Wrd68.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_161)
  (Wrd65.Obj) = Rvl;
  goto label_310;

DEFLABEL (label_313)
  (Wrd63.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_59]))));
  (* (--Rsp)) = (Wrd63.Obj);
  (* (--Rsp)) = (Wrd58.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_160)
  (Wrd55.Obj) = Rvl;
  goto label_312;

DEFLABEL (label_315)
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_58]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_159)
  (Wrd45.Obj) = Rvl;
  goto label_314;

DEFLABEL (label_317)
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_25]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd42.Obj) = (Rsp [4]);
  (Wrd43.uLng) = (OBJECT_TYPE (Wrd42.Obj));
  if (! ((Wrd43.uLng) == 1))
    goto label_322;
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd42.Obj));
  (Wrd39.Obj) = ((Wrd41.pObj) [1]);

DEFLABEL (label_321)
  (Wrd50.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if (! ((Wrd50.uLng) == 1))
    goto label_319;
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd39.Obj));
  (Wrd49.Obj) = ((Wrd48.pObj) [0]);
  (* (--Rsp)) = (Wrd49.Obj);

DEFLABEL (label_318)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_33]));

DEFLABEL (label_319)
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_32]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_149)
DEFLABEL (label_320)
  (* (--Rsp)) = Rvl;
  goto label_318;

DEFLABEL (label_322)
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_31]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_0]), 1);

DEFLABEL (label_148)
  (Wrd39.Obj) = Rvl;
  goto label_321;

DEFLABEL (label_324)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_30]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_147)
  (Wrd22.Obj) = Rvl;
  goto label_323;

DEFLABEL (label_326)
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_15]))));
  (* (--Rsp)) = (Wrd57.Obj);
  (Wrd61.Obj) = (Rsp [4]);
  (Wrd62.uLng) = (OBJECT_TYPE (Wrd61.Obj));
  if (! ((Wrd62.uLng) == 1))
    goto label_329;
  (Wrd60.pObj) = (OBJECT_ADDRESS (Wrd61.Obj));
  (Wrd58.Obj) = ((Wrd60.pObj) [1]);

DEFLABEL (label_328)
  (Wrd69.uLng) = (OBJECT_TYPE (Wrd58.Obj));
  if (! ((Wrd69.uLng) == 1))
    goto label_327;
  (Wrd67.pObj) = (OBJECT_ADDRESS (Wrd58.Obj));
  (Wrd68.Obj) = ((Wrd67.pObj) [0]);
  (* (--Rsp)) = (Wrd68.Obj);
  goto label_318;

DEFLABEL (label_327)
  (Wrd73.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_29]))));
  (* (--Rsp)) = (Wrd73.Obj);
  (* (--Rsp)) = (Wrd58.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_151)
  goto label_320;

DEFLABEL (label_329)
  (Wrd66.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_28]))));
  (* (--Rsp)) = (Wrd66.Obj);
  (* (--Rsp)) = (Wrd61.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_0]), 1);

DEFLABEL (label_150)
  (Wrd58.Obj) = Rvl;
  goto label_328;

DEFLABEL (label_331)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_27]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_146)
  (Wrd12.Obj) = Rvl;
  goto label_330;

DEFLABEL (continuation_43)
  INTERRUPT_CHECK (27, LABEL_4_25);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_316;
  (Wrd76.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd76.Obj);
  (Wrd79.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_0]));
  (Wrd82.Obj) = ((Wrd79.pObj) [0]);
  (Wrd83.uLng) = (OBJECT_TYPE (Wrd82.Obj));
  if ((Wrd83.uLng) == 50)
    goto label_333;
  Wrd78 = Wrd82;

DEFLABEL (label_332)
  (Wrd84.Obj) = (Rsp [3]);
  (Rsp [2]) = (Wrd84.Obj);
  (Rsp [3]) = (Wrd78.Obj);
  goto label_243;

DEFLABEL (label_333)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_26])), (Wrd79.pObj));

DEFLABEL (label_187)
  (Wrd78.Obj) = Rvl;
  goto label_332;

DEFLABEL (continuation_33)
  INTERRUPT_CHECK (27, LABEL_4_15);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_325;
  (Wrd91.Obj) = (Rsp [3]);
  (Wrd92.uLng) = (OBJECT_TYPE (Wrd91.Obj));
  if (! ((Wrd92.uLng) == 1))
    goto label_351;
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  (Wrd88.Obj) = ((Wrd90.pObj) [1]);

DEFLABEL (label_350)
  (Wrd99.uLng) = (OBJECT_TYPE (Wrd88.Obj));
  if (! ((Wrd99.uLng) == 1))
    goto label_349;
  (Wrd98.pObj) = (OBJECT_ADDRESS (Wrd88.Obj));
  (Wrd97.Obj) = ((Wrd98.pObj) [1]);

DEFLABEL (label_348)
  (Wrd106.uLng) = (OBJECT_TYPE (Wrd97.Obj));
  if (! ((Wrd106.uLng) == 1))
    goto label_347;
  (Wrd105.pObj) = (OBJECT_ADDRESS (Wrd97.Obj));
  (Wrd104.Obj) = ((Wrd105.pObj) [0]);

DEFLABEL (label_346)
  (Wrd113.uLng) = (OBJECT_TYPE (Wrd104.Obj));
  if (! ((Wrd113.uLng) == 1))
    goto label_345;
  (Wrd112.pObj) = (OBJECT_ADDRESS (Wrd104.Obj));
  (Wrd111.Obj) = ((Wrd112.pObj) [0]);

DEFLABEL (label_344)
  if (! ((Wrd111.Obj) == (current_block [OBJECT_4_2])))
    goto label_325;
  (Wrd122.Obj) = (Rsp [3]);
  (Wrd123.uLng) = (OBJECT_TYPE (Wrd122.Obj));
  if (! ((Wrd123.uLng) == 1))
    goto label_343;
  (Wrd121.pObj) = (OBJECT_ADDRESS (Wrd122.Obj));
  (Wrd119.Obj) = ((Wrd121.pObj) [1]);

DEFLABEL (label_342)
  (Wrd130.uLng) = (OBJECT_TYPE (Wrd119.Obj));
  if (! ((Wrd130.uLng) == 1))
    goto label_341;
  (Wrd129.pObj) = (OBJECT_ADDRESS (Wrd119.Obj));
  (Wrd128.Obj) = ((Wrd129.pObj) [1]);

DEFLABEL (label_340)
  (Wrd137.uLng) = (OBJECT_TYPE (Wrd128.Obj));
  if (! ((Wrd137.uLng) == 1))
    goto label_339;
  (Wrd136.pObj) = (OBJECT_ADDRESS (Wrd128.Obj));
  (Wrd135.Obj) = ((Wrd136.pObj) [0]);

DEFLABEL (label_338)
  (Wrd144.uLng) = (OBJECT_TYPE (Wrd135.Obj));
  if (! ((Wrd144.uLng) == 1))
    goto label_337;
  (Wrd143.pObj) = (OBJECT_ADDRESS (Wrd135.Obj));
  (Wrd142.Obj) = ((Wrd143.pObj) [1]);

DEFLABEL (label_336)
  (Wrd151.uLng) = (OBJECT_TYPE (Wrd142.Obj));
  if (! ((Wrd151.uLng) == 1))
    goto label_335;
  (Wrd149.pObj) = (OBJECT_ADDRESS (Wrd142.Obj));
  (Wrd150.Obj) = ((Wrd149.pObj) [0]);
  (* (--Rsp)) = (Wrd150.Obj);

DEFLABEL (label_334)
  (Wrd156.Obj) = (Rsp [3]);
  (Wrd157.pObj) = (OBJECT_ADDRESS (Wrd156.Obj));
  (Wrd158.Obj) = ((Wrd157.pObj) [3]);
  (* (--Rsp)) = (Wrd158.Obj);
  goto phi_1_121;

DEFLABEL (label_335)
  (Wrd155.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_24]))));
  (* (--Rsp)) = (Wrd155.Obj);
  (* (--Rsp)) = (Wrd142.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_196)
  (* (--Rsp)) = Rvl;
  goto label_334;

DEFLABEL (label_337)
  (Wrd148.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_23]))));
  (* (--Rsp)) = (Wrd148.Obj);
  (* (--Rsp)) = (Wrd135.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_0]), 1);

DEFLABEL (label_195)
  (Wrd142.Obj) = Rvl;
  goto label_336;

DEFLABEL (label_339)
  (Wrd141.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_22]))));
  (* (--Rsp)) = (Wrd141.Obj);
  (* (--Rsp)) = (Wrd128.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_194)
  (Wrd135.Obj) = Rvl;
  goto label_338;

DEFLABEL (label_341)
  (Wrd134.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_21]))));
  (* (--Rsp)) = (Wrd134.Obj);
  (* (--Rsp)) = (Wrd119.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_0]), 1);

DEFLABEL (label_193)
  (Wrd128.Obj) = Rvl;
  goto label_340;

DEFLABEL (label_343)
  (Wrd127.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_20]))));
  (* (--Rsp)) = (Wrd127.Obj);
  (* (--Rsp)) = (Wrd122.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_0]), 1);

DEFLABEL (label_192)
  (Wrd119.Obj) = Rvl;
  goto label_342;

DEFLABEL (label_345)
  (Wrd117.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_19]))));
  (* (--Rsp)) = (Wrd117.Obj);
  (* (--Rsp)) = (Wrd104.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_191)
  (Wrd111.Obj) = Rvl;
  goto label_344;

DEFLABEL (label_347)
  (Wrd110.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_18]))));
  (* (--Rsp)) = (Wrd110.Obj);
  (* (--Rsp)) = (Wrd97.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_190)
  (Wrd104.Obj) = Rvl;
  goto label_346;

DEFLABEL (label_349)
  (Wrd103.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_17]))));
  (* (--Rsp)) = (Wrd103.Obj);
  (* (--Rsp)) = (Wrd88.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_0]), 1);

DEFLABEL (label_189)
  (Wrd97.Obj) = Rvl;
  goto label_348;

DEFLABEL (label_351)
  (Wrd96.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_16]))));
  (* (--Rsp)) = (Wrd96.Obj);
  (* (--Rsp)) = (Wrd91.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_0]), 1);

DEFLABEL (label_188)
  (Wrd88.Obj) = Rvl;
  goto label_350;

DEFLABEL (lambda_220)
DEFLABEL (lambda_21)
  INTERRUPT_CHECK (26, LABEL_4_7);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_14]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [3]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd14.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_4_14);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [2]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  goto loop_142;

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_4_13);
  (Rsp [1]) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_4_38);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_4_37])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  Wrd9 = Wrd8;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd9.pObj) [2]) = (Wrd10.Obj);
  (Rsp [2]) = (Wrd7.Obj);
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (lambda_221)
DEFLABEL (lambda_12)
  INTERRUPT_CHECK (26, LABEL_4_9);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  goto phi_1_6;

DEFLABEL (phi_1_223)
DEFLABEL (phi_1_6)
  INTERRUPT_CHECK (26, LABEL_4_39);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_40]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_360;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd16.Lng))))
    goto label_360;
  (Wrd10.Obj) = ((Wrd14.pObj) [1]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_359)
  (Wrd24.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd24.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_4_40);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_353;

DEFLABEL (label_352)
  Rvl = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_50]))));
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_353)
  (Wrd25.Obj) = (Rsp [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 10))
    goto label_358;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [0]);
  (Wrd24.Lng) = (FIXNUM_TO_LONG (Wrd23.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd24.Lng))))
    goto label_358;
  (Wrd16.Obj) = ((Wrd22.pObj) [3]);

DEFLABEL (label_357)
  (Rsp [0]) = (Wrd16.Obj);
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_55]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd45.uLng) == 10))
    goto label_356;
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd42.Obj) = ((Wrd41.pObj) [0]);
  (Wrd43.Lng) = (FIXNUM_TO_LONG (Wrd42.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd43.Lng))))
    goto label_356;
  (Wrd37.Obj) = ((Wrd41.pObj) [2]);
  (* (--Rsp)) = (Wrd37.Obj);

DEFLABEL (label_355)
  (Wrd51.Obj) = (Rsp [3]);
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [2]);
  (* (--Rsp)) = (Wrd53.Obj);

DEFLABEL (label_354)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_57]));

DEFLABEL (label_356)
  (Wrd46.Obj) = (Rsp [1]);
  (Wrd47.Obj) = (current_block [OBJECT_4_10]);
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_56]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd46.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_6]), 2);

DEFLABEL (label_155)
  (* (--Rsp)) = Rvl;
  goto label_355;

DEFLABEL (label_358)
  (Wrd27.Obj) = (Rsp [0]);
  (Wrd28.Obj) = (current_block [OBJECT_4_9]);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_54]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_6]), 2);

DEFLABEL (label_154)
  (Wrd16.Obj) = Rvl;
  goto label_357;

DEFLABEL (label_360)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_4_5]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_41]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_6]), 2);

DEFLABEL (label_152)
  (* (--Rsp)) = Rvl;
  goto label_359;

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_4_55);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_361;
  (Wrd7.Obj) = (Rsp [2]);
  (Rsp [3]) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd8.Obj);
  Rsp = (& (Rsp [2]));
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd11.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_4_97);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_4_96])));
  Rhp += 2;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd11.pObj)));
  Wrd14 = Wrd11;
  (Wrd15.Obj) = (Rsp [1]);
  ((Wrd14.pObj) [2]) = (Wrd15.Obj);
  (Wrd13.Obj) = (Rsp [0]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  Rvl = (Wrd10.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_361)
  goto phi_1_6;

DEFLABEL (lambda_226)
DEFLABEL (lambda_139)
  INTERRUPT_CHECK (26, LABEL_4_36);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_369;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [0]);

DEFLABEL (label_368)
  if ((Wrd5.Obj) == (current_block [OBJECT_4_7]))
    goto label_363;

DEFLABEL (label_362)
  Rsp = (& (Rsp [2]));
  goto label_353;

DEFLABEL (label_363)
  (Wrd57.Obj) = (Rsp [0]);
  (Wrd58.uLng) = (OBJECT_TYPE (Wrd57.Obj));
  if (! ((Wrd58.uLng) == 1))
    goto label_367;
  (Wrd56.pObj) = (OBJECT_ADDRESS (Wrd57.Obj));
  (Wrd54.Obj) = ((Wrd56.pObj) [1]);

DEFLABEL (label_366)
  (Wrd65.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if (! ((Wrd65.uLng) == 1))
    goto label_365;
  (Wrd64.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd63.Obj) = ((Wrd64.pObj) [0]);

DEFLABEL (label_364)
  (Rsp [0]) = (Wrd63.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_12]));

DEFLABEL (label_365)
  (Wrd69.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_53]))));
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd54.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_157)
  (Wrd63.Obj) = Rvl;
  goto label_364;

DEFLABEL (label_367)
  (Wrd62.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_52]))));
  (* (--Rsp)) = (Wrd62.Obj);
  (* (--Rsp)) = (Wrd57.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_0]), 1);

DEFLABEL (label_156)
  (Wrd54.Obj) = Rvl;
  goto label_366;

DEFLABEL (label_369)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_51]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_153)
  (Wrd5.Obj) = Rvl;
  goto label_368;

DEFLABEL (lambda_222)
  CLOSURE_HEADER (LABEL_4_37);

DEFLABEL (lambda_18)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  if (! ((Wrd5.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_370;
  Rvl = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_94]))));
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_370)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_95]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_4_95);
  (Wrd36.Obj) = Rvl;

DEFLABEL (label_371)
  (Rsp [2]) = (Wrd36.Obj);
  Rsp = (& (Rsp [1]));
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd42.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_4_107);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_4_106])));
  Rhp += 2;
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd42.pObj)));
  Wrd45 = Wrd42;
  (Wrd46.Obj) = (Rsp [1]);
  ((Wrd45.pObj) [2]) = (Wrd46.Obj);
  (Wrd44.Obj) = (Rsp [0]);
  ((Wrd45.pObj) [3]) = (Wrd44.Obj);
  Rvl = (Wrd41.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (loop_229)
DEFLABEL (loop_100)
  INTERRUPT_CHECK (26, LABEL_4_92);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_98]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_376;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_376;
  (Wrd10.Obj) = ((Wrd14.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_375)
  (Wrd24.Obj) = (Rsp [2]);
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [2]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_57]));

DEFLABEL (continuation_96)
  INTERRUPT_CHECK (27, LABEL_4_98);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_372;
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [3]);
  (Wrd10.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd10.Obj);
  (Rsp [1]) = (Wrd7.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd13.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_4_114);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_4_113])));
  Rhp += 2;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd13.pObj)));
  Wrd16 = Wrd13;
  ((Wrd16.pObj) [2]) = (Wrd7.Obj);
  ((Wrd16.pObj) [3]) = (Wrd10.Obj);
  Rvl = (Wrd12.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_372)
  (Wrd18.Obj) = (Rsp [0]);
  (Rsp [0]) = (Wrd18.Obj);
  (Wrd28.Obj) = (Rsp [1]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if (! ((Wrd29.uLng) == 10))
    goto label_374;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd27.Lng))))
    goto label_374;
  (Wrd19.Obj) = ((Wrd25.pObj) [3]);

DEFLABEL (label_373)
  (Rsp [1]) = (Wrd19.Obj);
  goto loop_100;

DEFLABEL (label_374)
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd31.Obj) = (current_block [OBJECT_4_9]);
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_112]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_6]), 2);

DEFLABEL (label_207)
  (Wrd19.Obj) = Rvl;
  goto label_373;

DEFLABEL (label_376)
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.Obj) = (current_block [OBJECT_4_10]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_99]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_6]), 2);

DEFLABEL (label_197)
  (* (--Rsp)) = Rvl;
  goto label_375;

DEFLABEL (lambda_231)
DEFLABEL (lambda_73)
  INTERRUPT_CHECK (26, LABEL_4_90);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Rsp [2]) = ((SCHEME_OBJECT) 0);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (lambda_232)
DEFLABEL (lambda_27)
  INTERRUPT_CHECK (26, LABEL_4_100);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_101]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd10.Obj);
  goto lambda_21;

DEFLABEL (continuation_26)
  INTERRUPT_CHECK (27, LABEL_4_101);
  (Rsp [4]) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_4_116);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_4_115])));
  Rhp += 2;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  Wrd11 = Wrd8;
  (Wrd12.Obj) = (Rsp [5]);
  ((Wrd11.pObj) [2]) = (Wrd12.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd11.pObj) [3]) = (Wrd10.Obj);
  (Rsp [5]) = (Wrd7.Obj);
  Rsp = (& (Rsp [4]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (lambda_228)
  CLOSURE_HEADER (LABEL_4_73);

DEFLABEL (lambda_79)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [2]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_381;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd5.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_380)
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_379;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd20.Obj) = ((Wrd21.pObj) [0]);

DEFLABEL (label_378)
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd31.Obj) = (current_block [OBJECT_4_20]);
  (* (Rhp++)) = (Wrd30.Obj);
  (* (Rhp++)) = (Wrd31.Obj);
  (Wrd29.pObj) = (& (Rhp [-2]));
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd29.pObj)));
  (* (Rhp++)) = (Wrd20.Obj);
  (* (Rhp++)) = (Wrd27.Obj);
  (Wrd34.pObj) = (& (Rhp [-2]));
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd34.pObj)));
  (Wrd39.Obj) = (current_block [OBJECT_4_14]);
  (* (Rhp++)) = (Wrd39.Obj);
  (* (Rhp++)) = (Wrd32.Obj);

DEFLABEL (label_377)
  (Wrd80.pObj) = (& (Rhp [-2]));
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd80.pObj)));
  Rsp = (& (Rsp [3]));
  goto label_371;

DEFLABEL (label_379)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_105]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_199)
  (Wrd20.Obj) = Rvl;
  goto label_378;

DEFLABEL (label_381)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_104]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_0]), 1);

DEFLABEL (label_198)
  (Wrd5.Obj) = Rvl;
  goto label_380;

DEFLABEL (lambda_227)
  CLOSURE_HEADER (LABEL_4_66);

DEFLABEL (lambda_84)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd53.Obj) = (Rsp [0]);
  (Wrd54.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd55.Obj) = ((Wrd54.pObj) [2]);
  (Wrd56.uLng) = (OBJECT_TYPE (Wrd55.Obj));
  if (! ((Wrd56.uLng) == 1))
    goto label_385;
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd55.Obj));
  (Wrd48.Obj) = ((Wrd52.pObj) [1]);

DEFLABEL (label_384)
  (Wrd65.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if (! ((Wrd65.uLng) == 1))
    goto label_383;
  (Wrd64.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd63.Obj) = ((Wrd64.pObj) [0]);

DEFLABEL (label_382)
  (Wrd73.Obj) = (Rsp [1]);
  (Wrd74.Obj) = (current_block [OBJECT_4_20]);
  (* (Rhp++)) = (Wrd73.Obj);
  (* (Rhp++)) = (Wrd74.Obj);
  (Wrd72.pObj) = (& (Rhp [-2]));
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd72.pObj)));
  (* (Rhp++)) = (Wrd63.Obj);
  (* (Rhp++)) = (Wrd70.Obj);
  (Wrd77.pObj) = (& (Rhp [-2]));
  (Wrd75.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd77.pObj)));
  (Wrd81.Obj) = (current_block [OBJECT_4_13]);
  (* (Rhp++)) = (Wrd81.Obj);
  (* (Rhp++)) = (Wrd75.Obj);
  goto label_377;

DEFLABEL (label_383)
  (Wrd69.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_103]))));
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_201)
  (Wrd63.Obj) = Rvl;
  goto label_382;

DEFLABEL (label_385)
  (Wrd62.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_102]))));
  (* (--Rsp)) = (Wrd62.Obj);
  (* (--Rsp)) = (Wrd55.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_0]), 1);

DEFLABEL (label_200)
  (Wrd48.Obj) = Rvl;
  goto label_384;

DEFLABEL (lambda_225)
DEFLABEL (lambda_92)
  INTERRUPT_CHECK (26, LABEL_4_44);
  (Wrd77.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_43]))));
  (* (--Rsp)) = (Wrd77.Obj);
  (Wrd81.Obj) = (Rsp [1]);
  (Wrd82.uLng) = (OBJECT_TYPE (Wrd81.Obj));
  if (! ((Wrd82.uLng) == 1))
    goto label_395;
  (Wrd80.pObj) = (OBJECT_ADDRESS (Wrd81.Obj));
  (Wrd78.Obj) = ((Wrd80.pObj) [0]);

DEFLABEL (label_394)
  if ((Wrd78.Obj) == (current_block [OBJECT_4_7]))
    goto label_388;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_387)
  (Wrd90.Obj) = (Rsp [0]);
  if (! ((Wrd90.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_386;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_49]));

DEFLABEL (label_386)
  Rsp = (& (Rsp [3]));
  if ((Wrd90.Obj) == ((SCHEME_OBJECT) 0))
    goto label_353;
  goto label_352;

DEFLABEL (label_388)
  (Wrd96.Obj) = (current_block [OBJECT_4_8]);
  (* (--Rsp)) = (Wrd96.Obj);
  (Wrd100.Obj) = (Rsp [2]);
  (Wrd101.uLng) = (OBJECT_TYPE (Wrd100.Obj));
  if (! ((Wrd101.uLng) == 1))
    goto label_393;
  (Wrd99.pObj) = (OBJECT_ADDRESS (Wrd100.Obj));
  (Wrd97.Obj) = ((Wrd99.pObj) [1]);

DEFLABEL (label_392)
  (Wrd108.uLng) = (OBJECT_TYPE (Wrd97.Obj));
  if (! ((Wrd108.uLng) == 1))
    goto label_391;
  (Wrd107.pObj) = (OBJECT_ADDRESS (Wrd97.Obj));
  (Wrd106.Obj) = ((Wrd107.pObj) [0]);

DEFLABEL (label_390)
  (Wrd115.uLng) = (OBJECT_TYPE (Wrd106.Obj));
  if (! ((Wrd115.uLng) == 1))
    goto label_389;
  (Wrd113.pObj) = (OBJECT_ADDRESS (Wrd106.Obj));
  (Wrd114.Obj) = ((Wrd113.pObj) [0]);
  (* (--Rsp)) = (Wrd114.Obj);
  goto label_354;

DEFLABEL (label_389)
  (Wrd119.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_48]))));
  (* (--Rsp)) = (Wrd119.Obj);
  (* (--Rsp)) = (Wrd106.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_205)
  (* (--Rsp)) = Rvl;
  goto label_354;

DEFLABEL (label_391)
  (Wrd112.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_47]))));
  (* (--Rsp)) = (Wrd112.Obj);
  (* (--Rsp)) = (Wrd97.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_204)
  (Wrd106.Obj) = Rvl;
  goto label_390;

DEFLABEL (label_393)
  (Wrd105.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_46]))));
  (* (--Rsp)) = (Wrd105.Obj);
  (* (--Rsp)) = (Wrd100.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_0]), 1);

DEFLABEL (label_203)
  (Wrd97.Obj) = Rvl;
  goto label_392;

DEFLABEL (label_395)
  (Wrd86.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_45]))));
  (* (--Rsp)) = (Wrd86.Obj);
  (* (--Rsp)) = (Wrd81.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_202)
  (Wrd78.Obj) = Rvl;
  goto label_394;

DEFLABEL (continuation_87)
  INTERRUPT_CHECK (27, LABEL_4_43);
  (* (--Rsp)) = Rvl;
  goto label_387;

DEFLABEL (phi_1_234)
DEFLABEL (phi_1_121)
  INTERRUPT_CHECK (26, LABEL_4_108);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_415;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd13.Lng))))
    goto label_415;
  (Wrd7.Obj) = ((Wrd11.pObj) [1]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_414)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_110]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_111]));

DEFLABEL (continuation_108)
  INTERRUPT_CHECK (27, LABEL_4_110);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_401;
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_400;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd15.Lng))))
    goto label_400;
  (Wrd7.Obj) = ((Wrd13.pObj) [3]);

DEFLABEL (label_399)
  (Rsp [1]) = (Wrd7.Obj);
  (Wrd28.Obj) = (Rsp [2]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if (! ((Wrd29.uLng) == 26))
    goto label_398;
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  (Wrd30.Lng) = ((Wrd32.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd30.Lng)))
    goto label_398;
  (Wrd27.Obj) = (LONG_TO_FIXNUM (Wrd30.Lng));

DEFLABEL (label_397)
  (Rsp [2]) = (Wrd27.Obj);

DEFLABEL (label_396)
  Rsp = (& (Rsp [1]));
  goto phi_2_133;

DEFLABEL (label_398)
  (Wrd23.Obj) = (Rsp [2]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_126]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_209)
  (Wrd27.Obj) = Rvl;
  goto label_397;

DEFLABEL (label_400)
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.Obj) = (current_block [OBJECT_4_9]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_125]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_6]), 2);

DEFLABEL (label_208)
  (Wrd7.Obj) = Rvl;
  goto label_399;

DEFLABEL (label_401)
  (Wrd37.Obj) = (Rsp [0]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd38.uLng) == 1))
    goto label_413;
  (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd34.Obj) = ((Wrd36.pObj) [0]);

DEFLABEL (label_412)
  if ((Wrd34.Obj) == (current_block [OBJECT_4_7]))
    goto label_407;

DEFLABEL (label_406)
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_118]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd47.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd47.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_49]));

DEFLABEL (continuation_114)
  INTERRUPT_CHECK (27, LABEL_4_118);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_403;

DEFLABEL (label_402)
  Rvl = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_120]))));
  Rsp = (& (Rsp [7]));
  goto pop_return;

DEFLABEL (label_403)
  (Wrd82.Obj) = (Rsp [1]);
  (Wrd83.uLng) = (OBJECT_TYPE (Wrd82.Obj));
  if (! ((Wrd83.uLng) == 10))
    goto label_405;
  (Wrd79.pObj) = (OBJECT_ADDRESS (Wrd82.Obj));
  (Wrd80.Obj) = ((Wrd79.pObj) [0]);
  (Wrd81.Lng) = (FIXNUM_TO_LONG (Wrd80.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd81.Lng))))
    goto label_405;
  (Wrd73.Obj) = ((Wrd79.pObj) [3]);

DEFLABEL (label_404)
  (Rsp [1]) = (Wrd73.Obj);
  goto label_396;

DEFLABEL (label_405)
  (Wrd84.Obj) = (Rsp [1]);
  (Wrd85.Obj) = (current_block [OBJECT_4_9]);
  (Wrd88.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_119]))));
  (* (--Rsp)) = (Wrd88.Obj);
  (* (--Rsp)) = (Wrd85.Obj);
  (* (--Rsp)) = (Wrd84.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_6]), 2);

DEFLABEL (label_214)
  (Wrd73.Obj) = Rvl;
  goto label_404;

DEFLABEL (label_407)
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_117]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (Wrd51.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd51.Obj);
  (Wrd55.Obj) = (Rsp [2]);
  (Wrd56.uLng) = (OBJECT_TYPE (Wrd55.Obj));
  if (! ((Wrd56.uLng) == 1))
    goto label_411;
  (Wrd54.pObj) = (OBJECT_ADDRESS (Wrd55.Obj));
  (Wrd52.Obj) = ((Wrd54.pObj) [1]);

DEFLABEL (label_410)
  (Wrd63.uLng) = (OBJECT_TYPE (Wrd52.Obj));
  if (! ((Wrd63.uLng) == 1))
    goto label_409;
  (Wrd61.pObj) = (OBJECT_ADDRESS (Wrd52.Obj));
  (Wrd62.Obj) = ((Wrd61.pObj) [0]);
  (* (--Rsp)) = (Wrd62.Obj);

DEFLABEL (label_408)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_124]));

DEFLABEL (continuation_113)
  INTERRUPT_CHECK (27, LABEL_4_117);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_406;
  goto label_402;

DEFLABEL (label_409)
  (Wrd67.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_123]))));
  (* (--Rsp)) = (Wrd67.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_212)
  (* (--Rsp)) = Rvl;
  goto label_408;

DEFLABEL (label_411)
  (Wrd60.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_122]))));
  (* (--Rsp)) = (Wrd60.Obj);
  (* (--Rsp)) = (Wrd55.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_0]), 1);

DEFLABEL (label_211)
  (Wrd52.Obj) = Rvl;
  goto label_410;

DEFLABEL (label_413)
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_121]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_210)
  (Wrd34.Obj) = Rvl;
  goto label_412;

DEFLABEL (label_415)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_4_5]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_109]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_6]), 2);

DEFLABEL (label_206)
  (* (--Rsp)) = Rvl;
  goto label_414;

DEFLABEL (lambda_235)
DEFLABEL (lambda_13)
  INTERRUPT_CHECK (26, LABEL_4_94);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Rsp [2]) = ((SCHEME_OBJECT) 0);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (lambda_236)
DEFLABEL (lambda_4)
  INTERRUPT_CHECK (26, LABEL_4_50);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Rsp [2]) = ((SCHEME_OBJECT) 0);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (lambda_230)
  CLOSURE_HEADER (LABEL_4_96);

DEFLABEL (lambda_9)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd9.Obj) = ((Wrd8.pObj) [3]);
  (Rsp [1]) = (Wrd9.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (lambda_233)
  CLOSURE_HEADER (LABEL_4_106);

DEFLABEL (lambda_16)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd9.Obj) = ((Wrd8.pObj) [3]);
  (Rsp [1]) = (Wrd9.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (lambda_237)
  CLOSURE_HEADER (LABEL_4_113);

DEFLABEL (lambda_98)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd9.Obj) = ((Wrd8.pObj) [3]);
  (Rsp [1]) = (Wrd9.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (lambda_238)
  CLOSURE_HEADER (LABEL_4_115);

DEFLABEL (lambda_25)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_416;
  Rsp = (& (Rsp [1]));
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_4_128);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_4_127])));
  Rhp += 2;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd12 = Wrd9;
  (Wrd13.Obj) = (Rsp [1]);
  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  Rvl = (Wrd8.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_416)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd15.Obj) = ((Wrd17.pObj) [2]);
  (Rsp [1]) = (Wrd15.Obj);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_42]))));
  (Rsp [2]) = (Wrd18.Obj);
  (Wrd20.Obj) = ((Wrd17.pObj) [3]);
  (Rsp [0]) = (Wrd20.Obj);
  goto lambda_12;

DEFLABEL (phi_2_240)
DEFLABEL (phi_2_133)
  INTERRUPT_CHECK (26, LABEL_4_129);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_130]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_423;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_423;
  (Wrd10.Obj) = ((Wrd14.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_422)
  (Wrd24.Obj) = (Rsp [6]);
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [2]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_57]));

DEFLABEL (continuation_123)
  INTERRUPT_CHECK (27, LABEL_4_130);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_417;
  goto phi_1_121;

DEFLABEL (label_417)
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [4]) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [5]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_421;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd8.Obj) = ((Wrd10.pObj) [1]);

DEFLABEL (label_420)
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd19.uLng) == 1))
    goto label_419;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd17.Obj) = ((Wrd18.pObj) [0]);

DEFLABEL (label_418)
  (Wrd27.Obj) = (Rsp [1]);
  (Wrd28.Obj) = (current_block [OBJECT_4_20]);
  (* (Rhp++)) = (Wrd27.Obj);
  (* (Rhp++)) = (Wrd28.Obj);
  (Wrd26.pObj) = (& (Rhp [-2]));
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd26.pObj)));
  (Wrd32.Obj) = (current_block [OBJECT_4_2]);
  (* (Rhp++)) = (Wrd32.Obj);
  (* (Rhp++)) = (Wrd24.Obj);
  (Wrd31.pObj) = (& (Rhp [-2]));
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd31.pObj)));
  (* (Rhp++)) = (Wrd29.Obj);
  (* (Rhp++)) = (Wrd28.Obj);
  (Wrd35.pObj) = (& (Rhp [-2]));
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd35.pObj)));
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd33.Obj);
  (Wrd39.pObj) = (& (Rhp [-2]));
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd39.pObj)));
  (Wrd43.Obj) = (current_block [OBJECT_4_3]);
  (* (Rhp++)) = (Wrd43.Obj);
  (* (Rhp++)) = (Wrd37.Obj);
  (Wrd42.pObj) = (& (Rhp [-2]));
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd42.pObj)));
  (Rsp [5]) = (Wrd40.Obj);
  Rsp = (& (Rsp [4]));
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd46.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_4_135);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_4_134])));
  Rhp += 2;
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd46.pObj)));
  Wrd49 = Wrd46;
  (Wrd50.Obj) = (Rsp [1]);
  ((Wrd49.pObj) [2]) = (Wrd50.Obj);
  (Wrd48.Obj) = (Rsp [0]);
  ((Wrd49.pObj) [3]) = (Wrd48.Obj);
  Rvl = (Wrd45.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_419)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_133]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_216)
  (Wrd17.Obj) = Rvl;
  goto label_418;

DEFLABEL (label_421)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_132]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_0]), 1);

DEFLABEL (label_215)
  (Wrd8.Obj) = Rvl;
  goto label_420;

DEFLABEL (label_423)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_4_10]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_131]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_6]), 2);

DEFLABEL (label_213)
  (* (--Rsp)) = Rvl;
  goto label_422;

DEFLABEL (lambda_239)
  CLOSURE_HEADER (LABEL_4_127);

DEFLABEL (lambda_23)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd9.Obj) = ((Wrd8.pObj) [3]);
  (Rsp [1]) = (Wrd9.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (lambda_224)
DEFLABEL (lambda_22)
  INTERRUPT_CHECK (26, LABEL_4_42);
  goto label_362;

DEFLABEL (lambda_242)
DEFLABEL (lambda_116)
  INTERRUPT_CHECK (26, LABEL_4_120);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Rsp [2]) = ((SCHEME_OBJECT) 0);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (lambda_241)
  CLOSURE_HEADER (LABEL_4_134);

DEFLABEL (lambda_131)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd9.Obj) = ((Wrd8.pObj) [3]);
  (Rsp [1]) = (Wrd9.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_5_5 3
#define LABEL_5_4 5
#define LABEL_5_6 7
#define LABEL_5_7 9
#define LABEL_5_8 11
#define LABEL_5_9 13
#define LABEL_5_10 15
#define LABEL_5_11 17
#define LABEL_5_13 19
#define LABEL_5_15 21
#define LABEL_5_17 23
#define LABEL_5_18 25
#define LABEL_5_20 27
#define LABEL_5_21 29
#define LABEL_5_22 31
#define LABEL_5_23 33
#define LABEL_5_24 35
#define LABEL_5_25 37
#define ENVIRONMENT_LABEL_5_3 54
#define DEBUGGING_LABEL_5_2 53
#define OBJECT_5_5 52
#define OBJECT_5_4 51
#define OBJECT_5_3 50
#define OBJECT_5_2 49
#define OBJECT_5_1 48
#define OBJECT_5_0 47
#define EXECUTE_CACHE_5_19 39
#define EXECUTE_CACHE_5_16 41
#define EXECUTE_CACHE_5_14 43
#define EXECUTE_CACHE_5_12 45
#define FREE_REFERENCES_LABEL_5_0 38
#define NUMBER_OF_LINKER_SECTIONS_5_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcompr_so_code_5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd40;
  machine_word Wrd34;
  machine_word Wrd35;
  machine_word Wrd33;
  machine_word Wrd25;
  machine_word Wrd29;
  machine_word Wrd23;
  machine_word Wrd15;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd51;
  machine_word Wrd52;
  machine_word Wrd49;
  machine_word Wrd41;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd20;
  machine_word Wrd69;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd65;
  machine_word Wrd62;
  machine_word Wrd54;
  machine_word Wrd56;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd50;
  machine_word Wrd44;
  machine_word Wrd45;
  machine_word Wrd46;
  machine_word Wrd43;
  machine_word Wrd37;
  machine_word Wrd38;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd28;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd16;
  machine_word Wrd8;
  machine_word Wrd10;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_5_5);
      goto continuation_2;

    case 1:
      current_block = (Rpc - LABEL_5_4);
      goto expression_clobbers_stack_pointerP_26;

    case 2:
      current_block = (Rpc - LABEL_5_6);
      goto label_28;

    case 3:
      current_block = (Rpc - LABEL_5_7);
      goto label_29;

    case 4:
      current_block = (Rpc - LABEL_5_8);
      goto label_30;

    case 5:
      current_block = (Rpc - LABEL_5_9);
      goto label_31;

    case 6:
      current_block = (Rpc - LABEL_5_10);
      goto label_32;

    case 7:
      current_block = (Rpc - LABEL_5_11);
      goto label_33;

    case 8:
      current_block = (Rpc - LABEL_5_13);
      goto continuation_9;

    case 9:
      current_block = (Rpc - LABEL_5_15);
      goto continuation_10;

    case 10:
      current_block = (Rpc - LABEL_5_17);
      goto loop_21;

    case 11:
      current_block = (Rpc - LABEL_5_18);
      goto lambda_20;

    case 12:
      current_block = (Rpc - LABEL_5_20);
      goto label_34;

    case 13:
      current_block = (Rpc - LABEL_5_21);
      goto label_38;

    case 14:
      current_block = (Rpc - LABEL_5_22);
      goto label_39;

    case 15:
      current_block = (Rpc - LABEL_5_23);
      goto label_35;

    case 16:
      current_block = (Rpc - LABEL_5_24);
      goto label_36;

    case 17:
      current_block = (Rpc - LABEL_5_25);
      goto label_37;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_clobbers_stack_pointerP_41)
DEFLABEL (expression_clobbers_stack_pointerP_26)
  INTERRUPT_CHECK (26, LABEL_5_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_61;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd8.Obj) = ((Wrd10.pObj) [0]);

DEFLABEL (label_60)
  if ((Wrd8.Obj) == (current_block [OBJECT_5_1]))
    goto label_49;

DEFLABEL (label_48)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_47)
  (Wrd20.Obj) = (Rsp [0]);
  if ((Wrd20.Obj) == ((SCHEME_OBJECT) 0))
    goto label_44;
  Rvl = (Wrd20.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_44)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_13]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd27.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_14]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_5_13);
  (Rsp [0]) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_45;
  Rvl = Rvl;
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_45)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_15]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_16]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_5_15);
  (Rsp [0]) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_46;
  Rvl = Rvl;
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_46)
  Rsp = (& (Rsp [1]));
  goto loop_21;

DEFLABEL (label_49)
  (Wrd31.Obj) = (Rsp [1]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if (! ((Wrd32.uLng) == 1))
    goto label_59;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd28.Obj) = ((Wrd30.pObj) [1]);

DEFLABEL (label_58)
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if (! ((Wrd39.uLng) == 1))
    goto label_57;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd37.Obj) = ((Wrd38.pObj) [0]);

DEFLABEL (label_56)
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd46.uLng) == 1))
    goto label_55;
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd44.Obj) = ((Wrd45.pObj) [0]);

DEFLABEL (label_54)
  if (! ((Wrd44.Obj) == (current_block [OBJECT_5_3])))
    goto label_48;
  (Wrd57.Obj) = (Rsp [1]);
  (Wrd58.uLng) = (OBJECT_TYPE (Wrd57.Obj));
  if (! ((Wrd58.uLng) == 1))
    goto label_53;
  (Wrd56.pObj) = (OBJECT_ADDRESS (Wrd57.Obj));
  (Wrd54.Obj) = ((Wrd56.pObj) [1]);

DEFLABEL (label_52)
  (Wrd65.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if (! ((Wrd65.uLng) == 1))
    goto label_51;
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd64.Obj) = ((Wrd63.pObj) [0]);
  (* (--Rsp)) = (Wrd64.Obj);

DEFLABEL (label_50)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_12]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_5_5);
  (* (--Rsp)) = Rvl;
  goto label_47;

DEFLABEL (label_51)
  (Wrd69.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_11]))));
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd54.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_0]), 1);

DEFLABEL (label_33)
  (* (--Rsp)) = Rvl;
  goto label_50;

DEFLABEL (label_53)
  (Wrd62.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_10]))));
  (* (--Rsp)) = (Wrd62.Obj);
  (* (--Rsp)) = (Wrd57.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_2]), 1);

DEFLABEL (label_32)
  (Wrd54.Obj) = Rvl;
  goto label_52;

DEFLABEL (label_55)
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_9]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_0]), 1);

DEFLABEL (label_31)
  (Wrd44.Obj) = Rvl;
  goto label_54;

DEFLABEL (label_57)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_8]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_0]), 1);

DEFLABEL (label_30)
  (Wrd37.Obj) = Rvl;
  goto label_56;

DEFLABEL (label_59)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_7]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd31.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_2]), 1);

DEFLABEL (label_29)
  (Wrd28.Obj) = Rvl;
  goto label_58;

DEFLABEL (label_61)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_6]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_0]), 1);

DEFLABEL (label_28)
  (Wrd8.Obj) = Rvl;
  goto label_60;

DEFLABEL (loop_42)
DEFLABEL (loop_21)
  INTERRUPT_CHECK (26, LABEL_5_17);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_18]))));
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_19]));

DEFLABEL (lambda_43)
DEFLABEL (lambda_20)
  INTERRUPT_CHECK (26, LABEL_5_18);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_75;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [0]);

DEFLABEL (label_74)
  if ((Wrd5.Obj) == (current_block [OBJECT_5_4]))
    goto label_69;
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 1))
    goto label_68;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd15.Obj) = ((Wrd17.pObj) [0]);

DEFLABEL (label_67)
  if ((Wrd15.Obj) == (current_block [OBJECT_5_5]))
    goto label_62;
  goto loop_21;

DEFLABEL (label_62)
  (Wrd28.Obj) = (Rsp [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if (! ((Wrd29.uLng) == 1))
    goto label_66;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd25.Obj) = ((Wrd27.pObj) [1]);

DEFLABEL (label_65)
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd36.uLng) == 1))
    goto label_64;
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd34.Obj) = ((Wrd35.pObj) [0]);

DEFLABEL (label_63)
  (Rsp [0]) = (Wrd34.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_12]));

DEFLABEL (label_64)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_25]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_0]), 1);

DEFLABEL (label_37)
  (Wrd34.Obj) = Rvl;
  goto label_63;

DEFLABEL (label_66)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_24]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_2]), 1);

DEFLABEL (label_36)
  (Wrd25.Obj) = Rvl;
  goto label_65;

DEFLABEL (label_68)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_23]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_0]), 1);

DEFLABEL (label_35)
  (Wrd15.Obj) = Rvl;
  goto label_67;

DEFLABEL (label_69)
  (Wrd44.Obj) = (Rsp [0]);
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if (! ((Wrd45.uLng) == 1))
    goto label_73;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd41.Obj) = ((Wrd43.pObj) [1]);

DEFLABEL (label_72)
  (Wrd52.uLng) = (OBJECT_TYPE (Wrd41.Obj));
  if (! ((Wrd52.uLng) == 1))
    goto label_71;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd41.Obj));
  (Wrd50.Obj) = ((Wrd51.pObj) [0]);

DEFLABEL (label_70)
  (Rsp [0]) = (Wrd50.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_12]));

DEFLABEL (label_71)
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_22]))));
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_0]), 1);

DEFLABEL (label_39)
  (Wrd50.Obj) = Rvl;
  goto label_70;

DEFLABEL (label_73)
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_21]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_2]), 1);

DEFLABEL (label_38)
  (Wrd41.Obj) = Rvl;
  goto label_72;

DEFLABEL (label_75)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_20]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_0]), 1);

DEFLABEL (label_34)
  (Wrd5.Obj) = Rvl;
  goto label_74;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_6_4 3
#define LABEL_6_5 5
#define LABEL_6_6 7
#define LABEL_6_7 9
#define LABEL_6_8 11
#define LABEL_6_10 13
#define LABEL_6_11 15
#define LABEL_6_9 17
#define LABEL_6_13 19
#define LABEL_6_14 21
#define LABEL_6_15 23
#define ENVIRONMENT_LABEL_6_3 34
#define DEBUGGING_LABEL_6_2 33
#define OBJECT_6_5 32
#define OBJECT_6_4 31
#define OBJECT_6_3 30
#define OBJECT_6_2 29
#define OBJECT_6_1 28
#define OBJECT_6_0 27
#define EXECUTE_CACHE_6_12 25
#define FREE_REFERENCES_LABEL_6_0 24
#define NUMBER_OF_LINKER_SECTIONS_6_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcompr_so_code_6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd30;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd18;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd63;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd59;
  machine_word Wrd56;
  machine_word Wrd48;
  machine_word Wrd50;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd47;
  machine_word Wrd41;
  machine_word Wrd33;
  machine_word Wrd35;
  machine_word Wrd37;
  machine_word Wrd32;
  machine_word Wrd26;
  machine_word Wrd27;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd7;
  machine_word Wrd9;
  machine_word Wrd8;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_6_4);
      goto expression_is_stack_pushP_13;

    case 1:
      current_block = (Rpc - LABEL_6_5);
      goto label_15;

    case 2:
      current_block = (Rpc - LABEL_6_6);
      goto label_16;

    case 3:
      current_block = (Rpc - LABEL_6_7);
      goto label_17;

    case 4:
      current_block = (Rpc - LABEL_6_8);
      goto label_18;

    case 5:
      current_block = (Rpc - LABEL_6_10);
      goto label_19;

    case 6:
      current_block = (Rpc - LABEL_6_11);
      goto label_20;

    case 7:
      current_block = (Rpc - LABEL_6_9);
      goto continuation_8;

    case 8:
      current_block = (Rpc - LABEL_6_13);
      goto label_21;

    case 9:
      current_block = (Rpc - LABEL_6_14);
      goto label_22;

    case 10:
      current_block = (Rpc - LABEL_6_15);
      goto label_23;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_is_stack_pushP_25)
DEFLABEL (expression_is_stack_pushP_13)
  INTERRUPT_CHECK (26, LABEL_6_4);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_50;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [0]);

DEFLABEL (label_49)
  if ((Wrd5.Obj) == (current_block [OBJECT_6_1]))
    goto label_27;

DEFLABEL (label_26)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_27)
  (Wrd20.Obj) = (Rsp [0]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 1))
    goto label_48;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [1]);

DEFLABEL (label_47)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd28.uLng) == 1))
    goto label_46;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd26.Obj) = ((Wrd27.pObj) [0]);

DEFLABEL (label_45)
  (Rsp [0]) = (Wrd26.Obj);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd37.uLng) == 1))
    goto label_44;
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd33.Obj) = ((Wrd35.pObj) [0]);

DEFLABEL (label_43)
  if (! ((Wrd33.Obj) == (current_block [OBJECT_6_3])))
    goto label_26;
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_9]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd51.Obj) = (Rsp [1]);
  (Wrd52.uLng) = (OBJECT_TYPE (Wrd51.Obj));
  if (! ((Wrd52.uLng) == 1))
    goto label_42;
  (Wrd50.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd48.Obj) = ((Wrd50.pObj) [1]);

DEFLABEL (label_41)
  (Wrd59.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if (! ((Wrd59.uLng) == 1))
    goto label_40;
  (Wrd57.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd58.Obj) = ((Wrd57.pObj) [0]);
  (* (--Rsp)) = (Wrd58.Obj);

DEFLABEL (label_39)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_12]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_6_9);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_28;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_28)
  (Wrd7.Obj) = (current_block [OBJECT_6_4]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_38;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd8.Obj) = ((Wrd10.pObj) [1]);

DEFLABEL (label_37)
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd19.uLng) == 1))
    goto label_36;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd17.Obj) = ((Wrd18.pObj) [1]);

DEFLABEL (label_35)
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd26.uLng) == 1))
    goto label_34;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd24.Obj) = ((Wrd25.pObj) [0]);

DEFLABEL (label_33)
  (Rsp [1]) = (Wrd24.Obj);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd33.uLng) == 26)
    goto label_29;
  INVOKE_INTERFACE_0 (36);

DEFLABEL (label_29)
  if ((Wrd24.Obj) == (current_block [OBJECT_6_4]))
    goto label_31;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_30;

DEFLABEL (label_31)
  Rvl = (current_block [OBJECT_6_5]);

DEFLABEL (label_30)
DEFLABEL (label_32)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_34)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_15]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6_0]), 1);

DEFLABEL (label_23)
  (Wrd24.Obj) = Rvl;
  goto label_33;

DEFLABEL (label_36)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_14]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6_2]), 1);

DEFLABEL (label_22)
  (Wrd17.Obj) = Rvl;
  goto label_35;

DEFLABEL (label_38)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_13]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6_2]), 1);

DEFLABEL (label_21)
  (Wrd8.Obj) = Rvl;
  goto label_37;

DEFLABEL (label_40)
  (Wrd63.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_11]))));
  (* (--Rsp)) = (Wrd63.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6_0]), 1);

DEFLABEL (label_20)
  (* (--Rsp)) = Rvl;
  goto label_39;

DEFLABEL (label_42)
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_10]))));
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6_2]), 1);

DEFLABEL (label_19)
  (Wrd48.Obj) = Rvl;
  goto label_41;

DEFLABEL (label_44)
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_8]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6_0]), 1);

DEFLABEL (label_18)
  (Wrd33.Obj) = Rvl;
  goto label_43;

DEFLABEL (label_46)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_7]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6_0]), 1);

DEFLABEL (label_17)
  (Wrd26.Obj) = Rvl;
  goto label_45;

DEFLABEL (label_48)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_6]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6_2]), 1);

DEFLABEL (label_16)
  (Wrd17.Obj) = Rvl;
  goto label_47;

DEFLABEL (label_50)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6_0]), 1);

DEFLABEL (label_15)
  (Wrd5.Obj) = Rvl;
  goto label_49;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_7_4 3
#define LABEL_7_5 5
#define LABEL_7_6 7
#define LABEL_7_8 9
#define LABEL_7_10 11
#define LABEL_7_12 13
#define LABEL_7_13 15
#define LABEL_7_15 17
#define LABEL_7_14 19
#define LABEL_7_21 21
#define LABEL_7_17 23
#define LABEL_7_22 25
#define LABEL_7_23 27
#define LABEL_7_24 29
#define LABEL_7_25 31
#define LABEL_7_26 33
#define LABEL_7_27 35
#define LABEL_7_28 37
#define LABEL_7_29 39
#define LABEL_7_30 41
#define LABEL_7_31 43
#define LABEL_7_32 45
#define LABEL_7_18 47
#define LABEL_7_34 49
#define LABEL_7_19 51
#define LABEL_7_36 53
#define LABEL_7_37 55
#define LABEL_7_33 57
#define ENVIRONMENT_LABEL_7_3 89
#define DEBUGGING_LABEL_7_2 88
#define OBJECT_7_9 87
#define OBJECT_7_8 86
#define OBJECT_7_7 85
#define OBJECT_7_6 84
#define OBJECT_7_5 83
#define OBJECT_7_4 82
#define OBJECT_7_3 81
#define OBJECT_7_2 80
#define OBJECT_7_1 79
#define OBJECT_7_0 78
#define EXECUTE_CACHE_7_39 59
#define EXECUTE_CACHE_7_38 61
#define EXECUTE_CACHE_7_35 63
#define EXECUTE_CACHE_7_20 65
#define EXECUTE_CACHE_7_16 67
#define EXECUTE_CACHE_7_11 69
#define EXECUTE_CACHE_7_9 71
#define EXECUTE_CACHE_7_7 73
#define FREE_REFERENCE_7_1 76
#define FREE_REFERENCE_7_0 77
#define FREE_REFERENCES_LABEL_7_0 58
#define NUMBER_OF_LINKER_SECTIONS_7_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcompr_so_code_7 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd34;
  machine_word Wrd91;
  machine_word Wrd88;
  machine_word Wrd101;
  machine_word Wrd100;
  machine_word Wrd99;
  machine_word Wrd97;
  machine_word Wrd95;
  machine_word Wrd94;
  machine_word Wrd103;
  machine_word Wrd102;
  machine_word Wrd84;
  machine_word Wrd81;
  machine_word Wrd72;
  machine_word Wrd78;
  machine_word Wrd77;
  machine_word Wrd76;
  machine_word Wrd79;
  machine_word Wrd65;
  machine_word Wrd66;
  machine_word Wrd71;
  machine_word Wrd70;
  machine_word Wrd67;
  machine_word Wrd123;
  machine_word Wrd120;
  machine_word Wrd119;
  machine_word Wrd109;
  machine_word Wrd108;
  machine_word Wrd106;
  machine_word Wrd116;
  machine_word Wrd115;
  machine_word Wrd114;
  machine_word Wrd113;
  machine_word Wrd111;
  machine_word Wrd110;
  machine_word Wrd117;
  machine_word Wrd64;
  machine_word Wrd61;
  machine_word Wrd52;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd56;
  machine_word Wrd59;
  machine_word Wrd51;
  machine_word Wrd47;
  machine_word Wrd142;
  machine_word Wrd139;
  machine_word Wrd138;
  machine_word Wrd128;
  machine_word Wrd127;
  machine_word Wrd125;
  machine_word Wrd135;
  machine_word Wrd134;
  machine_word Wrd133;
  machine_word Wrd132;
  machine_word Wrd130;
  machine_word Wrd129;
  machine_word Wrd136;
  machine_word Wrd32;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd39;
  machine_word Wrd31;
  machine_word Wrd161;
  machine_word Wrd158;
  machine_word Wrd157;
  machine_word Wrd147;
  machine_word Wrd146;
  machine_word Wrd144;
  machine_word Wrd154;
  machine_word Wrd153;
  machine_word Wrd152;
  machine_word Wrd151;
  machine_word Wrd149;
  machine_word Wrd148;
  machine_word Wrd155;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd172;
  machine_word Wrd171;
  machine_word Wrd170;
  machine_word Wrd174;
  machine_word Wrd173;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd19;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd50;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd8;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_7_4);
      goto fold_instructionsB_25;

    case 1:
      current_block = (Rpc - LABEL_7_5);
      goto label_27;

    case 2:
      current_block = (Rpc - LABEL_7_6);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_7_8);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_7_10);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_7_12);
      goto label_30;

    case 6:
      current_block = (Rpc - LABEL_7_13);
      goto label_29;

    case 7:
      current_block = (Rpc - LABEL_7_15);
      goto label_28;

    case 8:
      current_block = (Rpc - LABEL_7_14);
      goto continuation_6;

    case 9:
      current_block = (Rpc - LABEL_7_21);
      goto continuation_14;

    case 10:
      current_block = (Rpc - LABEL_7_17);
      goto continuation_11;

    case 11:
      current_block = (Rpc - LABEL_7_22);
      goto label_31;

    case 12:
      current_block = (Rpc - LABEL_7_23);
      goto label_32;

    case 13:
      current_block = (Rpc - LABEL_7_24);
      goto label_41;

    case 14:
      current_block = (Rpc - LABEL_7_25);
      goto label_33;

    case 15:
      current_block = (Rpc - LABEL_7_26);
      goto label_34;

    case 16:
      current_block = (Rpc - LABEL_7_27);
      goto label_40;

    case 17:
      current_block = (Rpc - LABEL_7_28);
      goto label_35;

    case 18:
      current_block = (Rpc - LABEL_7_29);
      goto label_36;

    case 19:
      current_block = (Rpc - LABEL_7_30);
      goto label_39;

    case 20:
      current_block = (Rpc - LABEL_7_31);
      goto label_37;

    case 21:
      current_block = (Rpc - LABEL_7_32);
      goto label_38;

    case 22:
      current_block = (Rpc - LABEL_7_18);
      goto continuation_10;

    case 23:
      current_block = (Rpc - LABEL_7_34);
      goto label_42;

    case 24:
      current_block = (Rpc - LABEL_7_19);
      goto continuation_9;

    case 25:
      current_block = (Rpc - LABEL_7_36);
      goto label_43;

    case 26:
      current_block = (Rpc - LABEL_7_37);
      goto label_44;

    case 27:
      current_block = (Rpc - LABEL_7_33);
      goto continuation_13;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (fold_instructionsB_46)
DEFLABEL (fold_instructionsB_25)
  INTERRUPT_CHECK (26, LABEL_7_4);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_87;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd13.Lng))))
    goto label_87;
  (Wrd7.Obj) = ((Wrd11.pObj) [1]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_86)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_6]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_7_6);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_47;
  Rvl = (current_block [OBJECT_7_2]);
  Rsp = (& (Rsp [6]));
  goto pop_return;

DEFLABEL (label_47)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_8]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_7_8);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_10]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_7_10);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_48;
  Rvl = (current_block [OBJECT_7_2]);
  Rsp = (& (Rsp [6]));
  goto pop_return;

DEFLABEL (label_48)
  (Wrd43.Obj) = (Rsp [2]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd44.uLng) == 10))
    goto label_85;
  (Wrd40.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  (Wrd41.Obj) = ((Wrd40.pObj) [0]);
  (Wrd42.Lng) = (FIXNUM_TO_LONG (Wrd41.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd42.Lng))))
    goto label_85;
  ((Wrd40.pObj) [1]) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_84)
  (Wrd26.Obj) = (Rsp [3]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd27.uLng) == 10))
    goto label_83;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [0]);
  (Wrd25.Lng) = (FIXNUM_TO_LONG (Wrd24.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd25.Lng))))
    goto label_83;
  (Wrd19.Obj) = (Rsp [0]);
  ((Wrd23.pObj) [1]) = (Wrd19.Obj);

DEFLABEL (label_82)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_14]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7_0]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_81;
  Wrd10 = Wrd14;

DEFLABEL (label_80)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd16.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_16]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_7_14);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_18]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_19]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_20]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_7_19);
  (* (--Rsp)) = Rvl;
  (Wrd14.Obj) = (Rsp [5]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_79;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd13.Lng))))
    goto label_79;
  (Wrd7.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_78)
  (Wrd21.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd31.Obj) = (Rsp [7]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if (! ((Wrd32.uLng) == 10))
    goto label_77;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [0]);
  (Wrd30.Lng) = (FIXNUM_TO_LONG (Wrd29.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd30.Lng))))
    goto label_77;
  (Wrd24.Obj) = ((Wrd28.pObj) [3]);
  (* (--Rsp)) = (Wrd24.Obj);

DEFLABEL (label_76)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_38]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_7_18);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_7_8]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_21]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_33]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if (! ((Wrd23.uLng) == 10))
    goto label_75;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd21.Lng))))
    goto label_75;
  (Wrd15.Obj) = ((Wrd19.pObj) [2]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_74)
  (Wrd29.Obj) = (Rsp [11]);
  (* (--Rsp)) = (Wrd29.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_35]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_7_33);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_39]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_7_21);
  (Rsp [2]) = Rvl;
  (Wrd173.Obj) = (Rsp [0]);
  (Wrd174.uLng) = (OBJECT_TYPE (Wrd173.Obj));
  if ((Wrd174.uLng) == 10)
    goto label_50;

DEFLABEL (label_49)
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_3]), 3);

DEFLABEL (label_50)
  (Wrd170.pObj) = (OBJECT_ADDRESS (Wrd173.Obj));
  (Wrd171.Obj) = ((Wrd170.pObj) [0]);
  (Wrd172.Lng) = (FIXNUM_TO_LONG (Wrd171.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd172.Lng))))
    goto label_49;
  ((Wrd170.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [4]));

DEFLABEL (label_73)
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7_1]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_72;
  Wrd6 = Wrd10;

DEFLABEL (label_71)
  Wrd5 = Wrd6;
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_70;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd18.Lng))))
    goto label_70;
  (Wrd12.Obj) = ((Wrd16.pObj) [5]);

DEFLABEL (label_69)
  (Wrd155.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd155.uLng) == 10))
    goto label_68;
  (Wrd148.Obj) = (Rsp [4]);
  (Wrd149.uLng) = (OBJECT_TYPE (Wrd148.Obj));
  if (! ((Wrd149.uLng) == 26))
    goto label_68;
  (Wrd151.Lng) = (FIXNUM_TO_LONG (Wrd148.Obj));
  (Wrd152.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd153.Obj) = ((Wrd152.pObj) [0]);
  (Wrd154.Lng) = (FIXNUM_TO_LONG (Wrd153.Obj));
  if (! (((unsigned long) (Wrd151.Lng)) < ((unsigned long) (Wrd154.Lng))))
    goto label_68;
  (Wrd144.uLng) = (OBJECT_DATUM (Wrd148.Obj));
  (Wrd146.pObj) = (& ((Wrd152.pObj) [(Wrd144.Lng)]));
  (Wrd147.Obj) = (current_block [OBJECT_7_0]);
  ((Wrd146.pObj) [1]) = (Wrd147.Obj);

DEFLABEL (label_67)
  (Wrd27.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7_1]));
  (Wrd30.Obj) = ((Wrd27.pObj) [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd31.uLng) == 50)
    goto label_66;
  Wrd26 = Wrd30;

DEFLABEL (label_65)
  Wrd25 = Wrd26;
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd39.uLng) == 10))
    goto label_64;
  (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd37.Obj) = ((Wrd36.pObj) [0]);
  (Wrd38.Lng) = (FIXNUM_TO_LONG (Wrd37.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd38.Lng))))
    goto label_64;
  (Wrd32.Obj) = ((Wrd36.pObj) [6]);

DEFLABEL (label_63)
  (Wrd136.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd136.uLng) == 10))
    goto label_62;
  (Wrd129.Obj) = (Rsp [4]);
  (Wrd130.uLng) = (OBJECT_TYPE (Wrd129.Obj));
  if (! ((Wrd130.uLng) == 26))
    goto label_62;
  (Wrd132.Lng) = (FIXNUM_TO_LONG (Wrd129.Obj));
  (Wrd133.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd134.Obj) = ((Wrd133.pObj) [0]);
  (Wrd135.Lng) = (FIXNUM_TO_LONG (Wrd134.Obj));
  if (! (((unsigned long) (Wrd132.Lng)) < ((unsigned long) (Wrd135.Lng))))
    goto label_62;
  (Wrd125.uLng) = (OBJECT_DATUM (Wrd129.Obj));
  (Wrd127.pObj) = (& ((Wrd133.pObj) [(Wrd125.Lng)]));
  (Wrd128.Obj) = (current_block [OBJECT_7_0]);
  ((Wrd127.pObj) [1]) = (Wrd128.Obj);

DEFLABEL (label_61)
  (Wrd47.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7_1]));
  (Wrd50.Obj) = ((Wrd47.pObj) [0]);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if ((Wrd51.uLng) == 50)
    goto label_60;
  Wrd46 = Wrd50;

DEFLABEL (label_59)
  Wrd45 = Wrd46;
  (Wrd59.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if (! ((Wrd59.uLng) == 10))
    goto label_58;
  (Wrd56.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd57.Obj) = ((Wrd56.pObj) [0]);
  (Wrd58.Lng) = (FIXNUM_TO_LONG (Wrd57.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd58.Lng))))
    goto label_58;
  (Wrd52.Obj) = ((Wrd56.pObj) [7]);

DEFLABEL (label_57)
  (Wrd117.uLng) = (OBJECT_TYPE (Wrd52.Obj));
  if (! ((Wrd117.uLng) == 10))
    goto label_56;
  (Wrd110.Obj) = (Rsp [4]);
  (Wrd111.uLng) = (OBJECT_TYPE (Wrd110.Obj));
  if (! ((Wrd111.uLng) == 26))
    goto label_56;
  (Wrd113.Lng) = (FIXNUM_TO_LONG (Wrd110.Obj));
  (Wrd114.pObj) = (OBJECT_ADDRESS (Wrd52.Obj));
  (Wrd115.Obj) = ((Wrd114.pObj) [0]);
  (Wrd116.Lng) = (FIXNUM_TO_LONG (Wrd115.Obj));
  if (! (((unsigned long) (Wrd113.Lng)) < ((unsigned long) (Wrd116.Lng))))
    goto label_56;
  (Wrd106.uLng) = (OBJECT_DATUM (Wrd110.Obj));
  (Wrd108.pObj) = (& ((Wrd114.pObj) [(Wrd106.Lng)]));
  (Wrd109.Obj) = (current_block [OBJECT_7_0]);
  ((Wrd108.pObj) [1]) = (Wrd109.Obj);

DEFLABEL (label_55)
  (Wrd67.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7_1]));
  (Wrd70.Obj) = ((Wrd67.pObj) [0]);
  (Wrd71.uLng) = (OBJECT_TYPE (Wrd70.Obj));
  if ((Wrd71.uLng) == 50)
    goto label_54;
  Wrd66 = Wrd70;

DEFLABEL (label_53)
  Wrd65 = Wrd66;
  (Wrd79.uLng) = (OBJECT_TYPE (Wrd66.Obj));
  if (! ((Wrd79.uLng) == 10))
    goto label_52;
  (Wrd76.pObj) = (OBJECT_ADDRESS (Wrd66.Obj));
  (Wrd77.Obj) = ((Wrd76.pObj) [0]);
  (Wrd78.Lng) = (FIXNUM_TO_LONG (Wrd77.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd78.Lng))))
    goto label_52;
  (Wrd72.Obj) = ((Wrd76.pObj) [4]);

DEFLABEL (label_51)
  (Rsp [3]) = (Wrd72.Obj);
  (Rsp [5]) = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  (Wrd102.Obj) = (Rsp [0]);
  (Wrd103.uLng) = (OBJECT_TYPE (Wrd102.Obj));
  if (! ((Wrd103.uLng) == 10))
    goto label_49;
  (Wrd94.Obj) = (Rsp [1]);
  (Wrd95.uLng) = (OBJECT_TYPE (Wrd94.Obj));
  if (! ((Wrd95.uLng) == 26))
    goto label_49;
  (Wrd97.Lng) = (FIXNUM_TO_LONG (Wrd94.Obj));
  (Wrd99.pObj) = (OBJECT_ADDRESS (Wrd102.Obj));
  (Wrd100.Obj) = ((Wrd99.pObj) [0]);
  (Wrd101.Lng) = (FIXNUM_TO_LONG (Wrd100.Obj));
  if (! (((unsigned long) (Wrd97.Lng)) < ((unsigned long) (Wrd101.Lng))))
    goto label_49;
  (Wrd88.uLng) = (OBJECT_DATUM (Wrd94.Obj));
  (Wrd91.pObj) = (& ((Wrd99.pObj) [(Wrd88.Lng)]));
  ((Wrd91.pObj) [1]) = ((SCHEME_OBJECT) 0);
  Rvl = (current_block [OBJECT_7_2]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_52)
  (Wrd81.Obj) = (current_block [OBJECT_7_7]);
  (Wrd84.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_32]))));
  (* (--Rsp)) = (Wrd84.Obj);
  (* (--Rsp)) = (Wrd81.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_1]), 2);

DEFLABEL (label_38)
  (Wrd72.Obj) = Rvl;
  goto label_51;

DEFLABEL (label_54)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_7_31])), (Wrd67.pObj));

DEFLABEL (label_37)
  (Wrd66.Obj) = Rvl;
  goto label_53;

DEFLABEL (label_56)
  (Wrd119.Obj) = (Rsp [4]);
  (Wrd120.Obj) = (current_block [OBJECT_7_0]);
  (Wrd123.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_30]))));
  (* (--Rsp)) = (Wrd123.Obj);
  (* (--Rsp)) = (Wrd120.Obj);
  (* (--Rsp)) = (Wrd119.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_3]), 3);

DEFLABEL (label_39)
  goto label_55;

DEFLABEL (label_58)
  (Wrd61.Obj) = (current_block [OBJECT_7_6]);
  (Wrd64.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_29]))));
  (* (--Rsp)) = (Wrd64.Obj);
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_1]), 2);

DEFLABEL (label_36)
  (Wrd52.Obj) = Rvl;
  goto label_57;

DEFLABEL (label_60)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_7_28])), (Wrd47.pObj));

DEFLABEL (label_35)
  (Wrd46.Obj) = Rvl;
  goto label_59;

DEFLABEL (label_62)
  (Wrd138.Obj) = (Rsp [4]);
  (Wrd139.Obj) = (current_block [OBJECT_7_0]);
  (Wrd142.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_27]))));
  (* (--Rsp)) = (Wrd142.Obj);
  (* (--Rsp)) = (Wrd139.Obj);
  (* (--Rsp)) = (Wrd138.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_3]), 3);

DEFLABEL (label_40)
  goto label_61;

DEFLABEL (label_64)
  (Wrd41.Obj) = (current_block [OBJECT_7_5]);
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_26]))));
  (* (--Rsp)) = (Wrd44.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_1]), 2);

DEFLABEL (label_34)
  (Wrd32.Obj) = Rvl;
  goto label_63;

DEFLABEL (label_66)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_7_25])), (Wrd27.pObj));

DEFLABEL (label_33)
  (Wrd26.Obj) = Rvl;
  goto label_65;

DEFLABEL (label_68)
  (Wrd157.Obj) = (Rsp [4]);
  (Wrd158.Obj) = (current_block [OBJECT_7_0]);
  (Wrd161.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_24]))));
  (* (--Rsp)) = (Wrd161.Obj);
  (* (--Rsp)) = (Wrd158.Obj);
  (* (--Rsp)) = (Wrd157.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_3]), 3);

DEFLABEL (label_41)
  goto label_67;

DEFLABEL (label_70)
  (Wrd21.Obj) = (current_block [OBJECT_7_4]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_23]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_1]), 2);

DEFLABEL (label_32)
  (Wrd12.Obj) = Rvl;
  goto label_69;

DEFLABEL (label_72)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_7_22])), (Wrd7.pObj));

DEFLABEL (label_31)
  (Wrd6.Obj) = Rvl;
  goto label_71;

DEFLABEL (label_75)
  (Wrd24.Obj) = (Rsp [9]);
  (Wrd25.Obj) = (current_block [OBJECT_7_8]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_34]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_1]), 2);

DEFLABEL (label_42)
  (* (--Rsp)) = Rvl;
  goto label_74;

DEFLABEL (label_77)
  (Wrd33.Obj) = (Rsp [7]);
  (Wrd34.Obj) = (current_block [OBJECT_7_9]);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_37]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_1]), 2);

DEFLABEL (label_44)
  (* (--Rsp)) = Rvl;
  goto label_76;

DEFLABEL (label_79)
  (Wrd16.Obj) = (Rsp [5]);
  (Wrd17.Obj) = (current_block [OBJECT_7_8]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_36]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_1]), 2);

DEFLABEL (label_43)
  (* (--Rsp)) = Rvl;
  goto label_78;

DEFLABEL (label_81)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_7_15])), (Wrd11.pObj));

DEFLABEL (label_28)
  (Wrd10.Obj) = Rvl;
  goto label_80;

DEFLABEL (label_83)
  (Wrd28.Obj) = (Rsp [3]);
  (Wrd29.Obj) = (current_block [OBJECT_7_0]);
  (Wrd30.Obj) = (Rsp [0]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_13]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_3]), 3);

DEFLABEL (label_29)
  goto label_82;

DEFLABEL (label_85)
  (Wrd45.Obj) = (Rsp [2]);
  (Wrd46.Obj) = (current_block [OBJECT_7_0]);
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_12]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (* (--Rsp)) = (Wrd46.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_3]), 3);

DEFLABEL (label_30)
  goto label_84;

DEFLABEL (label_87)
  (Wrd16.Obj) = (Rsp [2]);
  (Wrd17.Obj) = (current_block [OBJECT_7_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_1]), 2);

DEFLABEL (label_27)
  (* (--Rsp)) = Rvl;
  goto label_86;

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_7_17);
  goto label_73;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_8_4 3
#define LABEL_8_5 5
#define LABEL_8_7 7
#define LABEL_8_6 9
#define LABEL_8_9 11
#define LABEL_8_10 13
#define LABEL_8_12 15
#define LABEL_8_13 17
#define LABEL_8_15 19
#define LABEL_8_16 21
#define LABEL_8_17 23
#define ENVIRONMENT_LABEL_8_3 41
#define DEBUGGING_LABEL_8_2 40
#define OBJECT_8_4 39
#define OBJECT_8_3 38
#define OBJECT_8_2 37
#define OBJECT_8_1 36
#define OBJECT_8_0 35
#define EXECUTE_CACHE_8_18 25
#define EXECUTE_CACHE_8_14 27
#define EXECUTE_CACHE_8_11 29
#define EXECUTE_CACHE_8_8 31
#define FREE_REFERENCE_8_0 34
#define FREE_REFERENCES_LABEL_8_0 24
#define NUMBER_OF_LINKER_SECTIONS_8_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcompr_so_code_8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd42;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd11;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd12;
  machine_word Wrd20;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd17;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_8_4);
      goto new_dead_registers_15;

    case 1:
      current_block = (Rpc - LABEL_8_5);
      goto loop_13;

    case 2:
      current_block = (Rpc - LABEL_8_7);
      goto label_17;

    case 3:
      current_block = (Rpc - LABEL_8_6);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_8_9);
      goto label_18;

    case 5:
      current_block = (Rpc - LABEL_8_10);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_8_12);
      goto label_19;

    case 7:
      current_block = (Rpc - LABEL_8_13);
      goto continuation_6;

    case 8:
      current_block = (Rpc - LABEL_8_15);
      goto label_21;

    case 9:
      current_block = (Rpc - LABEL_8_16);
      goto label_20;

    case 10:
      current_block = (Rpc - LABEL_8_17);
      goto continuation_9;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (new_dead_registers_23)
DEFLABEL (new_dead_registers_15)
  INTERRUPT_CHECK (26, LABEL_8_4);
  (Wrd5.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  goto loop_13;

DEFLABEL (loop_24)
DEFLABEL (loop_13)
  INTERRUPT_CHECK (26, LABEL_8_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_8_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_36;
  Wrd9 = Wrd13;

DEFLABEL (label_35)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_8_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (Rsp [3]);
  if (! ((Wrd5.Obj) == (Wrd6.Obj)))
    goto label_25;
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [6]));
  goto pop_return;

DEFLABEL (label_25)
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_34;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd15.Lng))))
    goto label_34;
  (Wrd9.Obj) = ((Wrd13.pObj) [2]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_33)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_10]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd27.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8_11]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_8_10);
  (* (--Rsp)) = Rvl;
  if (Rvl == (current_block [OBJECT_8_2]))
    goto label_30;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_13]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8_14]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_8_13);
  (Wrd5.Obj) = Rvl;
  (Wrd35.Obj) = (Rsp [2]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd36.uLng) == 10))
    goto label_29;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [0]);
  (Wrd34.Lng) = (FIXNUM_TO_LONG (Wrd33.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd34.Lng))))
    goto label_29;
  ((Wrd32.pObj) [2]) = Rvl;

DEFLABEL (label_28)
  (Wrd15.Obj) = (Rsp [2]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 10))
    goto label_27;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd14.Lng))))
    goto label_27;
  (Wrd6.Obj) = ((Wrd12.pObj) [3]);

DEFLABEL (label_26)
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_17]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8_18]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_8_17);
  (Rsp [3]) = Rvl;
  Rsp = (& (Rsp [2]));
  goto loop_13;

DEFLABEL (label_27)
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.Obj) = (current_block [OBJECT_8_3]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_16]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_8_1]), 2);

DEFLABEL (label_20)
  (Wrd6.Obj) = Rvl;
  goto label_26;

DEFLABEL (label_29)
  (Wrd37.Obj) = (Rsp [2]);
  (Wrd38.Obj) = (current_block [OBJECT_8_0]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_15]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_8_4]), 3);

DEFLABEL (label_21)
  goto label_28;

DEFLABEL (label_30)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 10))
    goto label_32;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd20.Lng))))
    goto label_32;
  (Wrd12.Obj) = ((Wrd18.pObj) [3]);

DEFLABEL (label_31)
  (Rsp [2]) = (Wrd12.Obj);
  Rsp = (& (Rsp [2]));
  goto loop_13;

DEFLABEL (label_32)
  (Wrd23.Obj) = (Rsp [2]);
  (Wrd24.Obj) = (current_block [OBJECT_8_3]);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_12]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_8_1]), 2);

DEFLABEL (label_19)
  (Wrd12.Obj) = Rvl;
  goto label_31;

DEFLABEL (label_34)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_8_0]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_9]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_8_1]), 2);

DEFLABEL (label_18)
  (* (--Rsp)) = Rvl;
  goto label_33;

DEFLABEL (label_36)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_8_7])), (Wrd10.pObj));

DEFLABEL (label_17)
  (Wrd9.Obj) = Rvl;
  goto label_35;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_9_4 3
#define LABEL_9_5 5
#define LABEL_9_6 7
#define TAG_9_7 2
#define LABEL_9_8 9
#define LABEL_9_11 11
#define LABEL_9_12 13
#define LABEL_9_13 15
#define ENVIRONMENT_LABEL_9_3 28
#define DEBUGGING_LABEL_9_2 27
#define OBJECT_9_3 26
#define OBJECT_9_2 25
#define OBJECT_9_1 24
#define OBJECT_9_0 23
#define EXECUTE_CACHE_9_14 17
#define EXECUTE_CACHE_9_10 19
#define EXECUTE_CACHE_9_9 21
#define FREE_REFERENCES_LABEL_9_0 16
#define NUMBER_OF_LINKER_SECTIONS_9_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rcompr_so_code_9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd9;
  machine_word Wrd10;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd8;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_9_4);
      goto rtl_expression_register_references_13;

    case 1:
      current_block = (Rpc - LABEL_9_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_9_6);
      goto loop_19;

    case 3:
      current_block = (Rpc - LABEL_9_8);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_9_11);
      goto label_15;

    case 5:
      current_block = (Rpc - LABEL_9_12);
      goto label_16;

    case 6:
      current_block = (Rpc - LABEL_9_13);
      goto continuation_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (rtl_expression_register_references_18)
DEFLABEL (rtl_expression_register_references_13)
  INTERRUPT_CHECK (26, LABEL_9_4);
  (Wrd8.Obj) = (current_block [OBJECT_9_0]);
  (* (Rhp++)) = (Wrd8.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_5]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd18.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_9_7);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_9_6])));
  Rhp += 1;
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd18.pObj)));
  (* (--Rsp)) = (Wrd19.Obj);
  ((Wrd18.pObj) [2]) = (Wrd7.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd19.Obj);
  goto loop_10;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_9_5);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  Rvl = ((Wrd7.pObj) [0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (loop_19)
  CLOSURE_HEADER (LABEL_9_6);

DEFLABEL (loop_10)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_9_8);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_20;
  (Wrd32.Obj) = (Rsp [0]);
  (Wrd33.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd33.Obj);
  (Rsp [1]) = (Wrd32.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_10]));

DEFLABEL (label_20)
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_25;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_24)
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_23;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_22)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_13]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (Rsp [2]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [2]);
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd31.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd31.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_14]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_9_13);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_21;
  Rvl = (current_block [OBJECT_9_3]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_21)
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [2]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (Wrd11.pObj) = (& (Rhp [-2]));
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd11.pObj)));
  (Rsp [0]) = (Wrd9.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  ((Wrd16.pObj) [0]) = (Wrd9.Obj);
  Rvl = (Wrd17.Obj);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_23)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_12]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9_2]), 1);

DEFLABEL (label_16)
  (* (--Rsp)) = Rvl;
  goto label_22;

DEFLABEL (label_25)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_11]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9_1]), 1);

DEFLABEL (label_15)
  (Wrd7.Obj) = Rvl;
  goto label_24;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_5 3
#define LABEL_6 5
#define LABEL_7 7
#define ENVIRONMENT_LABEL_3 16
#define DEBUGGING_LABEL_2 15
#define PURIFICATION_ROOT 14
#define OBJECT_2 13
#define OBJECT_1 12
#define OBJECT_0 11
#define GLOBAL_EXECUTE_CACHE_4 9
#define FREE_REFERENCES_LABEL_0 8
#define NUMBER_OF_LINKER_SECTIONS_1 1

#ifndef WANT_ONLY_DATA

SCHEME_OBJECT *
rcompr_so_47add79172d30cd0 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_5);
      goto label_4;

    case 1:
      current_block = (Rpc - LABEL_6);
      goto label_5;

    case 2:
      current_block = (Rpc - LABEL_7);
      goto expression_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_1)
  (current_block [ENVIRONMENT_LABEL_3]) = (Rrb [REGBLOCK_ENV]);
  INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_6])), current_block, (& (current_block [FREE_REFERENCES_LABEL_0])), NUMBER_OF_LINKER_SECTIONS_1);

DEFLABEL (label_5)
  (* (--Rsp)) = (ULONG_TO_FIXNUM (1UL));

DEFLABEL (label_4)
  {
    static const short sections [] =
      {
	0,
	1,
	2,
	2,
	1,
	1,
	2,
	2,
	2,
	3
      };
    unsigned long counter = (OBJECT_DATUM (* Rsp));
    SCHEME_OBJECT blocks;
    SCHEME_OBJECT * sub_block;
    short section;
    if (counter > 9)
      goto label_3;
    blocks = (current_block [OBJECT_2]);
    sub_block = (OBJECT_ADDRESS (MEMORY_REF (blocks, counter)));
    (sub_block [(OBJECT_DATUM (sub_block [0]))]) = (Rrb [REGBLOCK_ENV]);
    section = (sections [counter]);
    (* Rsp) = (ULONG_TO_FIXNUM (counter + 1));
    INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_5])), sub_block, (sub_block + (2 + (OBJECT_DATUM (sub_block [1])))), section);
  }

DEFLABEL (label_3)
  Rsp += 1;
  (Wrd5.Obj) = (Rrb [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_0]);
  (* (--Rsp)) = (Wrd6.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_1]);
  (Rsp [2]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_4]));

INVOKE_INTERFACE_TARGET_4
}

static const struct liarc_code_S arr_decl_rcompr_so_47add79172d30cd0 [9] =
  {
    { "rcompr_so_code_1", 11, rcompr_so_code_1 },
    { "rcompr_so_code_2", 18, rcompr_so_code_2 },
    { "rcompr_so_code_3", 26, rcompr_so_code_3 },
    { "rcompr_so_code_4", 112, rcompr_so_code_4 },
    { "rcompr_so_code_5", 18, rcompr_so_code_5 },
    { "rcompr_so_code_6", 11, rcompr_so_code_6 },
    { "rcompr_so_code_7", 28, rcompr_so_code_7 },
    { "rcompr_so_code_8", 11, rcompr_so_code_8 },
    { "rcompr_so_code_9", 7, rcompr_so_code_9 }
  };

int
decl_rcompr_so_47add79172d30cd0 (void)
{
  DECLARE_SUBCODE_MULTIPLE (arr_decl_rcompr_so_47add79172d30cd0);
  return (0);
}

DECLARE_COMPILED_CODE ("rcompr.so", 3, decl_rcompr_so_47add79172d30cd0, rcompr_so_47add79172d30cd0)

#endif /* !WANT_ONLY_DATA */

#ifndef WANT_ONLY_CODE

static const unsigned char prog_rcompr_so_data_47add79172d30cd0 [4026] =
  "\x9c\x02\x17\xb9\x06\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc2\xb9\x82"
  "\x1d\x0d\xba\x25\xb2\x0d\xbb\x24\x28\x0d\xbc\x28\x0d\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\xbd\x1d\xb0\x82\x88\xc2\xc2\x81\xc2"
  "\x02\x80\x1d\x82\xb1\x86\xb2\x24\x28\x0d\x28\x0d\x28\x0d\x28\x0d"
  "\x28\x0d\xbe\x28\x0d\x28\xb4\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbf"
  "\x1d\xb0\x83\x88\x81\x1d\x82\x84\xb1\x83\x85\x0d\x1c\xc1\x1c\x0d"
  "\x1c\xc1\x1c\xb2\x0d\x24\x28\x0d\x28\x0d\x1c\x28\x0d\x1c\x28\x0d"
  "\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x84\x88\x08\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x81\x82\x0d\x1c\x0d\x1c\x0d\x1c"
  "\x08\x8a\x1b\xb1\x80\x0d\x1b\x0d\x1b\x1b\x0d\x1c\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x24\x28\x0d\x28\x0d\x1c\x28\x0d"
  "\x28\x1b\x28\x1b\x28\x0d\x1c\x28\x0d\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x85\x88\x1b\x1b\x1b\x1b\x1b\x1b\x28\x1b\x28\x0d\x28\x0d\x28\x0d"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x86\x88\x07\x87\x1b"
  "\x1b\x1b\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x82\x81\x83\x86\x85\x84\xc3\x1c\x1d\xb1\x80\x0d"
  "\xb2\x24\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x1c\x28\x0d\x28"
  "\x0d\x1c\x28\x0d\xba\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x1b\x82\x08\xb1\x81\x0d\x24\x28\xb4\x28"
  "\x0d\x28\x0d\x28\xb2\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x1d\x1b\x1b\x08\x28\x0d\x28\x0d\x28\x0d\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x17\x1c\x88\x1b\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\xb7\x2a\xb5\x2a\x17\x1b\x1b\x1b\x1b\x1b\x1b\xb6\xb3"
  "\x0d\x17\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x80\x01"
  "\x2f\x61\x66\x73\x2f\x63\x73\x61\x69\x6c\x2e\x6d\x69\x74\x2e\x65"
  "\x64\x75\x2f\x67\x72\x6f\x75\x70\x2f\x6d\x61\x63\x2f\x70\x72\x6f"
  "\x6a\x65\x63\x74\x73\x2f\x73\x63\x68\x65\x6d\x65\x2f\x76\x37\x2f"
  "\x64\x69\x73\x74\x2f\x73\x6e\x61\x70\x73\x68\x6f\x74\x2e\x70\x6b"
  "\x67\x2f\x32\x30\x30\x37\x30\x39\x30\x39\x2f\x6d\x69\x74\x2d\x73"
  "\x63\x68\x65\x6d\x65\x2d\x63\x2d\x32\x30\x30\x37\x30\x39\x30\x39"
  "\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2f\x72\x74"
  "\x6c\x6f\x70\x74\x2f\x72\x63\x6f\x6d\x70\x72\x2e\x69\x6e\x66\x15"
  "\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72"
  "\x6f\x6f\x74\x5d\x02\x0b\x76\x65\x63\x74\x6f\x72\x2d\x72\x65\x66"
  "\x02\x11\x2a\x63\x75\x72\x72\x65\x6e\x74\x2d\x72\x67\x72\x61\x70"
  "\x68\x2a\x02\x0c\x77\x61\x6c\x6b\x2d\x62\x62\x6c\x6f\x63\x6b\x03"
  "\x04\x09\x66\x6f\x72\x2d\x65\x61\x63\x68\x05\x13\x73\x68\x61\x6c"
  "\x6c\x6f\x77\x2d\x66\x6c\x75\x69\x64\x2d\x62\x69\x6e\x64\x03\x0e"
  "\x18\x81\x87\x02\x0d\x16\x81\x85\x02\x0c\x14\x81\x83\x02\x0b\x12"
  "\x81\x85\x02\x0a\x10\x81\x83\x02\x09\x0e\x81\x83\x02\x08\x0c\x81"
  "\x87\x02\x07\x0a\x81\x85\x02\x06\x08\x81\x83\x02\x05\x06\x83\x04"
  "\x04\x04\x83\x04\x17\x27\x02\x12\x62\x69\x74\x2d\x73\x74\x72\x69"
  "\x6e\x67\x2d\x63\x6c\x65\x61\x72\x21\x0f\x62\x69\x74\x2d\x73\x74"
  "\x72\x69\x6e\x67\x2d\x6f\x72\x21\x11\x62\x69\x74\x2d\x73\x74\x72"
  "\x69\x6e\x67\x2d\x66\x69\x6c\x6c\x21\x08\x02\x02\x04\x10\x6d\x61"
  "\x6b\x65\x2d\x62\x69\x74\x2d\x73\x74\x72\x69\x6e\x67\x03\x1a\x62"
  "\x62\x6c\x6f\x63\x6b\x2d\x70\x65\x72\x66\x6f\x72\x6d\x2d\x64\x65"
  "\x6c\x65\x74\x69\x6f\x6e\x73\x21\x03\x10\x62\x69\x74\x2d\x73\x74"
  "\x72\x69\x6e\x67\x2d\x63\x6f\x70\x79\x04\x14\x62\x62\x6c\x6f\x63"
  "\x6b\x2d\x77\x61\x6c\x6b\x2d\x66\x6f\x72\x77\x61\x72\x64\x06\x0d"
  "\x6f\x70\x74\x69\x6d\x69\x7a\x65\x2d\x72\x74\x6c\x06\x14\x6d\x61"
  "\x72\x6b\x2d\x73\x65\x74\x2d\x72\x65\x67\x69\x73\x74\x65\x72\x73"
  "\x21\x04\x08\x20\x26\x81\x85\x02\x1f\x24\x81\x87\x02\x1e\x22\x81"
  "\x89\x02\x1d\x20\x81\x87\x02\x1c\x1e\x81\x87\x02\x1b\x1c\x81\x87"
  "\x02\x1a\x1a\x81\x85\x02\x19\x18\x81\x85\x02\x18\x16\x81\x85\x02"
  "\x17\x14\x81\x87\x02\x16\x12\x81\x89\x02\x15\x10\x81\x85\x02\x14"
  "\x0e\x81\x83\x02\x13\x0c\x81\x89\x02\x12\x0a\x81\x89\x02\x11\x08"
  "\x81\x83\x02\x10\x06\x81\x83\x02\x0f\x04\x83\x04\x25\x43\x02\x02"
  "\x09\x72\x65\x67\x69\x73\x74\x65\x72\x09\x04\x63\x64\x72\x0a\x07"
  "\x61\x73\x73\x69\x67\x6e\x0b\x04\x63\x61\x72\x0c\x19\x72\x74\x6c"
  "\x3a\x76\x6f\x6c\x61\x74\x69\x6c\x65\x2d\x65\x78\x70\x72\x65\x73"
  "\x73\x69\x6f\x6e\x3f\x03\x04\x19\x72\x74\x6c\x3a\x65\x78\x70\x72"
  "\x65\x73\x73\x69\x6f\x6e\x2d\x63\x6f\x6e\x74\x61\x69\x6e\x73\x3f"
  "\x04\x05\x6d\x65\x6d\x71\x0d\x07\x13\x66\x6f\x6c\x64\x2d\x69\x6e"
  "\x73\x74\x72\x75\x63\x74\x69\x6f\x6e\x73\x21\x0e\x05\x1b\x66\x69"
  "\x6e\x64\x2d\x72\x65\x66\x65\x72\x65\x6e\x63\x65\x2d\x69\x6e\x73"
  "\x74\x72\x75\x63\x74\x69\x6f\x6e\x0f\x05\x3a\x36\x81\x85\x02\x39"
  "\x34\x81\x8d\x02\x38\x32\x81\x83\x02\x37\x30\x81\x87\x02\x36\x2e"
  "\x81\x85\x02\x35\x2c\x81\x8f\x02\x34\x2a\x81\x8d\x02\x33\x28\x81"
  "\x8f\x02\x32\x26\x81\x8b\x02\x31\x24\x81\x8b\x02\x30\x22\x81\x8b"
  "\x02\x2f\x20\x81\x8b\x02\x2e\x1e\x81\x8b\x02\x2d\x1c\x81\x8b\x02"
  "\x2c\x1a\x81\x8b\x02\x2b\x18\x81\x8b\x02\x2a\x16\x81\x8b\x02\x29"
  "\x14\x81\x8b\x02\x28\x12\x81\x8b\x02\x27\x10\x81\x83\x02\x26\x0e"
  "\x81\x83\x02\x25\x0c\x81\x8b\x02\x24\x0a\x81\x8b\x02\x23\x08\x81"
  "\x8b\x02\x22\x06\x86\x0a\x21\x04\x81\x89\x02\x35\x4f\x10\x02\x18"
  "\x6f\x62\x6a\x65\x63\x74\x2d\x3e\x75\x6e\x73\x69\x67\x6e\x65\x64"
  "\x2d\x66\x69\x78\x6e\x75\x6d\x0d\x6f\x62\x6a\x65\x63\x74\x2d\x3e"
  "\x74\x79\x70\x65\x0f\x6f\x62\x6a\x65\x63\x74\x2d\x3e\x66\x69\x78"
  "\x6e\x75\x6d\x0e\x6f\x62\x6a\x65\x63\x74\x2d\x3e\x64\x61\x74\x75"
  "\x6d\x10\x6f\x62\x6a\x65\x63\x74\x2d\x3e\x61\x64\x64\x72\x65\x73"
  "\x73\x11\x63\x6f\x6e\x73\x2d\x6e\x6f\x6e\x2d\x70\x6f\x69\x6e\x74"
  "\x65\x72\x0d\x63\x6f\x6e\x73\x2d\x70\x6f\x69\x6e\x74\x65\x72\x0d"
  "\x66\x6c\x6f\x61\x74\x2d\x6f\x66\x66\x73\x65\x74\x0c\x62\x79\x74"
  "\x65\x2d\x6f\x66\x66\x73\x65\x74\x07\x6f\x66\x66\x73\x65\x74\x11"
  "\x0f\x70\x6f\x73\x74\x2d\x69\x6e\x63\x72\x65\x6d\x65\x6e\x74\x12"
  "\x0e\x70\x72\x65\x2d\x69\x6e\x63\x72\x65\x6d\x65\x6e\x74\x13\x0b"
  "\x0f\x6f\x66\x66\x73\x65\x74\x2d\x61\x64\x64\x72\x65\x73\x73\x11"
  "\x11\x6d\x61\x63\x68\x69\x6e\x65\x2d\x63\x6f\x6e\x73\x74\x61\x6e"
  "\x74\x0c\x0a\x23\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x2d\x63"
  "\x6c\x6f\x62\x62\x65\x72\x73\x2d\x73\x74\x61\x63\x6b\x2d\x70\x6f"
  "\x69\x6e\x74\x65\x72\x3f\x11\x17\x72\x74\x6c\x3a\x63\x6f\x6e\x73"
  "\x2d\x70\x6f\x69\x6e\x74\x65\x72\x2d\x64\x61\x74\x75\x6d\x1b\x72"
  "\x74\x6c\x3a\x63\x6f\x6e\x73\x2d\x6e\x6f\x6e\x2d\x70\x6f\x69\x6e"
  "\x74\x65\x72\x2d\x64\x61\x74\x75\x6d\x19\x72\x74\x6c\x3a\x6d\x61"
  "\x6b\x65\x2d\x6f\x62\x6a\x65\x63\x74\x2d\x3e\x61\x64\x64\x72\x65"
  "\x73\x73\x1f\x72\x74\x6c\x3a\x6f\x62\x6a\x65\x63\x74\x2d\x3e\x61"
  "\x64\x64\x72\x65\x73\x73\x2d\x65\x78\x70\x72\x65\x73\x73\x69\x6f"
  "\x6e\x17\x72\x74\x6c\x3a\x6d\x61\x6b\x65\x2d\x6f\x62\x6a\x65\x63"
  "\x74\x2d\x3e\x64\x61\x74\x75\x6d\x1d\x72\x74\x6c\x3a\x6f\x62\x6a"
  "\x65\x63\x74\x2d\x3e\x64\x61\x74\x75\x6d\x2d\x65\x78\x70\x72\x65"
  "\x73\x73\x69\x6f\x6e\x18\x72\x74\x6c\x3a\x6d\x61\x6b\x65\x2d\x6f"
  "\x62\x6a\x65\x63\x74\x2d\x3e\x66\x69\x78\x6e\x75\x6d\x1e\x72\x74"
  "\x6c\x3a\x6f\x62\x6a\x65\x63\x74\x2d\x3e\x66\x69\x78\x6e\x75\x6d"
  "\x2d\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x16\x72\x74\x6c\x3a"
  "\x6d\x61\x6b\x65\x2d\x6f\x62\x6a\x65\x63\x74\x2d\x3e\x74\x79\x70"
  "\x65\x1c\x72\x74\x6c\x3a\x6f\x62\x6a\x65\x63\x74\x2d\x3e\x74\x79"
  "\x70\x65\x2d\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x21\x72\x74"
  "\x6c\x3a\x6d\x61\x6b\x65\x2d\x6f\x62\x6a\x65\x63\x74\x2d\x3e\x75"
  "\x6e\x73\x69\x67\x6e\x65\x64\x2d\x66\x69\x78\x6e\x75\x6d\x27\x72"
  "\x74\x6c\x3a\x6f\x62\x6a\x65\x63\x74\x2d\x3e\x75\x6e\x73\x69\x67"
  "\x6e\x65\x64\x2d\x66\x69\x78\x6e\x75\x6d\x2d\x65\x78\x70\x72\x65"
  "\x73\x73\x69\x6f\x6e\x0e\x03\x1c\x69\x6e\x74\x65\x72\x70\x72\x65"
  "\x74\x65\x72\x2d\x76\x61\x6c\x75\x65\x2d\x72\x65\x67\x69\x73\x74"
  "\x65\x72\x3f\x03\x1b\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72"
  "\x2d\x73\x74\x61\x63\x6b\x2d\x70\x6f\x69\x6e\x74\x65\x72\x3f\x14"
  "\x03\x19\x72\x74\x6c\x3a\x63\x6f\x6e\x73\x74\x61\x6e\x74\x2d\x65"
  "\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x3f\x03\x11\x04\x0d\x03\x1a"
  "\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x2d\x69\x73\x2d\x73\x74"
  "\x61\x63\x6b\x2d\x70\x75\x73\x68\x3f\x0d\x04\x11\x72\x74\x6c\x3a"
  "\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x3d\x3f\x08\xaa\x01\xe2"
  "\x01\x81\x85\x02\xa9\x01\xe0\x01\x83\x04\xa8\x01\xde\x01\x81\x8d"
  "\x02\xa7\x01\xdc\x01\x81\x8d\x02\xa6\x01\xda\x01\x81\x8d\x02\xa5"
  "\x01\xd8\x01\x81\x85\x02\xa4\x01\xd6\x01\x81\x8f\x02\xa3\x01\xd4"
  "\x01\x81\x8d\x02\xa2\x01\xd2\x01\x81\x87\x02\xa1\x01\xd0\x01\x81"
  "\x85\x02\xa0\x01\xce\x01\x81\x8f\x02\x9f\x01\xcc\x01\x81\x8f\x02"
  "\x9e\x01\xca\x01\x81\x93\x02\x9d\x01\xc8\x01\x81\x93\x02\x9c\x01"
  "\xc6\x01\x81\x8f\x02\x9b\x01\xc4\x01\x81\x8f\x02\x9a\x01\xc2\x01"
  "\x81\x8f\x02\x99\x01\xc0\x01\x81\x8f\x02\x98\x01\xbe\x01\x81\x8f"
  "\x02\x97\x01\xbc\x01\x81\x85\x02\x96\x01\xba\x01\x81\x8d\x02\x95"
  "\x01\xb8\x01\x81\x85\x02\x94\x01\xb6\x01\x81\x85\x02\x93\x01\xb4"
  "\x01\x81\x85\x02\x92\x01\xb2\x01\x83\x04\x91\x01\xb0\x01\x83\x04"
  "\x90\x01\xae\x01\x81\x8d\x02\x8f\x01\xac\x01\x81\x8d\x02\x8e\x01"
  "\xaa\x01\x81\x85\x02\x8d\x01\xa8\x01\x81\x85\x02\x8c\x01\xa6\x01"
  "\x81\x85\x02\x8b\x01\xa4\x01\x81\x85\x02\x8a\x01\xa2\x01\x81\x85"
  "\x02\x89\x01\xa0\x01\x81\x85\x02\x88\x01\x9e\x01\x81\x87\x02\x87"
  "\x01\x9c\x01\x81\x8d\x02\x86\x01\x9a\x01\x83\x04\x85\x01\x98\x01"
  "\x81\x87\x02\x84\x01\x96\x01\x81\x85\x02\x83\x01\x94\x01\x81\x89"
  "\x02\x82\x01\x92\x01\x81\x87\x02\x81\x01\x90\x01\x81\x89\x02\x80"
  "\x01\x8e\x01\x81\x89\x02\x7f\x8c\x01\x81\x89\x02\x7e\x8a\x01\x81"
  "\x89\x02\x7d\x88\x01\x81\x89\x02\x7c\x86\x01\x81\x89\x02\x7b\x84"
  "\x01\x81\x89\x02\x7a\x82\x01\x81\x8b\x02\x79\x80\x01\x81\x89\x02"
  "\x78\x7e\x81\x89\x02\x77\x7c\x81\x8b\x02\x76\x7a\x81\x89\x02\x75"
  "\x78\x81\x89\x02\x74\x76\x81\x89\x02\x73\x74\x81\x89\x02\x72\x72"
  "\x81\x89\x02\x71\x70\x81\x89\x02\x70\x6e\x81\x89\x02\x6f\x6c\x81"
  "\x89\x02\x6e\x6a\x81\x89\x02\x6d\x68\x81\x89\x02\x6c\x66\x81\x89"
  "\x02\x6b\x64\x81\x89\x02\x6a\x62\x81\x89\x02\x69\x60\x81\x89\x02"
  "\x68\x5e\x81\x89\x02\x67\x5c\x81\x89\x02\x66\x5a\x81\x89\x02\x65"
  "\x58\x81\x89\x02\x64\x56\x81\x89\x02\x63\x54\x81\x8b\x02\x62\x52"
  "\x81\x89\x02\x61\x50\x81\x83\x02\x60\x4e\x81\x83\x02\x5f\x4c\x81"
  "\x83\x02\x5e\x4a\x83\x04\x5d\x48\x81\x89\x02\x5c\x46\x81\x87\x02"
  "\x5b\x44\x81\x87\x02\x5a\x42\x81\x87\x02\x59\x40\x81\x85\x02\x58"
  "\x3e\x83\x04\x57\x3c\x81\x83\x02\x56\x3a\x83\x04\x55\x38\x81\x8b"
  "\x02\x54\x36\x81\x89\x02\x53\x34\x81\x89\x02\x52\x32\x81\x87\x02"
  "\x51\x30\x81\x8b\x02\x50\x2e\x81\x8b\x02\x4f\x2c\x81\x89\x02\x4e"
  "\x2a\x81\x8b\x02\x4d\x28\x81\x8b\x02\x4c\x26\x81\x89\x02\x4b\x24"
  "\x81\x89\x02\x4a\x22\x81\x89\x02\x49\x20\x81\x89\x02\x48\x1e\x81"
  "\x89\x02\x47\x1c\x81\x89\x02\x46\x1a\x81\x89\x02\x45\x18\x81\x89"
  "\x02\x44\x16\x81\x89\x02\x43\x14\x81\x89\x02\x42\x12\x81\x89\x02"
  "\x41\x10\x81\x89\x02\x40\x0e\x81\x89\x02\x3f\x0c\x81\x89\x02\x3e"
  "\x0a\x81\x87\x02\x3d\x08\x81\x87\x02\x3c\x06\x81\x85\x02\x3b\x04"
  "\x85\x08\xe1\x01\x96\x02\x15\x02\x12\x13\x09\x0a\x0b\x0c\x03\x14"
  "\x03\x10\x72\x74\x6c\x3a\x69\x6e\x76\x6f\x63\x61\x74\x69\x6f\x6e"
  "\x3f\x03\x17\x72\x74\x6c\x3a\x69\x6e\x76\x6f\x63\x61\x74\x69\x6f"
  "\x6e\x2d\x70\x72\x65\x66\x69\x78\x3f\x04\x17\x72\x74\x6c\x3a\x61"
  "\x6e\x79\x2d\x73\x75\x62\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e"
  "\x3f\x05\xbc\x01\x26\x81\x83\x02\xbb\x01\x24\x81\x83\x02\xba\x01"
  "\x22\x81\x83\x02\xb9\x01\x20\x81\x83\x02\xb8\x01\x1e\x81\x83\x02"
  "\xb7\x01\x1c\x81\x83\x02\xb6\x01\x1a\x83\x04\xb5\x01\x18\x81\x83"
  "\x02\xb4\x01\x16\x81\x85\x02\xb3\x01\x14\x81\x85\x02\xb2\x01\x12"
  "\x81\x85\x02\xb1\x01\x10\x81\x85\x02\xb0\x01\x0e\x81\x85\x02\xaf"
  "\x01\x0c\x81\x85\x02\xae\x01\x0a\x81\x85\x02\xad\x01\x08\x81\x85"
  "\x02\xac\x01\x06\x83\x04\xab\x01\x04\x81\x83\x02\x25\x37\x12\x02"
  "\x13\x0a\x0b\x0c\x03\x14\x02\xc7\x01\x18\x81\x85\x02\xc6\x01\x16"
  "\x81\x85\x02\xc5\x01\x14\x81\x85\x02\xc4\x01\x12\x81\x83\x02\xc3"
  "\x01\x10\x81\x85\x02\xc2\x01\x0e\x81\x85\x02\xc1\x01\x0c\x81\x83"
  "\x02\xc0\x01\x0a\x81\x83\x02\xbf\x01\x08\x81\x83\x02\xbe\x01\x06"
  "\x81\x83\x02\xbd\x01\x04\x83\x04\x17\x23\x14\x02\x08\x0c\x76\x65"
  "\x63\x74\x6f\x72\x2d\x73\x65\x74\x21\x13\x02\x20\x64\x65\x63\x72"
  "\x65\x6d\x65\x6e\x74\x2d\x72\x65\x67\x69\x73\x74\x65\x72\x2d\x6c"
  "\x69\x76\x65\x2d\x6c\x65\x6e\x67\x74\x68\x21\x03\x04\x18\x72\x74"
  "\x6c\x3a\x72\x65\x66\x65\x72\x73\x2d\x74\x6f\x2d\x72\x65\x67\x69"
  "\x73\x74\x65\x72\x3f\x05\x13\x72\x74\x6c\x3a\x73\x75\x62\x73\x74"
  "\x2d\x72\x65\x67\x69\x73\x74\x65\x72\x03\x24\x6c\x61\x70\x2d\x67"
  "\x65\x6e\x65\x72\x61\x74\x6f\x72\x2f\x6d\x61\x74\x63\x68\x2d\x72"
  "\x74\x6c\x2d\x69\x6e\x73\x74\x72\x75\x63\x74\x69\x6f\x6e\x04\x17"
  "\x66\x6f\x72\x2d\x65\x61\x63\x68\x2d\x72\x65\x67\x73\x65\x74\x2d"
  "\x6d\x65\x6d\x62\x65\x72\x03\x23\x72\x74\x6c\x3a\x65\x78\x70\x72"
  "\x65\x73\x73\x69\x6f\x6e\x2d\x72\x65\x67\x69\x73\x74\x65\x72\x2d"
  "\x72\x65\x66\x65\x72\x65\x6e\x63\x65\x73\x0b\x04\x06\x64\x65\x6c"
  "\x76\x21\x06\x13\x6e\x65\x77\x2d\x64\x65\x61\x64\x2d\x72\x65\x67"
  "\x69\x73\x74\x65\x72\x73\x09\x04\x0e\x65\x71\x76\x2d\x73\x65\x74"
  "\x2d\x75\x6e\x69\x6f\x6e\x09\xe3\x01\x3a\x81\x89\x02\xe2\x01\x38"
  "\x81\x97\x02\xe1\x01\x36\x81\x93\x02\xe0\x01\x34\x81\x91\x02\xdf"
  "\x01\x32\x81\x8b\x02\xde\x01\x30\x81\x8f\x02\xdd\x01\x2e\x81\x8d"
  "\x02\xdc\x01\x2c\x81\x8d\x02\xdb\x01\x2a\x81\x8d\x02\xda\x01\x28"
  "\x81\x8d\x02\xd9\x01\x26\x81\x8d\x02\xd8\x01\x24\x81\x8d\x02\xd7"
  "\x01\x22\x81\x8d\x02\xd6\x01\x20\x81\x8d\x02\xd5\x01\x1e\x81\x8d"
  "\x02\xd4\x01\x1c\x81\x8d\x02\xd3\x01\x1a\x81\x8d\x02\xd2\x01\x18"
  "\x81\x8d\x02\xd1\x01\x16\x81\x87\x02\xd0\x01\x14\x81\x8d\x02\xcf"
  "\x01\x12\x81\x8f\x02\xce\x01\x10\x81\x8d\x02\xcd\x01\x0e\x81\x8d"
  "\x02\xcc\x01\x0c\x81\x8d\x02\xcb\x01\x0a\x81\x8d\x02\xca\x01\x08"
  "\x81\x8d\x02\xc9\x01\x06\x81\x8b\x02\xc8\x01\x04\x87\x0c\x39\x5a"
  "\x16\x02\x09\x13\x20\x69\x6e\x63\x72\x65\x6d\x65\x6e\x74\x2d\x72"
  "\x65\x67\x69\x73\x74\x65\x72\x2d\x6c\x69\x76\x65\x2d\x6c\x65\x6e"
  "\x67\x74\x68\x21\x02\x04\x04\x15\x65\x71\x76\x2d\x73\x65\x74\x2d"
  "\x69\x6e\x74\x65\x72\x73\x65\x63\x74\x69\x6f\x6e\x04\x13\x65\x71"
  "\x76\x2d\x73\x65\x74\x2d\x64\x69\x66\x66\x65\x72\x65\x6e\x63\x65"
  "\x04\x05\xee\x01\x18\x81\x91\x02\xed\x01\x16\x81\x91\x02\xec\x01"
  "\x14\x81\x91\x02\xeb\x01\x12\x81\x91\x02\xea\x01\x10\x81\x91\x02"
  "\xe9\x01\x0e\x81\x8f\x02\xe8\x01\x0c\x81\x8d\x02\xe7\x01\x0a\x81"
  "\x8d\x02\xe6\x01\x08\x81\x91\x02\xe5\x01\x06\x81\x8d\x02\xe4\x01"
  "\x04\x86\x0a\x17\x2a\x13\x02\x0a\x02\x0c\x0a\x03\x20\x72\x74\x6c"
  "\x3a\x70\x73\x65\x75\x64\x6f\x2d\x72\x65\x67\x69\x73\x74\x65\x72"
  "\x2d\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x3f\x04\x1b\x72\x74"
  "\x6c\x3a\x66\x6f\x72\x2d\x65\x61\x63\x68\x2d\x73\x75\x62\x65\x78"
  "\x70\x72\x65\x73\x73\x69\x6f\x6e\x04\x05\x6d\x65\x6d\x76\x04\xf5"
  "\x01\x10\x81\x87\x02\xf4\x01\x0e\x81\x85\x02\xf3\x01\x0c\x81\x85"
  "\x02\xf2\x01\x0a\x81\x85\x02\xf1\x01\x08\x81\x85\x02\xf0\x01\x06"
  "\x81\x85\x02\xef\x01\x04\x83\x04\x0f\x1d\x0c\x0a\x0a\x0a\x0c\x04"
  "\x13\x04\x16\x04\x14\x04\x12\x06\x15\x04\x10\x06\x04\x04\x0a\x0b"
  "\x09\x0e\x0d\x11\x0f\x11\x63\x6f\x64\x65\x2d\x63\x6f\x6d\x70\x72"
  "\x65\x73\x73\x69\x6f\x6e\x0a\x05\x10\x64\x65\x66\x69\x6e\x65\x2d"
  "\x6d\x75\x6c\x74\x69\x70\x6c\x65\x02\x03\x08\x80\x80\x04\x02\x06"
  "\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";

SCHEME_OBJECT *
rcompr_so_data_47add79172d30cd0 (entry_count_t dispatch_base)
{
  SCHEME_OBJECT ccb;
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES_FOR_DATA ();

  ccb = (unstackify (((unsigned char *) (& (prog_rcompr_so_data_47add79172d30cd0 [0]))), (sizeof (prog_rcompr_so_data_47add79172d30cd0)), dispatch_base));
  current_block = (OBJECT_ADDRESS (ccb));
  return (& (current_block [LABEL_7]));
}

DECLARE_COMPILED_DATA_NS ("rcompr.so", rcompr_so_data_47add79172d30cd0)

#endif /* !WANT_ONLY_CODE */

DECLARE_DYNAMIC_INITIALIZATION ("rcompr.so", "7601115582077ec1")
