/* Emacs: this is -*- C -*- code, */
/* generated 2007-09-09T13:46:26-0400 by Liar version UNKNOWN. */

#include "liarc.h"

#define LABEL_1_4 3
#define LABEL_1_5 5
#define ENVIRONMENT_LABEL_1_3 12
#define DEBUGGING_LABEL_1_2 11
#define EXECUTE_CACHE_1_7 7
#define EXECUTE_CACHE_1_6 9
#define FREE_REFERENCES_LABEL_1_0 6
#define NUMBER_OF_LINKER_SECTIONS_1_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_1_4);
      goto define_er_macro_transformer_1;

    case 1:
      current_block = (Rpc - LABEL_1_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (define_er_macro_transformer_4)
DEFLABEL (define_er_macro_transformer_1)
  INTERRUPT_CHECK (26, LABEL_1_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_1_5);
  (Rsp [2]) = Rvl;
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd7.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_2_4 3
#define LABEL_2_5 5
#define TAG_2_6 1
#define LABEL_2_7 7
#define LABEL_2_10 9
#define LABEL_2_11 11
#define LABEL_2_12 13
#define LABEL_2_9 15
#define ENVIRONMENT_LABEL_2_3 29
#define DEBUGGING_LABEL_2_2 28
#define OBJECT_2_2 27
#define OBJECT_2_1 26
#define OBJECT_2_0 25
#define EXECUTE_CACHE_2_14 17
#define EXECUTE_CACHE_2_13 19
#define EXECUTE_CACHE_2_8 21
#define FREE_REFERENCE_2_0 24
#define FREE_REFERENCES_LABEL_2_0 16
#define NUMBER_OF_LINKER_SECTIONS_2_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd34;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd30;
  machine_word Wrd27;
  machine_word Wrd19;
  machine_word Wrd21;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_2_4);
      goto transformer_keyword_5;

    case 1:
      current_block = (Rpc - LABEL_2_5);
      goto lambda_12;

    case 2:
      current_block = (Rpc - LABEL_2_7);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_2_10);
      goto label_7;

    case 4:
      current_block = (Rpc - LABEL_2_11);
      goto label_8;

    case 5:
      current_block = (Rpc - LABEL_2_12);
      goto label_9;

    case 6:
      current_block = (Rpc - LABEL_2_9);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (transformer_keyword_11)
DEFLABEL (transformer_keyword_5)
  INTERRUPT_CHECK (26, LABEL_2_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x505, 2);
  (* (Rhp++)) = (dispatch_base + TAG_2_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_2_5])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (lambda_12)
  CLOSURE_HEADER (LABEL_2_5);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_2_0]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_2_7);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [3]);
  (Rsp [3]) = (Wrd5.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_9]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_18;
  Wrd11 = Wrd15;

DEFLABEL (label_17)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd17.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd22.Obj) = (Rsp [5]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd23.uLng) == 1))
    goto label_16;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd19.Obj) = ((Wrd21.pObj) [1]);

DEFLABEL (label_15)
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd30.uLng) == 1))
    goto label_14;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [0]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_13)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_13]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_2_9);
  (Wrd5.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [4]);
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [4]) = (Wrd7.Obj);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_14]));

DEFLABEL (label_14)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_12]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_2]), 1);

DEFLABEL (label_9)
  (* (--Rsp)) = Rvl;
  goto label_13;

DEFLABEL (label_16)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_11]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_1]), 1);

DEFLABEL (label_8)
  (Wrd19.Obj) = Rvl;
  goto label_15;

DEFLABEL (label_18)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_10])), (Wrd12.pObj));

DEFLABEL (label_7)
  (Wrd11.Obj) = Rvl;
  goto label_17;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_3_4 3
#define LABEL_3_5 5
#define LABEL_3_6 7
#define TAG_3_7 2
#define LABEL_3_9 9
#define LABEL_3_10 11
#define LABEL_3_11 13
#define LABEL_3_13 15
#define LABEL_3_16 17
#define LABEL_3_18 19
#define LABEL_3_21 21
#define ENVIRONMENT_LABEL_3_3 41
#define DEBUGGING_LABEL_3_2 40
#define OBJECT_3_0 39
#define EXECUTE_CACHE_3_22 23
#define EXECUTE_CACHE_3_20 25
#define EXECUTE_CACHE_3_19 27
#define EXECUTE_CACHE_3_17 29
#define EXECUTE_CACHE_3_15 31
#define EXECUTE_CACHE_3_14 33
#define EXECUTE_CACHE_3_12 35
#define EXECUTE_CACHE_3_8 37
#define FREE_REFERENCES_LABEL_3_0 22
#define NUMBER_OF_LINKER_SECTIONS_3_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd10;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_3_4);
      goto expression__keyword_value_item_11;

    case 1:
      current_block = (Rpc - LABEL_3_5);
      goto continuation_10;

    case 2:
      current_block = (Rpc - LABEL_3_6);
      goto lambda_15;

    case 3:
      current_block = (Rpc - LABEL_3_9);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_3_10);
      goto continuation_2;

    case 5:
      current_block = (Rpc - LABEL_3_11);
      goto continuation_1;

    case 6:
      current_block = (Rpc - LABEL_3_13);
      goto continuation_4;

    case 7:
      current_block = (Rpc - LABEL_3_16);
      goto continuation_0;

    case 8:
      current_block = (Rpc - LABEL_3_18);
      goto continuation_6;

    case 9:
      current_block = (Rpc - LABEL_3_21);
      goto continuation_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression__keyword_value_item_14)
DEFLABEL (expression__keyword_value_item_11)
  INTERRUPT_CHECK (26, LABEL_3_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_3_7);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_3_6])));
  Rhp += 2;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd12 = Wrd9;
  (Wrd13.Obj) = (Rsp [4]);
  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_8]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_3_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_10]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_11]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_12]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_3_11);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_17]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_3_16);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_20]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_3_10);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_3_9);
  (Rsp [4]) = Rvl;
  (Wrd6.Obj) = (* (Rsp++));
  (Rsp [4]) = (Wrd6.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_15]));

DEFLABEL (lambda_15)
  CLOSURE_HEADER (LABEL_3_6);

DEFLABEL (lambda_9)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_14]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_3_13);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_18]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_19]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_3_18);
  (Wrd9.Obj) = (current_block [OBJECT_3_0]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_21]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [3]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [3]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_17]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_3_21);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Rsp [1]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_22]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4_4 3
#define LABEL_4_5 5
#define LABEL_4_8 7
#define LABEL_4_9 9
#define LABEL_4_10 11
#define LABEL_4_11 13
#define LABEL_4_12 15
#define LABEL_4_7 17
#define LABEL_4_14 19
#define ENVIRONMENT_LABEL_4_3 33
#define DEBUGGING_LABEL_4_2 32
#define OBJECT_4_2 31
#define OBJECT_4_1 30
#define OBJECT_4_0 29
#define EXECUTE_CACHE_4_15 21
#define EXECUTE_CACHE_4_13 23
#define EXECUTE_CACHE_4_6 25
#define FREE_REFERENCE_4_0 28
#define FREE_REFERENCES_LABEL_4_0 20
#define NUMBER_OF_LINKER_SECTIONS_4_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd47;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd43;
  machine_word Wrd40;
  machine_word Wrd32;
  machine_word Wrd34;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd31;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd27;
  machine_word Wrd24;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4_4);
      goto lambda_7;

    case 1:
      current_block = (Rpc - LABEL_4_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_4_8);
      goto label_9;

    case 3:
      current_block = (Rpc - LABEL_4_9);
      goto label_10;

    case 4:
      current_block = (Rpc - LABEL_4_10);
      goto label_11;

    case 5:
      current_block = (Rpc - LABEL_4_11);
      goto label_12;

    case 6:
      current_block = (Rpc - LABEL_4_12);
      goto label_13;

    case 7:
      current_block = (Rpc - LABEL_4_7);
      goto continuation_6;

    case 8:
      current_block = (Rpc - LABEL_4_14);
      goto lambda_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_15)
DEFLABEL (lambda_7)
  INTERRUPT_CHECK (26, LABEL_4_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_4_0]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_4_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_0]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_26;
  Wrd10 = Wrd14;

DEFLABEL (label_25)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd19.Obj) = (Rsp [4]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_24;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [1]);

DEFLABEL (label_23)
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd27.uLng) == 1))
    goto label_22;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [1]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_21)
  (Wrd35.Obj) = (Rsp [5]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd36.uLng) == 1))
    goto label_20;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd32.Obj) = ((Wrd34.pObj) [1]);

DEFLABEL (label_19)
  (Wrd43.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd43.uLng) == 1))
    goto label_18;
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd42.Obj) = ((Wrd41.pObj) [0]);
  (* (--Rsp)) = (Wrd42.Obj);

DEFLABEL (label_17)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_13]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_4_7);
  (Rsp [1]) = Rvl;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_14]))));
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_18)
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_12]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_2]), 1);

DEFLABEL (label_13)
  (* (--Rsp)) = Rvl;
  goto label_17;

DEFLABEL (label_20)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_11]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_12)
  (Wrd32.Obj) = Rvl;
  goto label_19;

DEFLABEL (label_22)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_10]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_11)
  (* (--Rsp)) = Rvl;
  goto label_21;

DEFLABEL (label_24)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_9]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_10)
  (Wrd16.Obj) = Rvl;
  goto label_23;

DEFLABEL (label_26)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_8])), (Wrd11.pObj));

DEFLABEL (label_9)
  (Wrd10.Obj) = Rvl;
  goto label_25;

DEFLABEL (lambda_16)
DEFLABEL (lambda_1)
  INTERRUPT_CHECK (26, LABEL_4_14);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_15]));

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_5_4 3
#define LABEL_5_5 5
#define LABEL_5_8 7
#define LABEL_5_9 9
#define LABEL_5_10 11
#define LABEL_5_11 13
#define LABEL_5_12 15
#define LABEL_5_13 17
#define LABEL_5_7 19
#define LABEL_5_15 21
#define TAG_5_16 9
#define LABEL_5_18 23
#define LABEL_5_19 25
#define LABEL_5_20 27
#define LABEL_5_17 29
#define ENVIRONMENT_LABEL_5_3 45
#define DEBUGGING_LABEL_5_2 44
#define OBJECT_5_2 43
#define OBJECT_5_1 42
#define OBJECT_5_0 41
#define EXECUTE_CACHE_5_22 31
#define EXECUTE_CACHE_5_21 33
#define EXECUTE_CACHE_5_14 35
#define EXECUTE_CACHE_5_6 37
#define FREE_REFERENCE_5_0 40
#define FREE_REFERENCES_LABEL_5_0 30
#define NUMBER_OF_LINKER_SECTIONS_5_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd12;
  machine_word Wrd13;
  machine_word Wrd54;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd50;
  machine_word Wrd47;
  machine_word Wrd41;
  machine_word Wrd42;
  machine_word Wrd43;
  machine_word Wrd40;
  machine_word Wrd32;
  machine_word Wrd34;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd31;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd27;
  machine_word Wrd24;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_5_4);
      goto lambda_12;

    case 1:
      current_block = (Rpc - LABEL_5_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_5_8);
      goto label_14;

    case 3:
      current_block = (Rpc - LABEL_5_9);
      goto label_15;

    case 4:
      current_block = (Rpc - LABEL_5_10);
      goto label_16;

    case 5:
      current_block = (Rpc - LABEL_5_11);
      goto label_17;

    case 6:
      current_block = (Rpc - LABEL_5_12);
      goto label_18;

    case 7:
      current_block = (Rpc - LABEL_5_13);
      goto label_19;

    case 8:
      current_block = (Rpc - LABEL_5_7);
      goto continuation_11;

    case 9:
      current_block = (Rpc - LABEL_5_15);
      goto lambda_25;

    case 10:
      current_block = (Rpc - LABEL_5_18);
      goto label_20;

    case 11:
      current_block = (Rpc - LABEL_5_19);
      goto label_21;

    case 12:
      current_block = (Rpc - LABEL_5_20);
      goto label_22;

    case 13:
      current_block = (Rpc - LABEL_5_17);
      goto continuation_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_24)
DEFLABEL (lambda_12)
  INTERRUPT_CHECK (26, LABEL_5_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_5_0]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_5_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_5_0]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_37;
  Wrd10 = Wrd14;

DEFLABEL (label_36)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd19.Obj) = (Rsp [4]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_35;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [1]);

DEFLABEL (label_34)
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd27.uLng) == 1))
    goto label_33;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [1]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_32)
  (Wrd35.Obj) = (Rsp [5]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd36.uLng) == 1))
    goto label_31;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd32.Obj) = ((Wrd34.pObj) [1]);

DEFLABEL (label_30)
  (Wrd43.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd43.uLng) == 1))
    goto label_29;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd41.Obj) = ((Wrd42.pObj) [0]);

DEFLABEL (label_28)
  (Wrd50.uLng) = (OBJECT_TYPE (Wrd41.Obj));
  if (! ((Wrd50.uLng) == 1))
    goto label_27;
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd41.Obj));
  (Wrd49.Obj) = ((Wrd48.pObj) [1]);
  (* (--Rsp)) = (Wrd49.Obj);

DEFLABEL (label_26)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_14]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_5_7);
  (Rsp [1]) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_5_16);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_5_15])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  Wrd9 = Wrd8;
  (Wrd10.Obj) = (Rsp [0]);
  ((Wrd9.pObj) [2]) = (Wrd10.Obj);
  (Rsp [2]) = (Wrd7.Obj);
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_27)
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_13]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_1]), 1);

DEFLABEL (label_19)
  (* (--Rsp)) = Rvl;
  goto label_26;

DEFLABEL (label_29)
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_12]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_2]), 1);

DEFLABEL (label_18)
  (Wrd41.Obj) = Rvl;
  goto label_28;

DEFLABEL (label_31)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_11]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_1]), 1);

DEFLABEL (label_17)
  (Wrd32.Obj) = Rvl;
  goto label_30;

DEFLABEL (label_33)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_10]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_1]), 1);

DEFLABEL (label_16)
  (* (--Rsp)) = Rvl;
  goto label_32;

DEFLABEL (label_35)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_9]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_1]), 1);

DEFLABEL (label_15)
  (Wrd16.Obj) = Rvl;
  goto label_34;

DEFLABEL (label_37)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_5_8])), (Wrd11.pObj));

DEFLABEL (label_14)
  (Wrd10.Obj) = Rvl;
  goto label_36;

DEFLABEL (lambda_25)
  CLOSURE_HEADER (LABEL_5_15);

DEFLABEL (lambda_5)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [2]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_43;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd8.Obj) = ((Wrd12.pObj) [1]);

DEFLABEL (label_42)
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd25.uLng) == 1))
    goto label_41;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd23.Obj) = ((Wrd24.pObj) [0]);

DEFLABEL (label_40)
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd32.uLng) == 1))
    goto label_39;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (* (--Rsp)) = (Wrd31.Obj);

DEFLABEL (label_38)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_21]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_5_17);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_22]));

DEFLABEL (label_39)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_20]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_2]), 1);

DEFLABEL (label_22)
  (* (--Rsp)) = Rvl;
  goto label_38;

DEFLABEL (label_41)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_19]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_2]), 1);

DEFLABEL (label_21)
  (Wrd23.Obj) = Rvl;
  goto label_40;

DEFLABEL (label_43)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_18]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_1]), 1);

DEFLABEL (label_20)
  (Wrd8.Obj) = Rvl;
  goto label_42;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_6_4 3
#define LABEL_6_5 5
#define LABEL_6_7 7
#define LABEL_6_8 9
#define TAG_6_9 3
#define LABEL_6_11 11
#define LABEL_6_12 13
#define LABEL_6_15 15
#define TAG_6_16 6
#define ENVIRONMENT_LABEL_6_3 28
#define DEBUGGING_LABEL_6_2 27
#define EXECUTE_CACHE_6_17 17
#define EXECUTE_CACHE_6_14 19
#define EXECUTE_CACHE_6_13 21
#define EXECUTE_CACHE_6_10 23
#define EXECUTE_CACHE_6_6 25
#define FREE_REFERENCES_LABEL_6_0 16
#define NUMBER_OF_LINKER_SECTIONS_6_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_6_4);
      goto compile_lambda_9;

    case 1:
      current_block = (Rpc - LABEL_6_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_6_7);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_6_8);
      goto lambda_13;

    case 4:
      current_block = (Rpc - LABEL_6_11);
      goto continuation_4;

    case 5:
      current_block = (Rpc - LABEL_6_12);
      goto continuation_3;

    case 6:
      current_block = (Rpc - LABEL_6_15);
      goto lambda_14;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (compile_lambda_12)
DEFLABEL (compile_lambda_9)
  INTERRUPT_CHECK (26, LABEL_6_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_6_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd10.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_6_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_6_8])));
  Rhp += 1;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd10.pObj)));
  ((Wrd10.pObj) [2]) = Rvl;
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_6_7);
  (* (--Rsp)) = Rvl;
  (Rsp [5]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_11]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_12]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd16.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_13]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_6_12);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_17]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_6_11);
  (Rsp [6]) = Rvl;
  Rsp = (& (Rsp [5]));
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_6_16);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_6_15])));
  Rhp += 2;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  Wrd11 = Wrd8;
  (Wrd12.Obj) = (Rsp [1]);
  ((Wrd11.pObj) [2]) = (Wrd12.Obj);
  (Wrd10.Obj) = (Rsp [0]);
  ((Wrd11.pObj) [3]) = (Wrd10.Obj);
  Rvl = (Wrd7.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (lambda_13)
  CLOSURE_HEADER (LABEL_6_8);

DEFLABEL (lambda_1)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_14]));

DEFLABEL (lambda_14)
  CLOSURE_HEADER (LABEL_6_15);

DEFLABEL (lambda_5)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd9.Obj) = ((Wrd8.pObj) [3]);
  (Rsp [1]) = (Wrd9.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_7_4 3
#define LABEL_7_5 5
#define LABEL_7_7 7
#define LABEL_7_8 9
#define LABEL_7_10 11
#define LABEL_7_6 13
#define LABEL_7_11 15
#define LABEL_7_12 17
#define LABEL_7_13 19
#define LABEL_7_14 21
#define LABEL_7_15 23
#define LABEL_7_16 25
#define ENVIRONMENT_LABEL_7_3 36
#define DEBUGGING_LABEL_7_2 35
#define OBJECT_7_2 34
#define OBJECT_7_1 33
#define OBJECT_7_0 32
#define EXECUTE_CACHE_7_9 27
#define FREE_REFERENCE_7_1 30
#define FREE_REFERENCE_7_0 31
#define FREE_REFERENCES_LABEL_7_0 26
#define NUMBER_OF_LINKER_SECTIONS_7_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_7 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd75;
  machine_word Wrd74;
  machine_word Wrd73;
  machine_word Wrd65;
  machine_word Wrd72;
  machine_word Wrd68;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd94;
  machine_word Wrd92;
  machine_word Wrd76;
  machine_word Wrd84;
  machine_word Wrd91;
  machine_word Wrd87;
  machine_word Wrd81;
  machine_word Wrd83;
  machine_word Wrd82;
  machine_word Wrd59;
  machine_word Wrd51;
  machine_word Wrd58;
  machine_word Wrd54;
  machine_word Wrd46;
  machine_word Wrd48;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd36;
  machine_word Wrd38;
  machine_word Wrd41;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd37;
  machine_word Wrd35;
  machine_word Wrd30;
  machine_word Wrd22;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd20;
  machine_word Wrd13;
  machine_word Wrd79;
  machine_word Wrd96;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd27;
  machine_word Wrd34;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd14;
  machine_word Wrd5;
  machine_word Wrd7;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_7_4);
      goto map_mit_lambda_list_13;

    case 1:
      current_block = (Rpc - LABEL_7_5);
      goto loop_11;

    case 2:
      current_block = (Rpc - LABEL_7_7);
      goto label_15;

    case 3:
      current_block = (Rpc - LABEL_7_8);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_7_10);
      goto continuation_7;

    case 5:
      current_block = (Rpc - LABEL_7_6);
      goto continuation_10;

    case 6:
      current_block = (Rpc - LABEL_7_11);
      goto label_16;

    case 7:
      current_block = (Rpc - LABEL_7_12);
      goto label_17;

    case 8:
      current_block = (Rpc - LABEL_7_13);
      goto label_18;

    case 9:
      current_block = (Rpc - LABEL_7_14);
      goto label_19;

    case 10:
      current_block = (Rpc - LABEL_7_15);
      goto label_21;

    case 11:
      current_block = (Rpc - LABEL_7_16);
      goto label_20;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (map_mit_lambda_list_23)
DEFLABEL (map_mit_lambda_list_13)
  INTERRUPT_CHECK (26, LABEL_7_4);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  Rdl = (& (Rsp [4]));
  goto loop_11;

DEFLABEL (loop_24)
DEFLABEL (loop_11)
  DLINK_INTERRUPT_CHECK (25, LABEL_7_5);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_26;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_8]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_7_8);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_25;
  (Wrd9.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_25)
  Rvl = (current_block [OBJECT_7_1]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_26)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_6]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [3]);
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd19.pObj)));
  (* (--Rsp)) = (Wrd21.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_42;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [1]);
  (* (--Rsp)) = (Wrd24.Obj);

DEFLABEL (label_41)
  Rdl = (& (Rsp [2]));
  goto loop_11;

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_7_6);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_10]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7_0]));
  (Wrd20.Obj) = ((Wrd13.pObj) [0]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd21.uLng) == 50)
    goto label_40;
  Wrd12 = Wrd20;

DEFLABEL (label_39)
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd25.Obj) = (Rsp [4]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 1))
    goto label_38;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd22.Obj) = ((Wrd24.pObj) [0]);

DEFLABEL (label_37)
  (Wrd35.Obj) = (* (Rsp++));
  if ((Wrd22.Obj) == (Wrd35.Obj))
    goto label_30;
  (Wrd37.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7_1]));
  (Wrd44.Obj) = ((Wrd37.pObj) [0]);
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if ((Wrd45.uLng) == 50)
    goto label_36;
  Wrd36 = Wrd44;

DEFLABEL (label_35)
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd49.Obj) = (Rsp [4]);
  (Wrd50.uLng) = (OBJECT_TYPE (Wrd49.Obj));
  if (! ((Wrd50.uLng) == 1))
    goto label_34;
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd49.Obj));
  (Wrd46.Obj) = ((Wrd48.pObj) [0]);

DEFLABEL (label_33)
  (Wrd59.Obj) = (* (Rsp++));
  if ((Wrd46.Obj) == (Wrd59.Obj))
    goto label_30;
  (Wrd63.Obj) = (Rsp [3]);
  (Wrd64.uLng) = (OBJECT_TYPE (Wrd63.Obj));
  if (! ((Wrd64.uLng) == 1))
    goto label_29;
  (Wrd61.pObj) = (OBJECT_ADDRESS (Wrd63.Obj));
  (Wrd62.Obj) = ((Wrd61.pObj) [0]);
  (* (--Rsp)) = (Wrd62.Obj);

DEFLABEL (label_28)
  (Wrd73.Obj) = (Rsp [5]);
  (Wrd74.pObj) = (OBJECT_ADDRESS (Wrd73.Obj));
  (Wrd75.Obj) = ((Wrd74.pObj) [0]);
  (* (--Rsp)) = (Wrd75.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_7_10);
  (Wrd96.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd96.Obj));
  (Wrd79.Obj) = Rvl;

DEFLABEL (label_27)
  (Wrd92.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd79.Obj);
  (* (Rhp++)) = (Wrd92.Obj);
  (Wrd94.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd94.pObj)));
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_29)
  (Wrd68.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd68.Obj);
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_16]))));
  (* (--Rsp)) = (Wrd72.Obj);
  (* (--Rsp)) = (Wrd63.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_2]), 1);

DEFLABEL (label_20)
  (Wrd65.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd65.Obj));
  (* (--Rsp)) = Rvl;
  goto label_28;

DEFLABEL (label_30)
  (Wrd82.Obj) = (Rsp [3]);
  (Wrd83.uLng) = (OBJECT_TYPE (Wrd82.Obj));
  if (! ((Wrd83.uLng) == 1))
    goto label_32;
  (Wrd81.pObj) = (OBJECT_ADDRESS (Wrd82.Obj));
  (Wrd79.Obj) = ((Wrd81.pObj) [0]);

DEFLABEL (label_31)
  Rsp = (& (Rsp [1]));
  (Wrd76.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd76.Obj));
  goto label_27;

DEFLABEL (label_32)
  (Wrd87.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd87.Obj);
  (Wrd91.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_15]))));
  (* (--Rsp)) = (Wrd91.Obj);
  (* (--Rsp)) = (Wrd82.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_2]), 1);

DEFLABEL (label_21)
  (Wrd84.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd84.Obj));
  (Wrd79.Obj) = Rvl;
  goto label_31;

DEFLABEL (label_34)
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd54.Obj);
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_14]))));
  (* (--Rsp)) = (Wrd58.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_2]), 1);

DEFLABEL (label_19)
  (Wrd51.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd46.Obj) = Rvl;
  goto label_33;

DEFLABEL (label_36)
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd41.Obj);
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_7_13])), (Wrd37.pObj));

DEFLABEL (label_18)
  (Wrd38.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd36.Obj) = Rvl;
  goto label_35;

DEFLABEL (label_38)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_12]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_2]), 1);

DEFLABEL (label_17)
  (Wrd27.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd22.Obj) = Rvl;
  goto label_37;

DEFLABEL (label_40)
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_7_11])), (Wrd13.pObj));

DEFLABEL (label_16)
  (Wrd14.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = Rvl;
  goto label_39;

DEFLABEL (label_42)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_7]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_0]), 1);

DEFLABEL (label_15)
  (Wrd27.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd27.Obj));
  (* (--Rsp)) = Rvl;
  goto label_41;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_8_4 3
#define LABEL_8_5 5
#define LABEL_8_8 7
#define LABEL_8_9 9
#define LABEL_8_7 11
#define ENVIRONMENT_LABEL_8_3 24
#define DEBUGGING_LABEL_8_2 23
#define OBJECT_8_1 22
#define OBJECT_8_0 21
#define EXECUTE_CACHE_8_11 13
#define EXECUTE_CACHE_8_10 15
#define EXECUTE_CACHE_8_6 17
#define FREE_REFERENCE_8_0 20
#define FREE_REFERENCES_LABEL_8_0 12
#define NUMBER_OF_LINKER_SECTIONS_8_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd25;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_8_4);
      goto lambda_3;

    case 1:
      current_block = (Rpc - LABEL_8_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_8_8);
      goto label_5;

    case 3:
      current_block = (Rpc - LABEL_8_9);
      goto label_6;

    case 4:
      current_block = (Rpc - LABEL_8_7);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_8)
DEFLABEL (lambda_3)
  INTERRUPT_CHECK (26, LABEL_8_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_8_0]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_8_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_8_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_12;
  Wrd8 = Wrd12;

DEFLABEL (label_11)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd20.Obj) = (Rsp [5]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 1))
    goto label_10;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [1]);
  (* (--Rsp)) = (Wrd19.Obj);

DEFLABEL (label_9)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_8_7);
  (Wrd5.Obj) = (Rsp [3]);
  (Rsp [2]) = (Wrd5.Obj);
  (Rsp [3]) = Rvl;
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8_11]));

DEFLABEL (label_10)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_9]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_8_1]), 1);

DEFLABEL (label_6)
  (* (--Rsp)) = Rvl;
  goto label_9;

DEFLABEL (label_12)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_8_8])), (Wrd9.pObj));

DEFLABEL (label_5)
  (Wrd8.Obj) = Rvl;
  goto label_11;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_9_4 3
#define LABEL_9_5 5
#define LABEL_9_8 7
#define LABEL_9_9 9
#define LABEL_9_10 11
#define LABEL_9_7 13
#define LABEL_9_13 15
#define LABEL_9_14 17
#define LABEL_9_15 19
#define LABEL_9_16 21
#define LABEL_9_12 23
#define LABEL_9_18 25
#define LABEL_9_19 27
#define LABEL_9_20 29
#define LABEL_9_21 31
#define LABEL_9_22 33
#define LABEL_9_23 35
#define LABEL_9_24 37
#define LABEL_9_25 39
#define LABEL_9_17 41
#define ENVIRONMENT_LABEL_9_3 59
#define DEBUGGING_LABEL_9_2 58
#define OBJECT_9_2 57
#define OBJECT_9_1 56
#define OBJECT_9_0 55
#define EXECUTE_CACHE_9_27 43
#define EXECUTE_CACHE_9_26 45
#define EXECUTE_CACHE_9_11 47
#define EXECUTE_CACHE_9_6 49
#define FREE_REFERENCE_9_2 52
#define FREE_REFERENCE_9_1 53
#define FREE_REFERENCE_9_0 54
#define FREE_REFERENCES_LABEL_9_0 42
#define NUMBER_OF_LINKER_SECTIONS_9_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd69;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd65;
  machine_word Wrd62;
  machine_word Wrd56;
  machine_word Wrd57;
  machine_word Wrd58;
  machine_word Wrd55;
  machine_word Wrd49;
  machine_word Wrd50;
  machine_word Wrd51;
  machine_word Wrd48;
  machine_word Wrd40;
  machine_word Wrd42;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd39;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd30;
  machine_word Wrd23;
  machine_word Wrd17;
  machine_word Wrd11;
  machine_word Wrd38;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd34;
  machine_word Wrd31;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd27;
  machine_word Wrd24;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_9_4);
      goto lambda_17;

    case 1:
      current_block = (Rpc - LABEL_9_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_9_8);
      goto label_19;

    case 3:
      current_block = (Rpc - LABEL_9_9);
      goto label_20;

    case 4:
      current_block = (Rpc - LABEL_9_10);
      goto label_21;

    case 5:
      current_block = (Rpc - LABEL_9_7);
      goto continuation_3;

    case 6:
      current_block = (Rpc - LABEL_9_13);
      goto label_22;

    case 7:
      current_block = (Rpc - LABEL_9_14);
      goto label_23;

    case 8:
      current_block = (Rpc - LABEL_9_15);
      goto label_24;

    case 9:
      current_block = (Rpc - LABEL_9_16);
      goto label_25;

    case 10:
      current_block = (Rpc - LABEL_9_12);
      goto continuation_7;

    case 11:
      current_block = (Rpc - LABEL_9_18);
      goto label_26;

    case 12:
      current_block = (Rpc - LABEL_9_19);
      goto label_27;

    case 13:
      current_block = (Rpc - LABEL_9_20);
      goto label_28;

    case 14:
      current_block = (Rpc - LABEL_9_21);
      goto label_29;

    case 15:
      current_block = (Rpc - LABEL_9_22);
      goto label_30;

    case 16:
      current_block = (Rpc - LABEL_9_23);
      goto label_31;

    case 17:
      current_block = (Rpc - LABEL_9_24);
      goto label_32;

    case 18:
      current_block = (Rpc - LABEL_9_25);
      goto label_33;

    case 19:
      current_block = (Rpc - LABEL_9_17);
      goto continuation_12;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_35)
DEFLABEL (lambda_17)
  INTERRUPT_CHECK (26, LABEL_9_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_9_0]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_9_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_66;
  Wrd8 = Wrd12;

DEFLABEL (label_65)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd19.Obj) = (Rsp [4]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_64;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [1]);

DEFLABEL (label_63)
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd27.uLng) == 1))
    goto label_62;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_61)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_9_7);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_1]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_60;
  Wrd8 = Wrd12;

DEFLABEL (label_59)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd19.Obj) = (Rsp [5]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_58;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [1]);

DEFLABEL (label_57)
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd27.uLng) == 1))
    goto label_56;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd25.Obj) = ((Wrd26.pObj) [1]);

DEFLABEL (label_55)
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd34.uLng) == 1))
    goto label_54;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [0]);
  (* (--Rsp)) = (Wrd33.Obj);

DEFLABEL (label_53)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_11]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_9_12);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_52;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd8.Obj) = ((Wrd10.pObj) [1]);

DEFLABEL (label_51)
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd19.uLng) == 1))
    goto label_50;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd17.Obj) = ((Wrd18.pObj) [1]);

DEFLABEL (label_49)
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd26.uLng) == 1))
    goto label_48;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd24.Obj) = ((Wrd25.pObj) [1]);

DEFLABEL (label_47)
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd31.uLng) == 1)
    goto label_36;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_26]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_9_17);
  (Rsp [4]) = Rvl;
  (Wrd6.Obj) = (* (Rsp++));
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd7.Obj) = (* (Rsp++));
  (Rsp [0]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_27]));

DEFLABEL (label_36)
  (Wrd33.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_2]));
  (Wrd36.Obj) = ((Wrd33.pObj) [0]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if ((Wrd37.uLng) == 50)
    goto label_46;
  Wrd32 = Wrd36;

DEFLABEL (label_45)
  (* (--Rsp)) = (Wrd32.Obj);
  (Wrd38.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd39.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd43.Obj) = (Rsp [6]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd44.uLng) == 1))
    goto label_44;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  (Wrd40.Obj) = ((Wrd42.pObj) [1]);

DEFLABEL (label_43)
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if (! ((Wrd51.uLng) == 1))
    goto label_42;
  (Wrd50.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  (Wrd49.Obj) = ((Wrd50.pObj) [1]);

DEFLABEL (label_41)
  (Wrd58.uLng) = (OBJECT_TYPE (Wrd49.Obj));
  if (! ((Wrd58.uLng) == 1))
    goto label_40;
  (Wrd57.pObj) = (OBJECT_ADDRESS (Wrd49.Obj));
  (Wrd56.Obj) = ((Wrd57.pObj) [1]);

DEFLABEL (label_39)
  (Wrd65.uLng) = (OBJECT_TYPE (Wrd56.Obj));
  if (! ((Wrd65.uLng) == 1))
    goto label_38;
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd56.Obj));
  (Wrd64.Obj) = ((Wrd63.pObj) [0]);
  (* (--Rsp)) = (Wrd64.Obj);

DEFLABEL (label_37)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_11]));

DEFLABEL (label_38)
  (Wrd69.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_25]))));
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9_2]), 1);

DEFLABEL (label_33)
  (* (--Rsp)) = Rvl;
  goto label_37;

DEFLABEL (label_40)
  (Wrd62.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_24]))));
  (* (--Rsp)) = (Wrd62.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9_1]), 1);

DEFLABEL (label_32)
  (Wrd56.Obj) = Rvl;
  goto label_39;

DEFLABEL (label_42)
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_23]))));
  (* (--Rsp)) = (Wrd55.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9_1]), 1);

DEFLABEL (label_31)
  (Wrd49.Obj) = Rvl;
  goto label_41;

DEFLABEL (label_44)
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_22]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9_1]), 1);

DEFLABEL (label_30)
  (Wrd40.Obj) = Rvl;
  goto label_43;

DEFLABEL (label_46)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_9_21])), (Wrd33.pObj));

DEFLABEL (label_29)
  (Wrd32.Obj) = Rvl;
  goto label_45;

DEFLABEL (label_48)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_20]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9_1]), 1);

DEFLABEL (label_28)
  (Wrd24.Obj) = Rvl;
  goto label_47;

DEFLABEL (label_50)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_19]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9_1]), 1);

DEFLABEL (label_27)
  (Wrd17.Obj) = Rvl;
  goto label_49;

DEFLABEL (label_52)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_18]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9_1]), 1);

DEFLABEL (label_26)
  (Wrd8.Obj) = Rvl;
  goto label_51;

DEFLABEL (label_54)
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_16]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9_2]), 1);

DEFLABEL (label_25)
  (* (--Rsp)) = Rvl;
  goto label_53;

DEFLABEL (label_56)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_15]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9_1]), 1);

DEFLABEL (label_24)
  (Wrd25.Obj) = Rvl;
  goto label_55;

DEFLABEL (label_58)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_14]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9_1]), 1);

DEFLABEL (label_23)
  (Wrd16.Obj) = Rvl;
  goto label_57;

DEFLABEL (label_60)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_9_13])), (Wrd9.pObj));

DEFLABEL (label_22)
  (Wrd8.Obj) = Rvl;
  goto label_59;

DEFLABEL (label_62)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_10]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9_2]), 1);

DEFLABEL (label_21)
  (* (--Rsp)) = Rvl;
  goto label_61;

DEFLABEL (label_64)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_9]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9_1]), 1);

DEFLABEL (label_20)
  (Wrd16.Obj) = Rvl;
  goto label_63;

DEFLABEL (label_66)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_9_8])), (Wrd9.pObj));

DEFLABEL (label_19)
  (Wrd8.Obj) = Rvl;
  goto label_65;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_10_4 3
#define LABEL_10_5 5
#define LABEL_10_8 7
#define LABEL_10_9 9
#define LABEL_10_7 11
#define ENVIRONMENT_LABEL_10_3 23
#define DEBUGGING_LABEL_10_2 22
#define OBJECT_10_2 21
#define OBJECT_10_1 20
#define OBJECT_10_0 19
#define EXECUTE_CACHE_10_11 13
#define EXECUTE_CACHE_10_10 15
#define EXECUTE_CACHE_10_6 17
#define FREE_REFERENCES_LABEL_10_0 12
#define NUMBER_OF_LINKER_SECTIONS_10_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_10 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd23;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_10_4);
      goto lambda_4;

    case 1:
      current_block = (Rpc - LABEL_10_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_10_8);
      goto label_6;

    case 3:
      current_block = (Rpc - LABEL_10_9);
      goto label_7;

    case 4:
      current_block = (Rpc - LABEL_10_7);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_9)
DEFLABEL (lambda_4)
  INTERRUPT_CHECK (26, LABEL_10_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_10_0]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_10_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_10_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_13;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd8.Obj) = ((Wrd10.pObj) [1]);

DEFLABEL (label_12)
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd19.uLng) == 1))
    goto label_11;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_10)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_10_10]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_10_7);
  (Rsp [2]) = Rvl;
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_10_11]));

DEFLABEL (label_11)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_9]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_2]), 1);

DEFLABEL (label_7)
  (* (--Rsp)) = Rvl;
  goto label_10;

DEFLABEL (label_13)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_8]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_1]), 1);

DEFLABEL (label_6)
  (Wrd8.Obj) = Rvl;
  goto label_12;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_11_4 3
#define LABEL_11_5 5
#define LABEL_11_10 7
#define LABEL_11_11 9
#define LABEL_11_12 11
#define LABEL_11_7 13
#define TAG_11_8 5
#define LABEL_11_15 15
#define LABEL_11_16 17
#define LABEL_11_17 19
#define LABEL_11_18 21
#define LABEL_11_19 23
#define LABEL_11_20 25
#define LABEL_11_9 27
#define LABEL_11_14 29
#define LABEL_11_24 31
#define ENVIRONMENT_LABEL_11_3 54
#define DEBUGGING_LABEL_11_2 53
#define OBJECT_11_2 52
#define OBJECT_11_1 51
#define OBJECT_11_0 50
#define EXECUTE_CACHE_11_26 33
#define EXECUTE_CACHE_11_25 35
#define EXECUTE_CACHE_11_23 37
#define EXECUTE_CACHE_11_22 39
#define EXECUTE_CACHE_11_21 41
#define EXECUTE_CACHE_11_13 43
#define EXECUTE_CACHE_11_6 45
#define FREE_REFERENCE_11_1 48
#define FREE_REFERENCE_11_0 49
#define FREE_REFERENCES_LABEL_11_0 32
#define NUMBER_OF_LINKER_SECTIONS_11_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_11 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd71;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd67;
  machine_word Wrd64;
  machine_word Wrd58;
  machine_word Wrd59;
  machine_word Wrd60;
  machine_word Wrd57;
  machine_word Wrd43;
  machine_word Wrd47;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd42;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd31;
  machine_word Wrd36;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd25;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd39;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd24;
  machine_word Wrd26;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_11_4);
      goto lambda_14;

    case 1:
      current_block = (Rpc - LABEL_11_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_11_10);
      goto label_16;

    case 3:
      current_block = (Rpc - LABEL_11_11);
      goto label_17;

    case 4:
      current_block = (Rpc - LABEL_11_12);
      goto label_18;

    case 5:
      current_block = (Rpc - LABEL_11_7);
      goto lambda_27;

    case 6:
      current_block = (Rpc - LABEL_11_15);
      goto label_19;

    case 7:
      current_block = (Rpc - LABEL_11_16);
      goto label_20;

    case 8:
      current_block = (Rpc - LABEL_11_17);
      goto label_21;

    case 9:
      current_block = (Rpc - LABEL_11_18);
      goto label_22;

    case 10:
      current_block = (Rpc - LABEL_11_19);
      goto label_23;

    case 11:
      current_block = (Rpc - LABEL_11_20);
      goto label_24;

    case 12:
      current_block = (Rpc - LABEL_11_9);
      goto continuation_13;

    case 13:
      current_block = (Rpc - LABEL_11_14);
      goto continuation_4;

    case 14:
      current_block = (Rpc - LABEL_11_24);
      goto continuation_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_26)
DEFLABEL (lambda_14)
  INTERRUPT_CHECK (26, LABEL_11_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_11_0]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_11_5);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_11_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_11_7])));
  Rhp += 3;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd11 = Wrd6;
  (Wrd12.Obj) = (Rsp [2]);
  ((Wrd11.pObj) [2]) = (Wrd12.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  ((Wrd11.pObj) [3]) = (Wrd10.Obj);
  (Wrd8.Obj) = (Rsp [0]);
  ((Wrd11.pObj) [4]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_9]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd17.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11_0]));
  (Wrd20.Obj) = ((Wrd17.pObj) [0]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd21.uLng) == 50)
    goto label_33;
  Wrd16 = Wrd20;

DEFLABEL (label_32)
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd22.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd27.Obj) = (Rsp [5]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd28.uLng) == 1))
    goto label_31;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd24.Obj) = ((Wrd26.pObj) [1]);

DEFLABEL (label_30)
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd35.uLng) == 1))
    goto label_29;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (* (--Rsp)) = (Wrd34.Obj);

DEFLABEL (label_28)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_13]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_11_9);
  (Rsp [2]) = Rvl;
  (Wrd6.Obj) = (* (Rsp++));
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_29)
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_12]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_11_2]), 1);

DEFLABEL (label_18)
  (* (--Rsp)) = Rvl;
  goto label_28;

DEFLABEL (label_31)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_11]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_11_1]), 1);

DEFLABEL (label_17)
  (Wrd24.Obj) = Rvl;
  goto label_30;

DEFLABEL (label_33)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_11_10])), (Wrd17.pObj));

DEFLABEL (label_16)
  (Wrd16.Obj) = Rvl;
  goto label_32;

DEFLABEL (lambda_27)
  CLOSURE_HEADER (LABEL_11_7);

DEFLABEL (lambda_10)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [4]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_47;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd8.Obj) = ((Wrd12.pObj) [1]);

DEFLABEL (label_46)
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd25.uLng) == 1))
    goto label_45;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd23.Obj) = ((Wrd24.pObj) [1]);

DEFLABEL (label_44)
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd30.uLng) == 1)
    goto label_35;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_22]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_11_14);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [3]);
  if (! ((Wrd5.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_34;
  (Rsp [3]) = Rvl;
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_23]));

DEFLABEL (label_34)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_24]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_25]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_11_24);
  (Wrd5.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [0]);
  (Rsp [3]) = (Wrd6.Obj);
  (Rsp [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_26]));

DEFLABEL (label_35)
  (Wrd32.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11_1]));
  (Wrd35.Obj) = ((Wrd32.pObj) [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if ((Wrd36.uLng) == 50)
    goto label_43;
  Wrd31 = Wrd35;

DEFLABEL (label_42)
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd37.Obj) = (Rsp [2]);
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [2]);
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd42.Obj) = ((Wrd38.pObj) [3]);
  (* (--Rsp)) = (Wrd42.Obj);
  (Wrd50.Obj) = ((Wrd38.pObj) [4]);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd51.uLng) == 1))
    goto label_41;
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd43.Obj) = ((Wrd47.pObj) [1]);

DEFLABEL (label_40)
  (Wrd60.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd60.uLng) == 1))
    goto label_39;
  (Wrd59.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  (Wrd58.Obj) = ((Wrd59.pObj) [1]);

DEFLABEL (label_38)
  (Wrd67.uLng) = (OBJECT_TYPE (Wrd58.Obj));
  if (! ((Wrd67.uLng) == 1))
    goto label_37;
  (Wrd65.pObj) = (OBJECT_ADDRESS (Wrd58.Obj));
  (Wrd66.Obj) = ((Wrd65.pObj) [0]);
  (* (--Rsp)) = (Wrd66.Obj);

DEFLABEL (label_36)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_21]));

DEFLABEL (label_37)
  (Wrd71.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_20]))));
  (* (--Rsp)) = (Wrd71.Obj);
  (* (--Rsp)) = (Wrd58.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_11_2]), 1);

DEFLABEL (label_24)
  (* (--Rsp)) = Rvl;
  goto label_36;

DEFLABEL (label_39)
  (Wrd64.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_19]))));
  (* (--Rsp)) = (Wrd64.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_11_1]), 1);

DEFLABEL (label_23)
  (Wrd58.Obj) = Rvl;
  goto label_38;

DEFLABEL (label_41)
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_18]))));
  (* (--Rsp)) = (Wrd57.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_11_1]), 1);

DEFLABEL (label_22)
  (Wrd43.Obj) = Rvl;
  goto label_40;

DEFLABEL (label_43)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_11_17])), (Wrd32.pObj));

DEFLABEL (label_21)
  (Wrd31.Obj) = Rvl;
  goto label_42;

DEFLABEL (label_45)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_16]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_11_1]), 1);

DEFLABEL (label_20)
  (Wrd23.Obj) = Rvl;
  goto label_44;

DEFLABEL (label_47)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_15]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_11_1]), 1);

DEFLABEL (label_19)
  (Wrd8.Obj) = Rvl;
  goto label_46;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_12_4 3
#define LABEL_12_5 5
#define ENVIRONMENT_LABEL_12_3 12
#define DEBUGGING_LABEL_12_2 11
#define EXECUTE_CACHE_12_7 7
#define EXECUTE_CACHE_12_6 9
#define FREE_REFERENCES_LABEL_12_0 6
#define NUMBER_OF_LINKER_SECTIONS_12_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_12 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_12_4);
      goto classify_sublocation_1;

    case 1:
      current_block = (Rpc - LABEL_12_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (classify_sublocation_4)
DEFLABEL (classify_sublocation_1)
  INTERRUPT_CHECK (26, LABEL_12_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_12_5);
  (Rsp [3]) = Rvl;
  (Wrd6.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd7.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_13_4 3
#define LABEL_13_5 5
#define LABEL_13_7 7
#define LABEL_13_11 9
#define LABEL_13_9 11
#define LABEL_13_13 13
#define TAG_13_14 5
#define LABEL_13_16 15
#define LABEL_13_18 17
#define LABEL_13_20 19
#define TAG_13_21 8
#define ENVIRONMENT_LABEL_13_3 37
#define DEBUGGING_LABEL_13_2 36
#define OBJECT_13_0 35
#define EXECUTE_CACHE_13_19 21
#define EXECUTE_CACHE_13_17 23
#define EXECUTE_CACHE_13_15 25
#define EXECUTE_CACHE_13_12 27
#define EXECUTE_CACHE_13_10 29
#define EXECUTE_CACHE_13_8 31
#define EXECUTE_CACHE_13_6 33
#define FREE_REFERENCES_LABEL_13_0 20
#define NUMBER_OF_LINKER_SECTIONS_13_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_13 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_13_4);
      goto classify_location_11;

    case 1:
      current_block = (Rpc - LABEL_13_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_13_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_13_11);
      goto continuation_7;

    case 4:
      current_block = (Rpc - LABEL_13_9);
      goto continuation_2;

    case 5:
      current_block = (Rpc - LABEL_13_13);
      goto lambda_15;

    case 6:
      current_block = (Rpc - LABEL_13_16);
      goto continuation_3;

    case 7:
      current_block = (Rpc - LABEL_13_18);
      goto continuation_4;

    case 8:
      current_block = (Rpc - LABEL_13_20);
      goto lambda_16;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (classify_location_14)
DEFLABEL (classify_location_11)
  INTERRUPT_CHECK (26, LABEL_13_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_13_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_13_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_17;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_11]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_12]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_13_11);
  (Rsp [3]) = Rvl;
  Rsp = (& (Rsp [3]));
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_13_14);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_13_13])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  Wrd9 = Wrd8;
  (Wrd10.Obj) = (Rsp [0]);
  ((Wrd9.pObj) [2]) = (Wrd10.Obj);
  Rvl = (Wrd7.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_17)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_9]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_13_9);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_18;
  (Wrd11.Obj) = (current_block [OBJECT_13_0]);
  (Rsp [2]) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (Wrd13.Obj) = (Rsp [3]);
  (Rsp [1]) = (Wrd13.Obj);
  (Rsp [3]) = (Wrd12.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_15]));

DEFLABEL (label_18)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_16]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_17]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_13_16);
  (Rsp [2]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_18]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_19]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_13_18);
  (Rsp [3]) = Rvl;
  Rsp = (& (Rsp [2]));
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_13_21);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_13_20])));
  Rhp += 2;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  Wrd11 = Wrd8;
  (Wrd12.Obj) = (Rsp [1]);
  ((Wrd11.pObj) [2]) = (Wrd12.Obj);
  (Wrd10.Obj) = (Rsp [0]);
  ((Wrd11.pObj) [3]) = (Wrd10.Obj);
  Rvl = (Wrd7.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (lambda_15)
  CLOSURE_HEADER (LABEL_13_13);

DEFLABEL (lambda_8)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [1]) = (Wrd6.Obj);
  (Rsp [2]) = ((SCHEME_OBJECT) 0);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (lambda_16)
  CLOSURE_HEADER (LABEL_13_20);

DEFLABEL (lambda_5)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd9.Obj) = ((Wrd8.pObj) [3]);
  (Rsp [1]) = (Wrd9.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_14_4 3
#define LABEL_14_5 5
#define LABEL_14_8 7
#define LABEL_14_9 9
#define LABEL_14_10 11
#define LABEL_14_7 13
#define ENVIRONMENT_LABEL_14_3 27
#define DEBUGGING_LABEL_14_2 26
#define OBJECT_14_2 25
#define OBJECT_14_1 24
#define OBJECT_14_0 23
#define EXECUTE_CACHE_14_12 15
#define EXECUTE_CACHE_14_11 17
#define EXECUTE_CACHE_14_6 19
#define FREE_REFERENCE_14_0 22
#define FREE_REFERENCES_LABEL_14_0 14
#define NUMBER_OF_LINKER_SECTIONS_14_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_14 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd31;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd27;
  machine_word Wrd24;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_14_4);
      goto lambda_4;

    case 1:
      current_block = (Rpc - LABEL_14_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_14_8);
      goto label_6;

    case 3:
      current_block = (Rpc - LABEL_14_9);
      goto label_7;

    case 4:
      current_block = (Rpc - LABEL_14_10);
      goto label_8;

    case 5:
      current_block = (Rpc - LABEL_14_7);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_10)
DEFLABEL (lambda_4)
  INTERRUPT_CHECK (26, LABEL_14_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_14_0]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_14_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_16;
  Wrd8 = Wrd12;

DEFLABEL (label_15)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd19.Obj) = (Rsp [4]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_14;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [1]);

DEFLABEL (label_13)
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd27.uLng) == 1))
    goto label_12;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_11)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_14_7);
  (Rsp [2]) = Rvl;
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_12]));

DEFLABEL (label_12)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_10]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_2]), 1);

DEFLABEL (label_8)
  (* (--Rsp)) = Rvl;
  goto label_11;

DEFLABEL (label_14)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_9]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_1]), 1);

DEFLABEL (label_7)
  (Wrd16.Obj) = Rvl;
  goto label_13;

DEFLABEL (label_16)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_14_8])), (Wrd9.pObj));

DEFLABEL (label_6)
  (Wrd8.Obj) = Rvl;
  goto label_15;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_15_4 3
#define LABEL_15_5 5
#define LABEL_15_7 7
#define ENVIRONMENT_LABEL_15_3 17
#define DEBUGGING_LABEL_15_2 16
#define OBJECT_15_0 15
#define EXECUTE_CACHE_15_8 9
#define EXECUTE_CACHE_15_6 11
#define FREE_REFERENCE_15_0 14
#define FREE_REFERENCES_LABEL_15_0 8
#define NUMBER_OF_LINKER_SECTIONS_15_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_15 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_15_4);
      goto lambda_1;

    case 1:
      current_block = (Rpc - LABEL_15_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_15_7);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_5)
DEFLABEL (lambda_1)
  INTERRUPT_CHECK (26, LABEL_15_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_15_0]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_15_5);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [3]);
  (Rsp [2]) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (Rsp [3]) = (Wrd8.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15_0]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_7;
  Wrd10 = Wrd14;

DEFLABEL (label_6)
  (Rsp [4]) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_8]));

DEFLABEL (label_7)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_15_7])), (Wrd11.pObj));

DEFLABEL (label_3)
  (Wrd10.Obj) = Rvl;
  goto label_6;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_16_4 3
#define LABEL_16_7 5
#define LABEL_16_5 7
#define LABEL_16_11 9
#define LABEL_16_12 11
#define LABEL_16_13 13
#define LABEL_16_14 15
#define LABEL_16_10 17
#define LABEL_16_16 19
#define LABEL_16_17 21
#define LABEL_16_8 23
#define LABEL_16_18 25
#define LABEL_16_19 27
#define ENVIRONMENT_LABEL_16_3 42
#define DEBUGGING_LABEL_16_2 41
#define OBJECT_16_1 40
#define OBJECT_16_0 39
#define EXECUTE_CACHE_16_20 29
#define EXECUTE_CACHE_16_15 31
#define EXECUTE_CACHE_16_9 33
#define EXECUTE_CACHE_16_6 35
#define FREE_REFERENCE_16_0 38
#define FREE_REFERENCES_LABEL_16_0 28
#define NUMBER_OF_LINKER_SECTIONS_16_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_16 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd40;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd27;
  machine_word Wrd28;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd43;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_16_4);
      goto classify_define_11;

    case 1:
      current_block = (Rpc - LABEL_16_7);
      goto continuation_4;

    case 2:
      current_block = (Rpc - LABEL_16_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_16_11);
      goto label_13;

    case 4:
      current_block = (Rpc - LABEL_16_12);
      goto label_14;

    case 5:
      current_block = (Rpc - LABEL_16_13);
      goto label_15;

    case 6:
      current_block = (Rpc - LABEL_16_14);
      goto label_16;

    case 7:
      current_block = (Rpc - LABEL_16_10);
      goto continuation_10;

    case 8:
      current_block = (Rpc - LABEL_16_16);
      goto label_17;

    case 9:
      current_block = (Rpc - LABEL_16_17);
      goto label_18;

    case 10:
      current_block = (Rpc - LABEL_16_8);
      goto continuation_3;

    case 11:
      current_block = (Rpc - LABEL_16_18);
      goto label_19;

    case 12:
      current_block = (Rpc - LABEL_16_19);
      goto label_20;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (classify_define_22)
DEFLABEL (classify_define_11)
  INTERRUPT_CHECK (26, LABEL_16_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_16_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_35;
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_7]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_8]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd47.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd47.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_9]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_16_8);
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (Rsp [2]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_39;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_38)
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_37;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_36)
  (Wrd21.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_20]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_16_7);

DEFLABEL (label_35)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_10]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_16_0]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_34;
  Wrd10 = Wrd14;

DEFLABEL (label_33)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd16.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd21.Obj) = (Rsp [4]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_32;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd18.Obj) = ((Wrd20.pObj) [1]);

DEFLABEL (label_31)
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd29.uLng) == 1))
    goto label_30;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd27.Obj) = ((Wrd28.pObj) [1]);

DEFLABEL (label_29)
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd36.uLng) == 1))
    goto label_28;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [0]);
  (* (--Rsp)) = (Wrd35.Obj);

DEFLABEL (label_27)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_15]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_16_10);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [3]);
  (Rsp [2]) = (Wrd5.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd10.uLng) == 1))
    goto label_26;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [1]);

DEFLABEL (label_25)
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if (! ((Wrd17.uLng) == 1))
    goto label_24;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd15.Obj) = ((Wrd16.pObj) [0]);

DEFLABEL (label_23)
  (Rsp [3]) = (Wrd15.Obj);
  (Wrd22.Obj) = (Rsp [5]);
  (Rsp [1]) = (Wrd22.Obj);
  (Wrd23.Obj) = (Rsp [4]);
  (Rsp [5]) = (Wrd23.Obj);
  (Wrd24.Obj) = (* (Rsp++));
  (Rsp [3]) = (Wrd24.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 5);
  }

DEFLABEL (label_24)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_17]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_16_1]), 1);

DEFLABEL (label_18)
  (Wrd15.Obj) = Rvl;
  goto label_23;

DEFLABEL (label_26)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_16]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_16_0]), 1);

DEFLABEL (label_17)
  (Wrd6.Obj) = Rvl;
  goto label_25;

DEFLABEL (label_28)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_14]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_16_1]), 1);

DEFLABEL (label_16)
  (* (--Rsp)) = Rvl;
  goto label_27;

DEFLABEL (label_30)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_13]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_16_0]), 1);

DEFLABEL (label_15)
  (Wrd27.Obj) = Rvl;
  goto label_29;

DEFLABEL (label_32)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_12]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_16_0]), 1);

DEFLABEL (label_14)
  (Wrd18.Obj) = Rvl;
  goto label_31;

DEFLABEL (label_34)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_16_11])), (Wrd11.pObj));

DEFLABEL (label_13)
  (Wrd10.Obj) = Rvl;
  goto label_33;

DEFLABEL (label_37)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_19]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_16_1]), 1);

DEFLABEL (label_20)
  (* (--Rsp)) = Rvl;
  goto label_36;

DEFLABEL (label_39)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_18]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_16_0]), 1);

DEFLABEL (label_19)
  (Wrd5.Obj) = Rvl;
  goto label_38;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_17_4 3
#define LABEL_17_7 5
#define LABEL_17_5 7
#define LABEL_17_10 9
#define LABEL_17_11 11
#define LABEL_17_8 13
#define LABEL_17_18 15
#define LABEL_17_13 17
#define LABEL_17_16 19
#define LABEL_17_19 21
#define ENVIRONMENT_LABEL_17_3 47
#define DEBUGGING_LABEL_17_2 46
#define OBJECT_17_0 45
#define EXECUTE_CACHE_17_24 23
#define EXECUTE_CACHE_17_23 25
#define EXECUTE_CACHE_17_22 27
#define EXECUTE_CACHE_17_21 29
#define EXECUTE_CACHE_17_20 31
#define EXECUTE_CACHE_17_17 33
#define EXECUTE_CACHE_17_15 35
#define EXECUTE_CACHE_17_14 37
#define EXECUTE_CACHE_17_12 39
#define EXECUTE_CACHE_17_9 41
#define EXECUTE_CACHE_17_6 43
#define FREE_REFERENCES_LABEL_17_0 22
#define NUMBER_OF_LINKER_SECTIONS_17_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_17 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd14;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_17_4);
      goto syntactic_binding_theory_10;

    case 1:
      current_block = (Rpc - LABEL_17_7);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_17_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_17_10);
      goto continuation_6;

    case 4:
      current_block = (Rpc - LABEL_17_11);
      goto continuation_5;

    case 5:
      current_block = (Rpc - LABEL_17_8);
      goto continuation_1;

    case 6:
      current_block = (Rpc - LABEL_17_18);
      goto continuation_8;

    case 7:
      current_block = (Rpc - LABEL_17_13);
      goto continuation_7;

    case 8:
      current_block = (Rpc - LABEL_17_16);
      goto continuation_3;

    case 9:
      current_block = (Rpc - LABEL_17_19);
      goto continuation_9;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (syntactic_binding_theory_13)
DEFLABEL (syntactic_binding_theory_10)
  INTERRUPT_CHECK (26, LABEL_17_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_17_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_17;

DEFLABEL (label_16)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_10]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_11]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd14.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_12]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_17_11);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_15]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_17_10);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_14]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_17_13);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_15;

DEFLABEL (label_14)
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_21]));

DEFLABEL (label_15)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_18]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_22]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_17_18);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_14;
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (Rsp [4]) = (Wrd15.Obj);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_19]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd19.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_20]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_17_19);
  (Rsp [3]) = Rvl;
  (Wrd6.Obj) = (* (Rsp++));
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_24]));

DEFLABEL (label_17)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_7]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_8]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_17_8);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_17_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_16]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_17]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_17_16);
  (Rsp [2]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_23]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_17_7);
  goto label_16;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_18_4 3
#define LABEL_18_7 5
#define LABEL_18_5 7
#define LABEL_18_10 9
#define LABEL_18_8 11
#define LABEL_18_12 13
#define ENVIRONMENT_LABEL_18_3 29
#define DEBUGGING_LABEL_18_2 28
#define OBJECT_18_0 27
#define EXECUTE_CACHE_18_15 15
#define EXECUTE_CACHE_18_14 17
#define EXECUTE_CACHE_18_13 19
#define EXECUTE_CACHE_18_11 21
#define EXECUTE_CACHE_18_9 23
#define EXECUTE_CACHE_18_6 25
#define FREE_REFERENCES_LABEL_18_0 14
#define NUMBER_OF_LINKER_SECTIONS_18_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_18 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_18_4);
      goto variable_binding_theory_6;

    case 1:
      current_block = (Rpc - LABEL_18_7);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_18_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_18_10);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_18_8);
      goto continuation_5;

    case 5:
      current_block = (Rpc - LABEL_18_12);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (variable_binding_theory_9)
DEFLABEL (variable_binding_theory_6)
  INTERRUPT_CHECK (26, LABEL_18_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_18_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_10;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_10]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_11]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_18_10);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_18_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_12]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_13]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_18_12);
  (Rsp [2]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_15]));

DEFLABEL (label_10)
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (Rsp [4]) = (Wrd15.Obj);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_8]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_9]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_18_8);
  (Rsp [3]) = Rvl;
  (Wrd6.Obj) = (* (Rsp++));
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_14]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_18_7);
  goto label_10;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_19_4 3
#define LABEL_19_8 5
#define LABEL_19_5 7
#define TAG_19_6 2
#define LABEL_19_7 9
#define LABEL_19_13 11
#define LABEL_19_11 13
#define TAG_19_12 5
#define LABEL_19_16 15
#define LABEL_19_17 17
#define LABEL_19_14 19
#define TAG_19_15 8
#define LABEL_19_20 21
#define LABEL_19_21 23
#define LABEL_19_23 25
#define LABEL_19_24 27
#define LABEL_19_18 29
#define LABEL_19_22 31
#define LABEL_19_29 33
#define LABEL_19_27 35
#define TAG_19_28 16
#define LABEL_19_30 37
#define LABEL_19_31 39
#define LABEL_19_25 41
#define TAG_19_26 19
#define LABEL_19_32 43
#define LABEL_19_37 45
#define LABEL_19_34 47
#define LABEL_19_35 49
#define TAG_19_36 23
#define LABEL_19_40 51
#define LABEL_19_41 53
#define LABEL_19_42 55
#define LABEL_19_33 57
#define LABEL_19_44 59
#define LABEL_19_39 61
#define LABEL_19_45 63
#define LABEL_19_46 65
#define LABEL_19_49 67
#define LABEL_19_43 69
#define LABEL_19_51 71
#define LABEL_19_52 73
#define LABEL_19_53 75
#define LABEL_19_56 77
#define LABEL_19_50 79
#define LABEL_19_57 81
#define LABEL_19_47 83
#define TAG_19_48 40
#define LABEL_19_59 85
#define LABEL_19_58 87
#define LABEL_19_60 89
#define TAG_19_61 43
#define LABEL_19_62 91
#define LABEL_19_54 93
#define TAG_19_55 45
#define LABEL_19_63 95
#define LABEL_19_64 97
#define TAG_19_65 47
#define LABEL_19_66 99
#define ENVIRONMENT_LABEL_19_3 123
#define DEBUGGING_LABEL_19_2 122
#define OBJECT_19_10 121
#define OBJECT_19_9 120
#define OBJECT_19_8 119
#define OBJECT_19_7 118
#define OBJECT_19_6 117
#define OBJECT_19_5 116
#define OBJECT_19_4 115
#define OBJECT_19_3 114
#define OBJECT_19_2 113
#define OBJECT_19_1 112
#define OBJECT_19_0 111
#define EXECUTE_CACHE_19_38 101
#define EXECUTE_CACHE_19_19 103
#define EXECUTE_CACHE_19_10 105
#define EXECUTE_CACHE_19_9 107
#define FREE_REFERENCE_19_0 110
#define FREE_REFERENCES_LABEL_19_0 100
#define NUMBER_OF_LINKER_SECTIONS_19_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_19 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd35;
  machine_word Wrd52;
  machine_word Wrd54;
  machine_word Wrd25;
  machine_word Wrd51;
  machine_word Wrd44;
  machine_word Wrd42;
  machine_word Wrd34;
  machine_word Wrd36;
  machine_word Wrd37;
  machine_word Wrd39;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd38;
  machine_word Wrd43;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd18;
  machine_word Wrd63;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd67;
  machine_word Wrd61;
  machine_word Wrd53;
  machine_word Wrd55;
  machine_word Wrd57;
  machine_word Wrd56;
  machine_word Wrd33;
  machine_word Wrd19;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd15;
  machine_word Wrd10;
  machine_word Wrd17;
  machine_word Wrd9;
  machine_word Wrd12;
  machine_word Wrd24;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd30;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd16;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd5;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_19_4);
      goto lambda_61;

    case 1:
      current_block = (Rpc - LABEL_19_8);
      goto label_63;

    case 2:
      current_block = (Rpc - LABEL_19_5);
      goto lambda_0;

    case 3:
      current_block = (Rpc - LABEL_19_7);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_19_13);
      goto label_64;

    case 5:
      current_block = (Rpc - LABEL_19_11);
      goto loop_58;

    case 6:
      current_block = (Rpc - LABEL_19_16);
      goto label_65;

    case 7:
      current_block = (Rpc - LABEL_19_17);
      goto label_66;

    case 8:
      current_block = (Rpc - LABEL_19_14);
      goto lambda_88;

    case 9:
      current_block = (Rpc - LABEL_19_20);
      goto label_67;

    case 10:
      current_block = (Rpc - LABEL_19_21);
      goto label_68;

    case 11:
      current_block = (Rpc - LABEL_19_23);
      goto continuation_13;

    case 12:
      current_block = (Rpc - LABEL_19_24);
      goto label_69;

    case 13:
      current_block = (Rpc - LABEL_19_18);
      goto continuation_11;

    case 14:
      current_block = (Rpc - LABEL_19_22);
      goto continuation_7;

    case 15:
      current_block = (Rpc - LABEL_19_29);
      goto continuation_12;

    case 16:
      current_block = (Rpc - LABEL_19_27);
      goto lambda_90;

    case 17:
      current_block = (Rpc - LABEL_19_30);
      goto label_70;

    case 18:
      current_block = (Rpc - LABEL_19_31);
      goto label_71;

    case 19:
      current_block = (Rpc - LABEL_19_25);
      goto req_loop_53;

    case 20:
      current_block = (Rpc - LABEL_19_32);
      goto continuation_19;

    case 21:
      current_block = (Rpc - LABEL_19_37);
      goto label_72;

    case 22:
      current_block = (Rpc - LABEL_19_34);
      goto continuation_52;

    case 23:
      current_block = (Rpc - LABEL_19_35);
      goto lambda_91;

    case 24:
      current_block = (Rpc - LABEL_19_40);
      goto continuation_23;

    case 25:
      current_block = (Rpc - LABEL_19_41);
      goto label_74;

    case 26:
      current_block = (Rpc - LABEL_19_42);
      goto label_75;

    case 27:
      current_block = (Rpc - LABEL_19_33);
      goto continuation_20;

    case 28:
      current_block = (Rpc - LABEL_19_44);
      goto label_73;

    case 29:
      current_block = (Rpc - LABEL_19_39);
      goto continuation_50;

    case 30:
      current_block = (Rpc - LABEL_19_45);
      goto continuation_21;

    case 31:
      current_block = (Rpc - LABEL_19_46);
      goto continuation_27;

    case 32:
      current_block = (Rpc - LABEL_19_49);
      goto label_77;

    case 33:
      current_block = (Rpc - LABEL_19_43);
      goto continuation_24;

    case 34:
      current_block = (Rpc - LABEL_19_51);
      goto label_76;

    case 35:
      current_block = (Rpc - LABEL_19_52);
      goto continuation_25;

    case 36:
      current_block = (Rpc - LABEL_19_53);
      goto continuation_31;

    case 37:
      current_block = (Rpc - LABEL_19_56);
      goto label_80;

    case 38:
      current_block = (Rpc - LABEL_19_50);
      goto continuation_28;

    case 39:
      current_block = (Rpc - LABEL_19_57);
      goto label_78;

    case 40:
      current_block = (Rpc - LABEL_19_47);
      goto and_loop_46;

    case 41:
      current_block = (Rpc - LABEL_19_59);
      goto label_79;

    case 42:
      current_block = (Rpc - LABEL_19_58);
      goto continuation_29;

    case 43:
      current_block = (Rpc - LABEL_19_60);
      goto lambda_94;

    case 44:
      current_block = (Rpc - LABEL_19_62);
      goto label_81;

    case 45:
      current_block = (Rpc - LABEL_19_54);
      goto or_loop_38;

    case 46:
      current_block = (Rpc - LABEL_19_63);
      goto label_82;

    case 47:
      current_block = (Rpc - LABEL_19_64);
      goto lambda_95;

    case 48:
      current_block = (Rpc - LABEL_19_66);
      goto label_83;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_85)
DEFLABEL (lambda_61)
  INTERRUPT_CHECK (26, LABEL_19_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_19_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_19_5])));
  Rhp += 1;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd7 = Wrd6;
  (Wrd8.Obj) = (Rsp [0]);
  ((Wrd7.pObj) [2]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_7]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_100;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [1]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_99)
  (Wrd21.Obj) = (current_block [OBJECT_19_1]);
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_19_7);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_96;
  (Wrd30.Obj) = (Rsp [0]);
  (Rsp [3]) = (Wrd30.Obj);
  Rsp = (& (Rsp [3]));
  goto lambda_0;

DEFLABEL (label_96)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd28.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_19_12);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_19_11])));
  Rhp += 3;
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd28.pObj)));
  (* (--Rsp)) = (Wrd29.Obj);
  Wrd26 = Wrd28;
  (Wrd27.Obj) = (Rsp [4]);
  ((Wrd26.pObj) [2]) = (Wrd27.Obj);
  (Wrd24.Obj) = (Rsp [3]);
  ((Wrd26.pObj) [3]) = (Wrd24.Obj);
  (Wrd21.Obj) = (Rsp [1]);
  ((Wrd26.pObj) [4]) = (Wrd21.Obj);
  Rsp = (& (Rsp [1]));
  (Rsp [2]) = (Wrd29.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_98;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [1]);

DEFLABEL (label_97)
  (Rsp [3]) = (Wrd9.Obj);
  Rsp = (& (Rsp [2]));
  goto loop_58;

DEFLABEL (label_98)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_13]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_0]), 1);

DEFLABEL (label_64)
  (Wrd9.Obj) = Rvl;
  goto label_97;

DEFLABEL (label_100)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_8]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_0]), 1);

DEFLABEL (label_63)
  (* (--Rsp)) = Rvl;
  goto label_99;

DEFLABEL (lambda_86)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_19_5);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_10]));

DEFLABEL (loop_87)
DEFLABEL (loop_58)
  INTERRUPT_CHECK (26, LABEL_19_11);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_19_15);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_19_14])));
  Rhp += 2;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd9 = Wrd6;
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [3]);
  ((Wrd9.pObj) [2]) = (Wrd12.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  ((Wrd9.pObj) [3]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd17.uLng) == 1))
    goto label_109;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd13.Obj) = ((Wrd15.pObj) [0]);

DEFLABEL (label_108)
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd24.uLng) == 1))
    goto label_107;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [0]);
  (* (--Rsp)) = (Wrd23.Obj);

DEFLABEL (label_106)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_18]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd32.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd32.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_19]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_19_18);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_102;

DEFLABEL (label_101)
  (Wrd18.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd19.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd49.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_19_26);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_19_25])));
  Rhp += 3;
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd49.pObj)));
  (* (--Rsp)) = (Wrd50.Obj);
  Wrd45 = Wrd49;
  (Wrd46.Obj) = (Rsp [4]);
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd48.Obj) = ((Wrd47.pObj) [2]);
  ((Wrd45.pObj) [2]) = (Wrd48.Obj);
  (Wrd43.Obj) = ((Wrd47.pObj) [3]);
  ((Wrd45.pObj) [3]) = (Wrd43.Obj);
  (Wrd38.Obj) = ((Wrd47.pObj) [4]);
  ((Wrd45.pObj) [4]) = (Wrd38.Obj);
  Rsp = (& (Rsp [1]));
  (Rsp [1]) = (Wrd50.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd24.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_19_28);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_19_27])));
  Rhp += 3;
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd24.pObj)));
  Wrd29 = Wrd24;
  (Wrd30.Obj) = (Rsp [3]);
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [4]);
  ((Wrd29.pObj) [2]) = (Wrd32.Obj);
  ((Wrd29.pObj) [3]) = (Wrd30.Obj);
  (Wrd26.Obj) = (Rsp [4]);
  ((Wrd29.pObj) [4]) = (Wrd26.Obj);
  (Rsp [4]) = (Wrd23.Obj);
  (Wrd33.Obj) = (* (Rsp++));
  (Rsp [2]) = (Wrd33.Obj);
  goto req_loop_53;

DEFLABEL (label_102)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_23]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_29]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_19_5]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [6]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [3]);
  (* (--Rsp)) = (Wrd17.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_19_29);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [5]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_19_23);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_101;
  (Wrd56.Obj) = (Rsp [3]);
  (Wrd57.uLng) = (OBJECT_TYPE (Wrd56.Obj));
  if (! ((Wrd57.uLng) == 1))
    goto label_105;
  (Wrd55.pObj) = (OBJECT_ADDRESS (Wrd56.Obj));
  (Wrd53.Obj) = ((Wrd55.pObj) [1]);

DEFLABEL (label_104)
  if ((Wrd53.Obj) == (current_block [OBJECT_19_4]))
    goto label_103;
  (Wrd64.Obj) = (Rsp [2]);
  (Wrd65.pObj) = (OBJECT_ADDRESS (Wrd64.Obj));
  (Wrd63.Obj) = ((Wrd65.pObj) [4]);
  (Rsp [3]) = (Wrd63.Obj);
  Rsp = (& (Rsp [3]));
  goto lambda_0;

DEFLABEL (label_103)
  (Wrd67.Obj) = (Rsp [1]);
  (Rsp [3]) = (Wrd67.Obj);
  Rsp = (& (Rsp [3]));
  goto lambda_10;

DEFLABEL (label_105)
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_24]))));
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_0]), 1);

DEFLABEL (label_69)
  (Wrd53.Obj) = Rvl;
  goto label_104;

DEFLABEL (label_107)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_17]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_2]), 1);

DEFLABEL (label_66)
  (* (--Rsp)) = Rvl;
  goto label_106;

DEFLABEL (label_109)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_16]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_2]), 1);

DEFLABEL (label_65)
  (Wrd13.Obj) = Rvl;
  goto label_108;

DEFLABEL (lambda_88)
  CLOSURE_HEADER (LABEL_19_14);

DEFLABEL (lambda_10)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [3]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_113;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd5.Obj) = ((Wrd9.pObj) [0]);

DEFLABEL (label_112)
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_111;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [1]);
  (* (--Rsp)) = (Wrd21.Obj);

DEFLABEL (label_110)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_22]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_19_3]);
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd31.Obj) = (Rsp [3]);
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [2]);
  (* (--Rsp)) = (Wrd33.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_19_22);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_111)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_21]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_0]), 1);

DEFLABEL (label_68)
  (* (--Rsp)) = Rvl;
  goto label_110;

DEFLABEL (label_113)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_20]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_2]), 1);

DEFLABEL (label_67)
  (Wrd5.Obj) = Rvl;
  goto label_112;

DEFLABEL (lambda_90)
  CLOSURE_HEADER (LABEL_19_27);

DEFLABEL (lambda_17)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [4]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_118;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd5.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_117)
  if (! ((Wrd5.Obj) == (current_block [OBJECT_19_4])))
    goto label_114;
  (Wrd40.Obj) = (Rsp [0]);
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  (Wrd39.Obj) = ((Wrd41.pObj) [2]);
  (Rsp [0]) = (Wrd39.Obj);
  goto lambda_0;

DEFLABEL (label_114)
  (Wrd21.Obj) = (Rsp [0]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [3]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd31.Obj) = ((Wrd22.pObj) [4]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if (! ((Wrd32.uLng) == 1))
    goto label_116;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd24.Obj) = ((Wrd28.pObj) [1]);

DEFLABEL (label_115)
  (Rsp [1]) = (Wrd24.Obj);
  goto loop_58;

DEFLABEL (label_116)
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_31]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd31.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_0]), 1);

DEFLABEL (label_71)
  (Wrd24.Obj) = Rvl;
  goto label_115;

DEFLABEL (label_118)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_30]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_0]), 1);

DEFLABEL (label_70)
  (Wrd5.Obj) = Rvl;
  goto label_117;

DEFLABEL (req_loop_89)
DEFLABEL (req_loop_53)
  INTERRUPT_CHECK (26, LABEL_19_25);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_32]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_19]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_19_32);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_139;
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_33]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd31.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd32.Obj) = (current_block [OBJECT_19_6]);
  (* (--Rsp)) = (Wrd32.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_9]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_19_33);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_132;

DEFLABEL (label_131)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_43]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd29.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_19_7]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_9]));

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_19_43);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_126;

DEFLABEL (label_125)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_50]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd29.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_19_7]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_9]));

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_19_50);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_120;

DEFLABEL (label_119)
  (Wrd27.Obj) = (Rsp [0]);
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd26.Obj) = ((Wrd28.pObj) [4]);
  (Rsp [3]) = (Wrd26.Obj);
  Rsp = (& (Rsp [3]));
  goto lambda_0;

DEFLABEL (label_120)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_53]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_124;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_123)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_58]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_19_10]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (Rsp [4]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [3]);
  (* (--Rsp)) = (Wrd25.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_19_58);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [3]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_19_53);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_119;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd53.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_19_55);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_19_54])));
  Rhp += 3;
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd53.pObj)));
  (* (--Rsp)) = (Wrd54.Obj);
  Wrd51 = Wrd53;
  (Wrd52.Obj) = (Rsp [1]);
  ((Wrd51.pObj) [2]) = (Wrd52.Obj);
  (Wrd49.Obj) = (Rsp [4]);
  ((Wrd51.pObj) [3]) = (Wrd49.Obj);
  (Wrd46.Obj) = (Rsp [3]);
  ((Wrd51.pObj) [4]) = (Wrd46.Obj);
  Rsp = (& (Rsp [1]));
  (Rsp [2]) = (Wrd54.Obj);
  (Wrd37.Obj) = (Rsp [1]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd38.uLng) == 1))
    goto label_122;
  (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd34.Obj) = ((Wrd36.pObj) [1]);

DEFLABEL (label_121)
  (Rsp [3]) = (Wrd34.Obj);
  Rsp = (& (Rsp [2]));
  goto or_loop_38;

DEFLABEL (label_122)
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_56]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_0]), 1);

DEFLABEL (label_80)
  (Wrd34.Obj) = Rvl;
  goto label_121;

DEFLABEL (label_124)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_57]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_2]), 1);

DEFLABEL (label_78)
  (* (--Rsp)) = Rvl;
  goto label_123;

DEFLABEL (label_126)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_46]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_130;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_129)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_52]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_19_9]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (Rsp [4]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [3]);
  (* (--Rsp)) = (Wrd25.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_19_52);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [3]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_19_46);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_125;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd54.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_19_48);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_19_47])));
  Rhp += 3;
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd54.pObj)));
  (* (--Rsp)) = (Wrd55.Obj);
  Wrd52 = Wrd54;
  (Wrd53.Obj) = (Rsp [1]);
  ((Wrd52.pObj) [2]) = (Wrd53.Obj);
  (Wrd50.Obj) = (Rsp [4]);
  ((Wrd52.pObj) [3]) = (Wrd50.Obj);
  (Wrd47.Obj) = (Rsp [3]);
  ((Wrd52.pObj) [4]) = (Wrd47.Obj);
  Rsp = (& (Rsp [1]));
  (Rsp [2]) = (Wrd55.Obj);
  (Wrd38.Obj) = (Rsp [1]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if (! ((Wrd39.uLng) == 1))
    goto label_128;
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd35.Obj) = ((Wrd37.pObj) [1]);

DEFLABEL (label_127)
  (Rsp [3]) = (Wrd35.Obj);
  Rsp = (& (Rsp [2]));
  goto and_loop_46;

DEFLABEL (label_128)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_49]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_0]), 1);

DEFLABEL (label_77)
  (Wrd35.Obj) = Rvl;
  goto label_127;

DEFLABEL (label_130)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_51]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_2]), 1);

DEFLABEL (label_76)
  (* (--Rsp)) = Rvl;
  goto label_129;

DEFLABEL (label_132)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_40]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_138;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_137)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_45]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_19_8]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (Rsp [4]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [3]);
  (* (--Rsp)) = (Wrd25.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_19_45);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [3]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_19_40);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_131;
  (Wrd33.Obj) = (Rsp [0]);
  (Rsp [0]) = (Wrd33.Obj);
  (Wrd37.Obj) = (Rsp [1]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd38.uLng) == 1))
    goto label_136;
  (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd34.Obj) = ((Wrd36.pObj) [1]);

DEFLABEL (label_135)
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd45.uLng) == 1))
    goto label_134;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd43.Obj) = ((Wrd44.pObj) [0]);

DEFLABEL (label_133)
  (Rsp [1]) = (Wrd43.Obj);
  (Wrd50.Obj) = (Rsp [2]);
  (Wrd51.Obj) = (Rsp [3]);
  (Rsp [2]) = (Wrd51.Obj);
  (Rsp [3]) = (Wrd50.Obj);
  goto req_loop_53;

DEFLABEL (label_134)
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_42]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_2]), 1);

DEFLABEL (label_75)
  (Wrd43.Obj) = Rvl;
  goto label_133;

DEFLABEL (label_136)
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_41]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_0]), 1);

DEFLABEL (label_74)
  (Wrd34.Obj) = Rvl;
  goto label_135;

DEFLABEL (label_138)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_44]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_2]), 1);

DEFLABEL (label_73)
  (* (--Rsp)) = Rvl;
  goto label_137;

DEFLABEL (label_139)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_34]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd11.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_19_36);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_19_35])));
  Rhp += 3;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd11.pObj)));
  Wrd18 = Wrd11;
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [2]);
  ((Wrd18.pObj) [2]) = (Wrd21.Obj);
  (Wrd17.Obj) = ((Wrd20.pObj) [3]);
  ((Wrd18.pObj) [3]) = (Wrd17.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd18.pObj) [4]) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd23.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_19_0]));
  (Wrd26.Obj) = ((Wrd23.pObj) [0]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if ((Wrd27.uLng) == 50)
    goto label_142;
  Wrd22 = Wrd26;

DEFLABEL (label_141)
  (* (--Rsp)) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_38]));

DEFLABEL (continuation_52)
  INTERRUPT_CHECK (27, LABEL_19_34);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_140;
  (Wrd7.Obj) = (Rsp [2]);
  (Rsp [3]) = (Wrd7.Obj);

DEFLABEL (label_140)
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_142)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_19_37])), (Wrd23.pObj));

DEFLABEL (label_72)
  (Wrd22.Obj) = Rvl;
  goto label_141;

DEFLABEL (lambda_91)
  CLOSURE_HEADER (LABEL_19_35);

DEFLABEL (lambda_51)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_39]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd17.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd17.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_50)
  INTERRUPT_CHECK (27, LABEL_19_39);
  (Rsp [2]) = Rvl;
  (Wrd6.Obj) = (* (Rsp++));
  (Rsp [2]) = (Wrd6.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (and_loop_92)
DEFLABEL (and_loop_46)
  INTERRUPT_CHECK (26, LABEL_19_47);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_143;
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [4]);
  (Rsp [1]) = (Wrd7.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_143)
  if (! ((Wrd6.uLng) == 1))
    goto label_145;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_144)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [2]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = ((Wrd21.pObj) [3]);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd28.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_19_61);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_19_60])));
  Rhp += 2;
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd28.pObj)));
  Wrd31 = Wrd28;
  ((Wrd31.pObj) [2]) = (Wrd20.Obj);
  (Wrd30.Obj) = (Rsp [3]);
  ((Wrd31.pObj) [3]) = (Wrd30.Obj);
  (Rsp [2]) = (Wrd27.Obj);
  (Rsp [3]) = (Wrd23.Obj);
  goto req_loop_53;

DEFLABEL (label_145)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_59]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_2]), 1);

DEFLABEL (label_79)
  (* (--Rsp)) = Rvl;
  goto label_144;

DEFLABEL (lambda_94)
  CLOSURE_HEADER (LABEL_19_60);

DEFLABEL (lambda_45)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd15.Obj) = ((Wrd6.pObj) [3]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_147;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd8.Obj) = ((Wrd12.pObj) [1]);

DEFLABEL (label_146)
  (Rsp [1]) = (Wrd8.Obj);
  goto and_loop_46;

DEFLABEL (label_147)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_62]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_0]), 1);

DEFLABEL (label_81)
  (Wrd8.Obj) = Rvl;
  goto label_146;

DEFLABEL (or_loop_93)
DEFLABEL (or_loop_38)
  INTERRUPT_CHECK (26, LABEL_19_54);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_148;
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [3]);
  (Rsp [1]) = (Wrd7.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_148)
  if (! ((Wrd6.uLng) == 1))
    goto label_150;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_149)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [2]);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd25.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_19_65);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_19_64])));
  Rhp += 2;
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd25.pObj)));
  Wrd28 = Wrd25;
  ((Wrd28.pObj) [2]) = (Wrd20.Obj);
  (Wrd27.Obj) = (Rsp [3]);
  ((Wrd28.pObj) [3]) = (Wrd27.Obj);
  (Rsp [3]) = (Wrd24.Obj);
  (Wrd30.Obj) = ((Wrd21.pObj) [4]);
  (Rsp [2]) = (Wrd30.Obj);
  goto req_loop_53;

DEFLABEL (label_150)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_63]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_2]), 1);

DEFLABEL (label_82)
  (* (--Rsp)) = Rvl;
  goto label_149;

DEFLABEL (lambda_95)
  CLOSURE_HEADER (LABEL_19_64);

DEFLABEL (lambda_37)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd15.Obj) = ((Wrd6.pObj) [3]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_152;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd8.Obj) = ((Wrd12.pObj) [1]);

DEFLABEL (label_151)
  (Rsp [1]) = (Wrd8.Obj);
  goto or_loop_38;

DEFLABEL (label_152)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_66]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_0]), 1);

DEFLABEL (label_83)
  (Wrd8.Obj) = Rvl;
  goto label_151;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_20_4 3
#define LABEL_20_6 5
#define LABEL_20_5 7
#define LABEL_20_9 9
#define LABEL_20_10 11
#define LABEL_20_11 13
#define LABEL_20_12 15
#define LABEL_20_13 17
#define LABEL_20_14 19
#define LABEL_20_15 21
#define LABEL_20_16 23
#define LABEL_20_17 25
#define LABEL_20_18 27
#define LABEL_20_19 29
#define ENVIRONMENT_LABEL_20_3 42
#define DEBUGGING_LABEL_20_2 41
#define OBJECT_20_5 40
#define OBJECT_20_4 39
#define OBJECT_20_3 38
#define OBJECT_20_2 37
#define OBJECT_20_1 36
#define OBJECT_20_0 35
#define EXECUTE_CACHE_20_8 31
#define EXECUTE_CACHE_20_7 33
#define FREE_REFERENCES_LABEL_20_0 30
#define NUMBER_OF_LINKER_SECTIONS_20_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_20 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd47;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd31;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd39;
  machine_word Wrd40;
  machine_word Wrd41;
  machine_word Wrd38;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd29;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd55;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_20_4);
      goto lambda_20;

    case 1:
      current_block = (Rpc - LABEL_20_6);
      goto label_22;

    case 2:
      current_block = (Rpc - LABEL_20_5);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_20_9);
      goto label_23;

    case 4:
      current_block = (Rpc - LABEL_20_10);
      goto label_24;

    case 5:
      current_block = (Rpc - LABEL_20_11);
      goto label_25;

    case 6:
      current_block = (Rpc - LABEL_20_12);
      goto label_26;

    case 7:
      current_block = (Rpc - LABEL_20_13);
      goto label_27;

    case 8:
      current_block = (Rpc - LABEL_20_14);
      goto continuation_10;

    case 9:
      current_block = (Rpc - LABEL_20_15);
      goto label_28;

    case 10:
      current_block = (Rpc - LABEL_20_16);
      goto label_29;

    case 11:
      current_block = (Rpc - LABEL_20_17);
      goto label_30;

    case 12:
      current_block = (Rpc - LABEL_20_18);
      goto continuation_3;

    case 13:
      current_block = (Rpc - LABEL_20_19);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_32)
DEFLABEL (lambda_20)
  INTERRUPT_CHECK (26, LABEL_20_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_51;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [1]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_50)
  (Wrd17.Obj) = (current_block [OBJECT_20_1]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_20_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_33;
  (Wrd55.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd55.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_8]));

DEFLABEL (label_33)
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_49;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_48)
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_47;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd16.Obj) = ((Wrd17.pObj) [1]);

DEFLABEL (label_46)
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd25.uLng) == 1))
    goto label_45;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [1]);
  (* (--Rsp)) = (Wrd24.Obj);

DEFLABEL (label_44)
  (Wrd33.Obj) = (Rsp [1]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 1))
    goto label_43;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [1]);

DEFLABEL (label_42)
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd41.uLng) == 1))
    goto label_41;
  (Wrd40.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd39.Obj) = ((Wrd40.pObj) [0]);

DEFLABEL (label_40)
  (Wrd46.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd39.Obj);
  (* (Rhp++)) = (Wrd46.Obj);
  (Wrd48.pObj) = (& (Rhp [-2]));
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd48.pObj)));
  (* (--Rsp)) = (Wrd49.Obj);
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_14]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (Wrd53.Obj) = (current_block [OBJECT_20_3]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd54.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd54.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_20_14);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Wrd13.Obj) = (current_block [OBJECT_20_4]);
  (* (Rhp++)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd11.pObj) = (& (Rhp [-2]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd11.pObj)));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_39;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [1]);

DEFLABEL (label_38)
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd25.uLng) == 1))
    goto label_37;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd23.Obj) = ((Wrd24.pObj) [1]);

DEFLABEL (label_36)
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd32.uLng) == 1))
    goto label_35;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd30.Obj) = ((Wrd31.pObj) [0]);

DEFLABEL (label_34)
  (Wrd40.Obj) = (current_block [OBJECT_20_4]);
  (* (Rhp++)) = (Wrd30.Obj);
  (* (Rhp++)) = (Wrd40.Obj);
  (Wrd39.pObj) = (& (Rhp [-2]));
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd39.pObj)));
  (* (Rhp++)) = (Wrd40.Obj);
  (* (Rhp++)) = (Wrd37.Obj);
  (Wrd42.pObj) = (& (Rhp [-2]));
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd42.pObj)));
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_18]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd48.Obj) = (current_block [OBJECT_20_3]);
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd49.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd49.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_20_18);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Wrd10.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_19]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (current_block [OBJECT_20_5]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd18.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_20_19);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_35)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_17]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_20_2]), 1);

DEFLABEL (label_30)
  (Wrd30.Obj) = Rvl;
  goto label_34;

DEFLABEL (label_37)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_16]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_20_0]), 1);

DEFLABEL (label_29)
  (Wrd23.Obj) = Rvl;
  goto label_36;

DEFLABEL (label_39)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_15]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_20_0]), 1);

DEFLABEL (label_28)
  (Wrd14.Obj) = Rvl;
  goto label_38;

DEFLABEL (label_41)
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_13]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_20_2]), 1);

DEFLABEL (label_27)
  (Wrd39.Obj) = Rvl;
  goto label_40;

DEFLABEL (label_43)
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_12]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_20_0]), 1);

DEFLABEL (label_26)
  (Wrd30.Obj) = Rvl;
  goto label_42;

DEFLABEL (label_45)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_11]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_20_0]), 1);

DEFLABEL (label_25)
  (* (--Rsp)) = Rvl;
  goto label_44;

DEFLABEL (label_47)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_10]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_20_0]), 1);

DEFLABEL (label_24)
  (Wrd16.Obj) = Rvl;
  goto label_46;

DEFLABEL (label_49)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_9]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_20_0]), 1);

DEFLABEL (label_23)
  (Wrd7.Obj) = Rvl;
  goto label_48;

DEFLABEL (label_51)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_6]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_20_0]), 1);

DEFLABEL (label_22)
  (* (--Rsp)) = Rvl;
  goto label_50;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_21_4 3
#define LABEL_21_6 5
#define LABEL_21_5 7
#define LABEL_21_9 9
#define LABEL_21_10 11
#define LABEL_21_11 13
#define LABEL_21_12 15
#define LABEL_21_13 17
#define LABEL_21_14 19
#define LABEL_21_15 21
#define LABEL_21_16 23
#define LABEL_21_17 25
#define LABEL_21_18 27
#define LABEL_21_19 29
#define LABEL_21_20 31
#define LABEL_21_21 33
#define LABEL_21_22 35
#define LABEL_21_23 37
#define LABEL_21_24 39
#define LABEL_21_25 41
#define LABEL_21_26 43
#define LABEL_21_27 45
#define LABEL_21_28 47
#define LABEL_21_33 49
#define LABEL_21_34 51
#define LABEL_21_35 53
#define LABEL_21_36 55
#define LABEL_21_29 57
#define TAG_21_30 27
#define LABEL_21_37 59
#define LABEL_21_38 61
#define LABEL_21_39 63
#define LABEL_21_32 65
#define LABEL_21_40 67
#define LABEL_21_42 69
#define LABEL_21_43 71
#define LABEL_21_41 73
#define LABEL_21_44 75
#define LABEL_21_46 77
#define LABEL_21_47 79
#define ENVIRONMENT_LABEL_21_3 102
#define DEBUGGING_LABEL_21_2 101
#define OBJECT_21_11 100
#define OBJECT_21_10 99
#define OBJECT_21_9 98
#define OBJECT_21_8 97
#define OBJECT_21_7 96
#define OBJECT_21_6 95
#define OBJECT_21_5 94
#define OBJECT_21_4 93
#define OBJECT_21_3 92
#define OBJECT_21_2 91
#define OBJECT_21_1 90
#define OBJECT_21_0 89
#define EXECUTE_CACHE_21_45 81
#define EXECUTE_CACHE_21_31 83
#define EXECUTE_CACHE_21_8 85
#define EXECUTE_CACHE_21_7 87
#define FREE_REFERENCES_LABEL_21_0 80
#define NUMBER_OF_LINKER_SECTIONS_21_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_21 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd56;
  machine_word Wrd47;
  machine_word Wrd40;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd26;
  machine_word Wrd36;
  machine_word Wrd31;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd24;
  machine_word Wrd25;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd108;
  machine_word Wrd107;
  machine_word Wrd109;
  machine_word Wrd100;
  machine_word Wrd102;
  machine_word Wrd96;
  machine_word Wrd91;
  machine_word Wrd84;
  machine_word Wrd77;
  machine_word Wrd71;
  machine_word Wrd70;
  machine_word Wrd66;
  machine_word Wrd61;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd48;
  machine_word Wrd49;
  machine_word Wrd148;
  machine_word Wrd150;
  machine_word Wrd152;
  machine_word Wrd151;
  machine_word Wrd145;
  machine_word Wrd146;
  machine_word Wrd144;
  machine_word Wrd143;
  machine_word Wrd140;
  machine_word Wrd135;
  machine_word Wrd134;
  machine_word Wrd136;
  machine_word Wrd133;
  machine_word Wrd125;
  machine_word Wrd127;
  machine_word Wrd129;
  machine_word Wrd128;
  machine_word Wrd124;
  machine_word Wrd119;
  machine_word Wrd118;
  machine_word Wrd120;
  machine_word Wrd117;
  machine_word Wrd111;
  machine_word Wrd112;
  machine_word Wrd113;
  machine_word Wrd110;
  machine_word Wrd104;
  machine_word Wrd105;
  machine_word Wrd106;
  machine_word Wrd103;
  machine_word Wrd95;
  machine_word Wrd97;
  machine_word Wrd99;
  machine_word Wrd98;
  machine_word Wrd94;
  machine_word Wrd89;
  machine_word Wrd88;
  machine_word Wrd90;
  machine_word Wrd87;
  machine_word Wrd81;
  machine_word Wrd82;
  machine_word Wrd83;
  machine_word Wrd80;
  machine_word Wrd74;
  machine_word Wrd75;
  machine_word Wrd76;
  machine_word Wrd73;
  machine_word Wrd65;
  machine_word Wrd67;
  machine_word Wrd69;
  machine_word Wrd68;
  machine_word Wrd64;
  machine_word Wrd59;
  machine_word Wrd58;
  machine_word Wrd60;
  machine_word Wrd57;
  machine_word Wrd51;
  machine_word Wrd52;
  machine_word Wrd53;
  machine_word Wrd50;
  machine_word Wrd44;
  machine_word Wrd45;
  machine_word Wrd46;
  machine_word Wrd43;
  machine_word Wrd35;
  machine_word Wrd37;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd34;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd30;
  machine_word Wrd27;
  machine_word Wrd21;
  machine_word Wrd22;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd15;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_21_4);
      goto lambda_84;

    case 1:
      current_block = (Rpc - LABEL_21_6);
      goto label_86;

    case 2:
      current_block = (Rpc - LABEL_21_5);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_21_9);
      goto continuation_20;

    case 4:
      current_block = (Rpc - LABEL_21_10);
      goto label_87;

    case 5:
      current_block = (Rpc - LABEL_21_11);
      goto label_88;

    case 6:
      current_block = (Rpc - LABEL_21_12);
      goto label_89;

    case 7:
      current_block = (Rpc - LABEL_21_13);
      goto label_90;

    case 8:
      current_block = (Rpc - LABEL_21_14);
      goto label_91;

    case 9:
      current_block = (Rpc - LABEL_21_15);
      goto label_92;

    case 10:
      current_block = (Rpc - LABEL_21_16);
      goto label_93;

    case 11:
      current_block = (Rpc - LABEL_21_17);
      goto label_94;

    case 12:
      current_block = (Rpc - LABEL_21_18);
      goto label_95;

    case 13:
      current_block = (Rpc - LABEL_21_19);
      goto label_96;

    case 14:
      current_block = (Rpc - LABEL_21_20);
      goto label_97;

    case 15:
      current_block = (Rpc - LABEL_21_21);
      goto label_98;

    case 16:
      current_block = (Rpc - LABEL_21_22);
      goto label_99;

    case 17:
      current_block = (Rpc - LABEL_21_23);
      goto label_100;

    case 18:
      current_block = (Rpc - LABEL_21_24);
      goto label_101;

    case 19:
      current_block = (Rpc - LABEL_21_25);
      goto label_102;

    case 20:
      current_block = (Rpc - LABEL_21_26);
      goto label_103;

    case 21:
      current_block = (Rpc - LABEL_21_27);
      goto label_104;

    case 22:
      current_block = (Rpc - LABEL_21_28);
      goto continuation_79;

    case 23:
      current_block = (Rpc - LABEL_21_33);
      goto continuation_68;

    case 24:
      current_block = (Rpc - LABEL_21_34);
      goto label_110;

    case 25:
      current_block = (Rpc - LABEL_21_35);
      goto label_111;

    case 26:
      current_block = (Rpc - LABEL_21_36);
      goto label_112;

    case 27:
      current_block = (Rpc - LABEL_21_29);
      goto lambda_115;

    case 28:
      current_block = (Rpc - LABEL_21_37);
      goto label_105;

    case 29:
      current_block = (Rpc - LABEL_21_38);
      goto label_106;

    case 30:
      current_block = (Rpc - LABEL_21_39);
      goto label_107;

    case 31:
      current_block = (Rpc - LABEL_21_32);
      goto continuation_43;

    case 32:
      current_block = (Rpc - LABEL_21_40);
      goto continuation_52;

    case 33:
      current_block = (Rpc - LABEL_21_42);
      goto label_108;

    case 34:
      current_block = (Rpc - LABEL_21_43);
      goto label_109;

    case 35:
      current_block = (Rpc - LABEL_21_41);
      goto continuation_34;

    case 36:
      current_block = (Rpc - LABEL_21_44);
      goto continuation_25;

    case 37:
      current_block = (Rpc - LABEL_21_46);
      goto continuation_22;

    case 38:
      current_block = (Rpc - LABEL_21_47);
      goto continuation_21;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_114)
DEFLABEL (lambda_84)
  INTERRUPT_CHECK (26, LABEL_21_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_154;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [1]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_153)
  (Wrd17.Obj) = (current_block [OBJECT_21_1]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_21_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_116;
  (Wrd12.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd12.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_8]));

DEFLABEL (label_116)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_21_2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_21_9);
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_152;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_151)
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_150;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd15.pObj) [1]);

DEFLABEL (label_149)
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd23.uLng) == 1))
    goto label_148;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd21.Obj) = ((Wrd22.pObj) [1]);

DEFLABEL (label_147)
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd30.uLng) == 1))
    goto label_146;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [1]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_145)
  (Wrd38.Obj) = (Rsp [2]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if (! ((Wrd39.uLng) == 1))
    goto label_144;
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd35.Obj) = ((Wrd37.pObj) [1]);

DEFLABEL (label_143)
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd46.uLng) == 1))
    goto label_142;
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd44.Obj) = ((Wrd45.pObj) [1]);

DEFLABEL (label_141)
  (Wrd53.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if (! ((Wrd53.uLng) == 1))
    goto label_140;
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd51.Obj) = ((Wrd52.pObj) [1]);

DEFLABEL (label_139)
  (Wrd60.uLng) = (OBJECT_TYPE (Wrd51.Obj));
  if (! ((Wrd60.uLng) == 1))
    goto label_138;
  (Wrd58.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd59.Obj) = ((Wrd58.pObj) [0]);
  (* (--Rsp)) = (Wrd59.Obj);

DEFLABEL (label_137)
  (Wrd68.Obj) = (Rsp [3]);
  (Wrd69.uLng) = (OBJECT_TYPE (Wrd68.Obj));
  if (! ((Wrd69.uLng) == 1))
    goto label_136;
  (Wrd67.pObj) = (OBJECT_ADDRESS (Wrd68.Obj));
  (Wrd65.Obj) = ((Wrd67.pObj) [1]);

DEFLABEL (label_135)
  (Wrd76.uLng) = (OBJECT_TYPE (Wrd65.Obj));
  if (! ((Wrd76.uLng) == 1))
    goto label_134;
  (Wrd75.pObj) = (OBJECT_ADDRESS (Wrd65.Obj));
  (Wrd74.Obj) = ((Wrd75.pObj) [1]);

DEFLABEL (label_133)
  (Wrd83.uLng) = (OBJECT_TYPE (Wrd74.Obj));
  if (! ((Wrd83.uLng) == 1))
    goto label_132;
  (Wrd82.pObj) = (OBJECT_ADDRESS (Wrd74.Obj));
  (Wrd81.Obj) = ((Wrd82.pObj) [0]);

DEFLABEL (label_131)
  (Wrd90.uLng) = (OBJECT_TYPE (Wrd81.Obj));
  if (! ((Wrd90.uLng) == 1))
    goto label_130;
  (Wrd88.pObj) = (OBJECT_ADDRESS (Wrd81.Obj));
  (Wrd89.Obj) = ((Wrd88.pObj) [1]);
  (* (--Rsp)) = (Wrd89.Obj);

DEFLABEL (label_129)
  (Wrd98.Obj) = (Rsp [4]);
  (Wrd99.uLng) = (OBJECT_TYPE (Wrd98.Obj));
  if (! ((Wrd99.uLng) == 1))
    goto label_128;
  (Wrd97.pObj) = (OBJECT_ADDRESS (Wrd98.Obj));
  (Wrd95.Obj) = ((Wrd97.pObj) [1]);

DEFLABEL (label_127)
  (Wrd106.uLng) = (OBJECT_TYPE (Wrd95.Obj));
  if (! ((Wrd106.uLng) == 1))
    goto label_126;
  (Wrd105.pObj) = (OBJECT_ADDRESS (Wrd95.Obj));
  (Wrd104.Obj) = ((Wrd105.pObj) [1]);

DEFLABEL (label_125)
  (Wrd113.uLng) = (OBJECT_TYPE (Wrd104.Obj));
  if (! ((Wrd113.uLng) == 1))
    goto label_124;
  (Wrd112.pObj) = (OBJECT_ADDRESS (Wrd104.Obj));
  (Wrd111.Obj) = ((Wrd112.pObj) [0]);

DEFLABEL (label_123)
  (Wrd120.uLng) = (OBJECT_TYPE (Wrd111.Obj));
  if (! ((Wrd120.uLng) == 1))
    goto label_122;
  (Wrd118.pObj) = (OBJECT_ADDRESS (Wrd111.Obj));
  (Wrd119.Obj) = ((Wrd118.pObj) [0]);
  (* (--Rsp)) = (Wrd119.Obj);

DEFLABEL (label_121)
  (Wrd128.Obj) = (Rsp [5]);
  (Wrd129.uLng) = (OBJECT_TYPE (Wrd128.Obj));
  if (! ((Wrd129.uLng) == 1))
    goto label_120;
  (Wrd127.pObj) = (OBJECT_ADDRESS (Wrd128.Obj));
  (Wrd125.Obj) = ((Wrd127.pObj) [1]);

DEFLABEL (label_119)
  (Wrd136.uLng) = (OBJECT_TYPE (Wrd125.Obj));
  if (! ((Wrd136.uLng) == 1))
    goto label_118;
  (Wrd134.pObj) = (OBJECT_ADDRESS (Wrd125.Obj));
  (Wrd135.Obj) = ((Wrd134.pObj) [0]);
  (* (--Rsp)) = (Wrd135.Obj);

DEFLABEL (label_117)
  (Wrd143.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_28]))));
  (* (--Rsp)) = (Wrd143.Obj);
  (Wrd144.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd144.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd146.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_21_30);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_21_29])));
  Rhp += 3;
  (Wrd145.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd146.pObj)));
  Wrd151 = Wrd146;
  (Wrd152.Obj) = (Rsp [9]);
  ((Wrd151.pObj) [2]) = (Wrd152.Obj);
  (Wrd150.Obj) = (Rsp [7]);
  ((Wrd151.pObj) [3]) = (Wrd150.Obj);
  (Wrd148.Obj) = (Rsp [2]);
  ((Wrd151.pObj) [4]) = (Wrd148.Obj);
  (* (--Rsp)) = (Wrd145.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_31]));

DEFLABEL (continuation_79)
  INTERRUPT_CHECK (27, LABEL_21_28);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_32]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_21_4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd9.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_43)
  INTERRUPT_CHECK (27, LABEL_21_32);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.Obj) = (current_block [OBJECT_21_5]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd13.pObj) = (& (Rhp [-2]));
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd13.pObj)));
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  (Wrd21.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd21.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd20.pObj) = (& (Rhp [-2]));
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));
  (Wrd25.Obj) = (Rsp [6]);
  (* (Rhp++)) = (Wrd25.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (Wrd24.pObj) = (& (Rhp [-2]));
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd24.pObj)));
  (Wrd26.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd22.Obj);
  (* (Rhp++)) = (Wrd26.Obj);
  (Wrd28.pObj) = (& (Rhp [-2]));
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd28.pObj)));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_41]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (Wrd33.Obj) = (current_block [OBJECT_21_9]);
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd34.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_34)
  INTERRUPT_CHECK (27, LABEL_21_41);
  (Wrd8.Obj) = (Rsp [3]);
  (Wrd9.Obj) = (current_block [OBJECT_21_5]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Wrd13.Obj) = (current_block [OBJECT_21_6]);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  (Wrd21.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd21.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd20.pObj) = (& (Rhp [-2]));
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd18.Obj);
  (Wrd25.pObj) = (& (Rhp [-2]));
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd25.pObj)));
  (* (Rhp++)) = (Wrd23.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd28.pObj) = (& (Rhp [-2]));
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd28.pObj)));
  (Wrd33.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd33.Obj);
  (* (Rhp++)) = (Wrd26.Obj);
  (Wrd32.pObj) = (& (Rhp [-2]));
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd32.pObj)));
  (Wrd37.Obj) = (Rsp [6]);
  (* (Rhp++)) = (Wrd37.Obj);
  (* (Rhp++)) = (Wrd30.Obj);
  (Wrd36.pObj) = (& (Rhp [-2]));
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd36.pObj)));
  (Wrd38.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd34.Obj);
  (* (Rhp++)) = (Wrd38.Obj);
  (Wrd40.pObj) = (& (Rhp [-2]));
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd40.pObj)));
  (* (--Rsp)) = (Wrd41.Obj);
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_44]))));
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd45.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd46.Obj) = (current_block [OBJECT_21_3]);
  (* (--Rsp)) = (Wrd46.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_45]));

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_21_44);
  (Wrd9.Obj) = (current_block [OBJECT_21_5]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Wrd13.Obj) = (current_block [OBJECT_21_6]);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd6.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  (Wrd21.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd21.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd20.pObj) = (& (Rhp [-2]));
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (Wrd25.pObj) = (& (Rhp [-2]));
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd25.pObj)));
  (* (Rhp++)) = (Wrd23.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd28.pObj) = (& (Rhp [-2]));
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd28.pObj)));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_46]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (Wrd33.Obj) = (current_block [OBJECT_21_10]);
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (Rsp [11]);
  (* (--Rsp)) = (Wrd34.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_21_46);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Wrd13.Obj) = (current_block [OBJECT_21_5]);
  (* (Rhp++)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (Wrd17.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  (Wrd21.Obj) = (Rsp [6]);
  (* (Rhp++)) = (Wrd21.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd20.pObj) = (& (Rhp [-2]));
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));
  (Wrd22.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd22.Obj);
  (Wrd24.pObj) = (& (Rhp [-2]));
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd24.pObj)));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_47]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd29.Obj) = (current_block [OBJECT_21_11]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd30.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_21_47);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  Rsp = (& (Rsp [9]));
  goto pop_return;

DEFLABEL (label_118)
  (Wrd140.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_27]))));
  (* (--Rsp)) = (Wrd140.Obj);
  (* (--Rsp)) = (Wrd125.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_3]), 1);

DEFLABEL (label_104)
  (* (--Rsp)) = Rvl;
  goto label_117;

DEFLABEL (label_120)
  (Wrd133.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_26]))));
  (* (--Rsp)) = (Wrd133.Obj);
  (* (--Rsp)) = (Wrd128.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_0]), 1);

DEFLABEL (label_103)
  (Wrd125.Obj) = Rvl;
  goto label_119;

DEFLABEL (label_122)
  (Wrd124.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_25]))));
  (* (--Rsp)) = (Wrd124.Obj);
  (* (--Rsp)) = (Wrd111.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_3]), 1);

DEFLABEL (label_102)
  (* (--Rsp)) = Rvl;
  goto label_121;

DEFLABEL (label_124)
  (Wrd117.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_24]))));
  (* (--Rsp)) = (Wrd117.Obj);
  (* (--Rsp)) = (Wrd104.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_3]), 1);

DEFLABEL (label_101)
  (Wrd111.Obj) = Rvl;
  goto label_123;

DEFLABEL (label_126)
  (Wrd110.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_23]))));
  (* (--Rsp)) = (Wrd110.Obj);
  (* (--Rsp)) = (Wrd95.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_0]), 1);

DEFLABEL (label_100)
  (Wrd104.Obj) = Rvl;
  goto label_125;

DEFLABEL (label_128)
  (Wrd103.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_22]))));
  (* (--Rsp)) = (Wrd103.Obj);
  (* (--Rsp)) = (Wrd98.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_0]), 1);

DEFLABEL (label_99)
  (Wrd95.Obj) = Rvl;
  goto label_127;

DEFLABEL (label_130)
  (Wrd94.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_21]))));
  (* (--Rsp)) = (Wrd94.Obj);
  (* (--Rsp)) = (Wrd81.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_0]), 1);

DEFLABEL (label_98)
  (* (--Rsp)) = Rvl;
  goto label_129;

DEFLABEL (label_132)
  (Wrd87.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_20]))));
  (* (--Rsp)) = (Wrd87.Obj);
  (* (--Rsp)) = (Wrd74.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_3]), 1);

DEFLABEL (label_97)
  (Wrd81.Obj) = Rvl;
  goto label_131;

DEFLABEL (label_134)
  (Wrd80.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_19]))));
  (* (--Rsp)) = (Wrd80.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_0]), 1);

DEFLABEL (label_96)
  (Wrd74.Obj) = Rvl;
  goto label_133;

DEFLABEL (label_136)
  (Wrd73.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_18]))));
  (* (--Rsp)) = (Wrd73.Obj);
  (* (--Rsp)) = (Wrd68.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_0]), 1);

DEFLABEL (label_95)
  (Wrd65.Obj) = Rvl;
  goto label_135;

DEFLABEL (label_138)
  (Wrd64.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_17]))));
  (* (--Rsp)) = (Wrd64.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_3]), 1);

DEFLABEL (label_94)
  (* (--Rsp)) = Rvl;
  goto label_137;

DEFLABEL (label_140)
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_16]))));
  (* (--Rsp)) = (Wrd57.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_0]), 1);

DEFLABEL (label_93)
  (Wrd51.Obj) = Rvl;
  goto label_139;

DEFLABEL (label_142)
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_15]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_0]), 1);

DEFLABEL (label_92)
  (Wrd44.Obj) = Rvl;
  goto label_141;

DEFLABEL (label_144)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_14]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_0]), 1);

DEFLABEL (label_91)
  (Wrd35.Obj) = Rvl;
  goto label_143;

DEFLABEL (label_146)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_13]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_0]), 1);

DEFLABEL (label_90)
  (* (--Rsp)) = Rvl;
  goto label_145;

DEFLABEL (label_148)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_12]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_0]), 1);

DEFLABEL (label_89)
  (Wrd21.Obj) = Rvl;
  goto label_147;

DEFLABEL (label_150)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_11]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_0]), 1);

DEFLABEL (label_88)
  (Wrd14.Obj) = Rvl;
  goto label_149;

DEFLABEL (label_152)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_10]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_0]), 1);

DEFLABEL (label_87)
  (Wrd5.Obj) = Rvl;
  goto label_151;

DEFLABEL (label_154)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_6]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_0]), 1);

DEFLABEL (label_86)
  (* (--Rsp)) = Rvl;
  goto label_153;

DEFLABEL (lambda_115)
  CLOSURE_HEADER (LABEL_21_29);

DEFLABEL (lambda_78)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_172;
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [0]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_171)
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_170;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [1]);

DEFLABEL (label_169)
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd25.uLng) == 1))
    goto label_168;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd23.Obj) = ((Wrd24.pObj) [1]);

DEFLABEL (label_167)
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd30.uLng) == 1))
    goto label_166;
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_33]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (Wrd42.Obj) = (current_block [OBJECT_21_7]);
  (* (--Rsp)) = (Wrd42.Obj);
  (Wrd43.Obj) = (Rsp [3]);
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  (Wrd45.Obj) = ((Wrd44.pObj) [2]);
  (* (--Rsp)) = (Wrd45.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_68)
  INTERRUPT_CHECK (27, LABEL_21_33);
  (Wrd49.Obj) = (Rsp [0]);
  (Wrd50.Obj) = (current_block [OBJECT_21_5]);
  (* (Rhp++)) = (Wrd49.Obj);
  (* (Rhp++)) = (Wrd50.Obj);
  (Wrd48.pObj) = (& (Rhp [-2]));
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd48.pObj)));
  (Wrd54.Obj) = (current_block [OBJECT_21_6]);
  (* (Rhp++)) = (Wrd54.Obj);
  (* (Rhp++)) = (Wrd46.Obj);
  (Wrd53.pObj) = (& (Rhp [-2]));
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd53.pObj)));
  (* (Rhp++)) = (Wrd51.Obj);
  (* (Rhp++)) = (Wrd50.Obj);
  (Wrd57.pObj) = (& (Rhp [-2]));
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd57.pObj)));
  (Wrd62.Obj) = (Rsp [1]);
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd62.Obj));
  (Wrd64.Obj) = ((Wrd63.pObj) [4]);
  (* (Rhp++)) = (Wrd64.Obj);
  (* (Rhp++)) = (Wrd55.Obj);
  (Wrd61.pObj) = (& (Rhp [-2]));
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd61.pObj)));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd59.Obj);
  (Wrd68.pObj) = (& (Rhp [-2]));
  (Wrd66.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd68.pObj)));
  (* (Rhp++)) = (Wrd66.Obj);
  (* (Rhp++)) = (Wrd50.Obj);
  (Wrd70.pObj) = (& (Rhp [-2]));
  (Wrd71.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd70.pObj)));
  (* (--Rsp)) = (Wrd71.Obj);
  (Wrd76.Obj) = (Rsp [3]);
  (Wrd77.uLng) = (OBJECT_TYPE (Wrd76.Obj));
  if (! ((Wrd77.uLng) == 1))
    goto label_165;
  (Wrd75.pObj) = (OBJECT_ADDRESS (Wrd76.Obj));
  (Wrd73.Obj) = ((Wrd75.pObj) [1]);

DEFLABEL (label_164)
  (Wrd84.uLng) = (OBJECT_TYPE (Wrd73.Obj));
  if (! ((Wrd84.uLng) == 1))
    goto label_163;
  (Wrd83.pObj) = (OBJECT_ADDRESS (Wrd73.Obj));
  (Wrd82.Obj) = ((Wrd83.pObj) [1]);

DEFLABEL (label_162)
  (Wrd91.uLng) = (OBJECT_TYPE (Wrd82.Obj));
  if (! ((Wrd91.uLng) == 1))
    goto label_161;
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd82.Obj));
  (Wrd89.Obj) = ((Wrd90.pObj) [0]);

DEFLABEL (label_160)
  (Wrd96.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd89.Obj);
  (* (Rhp++)) = (Wrd96.Obj);
  (Wrd99.pObj) = (& (Rhp [-2]));
  (Wrd97.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd99.pObj)));
  (Wrd103.Obj) = (Rsp [1]);
  (Wrd104.pObj) = (OBJECT_ADDRESS (Wrd103.Obj));
  (Wrd105.Obj) = ((Wrd104.pObj) [3]);
  (* (Rhp++)) = (Wrd105.Obj);
  (* (Rhp++)) = (Wrd97.Obj);
  (Wrd102.pObj) = (& (Rhp [-2]));
  (Wrd100.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd102.pObj)));
  (Wrd109.Obj) = (current_block [OBJECT_21_5]);
  (* (Rhp++)) = (Wrd100.Obj);
  (* (Rhp++)) = (Wrd109.Obj);
  (Wrd107.pObj) = (& (Rhp [-2]));
  (Wrd108.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd107.pObj)));
  (* (--Rsp)) = (Wrd108.Obj);

DEFLABEL (label_159)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_40]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd35.Obj) = (current_block [OBJECT_21_8]);
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd36.Obj) = (Rsp [4]);
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd38.Obj) = ((Wrd37.pObj) [2]);
  (* (--Rsp)) = (Wrd38.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_52)
  INTERRUPT_CHECK (27, LABEL_21_40);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.Obj) = (current_block [OBJECT_21_5]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Wrd13.Obj) = (current_block [OBJECT_21_6]);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [4]);
  (* (Rhp++)) = (Wrd23.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd20.pObj) = (& (Rhp [-2]));
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd18.Obj);
  (Wrd27.pObj) = (& (Rhp [-2]));
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd27.pObj)));
  (* (Rhp++)) = (Wrd25.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd29.pObj) = (& (Rhp [-2]));
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd29.pObj)));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd35.Obj) = (Rsp [4]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd36.uLng) == 1))
    goto label_158;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd32.Obj) = ((Wrd34.pObj) [1]);

DEFLABEL (label_157)
  (Wrd43.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd43.uLng) == 1))
    goto label_156;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd41.Obj) = ((Wrd42.pObj) [0]);

DEFLABEL (label_155)
  (Wrd48.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd41.Obj);
  (* (Rhp++)) = (Wrd48.Obj);
  (Wrd51.pObj) = (& (Rhp [-2]));
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd51.pObj)));
  (Wrd55.Obj) = (Rsp [2]);
  (Wrd56.pObj) = (OBJECT_ADDRESS (Wrd55.Obj));
  (Wrd57.Obj) = ((Wrd56.pObj) [3]);
  (* (Rhp++)) = (Wrd57.Obj);
  (* (Rhp++)) = (Wrd49.Obj);
  (Wrd54.pObj) = (& (Rhp [-2]));
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd54.pObj)));
  (Wrd58.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd52.Obj);
  (* (Rhp++)) = (Wrd58.Obj);
  (Wrd61.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd61.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_156)
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_43]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_3]), 1);

DEFLABEL (label_109)
  (Wrd41.Obj) = Rvl;
  goto label_155;

DEFLABEL (label_158)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_42]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_0]), 1);

DEFLABEL (label_108)
  (Wrd32.Obj) = Rvl;
  goto label_157;

DEFLABEL (label_161)
  (Wrd95.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_36]))));
  (* (--Rsp)) = (Wrd95.Obj);
  (* (--Rsp)) = (Wrd82.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_3]), 1);

DEFLABEL (label_112)
  (Wrd89.Obj) = Rvl;
  goto label_160;

DEFLABEL (label_163)
  (Wrd88.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_35]))));
  (* (--Rsp)) = (Wrd88.Obj);
  (* (--Rsp)) = (Wrd73.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_0]), 1);

DEFLABEL (label_111)
  (Wrd82.Obj) = Rvl;
  goto label_162;

DEFLABEL (label_165)
  (Wrd81.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_34]))));
  (* (--Rsp)) = (Wrd81.Obj);
  (* (--Rsp)) = (Wrd76.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_0]), 1);

DEFLABEL (label_110)
  (Wrd73.Obj) = Rvl;
  goto label_164;

DEFLABEL (label_166)
  (Wrd31.Obj) = (current_block [OBJECT_21_5]);
  (* (--Rsp)) = (Wrd31.Obj);
  goto label_159;

DEFLABEL (label_168)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_39]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_0]), 1);

DEFLABEL (label_107)
  (Wrd23.Obj) = Rvl;
  goto label_167;

DEFLABEL (label_170)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_38]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_0]), 1);

DEFLABEL (label_106)
  (Wrd14.Obj) = Rvl;
  goto label_169;

DEFLABEL (label_172)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_37]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_3]), 1);

DEFLABEL (label_105)
  (* (--Rsp)) = Rvl;
  goto label_171;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_22_4 3
#define ENVIRONMENT_LABEL_22_3 9
#define DEBUGGING_LABEL_22_2 8
#define OBJECT_22_0 7
#define EXECUTE_CACHE_22_5 5
#define FREE_REFERENCES_LABEL_22_0 4
#define NUMBER_OF_LINKER_SECTIONS_22_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_22 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_22_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_22_4);
  (Wrd5.Obj) = (current_block [OBJECT_22_0]);
  (Rsp [2]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_23_4 3
#define LABEL_23_5 5
#define LABEL_23_7 7
#define LABEL_23_9 9
#define LABEL_23_11 11
#define LABEL_23_12 13
#define LABEL_23_10 15
#define LABEL_23_15 17
#define LABEL_23_16 19
#define LABEL_23_13 21
#define LABEL_23_18 23
#define TAG_23_19 10
#define LABEL_23_21 25
#define ENVIRONMENT_LABEL_23_3 46
#define DEBUGGING_LABEL_23_2 45
#define OBJECT_23_2 44
#define OBJECT_23_1 43
#define OBJECT_23_0 42
#define EXECUTE_CACHE_23_22 27
#define EXECUTE_CACHE_23_20 29
#define EXECUTE_CACHE_23_17 31
#define EXECUTE_CACHE_23_14 33
#define EXECUTE_CACHE_23_8 35
#define EXECUTE_CACHE_23_6 37
#define FREE_REFERENCE_23_1 40
#define FREE_REFERENCE_23_0 41
#define FREE_REFERENCES_LABEL_23_0 26
#define NUMBER_OF_LINKER_SECTIONS_23_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_23 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_23_4);
      goto lambda_13;

    case 1:
      current_block = (Rpc - LABEL_23_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_23_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_23_9);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_23_11);
      goto label_15;

    case 5:
      current_block = (Rpc - LABEL_23_12);
      goto label_16;

    case 6:
      current_block = (Rpc - LABEL_23_10);
      goto continuation_10;

    case 7:
      current_block = (Rpc - LABEL_23_15);
      goto label_17;

    case 8:
      current_block = (Rpc - LABEL_23_16);
      goto label_18;

    case 9:
      current_block = (Rpc - LABEL_23_13);
      goto continuation_3;

    case 10:
      current_block = (Rpc - LABEL_23_18);
      goto lambda_22;

    case 11:
      current_block = (Rpc - LABEL_23_21);
      goto label_19;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_21)
DEFLABEL (lambda_13)
  INTERRUPT_CHECK (26, LABEL_23_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_23_0]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_23_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_23_7);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_23_9);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_30;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd8.Obj) = ((Wrd10.pObj) [1]);

DEFLABEL (label_29)
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd19.uLng) == 1))
    goto label_28;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_27)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_13]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd27.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_14]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_23_13);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_23_19);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_23_18])));
  Rhp += 2;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  Wrd11 = Wrd8;
  (Wrd12.Obj) = (Rsp [4]);
  ((Wrd11.pObj) [2]) = (Wrd12.Obj);
  ((Wrd11.pObj) [3]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_20]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_23_10);
  (Wrd5.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (Rsp [3]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [6]);
  (Rsp [4]) = (Wrd7.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_23_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_26;
  Wrd9 = Wrd13;

DEFLABEL (label_25)
  (Rsp [5]) = (Wrd9.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd15.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_23_1]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_24;
  Wrd17 = Wrd21;

DEFLABEL (label_23)
  (Rsp [6]) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_17]));

DEFLABEL (label_24)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_23_16])), (Wrd18.pObj));

DEFLABEL (label_18)
  (Wrd17.Obj) = Rvl;
  goto label_23;

DEFLABEL (label_26)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_23_15])), (Wrd10.pObj));

DEFLABEL (label_17)
  (Wrd9.Obj) = Rvl;
  goto label_25;

DEFLABEL (label_28)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_12]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_23_2]), 1);

DEFLABEL (label_16)
  (* (--Rsp)) = Rvl;
  goto label_27;

DEFLABEL (label_30)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_11]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_23_1]), 1);

DEFLABEL (label_15)
  (Wrd8.Obj) = Rvl;
  goto label_29;

DEFLABEL (lambda_22)
  CLOSURE_HEADER (LABEL_23_18);

DEFLABEL (lambda_6)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 1))
    goto label_32;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd11.Obj) = ((Wrd13.pObj) [0]);

DEFLABEL (label_31)
  (Rsp [2]) = (Wrd11.Obj);
  (Wrd20.Obj) = (* (Rsp++));
  (Rsp [2]) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_22]));

DEFLABEL (label_32)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_21]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_23_2]), 1);

DEFLABEL (label_19)
  (Wrd11.Obj) = Rvl;
  goto label_31;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_24_4 3
#define LABEL_24_5 5
#define LABEL_24_6 7
#define LABEL_24_8 9
#define LABEL_24_9 11
#define LABEL_24_7 13
#define LABEL_24_12 15
#define LABEL_24_10 17
#define LABEL_24_13 19
#define LABEL_24_14 21
#define LABEL_24_16 23
#define ENVIRONMENT_LABEL_24_3 33
#define DEBUGGING_LABEL_24_2 32
#define OBJECT_24_2 31
#define OBJECT_24_1 30
#define OBJECT_24_0 29
#define EXECUTE_CACHE_24_15 25
#define EXECUTE_CACHE_24_11 27
#define FREE_REFERENCES_LABEL_24_0 24
#define NUMBER_OF_LINKER_SECTIONS_24_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_24 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd17;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd10;
  machine_word Wrd12;
  machine_word Wrd41;
  machine_word Wrd39;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd24;
  machine_word Wrd26;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd7;
  machine_word Wrd9;
  machine_word Wrd8;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_24_4);
      goto normalize_let_bindings_13;

    case 1:
      current_block = (Rpc - LABEL_24_5);
      goto label_15;

    case 2:
      current_block = (Rpc - LABEL_24_6);
      goto label_16;

    case 3:
      current_block = (Rpc - LABEL_24_8);
      goto label_17;

    case 4:
      current_block = (Rpc - LABEL_24_9);
      goto label_18;

    case 5:
      current_block = (Rpc - LABEL_24_7);
      goto continuation_9;

    case 6:
      current_block = (Rpc - LABEL_24_12);
      goto label_19;

    case 7:
      current_block = (Rpc - LABEL_24_10);
      goto lambda_6;

    case 8:
      current_block = (Rpc - LABEL_24_13);
      goto label_20;

    case 9:
      current_block = (Rpc - LABEL_24_14);
      goto continuation_4;

    case 10:
      current_block = (Rpc - LABEL_24_16);
      goto label_21;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (normalize_let_bindings_23)
DEFLABEL (normalize_let_bindings_13)
  INTERRUPT_CHECK (26, LABEL_24_4);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_34;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_33)
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_32;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [1]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_31)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_7]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd27.Obj) = (Rsp [2]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd28.uLng) == 1))
    goto label_30;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd24.Obj) = ((Wrd26.pObj) [1]);

DEFLABEL (label_29)
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd35.uLng) == 1))
    goto label_28;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (* (--Rsp)) = (Wrd34.Obj);

DEFLABEL (label_27)
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_10]))));
  (* (--Rsp)) = (Wrd41.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_11]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_24_7);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_26;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [0]);

DEFLABEL (label_25)
  (Wrd19.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (Wrd22.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd22.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_26)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_12]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_24_1]), 1);

DEFLABEL (label_19)
  (Wrd10.Obj) = Rvl;
  goto label_25;

DEFLABEL (label_28)
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_9]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_24_1]), 1);

DEFLABEL (label_18)
  (* (--Rsp)) = Rvl;
  goto label_27;

DEFLABEL (label_30)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_8]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_24_0]), 1);

DEFLABEL (label_17)
  (Wrd24.Obj) = Rvl;
  goto label_29;

DEFLABEL (label_32)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_6]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_24_0]), 1);

DEFLABEL (label_16)
  (* (--Rsp)) = Rvl;
  goto label_31;

DEFLABEL (label_34)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_24_0]), 1);

DEFLABEL (label_15)
  (Wrd5.Obj) = Rvl;
  goto label_33;

DEFLABEL (lambda_24)
DEFLABEL (lambda_6)
  INTERRUPT_CHECK (26, LABEL_24_10);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_39;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_38)
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_35;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_35)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_14]))));
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_15]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_24_14);
  (Wrd9.Obj) = (current_block [OBJECT_24_2]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_37;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [0]);

DEFLABEL (label_36)
  (Wrd19.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (Wrd22.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd22.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_37)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_16]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_24_1]), 1);

DEFLABEL (label_21)
  (Wrd10.Obj) = Rvl;
  goto label_36;

DEFLABEL (label_39)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_13]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_24_0]), 1);

DEFLABEL (label_20)
  (Wrd5.Obj) = Rvl;
  goto label_38;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_25_4 3
#define LABEL_25_5 5
#define LABEL_25_7 7
#define LABEL_25_9 9
#define LABEL_25_10 11
#define LABEL_25_11 13
#define ENVIRONMENT_LABEL_25_3 26
#define DEBUGGING_LABEL_25_2 25
#define OBJECT_25_0 24
#define EXECUTE_CACHE_25_12 15
#define EXECUTE_CACHE_25_8 17
#define EXECUTE_CACHE_25_6 19
#define FREE_REFERENCE_25_1 22
#define FREE_REFERENCE_25_0 23
#define FREE_REFERENCES_LABEL_25_0 14
#define NUMBER_OF_LINKER_SECTIONS_25_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_25 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd17;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_25_4);
      goto lambda_5;

    case 1:
      current_block = (Rpc - LABEL_25_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_25_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_25_9);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_25_10);
      goto label_7;

    case 5:
      current_block = (Rpc - LABEL_25_11);
      goto label_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_10)
DEFLABEL (lambda_5)
  INTERRUPT_CHECK (26, LABEL_25_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_25_0]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_25_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_25_7);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_25_9);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Rsp [3]) = Rvl;
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_25_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_14;
  Wrd8 = Wrd12;

DEFLABEL (label_13)
  (Rsp [5]) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [4]);
  (Rsp [1]) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [6]);
  (Rsp [4]) = (Wrd15.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_25_1]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_12;
  Wrd17 = Wrd21;

DEFLABEL (label_11)
  (Rsp [6]) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_12]));

DEFLABEL (label_12)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_25_11])), (Wrd18.pObj));

DEFLABEL (label_8)
  (Wrd17.Obj) = Rvl;
  goto label_11;

DEFLABEL (label_14)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_25_10])), (Wrd9.pObj));

DEFLABEL (label_7)
  (Wrd8.Obj) = Rvl;
  goto label_13;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_26_4 3
#define ENVIRONMENT_LABEL_26_3 9
#define DEBUGGING_LABEL_26_2 8
#define OBJECT_26_0 7
#define EXECUTE_CACHE_26_5 5
#define FREE_REFERENCES_LABEL_26_0 4
#define NUMBER_OF_LINKER_SECTIONS_26_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_26 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_26_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_26_4);
  (Wrd5.Obj) = (current_block [OBJECT_26_0]);
  (Rsp [2]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_26_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_27_4 3
#define LABEL_27_5 5
#define LABEL_27_7 7
#define LABEL_27_9 9
#define LABEL_27_11 11
#define LABEL_27_12 13
#define LABEL_27_10 15
#define LABEL_27_15 17
#define LABEL_27_16 19
#define LABEL_27_13 21
#define LABEL_27_18 23
#define TAG_27_19 10
#define LABEL_27_21 25
#define ENVIRONMENT_LABEL_27_3 46
#define DEBUGGING_LABEL_27_2 45
#define OBJECT_27_2 44
#define OBJECT_27_1 43
#define OBJECT_27_0 42
#define EXECUTE_CACHE_27_22 27
#define EXECUTE_CACHE_27_20 29
#define EXECUTE_CACHE_27_17 31
#define EXECUTE_CACHE_27_14 33
#define EXECUTE_CACHE_27_8 35
#define EXECUTE_CACHE_27_6 37
#define FREE_REFERENCE_27_1 40
#define FREE_REFERENCE_27_0 41
#define FREE_REFERENCES_LABEL_27_0 26
#define NUMBER_OF_LINKER_SECTIONS_27_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_27 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_27_4);
      goto lambda_13;

    case 1:
      current_block = (Rpc - LABEL_27_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_27_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_27_9);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_27_11);
      goto label_15;

    case 5:
      current_block = (Rpc - LABEL_27_12);
      goto label_16;

    case 6:
      current_block = (Rpc - LABEL_27_10);
      goto continuation_10;

    case 7:
      current_block = (Rpc - LABEL_27_15);
      goto label_17;

    case 8:
      current_block = (Rpc - LABEL_27_16);
      goto label_18;

    case 9:
      current_block = (Rpc - LABEL_27_13);
      goto continuation_3;

    case 10:
      current_block = (Rpc - LABEL_27_18);
      goto lambda_22;

    case 11:
      current_block = (Rpc - LABEL_27_21);
      goto label_19;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_21)
DEFLABEL (lambda_13)
  INTERRUPT_CHECK (26, LABEL_27_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_27_0]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_27_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_27_7);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_27_9);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_30;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd8.Obj) = ((Wrd10.pObj) [1]);

DEFLABEL (label_29)
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd19.uLng) == 1))
    goto label_28;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_27)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_13]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd27.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_14]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_27_13);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_27_19);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_27_18])));
  Rhp += 2;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  Wrd11 = Wrd8;
  (Wrd12.Obj) = (Rsp [4]);
  ((Wrd11.pObj) [2]) = (Wrd12.Obj);
  ((Wrd11.pObj) [3]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_20]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_27_10);
  (Wrd5.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (Rsp [3]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [6]);
  (Rsp [4]) = (Wrd7.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_27_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_26;
  Wrd9 = Wrd13;

DEFLABEL (label_25)
  (Rsp [5]) = (Wrd9.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd15.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_27_1]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_24;
  Wrd17 = Wrd21;

DEFLABEL (label_23)
  (Rsp [6]) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_17]));

DEFLABEL (label_24)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_27_16])), (Wrd18.pObj));

DEFLABEL (label_18)
  (Wrd17.Obj) = Rvl;
  goto label_23;

DEFLABEL (label_26)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_27_15])), (Wrd10.pObj));

DEFLABEL (label_17)
  (Wrd9.Obj) = Rvl;
  goto label_25;

DEFLABEL (label_28)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_12]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_27_2]), 1);

DEFLABEL (label_16)
  (* (--Rsp)) = Rvl;
  goto label_27;

DEFLABEL (label_30)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_11]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_27_1]), 1);

DEFLABEL (label_15)
  (Wrd8.Obj) = Rvl;
  goto label_29;

DEFLABEL (lambda_22)
  CLOSURE_HEADER (LABEL_27_18);

DEFLABEL (lambda_6)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 1))
    goto label_32;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd11.Obj) = ((Wrd13.pObj) [0]);

DEFLABEL (label_31)
  (Rsp [2]) = (Wrd11.Obj);
  (Wrd20.Obj) = (* (Rsp++));
  (Rsp [2]) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_22]));

DEFLABEL (label_32)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_21]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_27_2]), 1);

DEFLABEL (label_19)
  (Wrd11.Obj) = Rvl;
  goto label_31;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_28_4 3
#define LABEL_28_6 5
#define LABEL_28_9 7
#define LABEL_28_10 9
#define LABEL_28_11 11
#define LABEL_28_5 13
#define LABEL_28_16 15
#define LABEL_28_17 17
#define LABEL_28_18 19
#define LABEL_28_7 21
#define LABEL_28_8 23
#define LABEL_28_21 25
#define LABEL_28_22 27
#define LABEL_28_12 29
#define TAG_28_13 13
#define LABEL_28_26 31
#define LABEL_28_27 33
#define LABEL_28_15 35
#define LABEL_28_30 37
#define LABEL_28_23 39
#define TAG_28_24 18
#define LABEL_28_34 41
#define LABEL_28_28 43
#define LABEL_28_31 45
#define TAG_28_32 21
#define LABEL_28_36 47
#define LABEL_28_40 49
#define LABEL_28_37 51
#define LABEL_28_39 53
#define LABEL_28_41 55
#define LABEL_28_43 57
#define ENVIRONMENT_LABEL_28_3 90
#define DEBUGGING_LABEL_28_2 89
#define OBJECT_28_1 88
#define OBJECT_28_0 87
#define EXECUTE_CACHE_28_45 59
#define EXECUTE_CACHE_28_44 61
#define EXECUTE_CACHE_28_42 63
#define EXECUTE_CACHE_28_35 65
#define EXECUTE_CACHE_28_33 67
#define EXECUTE_CACHE_28_29 69
#define EXECUTE_CACHE_28_38 71
#define EXECUTE_CACHE_28_25 73
#define EXECUTE_CACHE_28_20 75
#define EXECUTE_CACHE_28_19 77
#define EXECUTE_CACHE_28_14 79
#define FREE_REFERENCE_28_4 82
#define FREE_REFERENCE_28_3 83
#define FREE_REFERENCE_28_2 84
#define FREE_REFERENCE_28_1 85
#define FREE_REFERENCE_28_0 86
#define FREE_REFERENCES_LABEL_28_0 58
#define NUMBER_OF_LINKER_SECTIONS_28_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_28 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd5;
  machine_word Wrd32;
  machine_word Wrd27;
  machine_word Wrd17;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd45;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd42;
  machine_word Wrd43;
  machine_word Wrd41;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd26;
  machine_word Wrd28;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd20;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_28_4);
      goto classify_let_like_25;

    case 1:
      current_block = (Rpc - LABEL_28_6);
      goto label_27;

    case 2:
      current_block = (Rpc - LABEL_28_9);
      goto label_28;

    case 3:
      current_block = (Rpc - LABEL_28_10);
      goto label_29;

    case 4:
      current_block = (Rpc - LABEL_28_11);
      goto label_30;

    case 5:
      current_block = (Rpc - LABEL_28_5);
      goto continuation_12;

    case 6:
      current_block = (Rpc - LABEL_28_16);
      goto label_31;

    case 7:
      current_block = (Rpc - LABEL_28_17);
      goto label_32;

    case 8:
      current_block = (Rpc - LABEL_28_18);
      goto label_33;

    case 9:
      current_block = (Rpc - LABEL_28_7);
      goto continuation_11;

    case 10:
      current_block = (Rpc - LABEL_28_8);
      goto continuation_10;

    case 11:
      current_block = (Rpc - LABEL_28_21);
      goto label_34;

    case 12:
      current_block = (Rpc - LABEL_28_22);
      goto label_35;

    case 13:
      current_block = (Rpc - LABEL_28_12);
      goto lambda_43;

    case 14:
      current_block = (Rpc - LABEL_28_26);
      goto label_36;

    case 15:
      current_block = (Rpc - LABEL_28_27);
      goto label_37;

    case 16:
      current_block = (Rpc - LABEL_28_15);
      goto continuation_15;

    case 17:
      current_block = (Rpc - LABEL_28_30);
      goto label_38;

    case 18:
      current_block = (Rpc - LABEL_28_23);
      goto lambda_44;

    case 19:
      current_block = (Rpc - LABEL_28_34);
      goto label_39;

    case 20:
      current_block = (Rpc - LABEL_28_28);
      goto continuation_6;

    case 21:
      current_block = (Rpc - LABEL_28_31);
      goto lambda_45;

    case 22:
      current_block = (Rpc - LABEL_28_36);
      goto continuation_20;

    case 23:
      current_block = (Rpc - LABEL_28_40);
      goto label_40;

    case 24:
      current_block = (Rpc - LABEL_28_37);
      goto lambda_19;

    case 25:
      current_block = (Rpc - LABEL_28_39);
      goto continuation_17;

    case 26:
      current_block = (Rpc - LABEL_28_41);
      goto continuation_18;

    case 27:
      current_block = (Rpc - LABEL_28_43);
      goto continuation_21;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (classify_let_like_42)
DEFLABEL (classify_let_like_25)
  INTERRUPT_CHECK (26, LABEL_28_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_28_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_67;
  Wrd8 = Wrd12;

DEFLABEL (label_66)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_7]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_8]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_28_1]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_65;
  Wrd20 = Wrd24;

DEFLABEL (label_64)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd29.Obj) = (Rsp [5]);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if (! ((Wrd30.uLng) == 1))
    goto label_63;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd26.Obj) = ((Wrd28.pObj) [1]);

DEFLABEL (label_62)
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd37.uLng) == 1))
    goto label_61;
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd36.Obj) = ((Wrd35.pObj) [0]);
  (* (--Rsp)) = (Wrd36.Obj);

DEFLABEL (label_60)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd43.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_28_13);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_28_12])));
  Rhp += 2;
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd43.pObj)));
  Wrd46 = Wrd43;
  (Wrd47.Obj) = (Rsp [10]);
  ((Wrd46.pObj) [2]) = (Wrd47.Obj);
  (Wrd45.Obj) = (Rsp [7]);
  ((Wrd46.pObj) [3]) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_28_14]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_28_8);
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (Rsp [4]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_59;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_58)
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_57;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_56)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd22.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_28_24);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_28_23])));
  Rhp += 3;
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd22.pObj)));
  Wrd27 = Wrd22;
  (Wrd28.Obj) = (Rsp [10]);
  ((Wrd27.pObj) [2]) = (Wrd28.Obj);
  (Wrd26.Obj) = (Rsp [9]);
  ((Wrd27.pObj) [3]) = (Wrd26.Obj);
  (Wrd24.Obj) = (Rsp [7]);
  ((Wrd27.pObj) [4]) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_28_25]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_28_7);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_28_20]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_28_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_15]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_28_2]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_55;
  Wrd8 = Wrd12;

DEFLABEL (label_54)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd20.Obj) = (Rsp [6]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 1))
    goto label_53;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [1]);

DEFLABEL (label_52)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd28.uLng) == 1))
    goto label_51;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [1]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_50)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_28_19]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_28_15);
  (* (--Rsp)) = Rvl;
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_28_3]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_49;
  Wrd6 = Wrd10;

DEFLABEL (label_48)
  (Wrd12.Obj) = (Rsp [7]);
  if ((Wrd12.Obj) == (Wrd6.Obj))
    goto label_47;
  (Wrd13.Obj) = (Rsp [6]);
  (Rsp [7]) = (Wrd13.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd16.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_28_32);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_28_31])));
  Rhp += 3;
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd16.pObj)));
  Wrd21 = Wrd16;
  (Wrd22.Obj) = (Rsp [8]);
  ((Wrd21.pObj) [2]) = (Wrd22.Obj);
  (Wrd20.Obj) = (Rsp [1]);
  ((Wrd21.pObj) [3]) = (Wrd20.Obj);
  (Wrd18.Obj) = (Rsp [0]);
  ((Wrd21.pObj) [4]) = (Wrd18.Obj);
  (Rsp [8]) = (Wrd15.Obj);
  Rsp = (& (Rsp [7]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_28_33]));

DEFLABEL (label_47)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [9]));
  goto pop_return;

DEFLABEL (label_49)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_28_30])), (Wrd7.pObj));

DEFLABEL (label_38)
  (Wrd6.Obj) = Rvl;
  goto label_48;

DEFLABEL (label_51)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_18]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_28_0]), 1);

DEFLABEL (label_33)
  (* (--Rsp)) = Rvl;
  goto label_50;

DEFLABEL (label_53)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_17]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_28_0]), 1);

DEFLABEL (label_32)
  (Wrd17.Obj) = Rvl;
  goto label_52;

DEFLABEL (label_55)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_28_16])), (Wrd9.pObj));

DEFLABEL (label_31)
  (Wrd8.Obj) = Rvl;
  goto label_54;

DEFLABEL (label_57)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_22]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_28_1]), 1);

DEFLABEL (label_35)
  (* (--Rsp)) = Rvl;
  goto label_56;

DEFLABEL (label_59)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_21]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_28_0]), 1);

DEFLABEL (label_34)
  (Wrd5.Obj) = Rvl;
  goto label_58;

DEFLABEL (label_61)
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_11]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_28_1]), 1);

DEFLABEL (label_30)
  (* (--Rsp)) = Rvl;
  goto label_60;

DEFLABEL (label_63)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_10]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_28_0]), 1);

DEFLABEL (label_29)
  (Wrd26.Obj) = Rvl;
  goto label_62;

DEFLABEL (label_65)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_28_9])), (Wrd21.pObj));

DEFLABEL (label_28)
  (Wrd20.Obj) = Rvl;
  goto label_64;

DEFLABEL (label_67)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_28_6])), (Wrd9.pObj));

DEFLABEL (label_27)
  (Wrd8.Obj) = Rvl;
  goto label_66;

DEFLABEL (lambda_43)
  CLOSURE_HEADER (LABEL_28_12);

DEFLABEL (lambda_7)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_71;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_70)
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_69;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_68)
  (Wrd22.Obj) = (Rsp [1]);
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd21.Obj) = ((Wrd23.pObj) [2]);
  (Rsp [2]) = (Wrd21.Obj);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_28]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd27.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_28_29]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_28_28);
  (Rsp [3]) = Rvl;
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [3]);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_28_35]));

DEFLABEL (label_69)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_27]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_28_1]), 1);

DEFLABEL (label_37)
  (* (--Rsp)) = Rvl;
  goto label_68;

DEFLABEL (label_71)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_26]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_28_0]), 1);

DEFLABEL (label_36)
  (Wrd5.Obj) = Rvl;
  goto label_70;

DEFLABEL (lambda_44)
  CLOSURE_HEADER (LABEL_28_23);

DEFLABEL (lambda_1)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 1))
    goto label_73;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd11.Obj) = ((Wrd13.pObj) [0]);

DEFLABEL (label_72)
  (Wrd20.Obj) = (Rsp [4]);
  (Rsp [3]) = (Wrd20.Obj);
  (Wrd22.Obj) = (Rsp [2]);
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd21.Obj) = ((Wrd23.pObj) [3]);
  (Rsp [4]) = (Wrd21.Obj);
  (Rsp [2]) = (Wrd11.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 5);
  }

DEFLABEL (label_73)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_34]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_28_1]), 1);

DEFLABEL (label_39)
  (Wrd11.Obj) = Rvl;
  goto label_72;

DEFLABEL (lambda_45)
  CLOSURE_HEADER (LABEL_28_31);

DEFLABEL (lambda_22)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_36]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_37]))));
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_28_38]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_28_36);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_39]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_28_4]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_75;
  Wrd11 = Wrd15;

DEFLABEL (label_74)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_28_38]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_28_39);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [2]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_43]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_28_44]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_28_43);
  (Rsp [3]) = Rvl;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_75)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_28_40])), (Wrd12.pObj));

DEFLABEL (label_40)
  (Wrd11.Obj) = Rvl;
  goto label_74;

DEFLABEL (lambda_46)
DEFLABEL (lambda_19)
  INTERRUPT_CHECK (26, LABEL_28_37);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_41]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_28_42]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_28_41);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_28_45]));

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_29_4 3
#define LABEL_29_5 5
#define TAG_29_6 1
#define LABEL_29_8 7
#define LABEL_29_10 9
#define LABEL_29_11 11
#define LABEL_29_12 13
#define LABEL_29_13 15
#define LABEL_29_14 17
#define LABEL_29_15 19
#define LABEL_29_16 21
#define LABEL_29_18 23
#define LABEL_29_17 25
#define LABEL_29_19 27
#define ENVIRONMENT_LABEL_29_3 38
#define DEBUGGING_LABEL_29_2 37
#define OBJECT_29_3 36
#define OBJECT_29_2 35
#define OBJECT_29_1 34
#define OBJECT_29_0 33
#define EXECUTE_CACHE_29_9 29
#define EXECUTE_CACHE_29_7 31
#define FREE_REFERENCES_LABEL_29_0 28
#define NUMBER_OF_LINKER_SECTIONS_29_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_29 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd34;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd46;
  machine_word Wrd53;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd40;
  machine_word Wrd38;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd37;
  machine_word Wrd39;
  machine_word Wrd41;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd23;
  machine_word Wrd14;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_29_4);
      goto expand_let__22;

    case 1:
      current_block = (Rpc - LABEL_29_5);
      goto lambda_33;

    case 2:
      current_block = (Rpc - LABEL_29_8);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_29_10);
      goto label_24;

    case 4:
      current_block = (Rpc - LABEL_29_11);
      goto label_25;

    case 5:
      current_block = (Rpc - LABEL_29_12);
      goto continuation_5;

    case 6:
      current_block = (Rpc - LABEL_29_13);
      goto label_26;

    case 7:
      current_block = (Rpc - LABEL_29_14);
      goto label_27;

    case 8:
      current_block = (Rpc - LABEL_29_15);
      goto loop_18;

    case 9:
      current_block = (Rpc - LABEL_29_16);
      goto label_28;

    case 10:
      current_block = (Rpc - LABEL_29_18);
      goto label_29;

    case 11:
      current_block = (Rpc - LABEL_29_17);
      goto continuation_15;

    case 12:
      current_block = (Rpc - LABEL_29_19);
      goto label_30;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expand_let__32)
DEFLABEL (expand_let__22)
  INTERRUPT_CHECK (26, LABEL_29_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_29_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_29_5])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd12 = Wrd7;
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd12.pObj) [4]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_29_7]));

DEFLABEL (lambda_33)
  CLOSURE_HEADER (LABEL_29_5);

DEFLABEL (lambda_21)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_29_0]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_29_9]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_29_8);
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [4]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_43;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd5.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_42)
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_41;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (* (--Rsp)) = (Wrd21.Obj);

DEFLABEL (label_40)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_12]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (Rsp [2]);
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [2]);
  (* (--Rsp)) = (Wrd32.Obj);
  (Wrd35.Obj) = ((Wrd31.pObj) [3]);
  (* (--Rsp)) = (Wrd35.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_29_12);
  (Rsp [2]) = Rvl;
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [4]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_39;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd6.Obj) = ((Wrd10.pObj) [1]);

DEFLABEL (label_38)
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if (! ((Wrd23.uLng) == 1))
    goto label_37;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd21.Obj) = ((Wrd22.pObj) [1]);

DEFLABEL (label_36)
  (Rsp [1]) = (Wrd21.Obj);
  (Wrd28.Obj) = (Rsp [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 1)
    goto label_35;
  (* (Rhp++)) = (Wrd28.Obj);
  (* (Rhp++)) = (Wrd21.Obj);
  (Wrd32.pObj) = (& (Rhp [-2]));
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd32.pObj)));
  (Wrd39.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd39.Obj);
  (* (Rhp++)) = (Wrd30.Obj);
  (Wrd37.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd37.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_35)
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  Rdl = (& (Rsp [5]));
  goto loop_18;

DEFLABEL (label_37)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_14]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_29_1]), 1);

DEFLABEL (label_27)
  (Wrd21.Obj) = Rvl;
  goto label_36;

DEFLABEL (label_39)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_13]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_29_1]), 1);

DEFLABEL (label_26)
  (Wrd6.Obj) = Rvl;
  goto label_38;

DEFLABEL (label_41)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_11]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_29_2]), 1);

DEFLABEL (label_25)
  (* (--Rsp)) = Rvl;
  goto label_40;

DEFLABEL (label_43)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_10]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_29_1]), 1);

DEFLABEL (label_24)
  (Wrd5.Obj) = Rvl;
  goto label_42;

DEFLABEL (loop_34)
DEFLABEL (loop_18)
  DLINK_INTERRUPT_CHECK (25, LABEL_29_15);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_50;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_49)
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 1)
    goto label_44;
  (Wrd22.Obj) = (Rsp [0]);
  (Wrd23.Obj) = (Rsp [1]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [1]);
  (* (Rhp++)) = (Wrd22.Obj);
  (* (Rhp++)) = (Wrd25.Obj);
  (Wrd21.pObj) = (& (Rhp [-2]));
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd21.pObj)));
  (Wrd31.Obj) = ((Wrd24.pObj) [2]);
  (* (Rhp++)) = (Wrd31.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (Wrd27.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd27.pObj)));
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_44)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_17]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd37.Obj) = (Rsp [3]);
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd38.pObj)));
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd44.Obj) = (Rsp [3]);
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if (! ((Wrd45.uLng) == 1))
    goto label_48;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd43.Obj) = ((Wrd42.pObj) [1]);
  (* (--Rsp)) = (Wrd43.Obj);

DEFLABEL (label_47)
  Rdl = (& (Rsp [2]));
  goto loop_18;

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_29_17);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd11.Obj) = (current_block [OBJECT_29_3]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd15.Obj) = (Rsp [1]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_46;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd12.Obj) = ((Wrd14.pObj) [0]);

DEFLABEL (label_45)
  (Wrd28.Obj) = (current_block [OBJECT_29_3]);
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = (Wrd28.Obj);
  (Wrd27.pObj) = (& (Rhp [-2]));
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd27.pObj)));
  (Wrd29.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd25.Obj);
  (* (Rhp++)) = (Wrd29.Obj);
  (Wrd32.pObj) = (& (Rhp [-2]));
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd32.pObj)));
  (Wrd36.Obj) = (Rsp [1]);
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd38.Obj) = ((Wrd37.pObj) [2]);
  (* (Rhp++)) = (Wrd38.Obj);
  (* (Rhp++)) = (Wrd30.Obj);
  (Wrd34.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd34.pObj)));
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_46)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_19]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_29_2]), 1);

DEFLABEL (label_30)
  (Wrd17.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd12.Obj) = Rvl;
  goto label_45;

DEFLABEL (label_48)
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_18]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_29_1]), 1);

DEFLABEL (label_29)
  (Wrd46.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd46.Obj));
  (* (--Rsp)) = Rvl;
  goto label_47;

DEFLABEL (label_50)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_16]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_29_1]), 1);

DEFLABEL (label_28)
  (Wrd10.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd5.Obj) = Rvl;
  goto label_49;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_30_4 3
#define LABEL_30_5 5
#define LABEL_30_6 7
#define LABEL_30_8 9
#define TAG_30_9 3
#define LABEL_30_12 11
#define LABEL_30_11 13
#define LABEL_30_14 15
#define ENVIRONMENT_LABEL_30_3 30
#define DEBUGGING_LABEL_30_2 29
#define EXECUTE_CACHE_30_16 17
#define EXECUTE_CACHE_30_15 19
#define EXECUTE_CACHE_30_13 21
#define EXECUTE_CACHE_30_10 23
#define EXECUTE_CACHE_30_7 25
#define FREE_REFERENCE_30_0 28
#define FREE_REFERENCES_LABEL_30_0 16
#define NUMBER_OF_LINKER_SECTIONS_30_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_30 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_30_4);
      goto compile_body_item_5;

    case 1:
      current_block = (Rpc - LABEL_30_5);
      goto continuation_4;

    case 2:
      current_block = (Rpc - LABEL_30_6);
      goto continuation_3;

    case 3:
      current_block = (Rpc - LABEL_30_8);
      goto lambda_10;

    case 4:
      current_block = (Rpc - LABEL_30_12);
      goto label_7;

    case 5:
      current_block = (Rpc - LABEL_30_11);
      goto continuation_0;

    case 6:
      current_block = (Rpc - LABEL_30_14);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (compile_body_item_9)
DEFLABEL (compile_body_item_5)
  INTERRUPT_CHECK (26, LABEL_30_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_7]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_30_6);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_10]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_30_5);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_30_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_30_8])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (lambda_10)
  CLOSURE_HEADER (LABEL_30_8);

DEFLABEL (lambda_2)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_11]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_30_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_12;
  Wrd9 = Wrd13;

DEFLABEL (label_11)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_13]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_30_11);
  (Rsp [1]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_14]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_15]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_30_14);
  (Rsp [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_16]));

DEFLABEL (label_12)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_30_12])), (Wrd10.pObj));

DEFLABEL (label_7)
  (Wrd9.Obj) = Rvl;
  goto label_11;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_31_4 3
#define LABEL_31_5 5
#define TAG_31_6 1
#define LABEL_31_8 7
#define LABEL_31_10 9
#define LABEL_31_11 11
#define LABEL_31_12 13
#define LABEL_31_13 15
#define LABEL_31_15 17
#define LABEL_31_14 19
#define LABEL_31_16 21
#define ENVIRONMENT_LABEL_31_3 34
#define DEBUGGING_LABEL_31_2 33
#define OBJECT_31_5 32
#define OBJECT_31_4 31
#define OBJECT_31_3 30
#define OBJECT_31_2 29
#define OBJECT_31_1 28
#define OBJECT_31_0 27
#define EXECUTE_CACHE_31_9 23
#define EXECUTE_CACHE_31_7 25
#define FREE_REFERENCES_LABEL_31_0 22
#define NUMBER_OF_LINKER_SECTIONS_31_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_31 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd22;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd40;
  machine_word Wrd47;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd34;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd5;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_31_4);
      goto lambda_18;

    case 1:
      current_block = (Rpc - LABEL_31_5);
      goto lambda_26;

    case 2:
      current_block = (Rpc - LABEL_31_8);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_31_10);
      goto label_20;

    case 4:
      current_block = (Rpc - LABEL_31_11);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_31_12);
      goto loop_13;

    case 6:
      current_block = (Rpc - LABEL_31_13);
      goto label_21;

    case 7:
      current_block = (Rpc - LABEL_31_15);
      goto label_22;

    case 8:
      current_block = (Rpc - LABEL_31_14);
      goto continuation_9;

    case 9:
      current_block = (Rpc - LABEL_31_16);
      goto label_23;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_25)
DEFLABEL (lambda_18)
  INTERRUPT_CHECK (26, LABEL_31_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_31_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_31_5])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_7]));

DEFLABEL (lambda_26)
  CLOSURE_HEADER (LABEL_31_5);

DEFLABEL (lambda_17)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_31_0]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_9]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_31_8);
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [3]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_30;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [1]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_29)
  (Wrd20.Obj) = (Rsp [0]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd21.uLng) == 1)
    goto label_28;
  Rvl = (current_block [OBJECT_31_3]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_28)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_11]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_31_2]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd28.Obj) = (Rsp [3]);
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [2]);
  (* (--Rsp)) = (Wrd30.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_31_11);
  (* (--Rsp)) = Rvl;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  Rdl = (& (Rsp [6]));
  goto loop_13;

DEFLABEL (label_30)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_10]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31_1]), 1);

DEFLABEL (label_20)
  (* (--Rsp)) = Rvl;
  goto label_29;

DEFLABEL (loop_27)
DEFLABEL (loop_13)
  DLINK_INTERRUPT_CHECK (25, LABEL_31_12);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_38;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_37)
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 1)
    goto label_32;
  (Wrd19.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  (Wrd24.Obj) = (Rsp [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd25.uLng) == 1))
    goto label_31;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  Rvl = ((Wrd22.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_31)
  INVOKE_PRIMITIVE ((current_block [OBJECT_31_4]), 1);

DEFLABEL (label_32)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_14]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd31.Obj) = (Rsp [3]);
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd32.pObj)));
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd38.Obj) = (Rsp [3]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if (! ((Wrd39.uLng) == 1))
    goto label_36;
  (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd37.Obj) = ((Wrd36.pObj) [1]);
  (* (--Rsp)) = (Wrd37.Obj);

DEFLABEL (label_35)
  Rdl = (& (Rsp [2]));
  goto loop_13;

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_31_14);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd11.Obj) = (current_block [OBJECT_31_5]);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd7.Obj);
  (Wrd14.pObj) = (& (Rhp [-2]));
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd14.pObj)));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_34;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [0]);

DEFLABEL (label_33)
  (Wrd29.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd29.Obj);
  (Wrd32.pObj) = (& (Rhp [-2]));
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd32.pObj)));
  (Wrd36.Obj) = (Rsp [1]);
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd38.Obj) = ((Wrd37.pObj) [0]);
  (* (Rhp++)) = (Wrd38.Obj);
  (* (Rhp++)) = (Wrd30.Obj);
  (Wrd34.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd34.pObj)));
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_34)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_16]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31_4]), 1);

DEFLABEL (label_23)
  (Wrd21.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd16.Obj) = Rvl;
  goto label_33;

DEFLABEL (label_36)
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_15]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31_1]), 1);

DEFLABEL (label_22)
  (Wrd40.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd40.Obj));
  (* (--Rsp)) = Rvl;
  goto label_35;

DEFLABEL (label_38)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_13]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31_1]), 1);

DEFLABEL (label_21)
  (Wrd10.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd5.Obj) = Rvl;
  goto label_37;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_32_4 3
#define LABEL_32_5 5
#define LABEL_32_7 7
#define LABEL_32_8 9
#define LABEL_32_9 11
#define LABEL_32_10 13
#define LABEL_32_11 15
#define LABEL_32_14 17
#define LABEL_32_12 19
#define LABEL_32_18 21
#define LABEL_32_15 23
#define LABEL_32_16 25
#define LABEL_32_21 27
#define ENVIRONMENT_LABEL_32_3 45
#define DEBUGGING_LABEL_32_2 44
#define OBJECT_32_2 43
#define OBJECT_32_1 42
#define OBJECT_32_0 41
#define EXECUTE_CACHE_32_20 29
#define EXECUTE_CACHE_32_19 31
#define EXECUTE_CACHE_32_17 33
#define EXECUTE_CACHE_32_13 35
#define EXECUTE_CACHE_32_6 37
#define FREE_REFERENCE_32_0 40
#define FREE_REFERENCES_LABEL_32_0 28
#define NUMBER_OF_LINKER_SECTIONS_32_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_32 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd25;
  machine_word Wrd21;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd30;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd6;
  machine_word Wrd33;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd19;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd18;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_32_4);
      goto lambda_16;

    case 1:
      current_block = (Rpc - LABEL_32_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_32_7);
      goto label_18;

    case 3:
      current_block = (Rpc - LABEL_32_8);
      goto label_19;

    case 4:
      current_block = (Rpc - LABEL_32_9);
      goto label_20;

    case 5:
      current_block = (Rpc - LABEL_32_10);
      goto loop_14;

    case 6:
      current_block = (Rpc - LABEL_32_11);
      goto continuation_7;

    case 7:
      current_block = (Rpc - LABEL_32_14);
      goto label_21;

    case 8:
      current_block = (Rpc - LABEL_32_12);
      goto continuation_6;

    case 9:
      current_block = (Rpc - LABEL_32_18);
      goto label_22;

    case 10:
      current_block = (Rpc - LABEL_32_15);
      goto continuation_12;

    case 11:
      current_block = (Rpc - LABEL_32_16);
      goto continuation_11;

    case 12:
      current_block = (Rpc - LABEL_32_21);
      goto label_23;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_25)
DEFLABEL (lambda_16)
  INTERRUPT_CHECK (26, LABEL_32_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_32_0]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_32_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_32_5);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_33;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_32)
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd14.uLng) == 1)
    goto label_27;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_27)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_32_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_31;
  Wrd19 = Wrd23;

DEFLABEL (label_30)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd28.Obj) = (Rsp [2]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if (! ((Wrd29.uLng) == 1))
    goto label_29;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [1]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_28)
  Rdl = (& (Rsp [6]));
  goto loop_14;

DEFLABEL (label_29)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32_9]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_32_1]), 1);

DEFLABEL (label_20)
  (* (--Rsp)) = Rvl;
  goto label_28;

DEFLABEL (label_31)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_32_8])), (Wrd20.pObj));

DEFLABEL (label_19)
  (Wrd19.Obj) = Rvl;
  goto label_30;

DEFLABEL (label_33)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32_7]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_32_1]), 1);

DEFLABEL (label_18)
  (Wrd5.Obj) = Rvl;
  goto label_32;

DEFLABEL (loop_26)
DEFLABEL (loop_14)
  DLINK_INTERRUPT_CHECK (25, LABEL_32_10);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32_11]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32_12]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_32_13]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_32_12);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [5]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = ((Wrd8.pObj) [1]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd16.Obj) = (Rsp [5]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 1))
    goto label_40;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_39)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_32_19]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_32_11);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_38;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_37)
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd20.uLng) == 1)
    goto label_34;
  Rvl = (Rsp [0]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_34)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32_15]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (Rsp [5]);
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd28.pObj)));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32_16]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd36.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd36.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_32_17]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_32_16);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd10.Obj) = (Rsp [5]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_36;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [1]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_35)
  Rdl = (& (Rsp [3]));
  goto loop_14;

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_32_15);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_32_20]));

DEFLABEL (label_36)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32_21]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_32_1]), 1);

DEFLABEL (label_23)
  (Wrd12.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd12.Obj));
  (* (--Rsp)) = Rvl;
  goto label_35;

DEFLABEL (label_38)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32_14]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_32_1]), 1);

DEFLABEL (label_21)
  (Wrd12.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd7.Obj) = Rvl;
  goto label_37;

DEFLABEL (label_40)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32_18]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_32_2]), 1);

DEFLABEL (label_22)
  (Wrd18.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd18.Obj));
  (* (--Rsp)) = Rvl;
  goto label_39;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_33_4 3
#define LABEL_33_5 5
#define TAG_33_6 1
#define LABEL_33_8 7
#define LABEL_33_10 9
#define TAG_33_11 3
#define LABEL_33_14 11
#define LABEL_33_15 13
#define LABEL_33_16 15
#define LABEL_33_17 17
#define LABEL_33_18 19
#define LABEL_33_19 21
#define LABEL_33_13 23
#define LABEL_33_20 25
#define LABEL_33_21 27
#define LABEL_33_23 29
#define LABEL_33_24 31
#define LABEL_33_26 33
#define LABEL_33_22 35
#define LABEL_33_29 37
#define LABEL_33_30 39
#define LABEL_33_25 41
#define LABEL_33_33 43
#define LABEL_33_35 45
#define LABEL_33_37 47
#define LABEL_33_38 49
#define LABEL_33_39 51
#define LABEL_33_28 53
#define LABEL_33_36 55
#define LABEL_33_32 57
#define LABEL_33_31 59
#define LABEL_33_41 61
#define LABEL_33_42 63
#define LABEL_33_43 65
#define LABEL_33_45 67
#define LABEL_33_46 69
#define LABEL_33_47 71
#define LABEL_33_48 73
#define LABEL_33_49 75
#define LABEL_33_51 77
#define LABEL_33_52 79
#define LABEL_33_53 81
#define LABEL_33_54 83
#define LABEL_33_55 85
#define LABEL_33_57 87
#define LABEL_33_58 89
#define LABEL_33_59 91
#define LABEL_33_60 93
#define LABEL_33_61 95
#define LABEL_33_62 97
#define LABEL_33_63 99
#define LABEL_33_65 101
#define LABEL_33_66 103
#define LABEL_33_67 105
#define LABEL_33_68 107
#define LABEL_33_70 109
#define LABEL_33_71 111
#define LABEL_33_72 113
#define LABEL_33_73 115
#define LABEL_33_44 117
#define LABEL_33_69 119
#define LABEL_33_64 121
#define LABEL_33_79 123
#define LABEL_33_80 125
#define LABEL_33_81 127
#define LABEL_33_82 129
#define LABEL_33_56 131
#define LABEL_33_85 133
#define LABEL_33_86 135
#define LABEL_33_50 137
#define LABEL_33_88 139
#define LABEL_33_74 141
#define LABEL_33_75 143
#define LABEL_33_89 145
#define LABEL_33_76 147
#define LABEL_33_90 149
#define LABEL_33_78 151
#define LABEL_33_94 153
#define LABEL_33_95 155
#define LABEL_33_83 157
#define LABEL_33_84 159
#define LABEL_33_99 161
#define LABEL_33_87 163
#define LABEL_33_91 165
#define LABEL_33_93 167
#define LABEL_33_101 169
#define LABEL_33_96 171
#define LABEL_33_97 173
#define LABEL_33_98 175
#define LABEL_33_100 177
#define ENVIRONMENT_LABEL_33_3 217
#define DEBUGGING_LABEL_33_2 216
#define OBJECT_33_20 215
#define OBJECT_33_19 214
#define OBJECT_33_18 213
#define OBJECT_33_17 212
#define OBJECT_33_16 211
#define OBJECT_33_15 210
#define OBJECT_33_14 209
#define OBJECT_33_13 208
#define OBJECT_33_12 207
#define OBJECT_33_11 206
#define OBJECT_33_10 205
#define OBJECT_33_9 204
#define OBJECT_33_8 203
#define OBJECT_33_7 202
#define OBJECT_33_6 201
#define OBJECT_33_5 200
#define OBJECT_33_4 199
#define OBJECT_33_3 198
#define OBJECT_33_2 197
#define OBJECT_33_1 196
#define OBJECT_33_0 195
#define EXECUTE_CACHE_33_92 179
#define EXECUTE_CACHE_33_77 181
#define EXECUTE_CACHE_33_40 183
#define EXECUTE_CACHE_33_34 185
#define EXECUTE_CACHE_33_27 187
#define EXECUTE_CACHE_33_12 189
#define EXECUTE_CACHE_33_9 191
#define EXECUTE_CACHE_33_7 193
#define FREE_REFERENCES_LABEL_33_0 178
#define NUMBER_OF_LINKER_SECTIONS_33_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_33 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd37;
  machine_word Wrd116;
  machine_word Wrd115;
  machine_word Wrd114;
  machine_word Wrd113;
  machine_word Wrd112;
  machine_word Wrd111;
  machine_word Wrd110;
  machine_word Wrd153;
  machine_word Wrd148;
  machine_word Wrd147;
  machine_word Wrd149;
  machine_word Wrd146;
  machine_word Wrd140;
  machine_word Wrd141;
  machine_word Wrd142;
  machine_word Wrd139;
  machine_word Wrd133;
  machine_word Wrd134;
  machine_word Wrd135;
  machine_word Wrd132;
  machine_word Wrd124;
  machine_word Wrd126;
  machine_word Wrd128;
  machine_word Wrd127;
  machine_word Wrd123;
  machine_word Wrd121;
  machine_word Wrd120;
  machine_word Wrd119;
  machine_word Wrd106;
  machine_word Wrd100;
  machine_word Wrd101;
  machine_word Wrd102;
  machine_word Wrd99;
  machine_word Wrd93;
  machine_word Wrd94;
  machine_word Wrd95;
  machine_word Wrd92;
  machine_word Wrd86;
  machine_word Wrd87;
  machine_word Wrd88;
  machine_word Wrd85;
  machine_word Wrd77;
  machine_word Wrd79;
  machine_word Wrd81;
  machine_word Wrd80;
  machine_word Wrd183;
  machine_word Wrd178;
  machine_word Wrd177;
  machine_word Wrd179;
  machine_word Wrd176;
  machine_word Wrd170;
  machine_word Wrd171;
  machine_word Wrd172;
  machine_word Wrd169;
  machine_word Wrd161;
  machine_word Wrd163;
  machine_word Wrd165;
  machine_word Wrd164;
  machine_word Wrd160;
  machine_word Wrd158;
  machine_word Wrd157;
  machine_word Wrd156;
  machine_word Wrd75;
  machine_word Wrd69;
  machine_word Wrd70;
  machine_word Wrd71;
  machine_word Wrd53;
  machine_word Wrd206;
  machine_word Wrd201;
  machine_word Wrd200;
  machine_word Wrd202;
  machine_word Wrd199;
  machine_word Wrd191;
  machine_word Wrd193;
  machine_word Wrd195;
  machine_word Wrd194;
  machine_word Wrd190;
  machine_word Wrd188;
  machine_word Wrd187;
  machine_word Wrd186;
  machine_word Wrd51;
  machine_word Wrd36;
  machine_word Wrd220;
  machine_word Wrd218;
  machine_word Wrd217;
  machine_word Wrd215;
  machine_word Wrd209;
  machine_word Wrd208;
  machine_word Wrd211;
  machine_word Wrd210;
  machine_word Wrd29;
  machine_word Wrd30;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd58;
  machine_word Wrd52;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd5;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd38;
  machine_word Wrd31;
  machine_word Wrd24;
  machine_word Wrd14;
  machine_word Wrd68;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd64;
  machine_word Wrd61;
  machine_word Wrd55;
  machine_word Wrd56;
  machine_word Wrd57;
  machine_word Wrd54;
  machine_word Wrd40;
  machine_word Wrd44;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd39;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd26;
  machine_word Wrd27;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_33_4);
      goto lambda_128;

    case 1:
      current_block = (Rpc - LABEL_33_5);
      goto lambda_180;

    case 2:
      current_block = (Rpc - LABEL_33_8);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_33_10);
      goto lambda_181;

    case 4:
      current_block = (Rpc - LABEL_33_14);
      goto label_130;

    case 5:
      current_block = (Rpc - LABEL_33_15);
      goto label_131;

    case 6:
      current_block = (Rpc - LABEL_33_16);
      goto label_132;

    case 7:
      current_block = (Rpc - LABEL_33_17);
      goto label_133;

    case 8:
      current_block = (Rpc - LABEL_33_18);
      goto label_134;

    case 9:
      current_block = (Rpc - LABEL_33_19);
      goto label_135;

    case 10:
      current_block = (Rpc - LABEL_33_13);
      goto continuation_14;

    case 11:
      current_block = (Rpc - LABEL_33_20);
      goto label_136;

    case 12:
      current_block = (Rpc - LABEL_33_21);
      goto label_137;

    case 13:
      current_block = (Rpc - LABEL_33_23);
      goto lambda_39;

    case 14:
      current_block = (Rpc - LABEL_33_24);
      goto label_138;

    case 15:
      current_block = (Rpc - LABEL_33_26);
      goto label_139;

    case 16:
      current_block = (Rpc - LABEL_33_22);
      goto continuation_2;

    case 17:
      current_block = (Rpc - LABEL_33_29);
      goto continuation_23;

    case 18:
      current_block = (Rpc - LABEL_33_30);
      goto label_144;

    case 19:
      current_block = (Rpc - LABEL_33_25);
      goto continuation_20;

    case 20:
      current_block = (Rpc - LABEL_33_33);
      goto label_141;

    case 21:
      current_block = (Rpc - LABEL_33_35);
      goto label_140;

    case 22:
      current_block = (Rpc - LABEL_33_37);
      goto lambda_43;

    case 23:
      current_block = (Rpc - LABEL_33_38);
      goto label_142;

    case 24:
      current_block = (Rpc - LABEL_33_39);
      goto label_143;

    case 25:
      current_block = (Rpc - LABEL_33_28);
      goto continuation_1;

    case 26:
      current_block = (Rpc - LABEL_33_36);
      goto continuation_21;

    case 27:
      current_block = (Rpc - LABEL_33_32);
      goto continuation_26;

    case 28:
      current_block = (Rpc - LABEL_33_31);
      goto continuation_37;

    case 29:
      current_block = (Rpc - LABEL_33_41);
      goto continuation_33;

    case 30:
      current_block = (Rpc - LABEL_33_42);
      goto label_145;

    case 31:
      current_block = (Rpc - LABEL_33_43);
      goto continuation_30;

    case 32:
      current_block = (Rpc - LABEL_33_45);
      goto label_146;

    case 33:
      current_block = (Rpc - LABEL_33_46);
      goto label_147;

    case 34:
      current_block = (Rpc - LABEL_33_47);
      goto label_166;

    case 35:
      current_block = (Rpc - LABEL_33_48);
      goto label_148;

    case 36:
      current_block = (Rpc - LABEL_33_49);
      goto label_149;

    case 37:
      current_block = (Rpc - LABEL_33_51);
      goto label_164;

    case 38:
      current_block = (Rpc - LABEL_33_52);
      goto label_165;

    case 39:
      current_block = (Rpc - LABEL_33_53);
      goto label_150;

    case 40:
      current_block = (Rpc - LABEL_33_54);
      goto label_151;

    case 41:
      current_block = (Rpc - LABEL_33_55);
      goto label_152;

    case 42:
      current_block = (Rpc - LABEL_33_57);
      goto label_161;

    case 43:
      current_block = (Rpc - LABEL_33_58);
      goto label_162;

    case 44:
      current_block = (Rpc - LABEL_33_59);
      goto label_163;

    case 45:
      current_block = (Rpc - LABEL_33_60);
      goto label_153;

    case 46:
      current_block = (Rpc - LABEL_33_61);
      goto label_154;

    case 47:
      current_block = (Rpc - LABEL_33_62);
      goto label_155;

    case 48:
      current_block = (Rpc - LABEL_33_63);
      goto label_156;

    case 49:
      current_block = (Rpc - LABEL_33_65);
      goto label_157;

    case 50:
      current_block = (Rpc - LABEL_33_66);
      goto label_158;

    case 51:
      current_block = (Rpc - LABEL_33_67);
      goto label_159;

    case 52:
      current_block = (Rpc - LABEL_33_68);
      goto label_160;

    case 53:
      current_block = (Rpc - LABEL_33_70);
      goto continuation_66;

    case 54:
      current_block = (Rpc - LABEL_33_71);
      goto continuation_85;

    case 55:
      current_block = (Rpc - LABEL_33_72);
      goto continuation_98;

    case 56:
      current_block = (Rpc - LABEL_33_73);
      goto continuation_60;

    case 57:
      current_block = (Rpc - LABEL_33_44);
      goto continuation_29;

    case 58:
      current_block = (Rpc - LABEL_33_69);
      goto continuation_61;

    case 59:
      current_block = (Rpc - LABEL_33_64);
      goto continuation_80;

    case 60:
      current_block = (Rpc - LABEL_33_79);
      goto label_167;

    case 61:
      current_block = (Rpc - LABEL_33_80);
      goto label_168;

    case 62:
      current_block = (Rpc - LABEL_33_81);
      goto label_169;

    case 63:
      current_block = (Rpc - LABEL_33_82);
      goto lambda_116;

    case 64:
      current_block = (Rpc - LABEL_33_56);
      goto continuation_94;

    case 65:
      current_block = (Rpc - LABEL_33_85);
      goto label_170;

    case 66:
      current_block = (Rpc - LABEL_33_86);
      goto label_171;

    case 67:
      current_block = (Rpc - LABEL_33_50);
      goto continuation_103;

    case 68:
      current_block = (Rpc - LABEL_33_88);
      goto label_172;

    case 69:
      current_block = (Rpc - LABEL_33_74);
      goto continuation_27;

    case 70:
      current_block = (Rpc - LABEL_33_75);
      goto continuation_58;

    case 71:
      current_block = (Rpc - LABEL_33_89);
      goto continuation_117;

    case 72:
      current_block = (Rpc - LABEL_33_76);
      goto lambda_124;

    case 73:
      current_block = (Rpc - LABEL_33_90);
      goto label_173;

    case 74:
      current_block = (Rpc - LABEL_33_78);
      goto continuation_75;

    case 75:
      current_block = (Rpc - LABEL_33_94);
      goto label_174;

    case 76:
      current_block = (Rpc - LABEL_33_95);
      goto label_175;

    case 77:
      current_block = (Rpc - LABEL_33_83);
      goto continuation_111;

    case 78:
      current_block = (Rpc - LABEL_33_84);
      goto continuation_90;

    case 79:
      current_block = (Rpc - LABEL_33_99);
      goto label_176;

    case 80:
      current_block = (Rpc - LABEL_33_87);
      goto continuation_100;

    case 81:
      current_block = (Rpc - LABEL_33_91);
      goto continuation_120;

    case 82:
      current_block = (Rpc - LABEL_33_93);
      goto continuation_71;

    case 83:
      current_block = (Rpc - LABEL_33_101);
      goto label_177;

    case 84:
      current_block = (Rpc - LABEL_33_96);
      goto continuation_110;

    case 85:
      current_block = (Rpc - LABEL_33_97);
      goto continuation_108;

    case 86:
      current_block = (Rpc - LABEL_33_98);
      goto continuation_87;

    case 87:
      current_block = (Rpc - LABEL_33_100);
      goto continuation_68;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_179)
DEFLABEL (lambda_128)
  INTERRUPT_CHECK (26, LABEL_33_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_33_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_33_5])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd12 = Wrd7;
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd12.pObj) [4]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_7]));

DEFLABEL (lambda_180)
  CLOSURE_HEADER (LABEL_33_5);

DEFLABEL (lambda_127)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_33_0]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_9]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_33_8);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_33_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_33_10])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd16 = Wrd7;
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [2]);
  ((Wrd16.pObj) [2]) = (Wrd19.Obj);
  (Wrd15.Obj) = ((Wrd18.pObj) [3]);
  ((Wrd16.pObj) [3]) = (Wrd15.Obj);
  (Wrd11.Obj) = ((Wrd18.pObj) [4]);
  ((Wrd16.pObj) [4]) = (Wrd11.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_12]));

DEFLABEL (lambda_181)
  CLOSURE_HEADER (LABEL_33_10);

DEFLABEL (lambda_126)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.pObj) = (& (Rsp [1]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd8.pObj)));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd16.Obj) = (Rsp [2]);
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [4]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 1))
    goto label_201;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd11.Obj) = ((Wrd15.pObj) [1]);

DEFLABEL (label_200)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd28.uLng) == 1))
    goto label_199;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd26.Obj) = ((Wrd27.pObj) [1]);

DEFLABEL (label_198)
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd35.uLng) == 1))
    goto label_197;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [1]);
  (* (--Rsp)) = (Wrd34.Obj);

DEFLABEL (label_196)
  (Wrd45.Obj) = (Rsp [3]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [4]);
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd47.Obj));
  if (! ((Wrd48.uLng) == 1))
    goto label_195;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  (Wrd40.Obj) = ((Wrd44.pObj) [1]);

DEFLABEL (label_194)
  (Wrd57.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if (! ((Wrd57.uLng) == 1))
    goto label_193;
  (Wrd56.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  (Wrd55.Obj) = ((Wrd56.pObj) [1]);

DEFLABEL (label_192)
  (Wrd64.uLng) = (OBJECT_TYPE (Wrd55.Obj));
  if (! ((Wrd64.uLng) == 1))
    goto label_191;
  (Wrd62.pObj) = (OBJECT_ADDRESS (Wrd55.Obj));
  (Wrd63.Obj) = ((Wrd62.pObj) [0]);
  (* (--Rsp)) = (Wrd63.Obj);

DEFLABEL (label_190)
  goto lambda_39;

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_33_13);
  (Wrd9.Obj) = (current_block [OBJECT_33_3]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.Obj) = (Rsp [1]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [4]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_189;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd10.Obj) = ((Wrd14.pObj) [1]);

DEFLABEL (label_188)
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd27.uLng) == 1))
    goto label_187;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd25.Obj) = ((Wrd26.pObj) [0]);

DEFLABEL (label_186)
  (Wrd35.Obj) = (current_block [OBJECT_33_3]);
  (* (Rhp++)) = (Wrd25.Obj);
  (* (Rhp++)) = (Wrd35.Obj);
  (Wrd33.pObj) = (& (Rhp [-2]));
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd33.pObj)));
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_22]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd39.Obj) = (current_block [OBJECT_33_4]);
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd40.Obj) = (Rsp [4]);
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  (Wrd42.Obj) = ((Wrd41.pObj) [3]);
  (* (--Rsp)) = (Wrd42.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_33_22);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Wrd13.Obj) = (current_block [OBJECT_33_3]);
  (* (Rhp++)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (Wrd14.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_28]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (current_block [OBJECT_33_5]);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (Rsp [3]);
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [3]);
  (* (--Rsp)) = (Wrd24.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_33_28);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_187)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_21]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_2]), 1);

DEFLABEL (label_137)
  (Wrd25.Obj) = Rvl;
  goto label_186;

DEFLABEL (label_189)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_20]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 1);

DEFLABEL (label_136)
  (Wrd10.Obj) = Rvl;
  goto label_188;

DEFLABEL (label_191)
  (Wrd68.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_19]))));
  (* (--Rsp)) = (Wrd68.Obj);
  (* (--Rsp)) = (Wrd55.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_2]), 1);

DEFLABEL (label_135)
  (* (--Rsp)) = Rvl;
  goto label_190;

DEFLABEL (label_193)
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_18]))));
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 1);

DEFLABEL (label_134)
  (Wrd55.Obj) = Rvl;
  goto label_192;

DEFLABEL (label_195)
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_17]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 1);

DEFLABEL (label_133)
  (Wrd40.Obj) = Rvl;
  goto label_194;

DEFLABEL (label_197)
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_16]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 1);

DEFLABEL (label_132)
  (* (--Rsp)) = Rvl;
  goto label_196;

DEFLABEL (label_199)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_15]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 1);

DEFLABEL (label_131)
  (Wrd26.Obj) = Rvl;
  goto label_198;

DEFLABEL (label_201)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_14]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 1);

DEFLABEL (label_130)
  (Wrd11.Obj) = Rvl;
  goto label_200;

DEFLABEL (lambda_182)
DEFLABEL (lambda_39)
  INTERRUPT_CHECK (26, LABEL_33_23);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_267;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [0]);

DEFLABEL (label_266)
  if (! ((Wrd5.Obj) == (current_block [OBJECT_33_3])))
    goto label_202;
  Rsp = (& (Rsp [1]));
  goto lambda_43;

DEFLABEL (label_202)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_25]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_265;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_264)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_27]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_33_25);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_258;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_29]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_263;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_262)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_36]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_33_7]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (Rsp [6]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [0]);
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [3]);
  (* (--Rsp)) = (Wrd27.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_33_36);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [5]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_33_29);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_258;
  (Wrd42.Obj) = (Rsp [1]);
  if ((Wrd42.Obj) == (current_block [OBJECT_33_3]))
    goto label_259;

DEFLABEL (label_258)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_32]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd34.Obj) = (Rsp [1]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 1))
    goto label_257;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [0]);
  (* (--Rsp)) = (Wrd33.Obj);

DEFLABEL (label_256)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_34]));

DEFLABEL (continuation_26)
  INTERRUPT_CHECK (27, LABEL_33_32);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_203;
  (Wrd15.Obj) = (current_block [OBJECT_33_8]);
  (Rsp [1]) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd18.Obj) = (Rsp [2]);
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [1]);
  (Rsp [0]) = (Wrd17.Obj);
  (Rsp [2]) = (Wrd16.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_203)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_41]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd11.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  goto lambda_43;

DEFLABEL (continuation_33)
  INTERRUPT_CHECK (27, LABEL_33_41);
  (Wrd9.Obj) = (current_block [OBJECT_33_3]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_255;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [1]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_254)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_43]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_33_6]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (Rsp [6]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [0]);
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [3]);
  (* (--Rsp)) = (Wrd27.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_33_43);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Wrd10.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_44]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd20.Obj) = (Rsp [2]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 1))
    goto label_253;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (* (--Rsp)) = (Wrd19.Obj);

DEFLABEL (label_252)
  (Wrd29.Obj) = (Rsp [0]);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if (! ((Wrd30.uLng) == 1))
    goto label_251;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd26.Obj) = ((Wrd28.pObj) [1]);

DEFLABEL (label_250)
  if ((Wrd26.Obj) == (current_block [OBJECT_33_3]))
    goto label_247;
  (Wrd39.Obj) = (Rsp [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if (! ((Wrd40.uLng) == 1))
    goto label_246;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd39.Obj));
  (Wrd36.Obj) = ((Wrd38.pObj) [1]);

DEFLABEL (label_245)
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd47.uLng) == 1))
    goto label_244;
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd45.Obj) = ((Wrd46.pObj) [1]);

DEFLABEL (label_243)
  if ((Wrd45.Obj) == (current_block [OBJECT_33_3]))
    goto label_239;
  (Wrd56.Obj) = (Rsp [0]);
  (Wrd57.uLng) = (OBJECT_TYPE (Wrd56.Obj));
  if (! ((Wrd57.uLng) == 1))
    goto label_238;
  (Wrd55.pObj) = (OBJECT_ADDRESS (Wrd56.Obj));
  (Wrd53.Obj) = ((Wrd55.pObj) [1]);

DEFLABEL (label_237)
  (Wrd64.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if (! ((Wrd64.uLng) == 1))
    goto label_236;
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd62.Obj) = ((Wrd63.pObj) [1]);

DEFLABEL (label_235)
  (Wrd71.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if (! ((Wrd71.uLng) == 1))
    goto label_234;
  (Wrd70.pObj) = (OBJECT_ADDRESS (Wrd62.Obj));
  (Wrd69.Obj) = ((Wrd70.pObj) [1]);

DEFLABEL (label_233)
  if ((Wrd69.Obj) == (current_block [OBJECT_33_3]))
    goto label_227;
  (Wrd80.Obj) = (Rsp [0]);
  (Wrd81.uLng) = (OBJECT_TYPE (Wrd80.Obj));
  if (! ((Wrd81.uLng) == 1))
    goto label_226;
  (Wrd79.pObj) = (OBJECT_ADDRESS (Wrd80.Obj));
  (Wrd77.Obj) = ((Wrd79.pObj) [1]);

DEFLABEL (label_225)
  (Wrd88.uLng) = (OBJECT_TYPE (Wrd77.Obj));
  if (! ((Wrd88.uLng) == 1))
    goto label_224;
  (Wrd87.pObj) = (OBJECT_ADDRESS (Wrd77.Obj));
  (Wrd86.Obj) = ((Wrd87.pObj) [1]);

DEFLABEL (label_223)
  (Wrd95.uLng) = (OBJECT_TYPE (Wrd86.Obj));
  if (! ((Wrd95.uLng) == 1))
    goto label_222;
  (Wrd94.pObj) = (OBJECT_ADDRESS (Wrd86.Obj));
  (Wrd93.Obj) = ((Wrd94.pObj) [1]);

DEFLABEL (label_221)
  (Wrd102.uLng) = (OBJECT_TYPE (Wrd93.Obj));
  if (! ((Wrd102.uLng) == 1))
    goto label_220;
  (Wrd101.pObj) = (OBJECT_ADDRESS (Wrd93.Obj));
  (Wrd100.Obj) = ((Wrd101.pObj) [1]);

DEFLABEL (label_219)
  if ((Wrd100.Obj) == (current_block [OBJECT_33_3]))
    goto label_209;
  (Wrd110.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_69]))));
  (* (--Rsp)) = (Wrd110.Obj);
  (Wrd111.Obj) = (current_block [OBJECT_33_4]);
  (* (--Rsp)) = (Wrd111.Obj);
  (Wrd112.Obj) = (Rsp [7]);
  (Wrd113.pObj) = (OBJECT_ADDRESS (Wrd112.Obj));
  (Wrd114.Obj) = ((Wrd113.pObj) [0]);
  (Wrd115.pObj) = (OBJECT_ADDRESS (Wrd114.Obj));
  (Wrd116.Obj) = ((Wrd115.pObj) [3]);
  (* (--Rsp)) = (Wrd116.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_61)
  INTERRUPT_CHECK (27, LABEL_33_69);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.Obj) = (current_block [OBJECT_33_3]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Wrd13.Obj) = (current_block [OBJECT_33_10]);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd20.pObj) = (& (Rhp [-2]));
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_73]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_75]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_76]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_77]));

DEFLABEL (continuation_58)
  INTERRUPT_CHECK (27, LABEL_33_75);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_205;
  (Wrd7.Obj) = (current_block [OBJECT_33_12]);
  (* (--Rsp)) = (Wrd7.Obj);
  goto label_204;

DEFLABEL (label_205)
  (Wrd13.Obj) = (current_block [OBJECT_33_11]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_204)
DEFLABEL (label_208)
  (Wrd8.Obj) = (Rsp [8]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [0]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_60)
  INTERRUPT_CHECK (27, LABEL_33_73);

DEFLABEL (label_207)
  (Wrd19.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd19.Obj);
  (Wrd23.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd23.pObj)));
  Rsp = (& (Rsp [2]));

DEFLABEL (label_206)
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_74]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_33_9]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [5]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [3]);
  (* (--Rsp)) = (Wrd18.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_33_74);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_209)
  (Wrd119.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_64]))));
  (* (--Rsp)) = (Wrd119.Obj);
  (Wrd120.Obj) = (Rsp [6]);
  (Wrd121.pObj) = (OBJECT_ADDRESS (Wrd120.Obj));
  (Wrd123.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd121.pObj)));
  (* (--Rsp)) = (Wrd123.Obj);
  (Wrd127.Obj) = (Rsp [2]);
  (Wrd128.uLng) = (OBJECT_TYPE (Wrd127.Obj));
  if (! ((Wrd128.uLng) == 1))
    goto label_218;
  (Wrd126.pObj) = (OBJECT_ADDRESS (Wrd127.Obj));
  (Wrd124.Obj) = ((Wrd126.pObj) [1]);

DEFLABEL (label_217)
  (Wrd135.uLng) = (OBJECT_TYPE (Wrd124.Obj));
  if (! ((Wrd135.uLng) == 1))
    goto label_216;
  (Wrd134.pObj) = (OBJECT_ADDRESS (Wrd124.Obj));
  (Wrd133.Obj) = ((Wrd134.pObj) [1]);

DEFLABEL (label_215)
  (Wrd142.uLng) = (OBJECT_TYPE (Wrd133.Obj));
  if (! ((Wrd142.uLng) == 1))
    goto label_214;
  (Wrd141.pObj) = (OBJECT_ADDRESS (Wrd133.Obj));
  (Wrd140.Obj) = ((Wrd141.pObj) [1]);

DEFLABEL (label_213)
  (Wrd149.uLng) = (OBJECT_TYPE (Wrd140.Obj));
  if (! ((Wrd149.uLng) == 1))
    goto label_211;
  (Wrd147.pObj) = (OBJECT_ADDRESS (Wrd140.Obj));
  (Wrd148.Obj) = ((Wrd147.pObj) [0]);
  (* (--Rsp)) = (Wrd148.Obj);

DEFLABEL (label_210)
  goto lambda_116;

DEFLABEL (label_211)
  (Wrd153.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_68]))));
  (* (--Rsp)) = (Wrd153.Obj);
  (* (--Rsp)) = (Wrd140.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_2]), 1);

DEFLABEL (label_160)
DEFLABEL (label_212)
  (* (--Rsp)) = Rvl;
  goto label_210;

DEFLABEL (label_214)
  (Wrd146.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_67]))));
  (* (--Rsp)) = (Wrd146.Obj);
  (* (--Rsp)) = (Wrd133.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 1);

DEFLABEL (label_159)
  (Wrd140.Obj) = Rvl;
  goto label_213;

DEFLABEL (label_216)
  (Wrd139.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_66]))));
  (* (--Rsp)) = (Wrd139.Obj);
  (* (--Rsp)) = (Wrd124.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 1);

DEFLABEL (label_158)
  (Wrd133.Obj) = Rvl;
  goto label_215;

DEFLABEL (label_218)
  (Wrd132.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_65]))));
  (* (--Rsp)) = (Wrd132.Obj);
  (* (--Rsp)) = (Wrd127.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 1);

DEFLABEL (label_157)
  (Wrd124.Obj) = Rvl;
  goto label_217;

DEFLABEL (label_220)
  (Wrd106.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_63]))));
  (* (--Rsp)) = (Wrd106.Obj);
  (* (--Rsp)) = (Wrd93.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 1);

DEFLABEL (label_156)
  (Wrd100.Obj) = Rvl;
  goto label_219;

DEFLABEL (label_222)
  (Wrd99.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_62]))));
  (* (--Rsp)) = (Wrd99.Obj);
  (* (--Rsp)) = (Wrd86.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 1);

DEFLABEL (label_155)
  (Wrd93.Obj) = Rvl;
  goto label_221;

DEFLABEL (label_224)
  (Wrd92.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_61]))));
  (* (--Rsp)) = (Wrd92.Obj);
  (* (--Rsp)) = (Wrd77.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 1);

DEFLABEL (label_154)
  (Wrd86.Obj) = Rvl;
  goto label_223;

DEFLABEL (label_226)
  (Wrd85.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_60]))));
  (* (--Rsp)) = (Wrd85.Obj);
  (* (--Rsp)) = (Wrd80.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 1);

DEFLABEL (label_153)
  (Wrd77.Obj) = Rvl;
  goto label_225;

DEFLABEL (label_227)
  (Wrd156.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_56]))));
  (* (--Rsp)) = (Wrd156.Obj);
  (Wrd157.Obj) = (Rsp [6]);
  (Wrd158.pObj) = (OBJECT_ADDRESS (Wrd157.Obj));
  (Wrd160.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd158.pObj)));
  (* (--Rsp)) = (Wrd160.Obj);
  (Wrd164.Obj) = (Rsp [2]);
  (Wrd165.uLng) = (OBJECT_TYPE (Wrd164.Obj));
  if (! ((Wrd165.uLng) == 1))
    goto label_232;
  (Wrd163.pObj) = (OBJECT_ADDRESS (Wrd164.Obj));
  (Wrd161.Obj) = ((Wrd163.pObj) [1]);

DEFLABEL (label_231)
  (Wrd172.uLng) = (OBJECT_TYPE (Wrd161.Obj));
  if (! ((Wrd172.uLng) == 1))
    goto label_230;
  (Wrd171.pObj) = (OBJECT_ADDRESS (Wrd161.Obj));
  (Wrd170.Obj) = ((Wrd171.pObj) [1]);

DEFLABEL (label_229)
  (Wrd179.uLng) = (OBJECT_TYPE (Wrd170.Obj));
  if (! ((Wrd179.uLng) == 1))
    goto label_228;
  (Wrd177.pObj) = (OBJECT_ADDRESS (Wrd170.Obj));
  (Wrd178.Obj) = ((Wrd177.pObj) [0]);
  (* (--Rsp)) = (Wrd178.Obj);
  goto label_210;

DEFLABEL (label_228)
  (Wrd183.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_59]))));
  (* (--Rsp)) = (Wrd183.Obj);
  (* (--Rsp)) = (Wrd170.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_2]), 1);

DEFLABEL (label_163)
  goto label_212;

DEFLABEL (label_230)
  (Wrd176.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_58]))));
  (* (--Rsp)) = (Wrd176.Obj);
  (* (--Rsp)) = (Wrd161.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 1);

DEFLABEL (label_162)
  (Wrd170.Obj) = Rvl;
  goto label_229;

DEFLABEL (label_232)
  (Wrd169.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_57]))));
  (* (--Rsp)) = (Wrd169.Obj);
  (* (--Rsp)) = (Wrd164.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 1);

DEFLABEL (label_161)
  (Wrd161.Obj) = Rvl;
  goto label_231;

DEFLABEL (label_234)
  (Wrd75.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_55]))));
  (* (--Rsp)) = (Wrd75.Obj);
  (* (--Rsp)) = (Wrd62.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 1);

DEFLABEL (label_152)
  (Wrd69.Obj) = Rvl;
  goto label_233;

DEFLABEL (label_236)
  (Wrd68.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_54]))));
  (* (--Rsp)) = (Wrd68.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 1);

DEFLABEL (label_151)
  (Wrd62.Obj) = Rvl;
  goto label_235;

DEFLABEL (label_238)
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_53]))));
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 1);

DEFLABEL (label_150)
  (Wrd53.Obj) = Rvl;
  goto label_237;

DEFLABEL (label_239)
  (Wrd186.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_50]))));
  (* (--Rsp)) = (Wrd186.Obj);
  (Wrd187.Obj) = (Rsp [6]);
  (Wrd188.pObj) = (OBJECT_ADDRESS (Wrd187.Obj));
  (Wrd190.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd188.pObj)));
  (* (--Rsp)) = (Wrd190.Obj);
  (Wrd194.Obj) = (Rsp [2]);
  (Wrd195.uLng) = (OBJECT_TYPE (Wrd194.Obj));
  if (! ((Wrd195.uLng) == 1))
    goto label_242;
  (Wrd193.pObj) = (OBJECT_ADDRESS (Wrd194.Obj));
  (Wrd191.Obj) = ((Wrd193.pObj) [1]);

DEFLABEL (label_241)
  (Wrd202.uLng) = (OBJECT_TYPE (Wrd191.Obj));
  if (! ((Wrd202.uLng) == 1))
    goto label_240;
  (Wrd200.pObj) = (OBJECT_ADDRESS (Wrd191.Obj));
  (Wrd201.Obj) = ((Wrd200.pObj) [0]);
  (* (--Rsp)) = (Wrd201.Obj);
  goto label_210;

DEFLABEL (label_240)
  (Wrd206.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_52]))));
  (* (--Rsp)) = (Wrd206.Obj);
  (* (--Rsp)) = (Wrd191.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_2]), 1);

DEFLABEL (label_165)
  goto label_212;

DEFLABEL (label_242)
  (Wrd199.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_51]))));
  (* (--Rsp)) = (Wrd199.Obj);
  (* (--Rsp)) = (Wrd194.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 1);

DEFLABEL (label_164)
  (Wrd191.Obj) = Rvl;
  goto label_241;

DEFLABEL (label_244)
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_49]))));
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 1);

DEFLABEL (label_149)
  (Wrd45.Obj) = Rvl;
  goto label_243;

DEFLABEL (label_246)
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_48]))));
  (* (--Rsp)) = (Wrd44.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 1);

DEFLABEL (label_148)
  (Wrd36.Obj) = Rvl;
  goto label_245;

DEFLABEL (label_247)
  (Wrd210.Obj) = (Rsp [0]);
  (Wrd211.uLng) = (OBJECT_TYPE (Wrd210.Obj));
  if (! ((Wrd211.uLng) == 1))
    goto label_249;
  (Wrd208.pObj) = (OBJECT_ADDRESS (Wrd210.Obj));
  (Wrd209.Obj) = ((Wrd208.pObj) [0]);
  (* (--Rsp)) = (Wrd209.Obj);

DEFLABEL (label_248)
  (Wrd217.Obj) = (Rsp [6]);
  (Wrd218.pObj) = (OBJECT_ADDRESS (Wrd217.Obj));
  (Wrd220.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd218.pObj)));
  (Rsp [1]) = (Wrd220.Obj);
  goto label_210;

DEFLABEL (label_249)
  (Wrd215.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_47]))));
  (* (--Rsp)) = (Wrd215.Obj);
  (* (--Rsp)) = (Wrd210.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_2]), 1);

DEFLABEL (label_166)
  (* (--Rsp)) = Rvl;
  goto label_248;

DEFLABEL (label_251)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_46]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 1);

DEFLABEL (label_147)
  (Wrd26.Obj) = Rvl;
  goto label_250;

DEFLABEL (label_253)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_45]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_2]), 1);

DEFLABEL (label_146)
  (* (--Rsp)) = Rvl;
  goto label_252;

DEFLABEL (label_255)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_42]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 1);

DEFLABEL (label_145)
  (* (--Rsp)) = Rvl;
  goto label_254;

DEFLABEL (label_257)
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_33]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_2]), 1);

DEFLABEL (label_141)
  (* (--Rsp)) = Rvl;
  goto label_256;

DEFLABEL (label_259)
  (Wrd47.Obj) = (Rsp [0]);
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd47.Obj));
  if (! ((Wrd48.uLng) == 1))
    goto label_261;
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  (Wrd46.Obj) = ((Wrd45.pObj) [1]);
  (* (--Rsp)) = (Wrd46.Obj);

DEFLABEL (label_260)
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_31]))));
  (* (--Rsp)) = (Wrd55.Obj);
  (Wrd56.Obj) = (current_block [OBJECT_33_6]);
  (* (--Rsp)) = (Wrd56.Obj);
  (Wrd57.Obj) = (Rsp [5]);
  (Wrd58.pObj) = (OBJECT_ADDRESS (Wrd57.Obj));
  (Wrd59.Obj) = ((Wrd58.pObj) [0]);
  (Wrd60.pObj) = (OBJECT_ADDRESS (Wrd59.Obj));
  (Wrd61.Obj) = ((Wrd60.pObj) [3]);
  (* (--Rsp)) = (Wrd61.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_37)
  INTERRUPT_CHECK (27, LABEL_33_31);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_261)
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_30]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 1);

DEFLABEL (label_144)
  (* (--Rsp)) = Rvl;
  goto label_260;

DEFLABEL (label_263)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_35]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_2]), 1);

DEFLABEL (label_140)
  (* (--Rsp)) = Rvl;
  goto label_262;

DEFLABEL (label_265)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_26]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_2]), 1);

DEFLABEL (label_139)
  (* (--Rsp)) = Rvl;
  goto label_264;

DEFLABEL (label_267)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_24]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_2]), 1);

DEFLABEL (label_138)
  (Wrd5.Obj) = Rvl;
  goto label_266;

DEFLABEL (continuation_80)
  INTERRUPT_CHECK (27, LABEL_33_64);
  (Wrd9.Obj) = (current_block [OBJECT_33_3]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_78]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [7]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd14.pObj)));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd20.Obj) = (Rsp [3]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 1))
    goto label_279;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [1]);

DEFLABEL (label_278)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd28.uLng) == 1))
    goto label_277;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd26.Obj) = ((Wrd27.pObj) [1]);

DEFLABEL (label_276)
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd35.uLng) == 1))
    goto label_275;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (* (--Rsp)) = (Wrd34.Obj);

DEFLABEL (label_274)
  goto lambda_116;

DEFLABEL (continuation_75)
  INTERRUPT_CHECK (27, LABEL_33_78);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_93]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [7]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd14.pObj)));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd20.Obj) = (Rsp [3]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 1))
    goto label_273;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [1]);

DEFLABEL (label_272)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd28.uLng) == 1))
    goto label_271;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [0]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_270)
  goto lambda_116;

DEFLABEL (continuation_71)
  INTERRUPT_CHECK (27, LABEL_33_93);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_100]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [7]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd14.pObj)));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd20.Obj) = (Rsp [3]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 1))
    goto label_269;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (* (--Rsp)) = (Wrd19.Obj);

DEFLABEL (label_268)
  goto lambda_116;

DEFLABEL (continuation_68)
  INTERRUPT_CHECK (27, LABEL_33_100);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_70]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_33_18]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [8]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [3]);
  (* (--Rsp)) = (Wrd18.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_66)
  INTERRUPT_CHECK (27, LABEL_33_70);
  goto label_207;

DEFLABEL (label_269)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_101]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_2]), 1);

DEFLABEL (label_177)
  (* (--Rsp)) = Rvl;
  goto label_268;

DEFLABEL (label_271)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_95]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_2]), 1);

DEFLABEL (label_175)
  (* (--Rsp)) = Rvl;
  goto label_270;

DEFLABEL (label_273)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_94]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 1);

DEFLABEL (label_174)
  (Wrd17.Obj) = Rvl;
  goto label_272;

DEFLABEL (label_275)
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_81]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_2]), 1);

DEFLABEL (label_169)
  (* (--Rsp)) = Rvl;
  goto label_274;

DEFLABEL (label_277)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_80]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 1);

DEFLABEL (label_168)
  (Wrd26.Obj) = Rvl;
  goto label_276;

DEFLABEL (label_279)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_79]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 1);

DEFLABEL (label_167)
  (Wrd17.Obj) = Rvl;
  goto label_278;

DEFLABEL (continuation_94)
  INTERRUPT_CHECK (27, LABEL_33_56);
  (Wrd9.Obj) = (current_block [OBJECT_33_3]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_84]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [7]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd14.pObj)));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd20.Obj) = (Rsp [3]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 1))
    goto label_285;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [1]);

DEFLABEL (label_284)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd28.uLng) == 1))
    goto label_283;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [0]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_282)
  goto lambda_116;

DEFLABEL (continuation_90)
  INTERRUPT_CHECK (27, LABEL_33_84);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_98]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [7]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd14.pObj)));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd20.Obj) = (Rsp [3]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 1))
    goto label_281;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (* (--Rsp)) = (Wrd19.Obj);

DEFLABEL (label_280)
  goto lambda_116;

DEFLABEL (continuation_87)
  INTERRUPT_CHECK (27, LABEL_33_98);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_71]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_33_18]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [8]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [3]);
  (* (--Rsp)) = (Wrd18.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_85)
  INTERRUPT_CHECK (27, LABEL_33_71);
  goto label_207;

DEFLABEL (label_281)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_99]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_2]), 1);

DEFLABEL (label_176)
  (* (--Rsp)) = Rvl;
  goto label_280;

DEFLABEL (label_283)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_86]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_2]), 1);

DEFLABEL (label_171)
  (* (--Rsp)) = Rvl;
  goto label_282;

DEFLABEL (label_285)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_85]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 1);

DEFLABEL (label_170)
  (Wrd17.Obj) = Rvl;
  goto label_284;

DEFLABEL (continuation_103)
  INTERRUPT_CHECK (27, LABEL_33_50);
  (Wrd9.Obj) = (current_block [OBJECT_33_3]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_87]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [7]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd14.pObj)));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd20.Obj) = (Rsp [3]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 1))
    goto label_287;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (* (--Rsp)) = (Wrd19.Obj);

DEFLABEL (label_286)
  goto lambda_116;

DEFLABEL (continuation_100)
  INTERRUPT_CHECK (27, LABEL_33_87);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_72]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_33_18]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [8]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [3]);
  (* (--Rsp)) = (Wrd18.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_98)
  INTERRUPT_CHECK (27, LABEL_33_72);
  goto label_207;

DEFLABEL (label_287)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_88]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_2]), 1);

DEFLABEL (label_172)
  (* (--Rsp)) = Rvl;
  goto label_286;

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_33_44);
  (Wrd6.Obj) = Rvl;
  goto label_206;

DEFLABEL (lambda_183)
DEFLABEL (lambda_43)
  INTERRUPT_CHECK (26, LABEL_33_37);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_288;
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_40]));

DEFLABEL (label_288)
  if (! ((Wrd6.uLng) == 1))
    goto label_292;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [0]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_291)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 1))
    goto label_290;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [1]);

DEFLABEL (label_289)
  (Rsp [1]) = (Wrd17.Obj);
  goto lambda_39;

DEFLABEL (label_290)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_39]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 1);

DEFLABEL (label_143)
  (Wrd17.Obj) = Rvl;
  goto label_289;

DEFLABEL (label_292)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_38]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_2]), 1);

DEFLABEL (label_142)
  (* (--Rsp)) = Rvl;
  goto label_291;

DEFLABEL (lambda_184)
DEFLABEL (lambda_116)
  INTERRUPT_CHECK (26, LABEL_33_82);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_83]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_33_4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [3]);
  (* (--Rsp)) = (Wrd13.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_111)
  INTERRUPT_CHECK (27, LABEL_33_83);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.Obj) = (current_block [OBJECT_33_3]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Wrd13.Obj) = (current_block [OBJECT_33_10]);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd20.pObj) = (& (Rhp [-2]));
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_96]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_97]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  goto lambda_124;

DEFLABEL (continuation_108)
  INTERRUPT_CHECK (27, LABEL_33_97);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_294;
  (Wrd7.Obj) = (current_block [OBJECT_33_20]);
  (* (--Rsp)) = (Wrd7.Obj);
  goto label_293;

DEFLABEL (label_294)
  (Wrd13.Obj) = (current_block [OBJECT_33_19]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_293)
DEFLABEL (label_295)
  (Wrd8.Obj) = (Rsp [4]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [0]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_110)
  INTERRUPT_CHECK (27, LABEL_33_96);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (lambda_185)
DEFLABEL (lambda_124)
  INTERRUPT_CHECK (26, LABEL_33_76);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_89]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd34.Obj) = (current_block [OBJECT_33_13]);
  (Wrd37.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 29L) < ((unsigned long) (Wrd37.Lng))))
    goto label_308;
  (Wrd10.uLng) = (OBJECT_DATUM (Wrd34.Obj));
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd10.Obj) == (Wrd12.Obj))
    goto label_307;

DEFLABEL (label_306)
  (Wrd13.Obj) = (current_block [OBJECT_33_15]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd23.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 5L) < ((unsigned long) (Wrd23.Lng)))
    goto label_296;
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_14]), 2);

DEFLABEL (label_296)
  (Wrd17.uLng) = (OBJECT_DATUM (Wrd13.Obj));
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd17.Obj) == (Wrd19.Obj))
    goto label_298;
  (Wrd15.Obj) = (current_block [OBJECT_33_17]);
  goto label_297;

DEFLABEL (label_298)
  (Wrd15.Obj) = (current_block [OBJECT_33_16]);

DEFLABEL (label_297)
DEFLABEL (label_305)
  Rsp = (& (Rsp [3]));
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_304)
  (Wrd24.Obj) = (Rsp [0]);
  if ((Wrd24.Obj) == ((SCHEME_OBJECT) 0))
    goto label_299;
  Rvl = (Wrd24.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_299)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_91]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd31.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd31.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_92]));

DEFLABEL (continuation_120)
  INTERRUPT_CHECK (27, LABEL_33_91);
  (Rsp [0]) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_301;
  Rvl = Rvl;

DEFLABEL (label_300)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_301)
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 2)
    goto label_303;
  if ((Wrd11.uLng) == 26)
    goto label_303;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_302;

DEFLABEL (label_303)
  Rvl = (current_block [OBJECT_33_16]);

DEFLABEL (label_302)
  goto label_300;

DEFLABEL (label_307)
  (Wrd33.Obj) = (current_block [OBJECT_33_16]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd33.Obj);
  goto label_304;

DEFLABEL (label_308)
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_90]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_14]), 2);

DEFLABEL (label_173)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_306;
  goto label_307;

DEFLABEL (continuation_117)
  INTERRUPT_CHECK (27, LABEL_33_89);
  (* (--Rsp)) = Rvl;
  goto label_304;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_34_4 3
#define LABEL_34_8 5
#define LABEL_34_5 7
#define TAG_34_6 2
#define LABEL_34_9 9
#define LABEL_34_10 11
#define LABEL_34_11 13
#define LABEL_34_13 15
#define LABEL_34_15 17
#define LABEL_34_16 19
#define LABEL_34_14 21
#define ENVIRONMENT_LABEL_34_3 37
#define DEBUGGING_LABEL_34_2 36
#define OBJECT_34_4 35
#define OBJECT_34_3 34
#define OBJECT_34_2 33
#define OBJECT_34_1 32
#define OBJECT_34_0 31
#define EXECUTE_CACHE_34_18 23
#define EXECUTE_CACHE_34_17 25
#define EXECUTE_CACHE_34_12 27
#define EXECUTE_CACHE_34_7 29
#define FREE_REFERENCES_LABEL_34_0 22
#define NUMBER_OF_LINKER_SECTIONS_34_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_34 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd23;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd37;
  machine_word Wrd30;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd15;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd51;
  machine_word Wrd49;
  machine_word Wrd47;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd38;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd8;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_34_4);
      goto lambda_15;

    case 1:
      current_block = (Rpc - LABEL_34_8);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_34_5);
      goto lambda_24;

    case 3:
      current_block = (Rpc - LABEL_34_9);
      goto label_17;

    case 4:
      current_block = (Rpc - LABEL_34_10);
      goto label_18;

    case 5:
      current_block = (Rpc - LABEL_34_11);
      goto label_19;

    case 6:
      current_block = (Rpc - LABEL_34_13);
      goto loop_11;

    case 7:
      current_block = (Rpc - LABEL_34_15);
      goto label_20;

    case 8:
      current_block = (Rpc - LABEL_34_16);
      goto label_21;

    case 9:
      current_block = (Rpc - LABEL_34_14);
      goto continuation_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_23)
DEFLABEL (lambda_15)
  INTERRUPT_CHECK (26, LABEL_34_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_34_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_34_5])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd12 = Wrd7;
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd12.pObj) [4]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_7]));

DEFLABEL (lambda_24)
  CLOSURE_HEADER (LABEL_34_5);

DEFLABEL (lambda_14)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [4]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_32;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [1]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_31)
  (Wrd20.Obj) = (Rsp [0]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd21.uLng) == 1)
    goto label_30;
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_8]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [2]);
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [4]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd28.Obj) = (current_block [OBJECT_34_2]);
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd29.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd29.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_12]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_34_8);

DEFLABEL (label_30)
  (Wrd33.Obj) = (Rsp [0]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 1))
    goto label_29;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [1]);
  (* (--Rsp)) = (Wrd32.Obj);

DEFLABEL (label_28)
  (Wrd42.Obj) = (Rsp [1]);
  (Wrd43.uLng) = (OBJECT_TYPE (Wrd42.Obj));
  if (! ((Wrd43.uLng) == 1))
    goto label_27;
  (Wrd40.pObj) = (OBJECT_ADDRESS (Wrd42.Obj));
  (Wrd41.Obj) = ((Wrd40.pObj) [0]);
  (* (--Rsp)) = (Wrd41.Obj);

DEFLABEL (label_26)
  (Wrd49.pObj) = (& (Rsp [3]));
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd49.pObj)));
  (Rsp [2]) = (Wrd51.Obj);
  Rdl = (& (Rsp [5]));
  goto loop_11;

DEFLABEL (label_27)
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_11]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_1]), 1);

DEFLABEL (label_19)
  (* (--Rsp)) = Rvl;
  goto label_26;

DEFLABEL (label_29)
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_10]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_0]), 1);

DEFLABEL (label_18)
  (* (--Rsp)) = Rvl;
  goto label_28;

DEFLABEL (label_32)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_9]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_0]), 1);

DEFLABEL (label_17)
  (* (--Rsp)) = Rvl;
  goto label_31;

DEFLABEL (loop_25)
DEFLABEL (loop_11)
  DLINK_INTERRUPT_CHECK (25, LABEL_34_13);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_14]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 1)
    goto label_36;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_17]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_34_14);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (current_block [OBJECT_34_3]))
    goto label_34;
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  goto label_33;

DEFLABEL (label_34)
  (Wrd10.Obj) = (current_block [OBJECT_34_4]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_33)
DEFLABEL (label_35)
  (Wrd11.Obj) = (Rsp [4]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [1]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd16.Obj) = ((Wrd12.pObj) [0]);
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [2]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd23.Obj) = ((Wrd17.pObj) [3]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd24.Obj);
  {
    SCHEME_OBJECT * MFUp1 = (& (Rsp [6]));
    SCHEME_OBJECT * MFUp2 = Rdl;
    while (MFUp1 > Rsp)
      {
	(* (--MFUp2)) = (* (--MFUp1));
      }
    Rsp = MFUp2;
  }
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_18]));

DEFLABEL (label_36)
  (Wrd12.Obj) = (Rsp [4]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd13.pObj)));
  (* (--Rsp)) = (Wrd15.Obj);
  if (! ((Wrd11.uLng) == 1))
    goto label_40;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [1]);
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_39)
  (Wrd32.Obj) = (Rsp [5]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 1))
    goto label_38;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (* (--Rsp)) = (Wrd31.Obj);

DEFLABEL (label_37)
  Rdl = (& (Rsp [3]));
  goto loop_11;

DEFLABEL (label_38)
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_16]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_1]), 1);

DEFLABEL (label_21)
  (Wrd34.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd34.Obj));
  (* (--Rsp)) = Rvl;
  goto label_37;

DEFLABEL (label_40)
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_15]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_0]), 1);

DEFLABEL (label_20)
  (Wrd21.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd21.Obj));
  (* (--Rsp)) = Rvl;
  goto label_39;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_35_4 3
#define LABEL_35_5 5
#define TAG_35_6 1
#define LABEL_35_8 7
#define LABEL_35_10 9
#define LABEL_35_11 11
#define LABEL_35_12 13
#define LABEL_35_13 15
#define LABEL_35_14 17
#define LABEL_35_15 19
#define LABEL_35_21 21
#define LABEL_35_22 23
#define LABEL_35_23 25
#define LABEL_35_16 27
#define LABEL_35_25 29
#define LABEL_35_26 31
#define LABEL_35_27 33
#define LABEL_35_28 35
#define LABEL_35_18 37
#define LABEL_35_19 39
#define LABEL_35_30 41
#define LABEL_35_31 43
#define LABEL_35_32 45
#define LABEL_35_20 47
#define LABEL_35_33 49
#define LABEL_35_34 51
#define LABEL_35_35 53
#define LABEL_35_29 55
#define ENVIRONMENT_LABEL_35_3 75
#define DEBUGGING_LABEL_35_2 74
#define OBJECT_35_6 73
#define OBJECT_35_5 72
#define OBJECT_35_4 71
#define OBJECT_35_3 70
#define OBJECT_35_2 69
#define OBJECT_35_1 68
#define OBJECT_35_0 67
#define EXECUTE_CACHE_35_36 57
#define EXECUTE_CACHE_35_24 59
#define EXECUTE_CACHE_35_17 61
#define EXECUTE_CACHE_35_9 63
#define EXECUTE_CACHE_35_7 65
#define FREE_REFERENCES_LABEL_35_0 56
#define NUMBER_OF_LINKER_SECTIONS_35_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_35 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd25;
  machine_word Wrd23;
  machine_word Wrd17;
  machine_word Wrd24;
  machine_word Wrd27;
  machine_word Wrd46;
  machine_word Wrd49;
  machine_word Wrd43;
  machine_word Wrd39;
  machine_word Wrd16;
  machine_word Wrd42;
  machine_word Wrd37;
  machine_word Wrd30;
  machine_word Wrd31;
  machine_word Wrd28;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd38;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_35_4);
      goto lambda_35;

    case 1:
      current_block = (Rpc - LABEL_35_5);
      goto lambda_54;

    case 2:
      current_block = (Rpc - LABEL_35_8);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_35_10);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_35_11);
      goto label_37;

    case 5:
      current_block = (Rpc - LABEL_35_12);
      goto label_38;

    case 6:
      current_block = (Rpc - LABEL_35_13);
      goto continuation_29;

    case 7:
      current_block = (Rpc - LABEL_35_14);
      goto continuation_27;

    case 8:
      current_block = (Rpc - LABEL_35_15);
      goto continuation_24;

    case 9:
      current_block = (Rpc - LABEL_35_21);
      goto label_39;

    case 10:
      current_block = (Rpc - LABEL_35_22);
      goto label_40;

    case 11:
      current_block = (Rpc - LABEL_35_23);
      goto label_41;

    case 12:
      current_block = (Rpc - LABEL_35_16);
      goto lambda_23;

    case 13:
      current_block = (Rpc - LABEL_35_25);
      goto label_42;

    case 14:
      current_block = (Rpc - LABEL_35_26);
      goto label_43;

    case 15:
      current_block = (Rpc - LABEL_35_27);
      goto label_44;

    case 16:
      current_block = (Rpc - LABEL_35_28);
      goto label_45;

    case 17:
      current_block = (Rpc - LABEL_35_18);
      goto continuation_10;

    case 18:
      current_block = (Rpc - LABEL_35_19);
      goto lambda_9;

    case 19:
      current_block = (Rpc - LABEL_35_30);
      goto label_46;

    case 20:
      current_block = (Rpc - LABEL_35_31);
      goto label_47;

    case 21:
      current_block = (Rpc - LABEL_35_32);
      goto label_48;

    case 22:
      current_block = (Rpc - LABEL_35_20);
      goto continuation_14;

    case 23:
      current_block = (Rpc - LABEL_35_33);
      goto label_49;

    case 24:
      current_block = (Rpc - LABEL_35_34);
      goto label_50;

    case 25:
      current_block = (Rpc - LABEL_35_35);
      goto label_51;

    case 26:
      current_block = (Rpc - LABEL_35_29);
      goto continuation_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_53)
DEFLABEL (lambda_35)
  INTERRUPT_CHECK (26, LABEL_35_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_35_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_35_5])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd12 = Wrd7;
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd12.pObj) [4]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_7]));

DEFLABEL (lambda_54)
  CLOSURE_HEADER (LABEL_35_5);

DEFLABEL (lambda_34)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_35_0]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_9]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_35_8);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_35_1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_35_10);
  (* (--Rsp)) = Rvl;
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [4]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_72;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd5.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_71)
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_70;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (* (--Rsp)) = (Wrd21.Obj);

DEFLABEL (label_69)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_13]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_14]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_15]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd36.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_16]))));
  (* (--Rsp)) = (Wrd38.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_17]));

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_35_15);
  (Wrd9.Obj) = (Rsp [3]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Wrd13.Obj) = (current_block [OBJECT_35_4]);
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd11.pObj) = (& (Rhp [-2]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd11.pObj)));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd19.Obj) = (Rsp [5]);
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [4]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_68;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd14.Obj) = ((Wrd18.pObj) [1]);

DEFLABEL (label_67)
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd31.uLng) == 1))
    goto label_66;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd29.Obj) = ((Wrd30.pObj) [1]);

DEFLABEL (label_65)
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if (! ((Wrd38.uLng) == 1))
    goto label_64;
  (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd37.Obj) = ((Wrd36.pObj) [1]);
  (* (--Rsp)) = (Wrd37.Obj);

DEFLABEL (label_63)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_24]));

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_35_14);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_20]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_35_5]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [6]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_35_20);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd11.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [6]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd17.Obj) = ((Wrd13.pObj) [3]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd25.Obj) = ((Wrd13.pObj) [4]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 1))
    goto label_62;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd18.Obj) = ((Wrd22.pObj) [1]);

DEFLABEL (label_61)
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd35.uLng) == 1))
    goto label_60;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd33.Obj) = ((Wrd34.pObj) [1]);

DEFLABEL (label_59)
  (Wrd42.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd42.uLng) == 1))
    goto label_58;
  (Wrd40.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd41.Obj) = ((Wrd40.pObj) [0]);
  (* (--Rsp)) = (Wrd41.Obj);

DEFLABEL (label_57)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_36]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_35_13);
  (Wrd9.Obj) = (current_block [OBJECT_35_4]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_18]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_19]))));
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_17]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_35_18);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Wrd13.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd7.Obj);
  (Wrd11.pObj) = (& (Rhp [-2]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd11.pObj)));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_29]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (current_block [OBJECT_35_6]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [5]);
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [3]);
  (* (--Rsp)) = (Wrd20.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_35_29);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_58)
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_35]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_3]), 1);

DEFLABEL (label_51)
  (* (--Rsp)) = Rvl;
  goto label_57;

DEFLABEL (label_60)
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_34]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_2]), 1);

DEFLABEL (label_50)
  (Wrd33.Obj) = Rvl;
  goto label_59;

DEFLABEL (label_62)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_33]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_2]), 1);

DEFLABEL (label_49)
  (Wrd18.Obj) = Rvl;
  goto label_61;

DEFLABEL (label_64)
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_23]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_2]), 1);

DEFLABEL (label_41)
  (* (--Rsp)) = Rvl;
  goto label_63;

DEFLABEL (label_66)
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_22]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_2]), 1);

DEFLABEL (label_40)
  (Wrd29.Obj) = Rvl;
  goto label_65;

DEFLABEL (label_68)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_21]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_2]), 1);

DEFLABEL (label_39)
  (Wrd14.Obj) = Rvl;
  goto label_67;

DEFLABEL (label_70)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_12]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_3]), 1);

DEFLABEL (label_38)
  (* (--Rsp)) = Rvl;
  goto label_69;

DEFLABEL (label_72)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_11]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_2]), 1);

DEFLABEL (label_37)
  (Wrd5.Obj) = Rvl;
  goto label_71;

DEFLABEL (lambda_55)
DEFLABEL (lambda_23)
  INTERRUPT_CHECK (26, LABEL_35_16);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_84;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_83)
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_82;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd15.pObj) [1]);

DEFLABEL (label_81)
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd21.uLng) == 1)
    goto label_76;
  (Wrd26.Obj) = (Rsp [0]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if ((Wrd27.uLng) == 1)
    goto label_74;

DEFLABEL (label_73)
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_3]), 1);

DEFLABEL (label_74)
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  Rvl = ((Wrd24.pObj) [0]);

DEFLABEL (label_75)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_76)
  (Wrd31.Obj) = (Rsp [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if (! ((Wrd32.uLng) == 1))
    goto label_80;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd28.Obj) = ((Wrd30.pObj) [1]);

DEFLABEL (label_79)
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if (! ((Wrd39.uLng) == 1))
    goto label_78;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd37.Obj) = ((Wrd38.pObj) [1]);

DEFLABEL (label_77)
  (Rsp [0]) = (Wrd37.Obj);
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd49.uLng) == 1))
    goto label_73;
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  Rvl = ((Wrd46.pObj) [0]);
  goto label_75;

DEFLABEL (label_78)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_28]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_2]), 1);

DEFLABEL (label_45)
  (Wrd37.Obj) = Rvl;
  goto label_77;

DEFLABEL (label_80)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_27]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd31.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_2]), 1);

DEFLABEL (label_44)
  (Wrd28.Obj) = Rvl;
  goto label_79;

DEFLABEL (label_82)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_26]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_2]), 1);

DEFLABEL (label_43)
  (Wrd14.Obj) = Rvl;
  goto label_81;

DEFLABEL (label_84)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_25]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_2]), 1);

DEFLABEL (label_42)
  (Wrd5.Obj) = Rvl;
  goto label_83;

DEFLABEL (lambda_56)
DEFLABEL (lambda_9)
  INTERRUPT_CHECK (26, LABEL_35_19);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_90;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_89)
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_88;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd15.pObj) [0]);

DEFLABEL (label_87)
  (Wrd24.Obj) = (current_block [OBJECT_35_4]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd24.Obj);
  (Wrd22.pObj) = (& (Rhp [-2]));
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd22.pObj)));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd28.Obj) = (Rsp [1]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if (! ((Wrd29.uLng) == 1))
    goto label_86;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd25.Obj) = ((Wrd27.pObj) [0]);

DEFLABEL (label_85)
  (Wrd34.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd25.Obj);
  (* (Rhp++)) = (Wrd34.Obj);
  (Wrd37.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd37.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_86)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_32]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_3]), 1);

DEFLABEL (label_48)
  (Wrd25.Obj) = Rvl;
  goto label_85;

DEFLABEL (label_88)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_31]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_3]), 1);

DEFLABEL (label_47)
  (Wrd14.Obj) = Rvl;
  goto label_87;

DEFLABEL (label_90)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_30]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_2]), 1);

DEFLABEL (label_46)
  (Wrd5.Obj) = Rvl;
  goto label_89;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_36_5 3
#define LABEL_36_6 5
#define LABEL_36_8 7
#define LABEL_36_4 9
#define LABEL_36_10 11
#define LABEL_36_13 13
#define LABEL_36_14 15
#define LABEL_36_15 17
#define LABEL_36_16 19
#define LABEL_36_17 21
#define LABEL_36_19 23
#define LABEL_36_20 25
#define LABEL_36_22 27
#define LABEL_36_23 29
#define LABEL_36_24 31
#define LABEL_36_25 33
#define LABEL_36_7 35
#define LABEL_36_26 37
#define LABEL_36_28 39
#define LABEL_36_29 41
#define LABEL_36_31 43
#define LABEL_36_32 45
#define LABEL_36_30 47
#define LABEL_36_34 49
#define LABEL_36_35 51
#define LABEL_36_36 53
#define LABEL_36_37 55
#define LABEL_36_38 57
#define LABEL_36_39 59
#define LABEL_36_40 61
#define LABEL_36_27 63
#define LABEL_36_42 65
#define LABEL_36_44 67
#define LABEL_36_45 69
#define LABEL_36_33 71
#define LABEL_36_47 73
#define LABEL_36_46 75
#define LABEL_36_43 77
#define LABEL_36_49 79
#define LABEL_36_21 81
#define LABEL_36_18 83
#define LABEL_36_48 85
#define LABEL_36_41 87
#define LABEL_36_51 89
#define LABEL_36_52 91
#define LABEL_36_53 93
#define LABEL_36_50 95
#define LABEL_36_54 97
#define LABEL_36_55 99
#define LABEL_36_56 101
#define ENVIRONMENT_LABEL_36_3 123
#define DEBUGGING_LABEL_36_2 122
#define OBJECT_36_12 121
#define OBJECT_36_11 120
#define OBJECT_36_10 119
#define OBJECT_36_9 118
#define OBJECT_36_8 117
#define OBJECT_36_7 116
#define OBJECT_36_6 115
#define OBJECT_36_5 114
#define OBJECT_36_4 113
#define OBJECT_36_3 112
#define OBJECT_36_2 111
#define OBJECT_36_1 110
#define OBJECT_36_0 109
#define EXECUTE_CACHE_36_12 103
#define EXECUTE_CACHE_36_11 105
#define EXECUTE_CACHE_36_9 107
#define FREE_REFERENCES_LABEL_36_0 102
#define NUMBER_OF_LINKER_SECTIONS_36_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_36 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd54;
  machine_word Wrd23;
  machine_word Wrd16;
  machine_word Wrd25;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd43;
  machine_word Wrd39;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd69;
  machine_word Wrd68;
  machine_word Wrd67;
  machine_word Wrd98;
  machine_word Wrd97;
  machine_word Wrd86;
  machine_word Wrd87;
  machine_word Wrd88;
  machine_word Wrd79;
  machine_word Wrd78;
  machine_word Wrd72;
  machine_word Wrd73;
  machine_word Wrd63;
  machine_word Wrd56;
  machine_word Wrd58;
  machine_word Wrd55;
  machine_word Wrd47;
  machine_word Wrd49;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd142;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd57;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd53;
  machine_word Wrd50;
  machine_word Wrd42;
  machine_word Wrd44;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd41;
  machine_word Wrd33;
  machine_word Wrd26;
  machine_word Wrd28;
  machine_word Wrd77;
  machine_word Wrd76;
  machine_word Wrd75;
  machine_word Wrd74;
  machine_word Wrd96;
  machine_word Wrd91;
  machine_word Wrd90;
  machine_word Wrd92;
  machine_word Wrd89;
  machine_word Wrd81;
  machine_word Wrd83;
  machine_word Wrd85;
  machine_word Wrd84;
  machine_word Wrd80;
  machine_word Wrd71;
  machine_word Wrd70;
  machine_word Wrd62;
  machine_word Wrd64;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd101;
  machine_word Wrd100;
  machine_word Wrd99;
  machine_word Wrd60;
  machine_word Wrd116;
  machine_word Wrd115;
  machine_word Wrd114;
  machine_word Wrd111;
  machine_word Wrd105;
  machine_word Wrd104;
  machine_word Wrd107;
  machine_word Wrd106;
  machine_word Wrd141;
  machine_word Wrd140;
  machine_word Wrd137;
  machine_word Wrd132;
  machine_word Wrd131;
  machine_word Wrd133;
  machine_word Wrd130;
  machine_word Wrd122;
  machine_word Wrd124;
  machine_word Wrd126;
  machine_word Wrd125;
  machine_word Wrd121;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd24;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd15;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd36;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd27;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_36_5);
      goto continuation_2;

    case 1:
      current_block = (Rpc - LABEL_36_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_36_8);
      goto label_83;

    case 3:
      current_block = (Rpc - LABEL_36_4);
      goto expand_cond_clause_80;

    case 4:
      current_block = (Rpc - LABEL_36_10);
      goto label_82;

    case 5:
      current_block = (Rpc - LABEL_36_13);
      goto continuation_76;

    case 6:
      current_block = (Rpc - LABEL_36_14);
      goto continuation_67;

    case 7:
      current_block = (Rpc - LABEL_36_15);
      goto continuation_72;

    case 8:
      current_block = (Rpc - LABEL_36_16);
      goto label_95;

    case 9:
      current_block = (Rpc - LABEL_36_17);
      goto label_96;

    case 10:
      current_block = (Rpc - LABEL_36_19);
      goto continuation_77;

    case 11:
      current_block = (Rpc - LABEL_36_20);
      goto label_94;

    case 12:
      current_block = (Rpc - LABEL_36_22);
      goto continuation_8;

    case 13:
      current_block = (Rpc - LABEL_36_23);
      goto label_88;

    case 14:
      current_block = (Rpc - LABEL_36_24);
      goto label_89;

    case 15:
      current_block = (Rpc - LABEL_36_25);
      goto label_90;

    case 16:
      current_block = (Rpc - LABEL_36_7);
      goto continuation_5;

    case 17:
      current_block = (Rpc - LABEL_36_26);
      goto label_85;

    case 18:
      current_block = (Rpc - LABEL_36_28);
      goto label_86;

    case 19:
      current_block = (Rpc - LABEL_36_29);
      goto label_87;

    case 20:
      current_block = (Rpc - LABEL_36_31);
      goto label_84;

    case 21:
      current_block = (Rpc - LABEL_36_32);
      goto continuation_6;

    case 22:
      current_block = (Rpc - LABEL_36_30);
      goto continuation_11;

    case 23:
      current_block = (Rpc - LABEL_36_34);
      goto continuation_47;

    case 24:
      current_block = (Rpc - LABEL_36_35);
      goto continuation_31;

    case 25:
      current_block = (Rpc - LABEL_36_36);
      goto label_98;

    case 26:
      current_block = (Rpc - LABEL_36_37);
      goto label_99;

    case 27:
      current_block = (Rpc - LABEL_36_38);
      goto label_100;

    case 28:
      current_block = (Rpc - LABEL_36_39);
      goto label_101;

    case 29:
      current_block = (Rpc - LABEL_36_40);
      goto label_102;

    case 30:
      current_block = (Rpc - LABEL_36_27);
      goto continuation_27;

    case 31:
      current_block = (Rpc - LABEL_36_42);
      goto label_93;

    case 32:
      current_block = (Rpc - LABEL_36_44);
      goto label_91;

    case 33:
      current_block = (Rpc - LABEL_36_45);
      goto label_92;

    case 34:
      current_block = (Rpc - LABEL_36_33);
      goto continuation_17;

    case 35:
      current_block = (Rpc - LABEL_36_47);
      goto label_97;

    case 36:
      current_block = (Rpc - LABEL_36_46);
      goto continuation_28;

    case 37:
      current_block = (Rpc - LABEL_36_43);
      goto continuation_34;

    case 38:
      current_block = (Rpc - LABEL_36_49);
      goto label_103;

    case 39:
      current_block = (Rpc - LABEL_36_21);
      goto continuation_78;

    case 40:
      current_block = (Rpc - LABEL_36_18);
      goto continuation_73;

    case 41:
      current_block = (Rpc - LABEL_36_48);
      goto continuation_12;

    case 42:
      current_block = (Rpc - LABEL_36_41);
      goto continuation_48;

    case 43:
      current_block = (Rpc - LABEL_36_51);
      goto label_104;

    case 44:
      current_block = (Rpc - LABEL_36_52);
      goto label_105;

    case 45:
      current_block = (Rpc - LABEL_36_53);
      goto label_106;

    case 46:
      current_block = (Rpc - LABEL_36_50);
      goto continuation_32;

    case 47:
      current_block = (Rpc - LABEL_36_54);
      goto continuation_54;

    case 48:
      current_block = (Rpc - LABEL_36_55);
      goto label_107;

    case 49:
      current_block = (Rpc - LABEL_36_56);
      goto continuation_49;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expand_cond_clause_109)
DEFLABEL (expand_cond_clause_80)
  INTERRUPT_CHECK (26, LABEL_36_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_128;

DEFLABEL (label_127)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_6]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_36_2]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_12]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_36_6);

DEFLABEL (label_126)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_7]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd31.Obj) = (Rsp [1]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if (! ((Wrd32.uLng) == 1))
    goto label_125;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_124)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_9]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_36_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_113;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_22]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_112;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_111)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_32]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_36_8]);
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_110)
  (Wrd142.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd142.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_112)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_31]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_0]), 1);

DEFLABEL (label_84)
  (* (--Rsp)) = Rvl;
  goto label_111;

DEFLABEL (label_113)
  (Wrd27.Obj) = (Rsp [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd28.uLng) == 1))
    goto label_123;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd24.Obj) = ((Wrd26.pObj) [1]);

DEFLABEL (label_122)
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd33.uLng) == 1)
    goto label_116;
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_30]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd37.Obj) = (current_block [OBJECT_36_7]);
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd38.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd38.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_36_30);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_33]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_36_9]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_36_33);
  (Wrd8.Obj) = (Rsp [6]);
  (Wrd9.Obj) = (current_block [OBJECT_36_10]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Wrd13.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd21.pObj) = (& (Rhp [-2]));
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd21.pObj)));
  (* (Rhp++)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd23.pObj) = (& (Rhp [-2]));
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd23.pObj)));
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd29.Obj) = (Rsp [2]);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if (! ((Wrd30.uLng) == 1))
    goto label_115;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd26.Obj) = ((Wrd28.pObj) [0]);

DEFLABEL (label_114)
  (Wrd38.Obj) = (current_block [OBJECT_36_10]);
  (* (Rhp++)) = (Wrd26.Obj);
  (* (Rhp++)) = (Wrd38.Obj);
  (Wrd37.pObj) = (& (Rhp [-2]));
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd37.pObj)));
  (Wrd42.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd42.Obj);
  (* (Rhp++)) = (Wrd35.Obj);
  (Wrd41.pObj) = (& (Rhp [-2]));
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd41.pObj)));
  (* (Rhp++)) = (Wrd39.Obj);
  (* (Rhp++)) = (Wrd38.Obj);
  (Wrd45.pObj) = (& (Rhp [-2]));
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd45.pObj)));
  (Wrd47.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd43.Obj);
  (* (Rhp++)) = (Wrd47.Obj);
  (Wrd49.pObj) = (& (Rhp [-2]));
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd49.pObj)));
  (* (--Rsp)) = (Wrd50.Obj);
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_48]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd54.Obj) = (current_block [OBJECT_36_12]);
  (* (--Rsp)) = (Wrd54.Obj);
  (Wrd55.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd55.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_36_48);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  Rsp = (& (Rsp [7]));
  goto pop_return;

DEFLABEL (label_115)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_47]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_0]), 1);

DEFLABEL (label_97)
  (Wrd26.Obj) = Rvl;
  goto label_114;

DEFLABEL (label_116)
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_27]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (Wrd45.Obj) = (Rsp [1]);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd45.Obj));
  if (! ((Wrd46.uLng) == 1))
    goto label_121;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd42.Obj) = ((Wrd44.pObj) [1]);

DEFLABEL (label_120)
  (Wrd53.uLng) = (OBJECT_TYPE (Wrd42.Obj));
  if (! ((Wrd53.uLng) == 1))
    goto label_118;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd42.Obj));
  (Wrd52.Obj) = ((Wrd51.pObj) [0]);
  (* (--Rsp)) = (Wrd52.Obj);

DEFLABEL (label_117)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_9]));

DEFLABEL (label_118)
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_29]))));
  (* (--Rsp)) = (Wrd57.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_0]), 1);

DEFLABEL (label_87)
DEFLABEL (label_119)
  (* (--Rsp)) = Rvl;
  goto label_117;

DEFLABEL (label_121)
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_28]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_1]), 1);

DEFLABEL (label_86)
  (Wrd42.Obj) = Rvl;
  goto label_120;

DEFLABEL (label_123)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_26]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_1]), 1);

DEFLABEL (label_85)
  (Wrd24.Obj) = Rvl;
  goto label_122;

DEFLABEL (label_125)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_8]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd31.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_0]), 1);

DEFLABEL (label_83)
  (* (--Rsp)) = Rvl;
  goto label_124;

DEFLABEL (label_128)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_5]))));
  (* (--Rsp)) = (Wrd15.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_130;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [1]);
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_129)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_36_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_127;
  goto label_126;

DEFLABEL (label_130)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_10]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_1]), 1);

DEFLABEL (label_82)
  (* (--Rsp)) = Rvl;
  goto label_129;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_36_32);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_36_22);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_113;
  (Wrd60.Obj) = (Rsp [4]);
  if ((Wrd60.Obj) == ((SCHEME_OBJECT) 0))
    goto label_140;

DEFLABEL (label_139)
  (Wrd65.Obj) = (Rsp [0]);
  (Wrd66.uLng) = (OBJECT_TYPE (Wrd65.Obj));
  if (! ((Wrd66.uLng) == 1))
    goto label_138;
  (Wrd64.pObj) = (OBJECT_ADDRESS (Wrd65.Obj));
  (Wrd62.Obj) = ((Wrd64.pObj) [1]);

DEFLABEL (label_137)
  (Wrd71.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if ((Wrd71.uLng) == 1)
    goto label_133;

DEFLABEL (label_132)
  (Wrd74.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_19]))));
  (* (--Rsp)) = (Wrd74.Obj);
  (Wrd75.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd75.Obj);
  (Wrd76.Obj) = (current_block [OBJECT_36_6]);
  (* (--Rsp)) = (Wrd76.Obj);

DEFLABEL (label_131)
  (Wrd77.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd77.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_12]));

DEFLABEL (label_133)
  (Wrd80.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_15]))));
  (* (--Rsp)) = (Wrd80.Obj);
  (Wrd84.Obj) = (Rsp [1]);
  (Wrd85.uLng) = (OBJECT_TYPE (Wrd84.Obj));
  if (! ((Wrd85.uLng) == 1))
    goto label_136;
  (Wrd83.pObj) = (OBJECT_ADDRESS (Wrd84.Obj));
  (Wrd81.Obj) = ((Wrd83.pObj) [1]);

DEFLABEL (label_135)
  (Wrd92.uLng) = (OBJECT_TYPE (Wrd81.Obj));
  if (! ((Wrd92.uLng) == 1))
    goto label_134;
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd81.Obj));
  (Wrd91.Obj) = ((Wrd90.pObj) [0]);
  (* (--Rsp)) = (Wrd91.Obj);
  goto label_117;

DEFLABEL (label_134)
  (Wrd96.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_25]))));
  (* (--Rsp)) = (Wrd96.Obj);
  (* (--Rsp)) = (Wrd81.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_0]), 1);

DEFLABEL (label_90)
  goto label_119;

DEFLABEL (label_136)
  (Wrd89.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_24]))));
  (* (--Rsp)) = (Wrd89.Obj);
  (* (--Rsp)) = (Wrd84.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_1]), 1);

DEFLABEL (label_89)
  (Wrd81.Obj) = Rvl;
  goto label_135;

DEFLABEL (label_138)
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_23]))));
  (* (--Rsp)) = (Wrd70.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_1]), 1);

DEFLABEL (label_88)
  (Wrd62.Obj) = Rvl;
  goto label_137;

DEFLABEL (label_140)
  (Wrd99.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_14]))));
  (* (--Rsp)) = (Wrd99.Obj);
  (Wrd100.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd100.Obj);
  (Wrd101.Obj) = (current_block [OBJECT_36_5]);
  (* (--Rsp)) = (Wrd101.Obj);
  goto label_131;

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_36_27);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_162;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_35]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_170;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [1]);

DEFLABEL (label_169)
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd21.uLng) == 1))
    goto label_168;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_167)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_46]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd29.Obj) = (current_block [OBJECT_36_3]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd30.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_36_46);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_36_35);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_162;
  (Wrd50.Obj) = (Rsp [0]);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd51.uLng) == 1))
    goto label_161;
  (Wrd49.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd47.Obj) = ((Wrd49.pObj) [1]);

DEFLABEL (label_160)
  (Wrd58.uLng) = (OBJECT_TYPE (Wrd47.Obj));
  if (! ((Wrd58.uLng) == 1))
    goto label_159;
  (Wrd57.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  (Wrd56.Obj) = ((Wrd57.pObj) [1]);

DEFLABEL (label_158)
  (Wrd63.uLng) = (OBJECT_TYPE (Wrd56.Obj));
  if ((Wrd63.uLng) == 1)
    goto label_151;

DEFLABEL (label_150)
  (Wrd66.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_34]))));
  (* (--Rsp)) = (Wrd66.Obj);
  (Wrd67.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd67.Obj);
  (Wrd68.Obj) = (current_block [OBJECT_36_11]);
  (* (--Rsp)) = (Wrd68.Obj);
  (Wrd69.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd69.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_12]));

DEFLABEL (continuation_47)
  INTERRUPT_CHECK (27, LABEL_36_34);

DEFLABEL (label_149)
  (Wrd96.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_41]))));
  (* (--Rsp)) = (Wrd96.Obj);
  (Wrd97.Obj) = (current_block [OBJECT_36_7]);
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd98.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd98.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_48)
  INTERRUPT_CHECK (27, LABEL_36_41);
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_148;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_147)
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_146;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd15.pObj) [1]);

DEFLABEL (label_145)
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd23.uLng) == 1))
    goto label_144;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd21.Obj) = ((Wrd22.pObj) [0]);

DEFLABEL (label_143)
  (Wrd31.Obj) = (Rsp [0]);
  (Wrd32.Obj) = (current_block [OBJECT_36_10]);
  (* (Rhp++)) = (Wrd31.Obj);
  (* (Rhp++)) = (Wrd32.Obj);
  (Wrd30.pObj) = (& (Rhp [-2]));
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd30.pObj)));
  (* (Rhp++)) = (Wrd21.Obj);
  (* (Rhp++)) = (Wrd28.Obj);
  (Wrd35.pObj) = (& (Rhp [-2]));
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd35.pObj)));
  (Wrd39.Obj) = (Rsp [6]);
  (* (Rhp++)) = (Wrd39.Obj);
  (* (Rhp++)) = (Wrd32.Obj);
  (Wrd38.pObj) = (& (Rhp [-2]));
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd38.pObj)));
  (* (Rhp++)) = (Wrd33.Obj);
  (* (Rhp++)) = (Wrd36.Obj);
  (Wrd43.pObj) = (& (Rhp [-2]));
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd43.pObj)));
  (* (Rhp++)) = (Wrd31.Obj);
  (* (Rhp++)) = (Wrd41.Obj);
  (Wrd45.pObj) = (& (Rhp [-2]));
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd45.pObj)));
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_54]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (Wrd51.Obj) = (current_block [OBJECT_36_9]);
  (* (--Rsp)) = (Wrd51.Obj);
  (Wrd52.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd52.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_54)
  INTERRUPT_CHECK (27, LABEL_36_54);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Wrd13.Obj) = (current_block [OBJECT_36_10]);
  (* (Rhp++)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd11.pObj) = (& (Rhp [-2]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd11.pObj)));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_142;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [0]);

DEFLABEL (label_141)
  (Wrd26.Obj) = (current_block [OBJECT_36_10]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd26.Obj);
  (Wrd25.pObj) = (& (Rhp [-2]));
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd25.pObj)));
  (Wrd30.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd30.Obj);
  (* (Rhp++)) = (Wrd23.Obj);
  (Wrd29.pObj) = (& (Rhp [-2]));
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd29.pObj)));
  (* (Rhp++)) = (Wrd27.Obj);
  (* (Rhp++)) = (Wrd26.Obj);
  (Wrd33.pObj) = (& (Rhp [-2]));
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd33.pObj)));
  (Wrd35.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd31.Obj);
  (* (Rhp++)) = (Wrd35.Obj);
  (Wrd37.pObj) = (& (Rhp [-2]));
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd37.pObj)));
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_56]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (Wrd42.Obj) = (current_block [OBJECT_36_12]);
  (* (--Rsp)) = (Wrd42.Obj);
  (Wrd43.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd43.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_49)
  INTERRUPT_CHECK (27, LABEL_36_56);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  Rsp = (& (Rsp [7]));
  goto pop_return;

DEFLABEL (label_142)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_55]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_0]), 1);

DEFLABEL (label_107)
  (Wrd14.Obj) = Rvl;
  goto label_141;

DEFLABEL (label_144)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_53]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_0]), 1);

DEFLABEL (label_106)
  (Wrd21.Obj) = Rvl;
  goto label_143;

DEFLABEL (label_146)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_52]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_1]), 1);

DEFLABEL (label_105)
  (Wrd14.Obj) = Rvl;
  goto label_145;

DEFLABEL (label_148)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_51]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_1]), 1);

DEFLABEL (label_104)
  (Wrd5.Obj) = Rvl;
  goto label_147;

DEFLABEL (label_151)
  (Wrd73.Obj) = (Rsp [0]);
  (Wrd74.uLng) = (OBJECT_TYPE (Wrd73.Obj));
  if (! ((Wrd74.uLng) == 1))
    goto label_157;
  (Wrd72.pObj) = (OBJECT_ADDRESS (Wrd73.Obj));
  (Wrd70.Obj) = ((Wrd72.pObj) [1]);

DEFLABEL (label_156)
  (Wrd81.uLng) = (OBJECT_TYPE (Wrd70.Obj));
  if (! ((Wrd81.uLng) == 1))
    goto label_155;
  (Wrd80.pObj) = (OBJECT_ADDRESS (Wrd70.Obj));
  (Wrd79.Obj) = ((Wrd80.pObj) [1]);

DEFLABEL (label_154)
  (Wrd88.uLng) = (OBJECT_TYPE (Wrd79.Obj));
  if (! ((Wrd88.uLng) == 1))
    goto label_153;
  (Wrd87.pObj) = (OBJECT_ADDRESS (Wrd79.Obj));
  (Wrd86.Obj) = ((Wrd87.pObj) [1]);

DEFLABEL (label_152)
  if ((Wrd86.Obj) == (current_block [OBJECT_36_10]))
    goto label_149;
  goto label_150;

DEFLABEL (label_153)
  (Wrd92.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_40]))));
  (* (--Rsp)) = (Wrd92.Obj);
  (* (--Rsp)) = (Wrd79.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_1]), 1);

DEFLABEL (label_102)
  (Wrd86.Obj) = Rvl;
  goto label_152;

DEFLABEL (label_155)
  (Wrd85.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_39]))));
  (* (--Rsp)) = (Wrd85.Obj);
  (* (--Rsp)) = (Wrd70.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_1]), 1);

DEFLABEL (label_101)
  (Wrd79.Obj) = Rvl;
  goto label_154;

DEFLABEL (label_157)
  (Wrd78.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_38]))));
  (* (--Rsp)) = (Wrd78.Obj);
  (* (--Rsp)) = (Wrd73.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_1]), 1);

DEFLABEL (label_100)
  (Wrd70.Obj) = Rvl;
  goto label_156;

DEFLABEL (label_159)
  (Wrd62.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_37]))));
  (* (--Rsp)) = (Wrd62.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_1]), 1);

DEFLABEL (label_99)
  (Wrd56.Obj) = Rvl;
  goto label_158;

DEFLABEL (label_161)
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_36]))));
  (* (--Rsp)) = (Wrd55.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_1]), 1);

DEFLABEL (label_98)
  (Wrd47.Obj) = Rvl;
  goto label_160;

DEFLABEL (label_162)
  (Wrd34.Obj) = (Rsp [0]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 1))
    goto label_166;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [1]);
  (* (--Rsp)) = (Wrd33.Obj);

DEFLABEL (label_165)
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_43]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (Wrd43.Obj) = (current_block [OBJECT_36_4]);
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd44.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd44.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_34)
  INTERRUPT_CHECK (27, LABEL_36_43);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Wrd13.Obj) = (Rsp [5]);
  (Wrd14.Obj) = (current_block [OBJECT_36_10]);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (Rhp++)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_164;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd18.Obj) = ((Wrd20.pObj) [0]);

DEFLABEL (label_163)
  (Wrd27.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd27.Obj);
  (Wrd29.pObj) = (& (Rhp [-2]));
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd29.pObj)));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_50]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (current_block [OBJECT_36_9]);
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd35.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd35.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_32)
  INTERRUPT_CHECK (27, LABEL_36_50);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  Rsp = (& (Rsp [6]));
  goto pop_return;

DEFLABEL (label_164)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_49]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_0]), 1);

DEFLABEL (label_103)
  (Wrd18.Obj) = Rvl;
  goto label_163;

DEFLABEL (label_166)
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_42]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_1]), 1);

DEFLABEL (label_93)
  (* (--Rsp)) = Rvl;
  goto label_165;

DEFLABEL (label_168)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_45]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_0]), 1);

DEFLABEL (label_92)
  (* (--Rsp)) = Rvl;
  goto label_167;

DEFLABEL (label_170)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_44]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_1]), 1);

DEFLABEL (label_91)
  (Wrd10.Obj) = Rvl;
  goto label_169;

DEFLABEL (continuation_77)
  INTERRUPT_CHECK (27, LABEL_36_19);

DEFLABEL (label_173)
  (Wrd106.Obj) = (Rsp [0]);
  (Wrd107.uLng) = (OBJECT_TYPE (Wrd106.Obj));
  if (! ((Wrd107.uLng) == 1))
    goto label_172;
  (Wrd104.pObj) = (OBJECT_ADDRESS (Wrd106.Obj));
  (Wrd105.Obj) = ((Wrd104.pObj) [1]);
  (* (--Rsp)) = (Wrd105.Obj);

DEFLABEL (label_171)
  (Wrd114.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_21]))));
  (* (--Rsp)) = (Wrd114.Obj);
  (Wrd115.Obj) = (current_block [OBJECT_36_4]);
  (* (--Rsp)) = (Wrd115.Obj);
  (Wrd116.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd116.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_78)
  INTERRUPT_CHECK (27, LABEL_36_21);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  Rsp = (& (Rsp [6]));
  goto pop_return;

DEFLABEL (label_172)
  (Wrd111.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_20]))));
  (* (--Rsp)) = (Wrd111.Obj);
  (* (--Rsp)) = (Wrd106.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_1]), 1);

DEFLABEL (label_94)
  (* (--Rsp)) = Rvl;
  goto label_171;

DEFLABEL (continuation_72)
  INTERRUPT_CHECK (27, LABEL_36_15);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_173;
  (Wrd121.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_13]))));
  (* (--Rsp)) = (Wrd121.Obj);
  (Wrd125.Obj) = (Rsp [1]);
  (Wrd126.uLng) = (OBJECT_TYPE (Wrd125.Obj));
  if (! ((Wrd126.uLng) == 1))
    goto label_177;
  (Wrd124.pObj) = (OBJECT_ADDRESS (Wrd125.Obj));
  (Wrd122.Obj) = ((Wrd124.pObj) [1]);

DEFLABEL (label_176)
  (Wrd133.uLng) = (OBJECT_TYPE (Wrd122.Obj));
  if (! ((Wrd133.uLng) == 1))
    goto label_175;
  (Wrd131.pObj) = (OBJECT_ADDRESS (Wrd122.Obj));
  (Wrd132.Obj) = ((Wrd131.pObj) [0]);
  (* (--Rsp)) = (Wrd132.Obj);

DEFLABEL (label_174)
  (Wrd140.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_18]))));
  (* (--Rsp)) = (Wrd140.Obj);
  (Wrd141.Obj) = (current_block [OBJECT_36_3]);
  (* (--Rsp)) = (Wrd141.Obj);
  goto label_110;

DEFLABEL (label_175)
  (Wrd137.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_17]))));
  (* (--Rsp)) = (Wrd137.Obj);
  (* (--Rsp)) = (Wrd122.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_0]), 1);

DEFLABEL (label_96)
  (* (--Rsp)) = Rvl;
  goto label_174;

DEFLABEL (label_177)
  (Wrd130.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_16]))));
  (* (--Rsp)) = (Wrd130.Obj);
  (* (--Rsp)) = (Wrd125.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_1]), 1);

DEFLABEL (label_95)
  (Wrd122.Obj) = Rvl;
  goto label_176;

DEFLABEL (continuation_67)
  INTERRUPT_CHECK (27, LABEL_36_14);
  goto label_139;

DEFLABEL (continuation_73)
  INTERRUPT_CHECK (27, LABEL_36_18);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_76)
  INTERRUPT_CHECK (27, LABEL_36_13);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_173;
  goto label_132;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_37_4 3
#define LABEL_37_5 5
#define TAG_37_6 1
#define LABEL_37_18 7
#define TAG_37_19 2
#define LABEL_37_16 9
#define TAG_37_17 3
#define LABEL_37_23 11
#define LABEL_37_24 13
#define LABEL_37_25 15
#define LABEL_37_26 17
#define LABEL_37_28 19
#define LABEL_37_14 21
#define TAG_37_15 9
#define LABEL_37_30 23
#define LABEL_37_12 25
#define TAG_37_13 11
#define LABEL_37_34 27
#define LABEL_37_10 29
#define TAG_37_11 13
#define LABEL_37_8 31
#define TAG_37_9 14
#define LABEL_37_21 33
#define LABEL_37_41 35
#define LABEL_37_42 37
#define LABEL_37_32 39
#define TAG_37_33 18
#define LABEL_37_45 41
#define LABEL_37_35 43
#define TAG_37_36 20
#define LABEL_37_37 45
#define LABEL_37_40 47
#define LABEL_37_39 49
#define LABEL_37_27 51
#define LABEL_37_48 53
#define LABEL_37_50 55
#define LABEL_37_29 57
#define LABEL_37_51 59
#define LABEL_37_43 61
#define TAG_37_44 29
#define LABEL_37_46 63
#define LABEL_37_47 65
#define LABEL_37_61 67
#define LABEL_37_63 69
#define LABEL_37_64 71
#define LABEL_37_65 73
#define LABEL_37_66 75
#define LABEL_37_49 77
#define LABEL_37_59 79
#define LABEL_37_58 81
#define LABEL_37_56 83
#define LABEL_37_60 85
#define LABEL_37_68 87
#define LABEL_37_69 89
#define LABEL_37_70 91
#define LABEL_37_71 93
#define LABEL_37_62 95
#define LABEL_37_67 97
#define LABEL_37_52 99
#define LABEL_37_53 101
#define TAG_37_54 49
#define LABEL_37_72 103
#define ENVIRONMENT_LABEL_37_3 135
#define DEBUGGING_LABEL_37_2 134
#define OBJECT_37_14 133
#define OBJECT_37_13 132
#define OBJECT_37_12 131
#define OBJECT_37_11 130
#define OBJECT_37_10 129
#define OBJECT_37_9 128
#define OBJECT_37_8 127
#define OBJECT_37_7 126
#define OBJECT_37_6 125
#define OBJECT_37_5 124
#define OBJECT_37_4 123
#define OBJECT_37_3 122
#define OBJECT_37_2 121
#define OBJECT_37_1 120
#define OBJECT_37_0 119
#define EXECUTE_CACHE_37_57 105
#define EXECUTE_CACHE_37_55 107
#define EXECUTE_CACHE_37_38 109
#define EXECUTE_CACHE_37_31 111
#define EXECUTE_CACHE_37_22 113
#define EXECUTE_CACHE_37_20 115
#define EXECUTE_CACHE_37_7 117
#define FREE_REFERENCES_LABEL_37_0 104
#define NUMBER_OF_LINKER_SECTIONS_37_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_37 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd39;
  machine_word Wrd41;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd54;
  machine_word Wrd82;
  machine_word Wrd81;
  machine_word Wrd80;
  machine_word Wrd79;
  machine_word Wrd77;
  machine_word Wrd78;
  machine_word Wrd76;
  machine_word Wrd75;
  machine_word Wrd72;
  machine_word Wrd31;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd25;
  machine_word Wrd29;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd69;
  machine_word Wrd68;
  machine_word Wrd67;
  machine_word Wrd66;
  machine_word Wrd55;
  machine_word Wrd53;
  machine_word Wrd49;
  machine_word Wrd43;
  machine_word Wrd44;
  machine_word Wrd45;
  machine_word Wrd42;
  machine_word Wrd36;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd24;
  machine_word Wrd26;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd14;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd15;
  machine_word Wrd50;
  machine_word Wrd52;
  machine_word Wrd46;
  machine_word Wrd40;
  machine_word Wrd30;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd21;
  machine_word Wrd57;
  machine_word Wrd56;
  machine_word Wrd59;
  machine_word Wrd58;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_37_4);
      goto lambda_77;

    case 1:
      current_block = (Rpc - LABEL_37_5);
      goto lambda_101;

    case 2:
      current_block = (Rpc - LABEL_37_18);
      goto lambda_107;

    case 3:
      current_block = (Rpc - LABEL_37_16);
      goto descend_quasiquote_6;

    case 4:
      current_block = (Rpc - LABEL_37_23);
      goto continuation_9;

    case 5:
      current_block = (Rpc - LABEL_37_24);
      goto label_83;

    case 6:
      current_block = (Rpc - LABEL_37_25);
      goto label_84;

    case 7:
      current_block = (Rpc - LABEL_37_26);
      goto label_85;

    case 8:
      current_block = (Rpc - LABEL_37_28);
      goto label_86;

    case 9:
      current_block = (Rpc - LABEL_37_14);
      goto descend_quasiquote_pair_33;

    case 10:
      current_block = (Rpc - LABEL_37_30);
      goto label_79;

    case 11:
      current_block = (Rpc - LABEL_37_12);
      goto descend_quasiquote_pair__59;

    case 12:
      current_block = (Rpc - LABEL_37_34);
      goto label_80;

    case 13:
      current_block = (Rpc - LABEL_37_10);
      goto descend_quasiquote_vector_67;

    case 14:
      current_block = (Rpc - LABEL_37_8);
      goto finalize_quasiquote_102;

    case 15:
      current_block = (Rpc - LABEL_37_21);
      goto continuation_0;

    case 16:
      current_block = (Rpc - LABEL_37_41);
      goto label_81;

    case 17:
      current_block = (Rpc - LABEL_37_42);
      goto label_82;

    case 18:
      current_block = (Rpc - LABEL_37_32);
      goto lambda_108;

    case 19:
      current_block = (Rpc - LABEL_37_45);
      goto label_87;

    case 20:
      current_block = (Rpc - LABEL_37_35);
      goto lambda_109;

    case 21:
      current_block = (Rpc - LABEL_37_37);
      goto continuation_60;

    case 22:
      current_block = (Rpc - LABEL_37_40);
      goto continuation_71;

    case 23:
      current_block = (Rpc - LABEL_37_39);
      goto continuation_72;

    case 24:
      current_block = (Rpc - LABEL_37_27);
      goto continuation_17;

    case 25:
      current_block = (Rpc - LABEL_37_48);
      goto label_89;

    case 26:
      current_block = (Rpc - LABEL_37_50);
      goto label_88;

    case 27:
      current_block = (Rpc - LABEL_37_29);
      goto continuation_15;

    case 28:
      current_block = (Rpc - LABEL_37_51);
      goto continuation_40;

    case 29:
      current_block = (Rpc - LABEL_37_43);
      goto lambda_110;

    case 30:
      current_block = (Rpc - LABEL_37_46);
      goto continuation_63;

    case 31:
      current_block = (Rpc - LABEL_37_47);
      goto continuation_20;

    case 32:
      current_block = (Rpc - LABEL_37_61);
      goto label_94;

    case 33:
      current_block = (Rpc - LABEL_37_63);
      goto label_90;

    case 34:
      current_block = (Rpc - LABEL_37_64);
      goto label_91;

    case 35:
      current_block = (Rpc - LABEL_37_65);
      goto label_92;

    case 36:
      current_block = (Rpc - LABEL_37_66);
      goto label_93;

    case 37:
      current_block = (Rpc - LABEL_37_49);
      goto continuation_18;

    case 38:
      current_block = (Rpc - LABEL_37_59);
      goto continuation_43;

    case 39:
      current_block = (Rpc - LABEL_37_58);
      goto continuation_46;

    case 40:
      current_block = (Rpc - LABEL_37_56);
      goto continuation_54;

    case 41:
      current_block = (Rpc - LABEL_37_60);
      goto continuation_23;

    case 42:
      current_block = (Rpc - LABEL_37_68);
      goto label_95;

    case 43:
      current_block = (Rpc - LABEL_37_69);
      goto label_96;

    case 44:
      current_block = (Rpc - LABEL_37_70);
      goto label_97;

    case 45:
      current_block = (Rpc - LABEL_37_71);
      goto label_98;

    case 46:
      current_block = (Rpc - LABEL_37_62);
      goto continuation_21;

    case 47:
      current_block = (Rpc - LABEL_37_67);
      goto continuation_42;

    case 48:
      current_block = (Rpc - LABEL_37_52);
      goto continuation_50;

    case 49:
      current_block = (Rpc - LABEL_37_53);
      goto lambda_111;

    case 50:
      current_block = (Rpc - LABEL_37_72);
      goto continuation_48;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_100)
DEFLABEL (lambda_77)
  INTERRUPT_CHECK (26, LABEL_37_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_37_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_37_5])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd12 = Wrd7;
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd12.pObj) [4]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_7]));

DEFLABEL (lambda_101)
  CLOSURE_HEADER (LABEL_37_5);

DEFLABEL (lambda_76)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd64.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_37_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_37_8])));
  Rhp += 2;
  (Wrd65.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd64.pObj)));
  (* (--Rsp)) = (Wrd65.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd62.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_37_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_37_10])));
  Rhp += 2;
  (Wrd63.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd62.pObj)));
  (* (--Rsp)) = (Wrd63.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd60.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_37_13);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_37_12])));
  Rhp += 2;
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd60.pObj)));
  (* (--Rsp)) = (Wrd61.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd58.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_37_15);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_37_14])));
  Rhp += 3;
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd58.pObj)));
  (* (--Rsp)) = (Wrd59.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd56.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_37_17);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_37_16])));
  Rhp += 2;
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd56.pObj)));
  (* (--Rsp)) = (Wrd57.Obj);
  Wrd21 = Wrd56;
  ((Wrd21.pObj) [2]) = (Wrd63.Obj);
  ((Wrd21.pObj) [3]) = (Wrd59.Obj);
  Wrd32 = Wrd58;
  (Wrd33.Obj) = (Rsp [5]);
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [2]);
  ((Wrd32.pObj) [2]) = (Wrd35.Obj);
  (Wrd30.Obj) = ((Wrd34.pObj) [3]);
  ((Wrd32.pObj) [3]) = (Wrd30.Obj);
  ((Wrd32.pObj) [4]) = (Wrd61.Obj);
  Wrd40 = Wrd60;
  ((Wrd40.pObj) [2]) = (Wrd65.Obj);
  ((Wrd40.pObj) [3]) = (Wrd57.Obj);
  Wrd46 = Wrd62;
  ((Wrd46.pObj) [2]) = (Wrd65.Obj);
  ((Wrd46.pObj) [3]) = (Wrd57.Obj);
  Wrd52 = Wrd64;
  ((Wrd52.pObj) [2]) = (Wrd30.Obj);
  (Wrd50.Obj) = (Rsp [6]);
  ((Wrd52.pObj) [3]) = (Wrd50.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_37_19);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_37_18])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd12 = Wrd7;
  (Wrd15.Obj) = ((Wrd34.pObj) [4]);
  ((Wrd12.pObj) [2]) = (Wrd15.Obj);
  ((Wrd12.pObj) [3]) = (Wrd65.Obj);
  ((Wrd12.pObj) [4]) = (Wrd57.Obj);
  (Rsp [6]) = (Wrd6.Obj);
  Rsp = (& (Rsp [6]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_20]));

DEFLABEL (lambda_107)
  CLOSURE_HEADER (LABEL_37_18);

DEFLABEL (lambda_3)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_21]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_37_0]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_22]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_37_21);
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [2]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_115;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd5.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_114)
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_113;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (* (--Rsp)) = (Wrd21.Obj);

DEFLABEL (label_112)
  (Wrd27.Obj) = (Rsp [1]);
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [4]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = ((Wrd28.pObj) [3]);
  (Rsp [3]) = (Wrd30.Obj);
  (Wrd33.Obj) = (current_block [OBJECT_37_9]);
  (Rsp [2]) = (Wrd33.Obj);
  goto descend_quasiquote_6;

DEFLABEL (label_113)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_42]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_4]), 1);

DEFLABEL (label_82)
  (* (--Rsp)) = Rvl;
  goto label_112;

DEFLABEL (label_115)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_41]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_2]), 1);

DEFLABEL (label_81)
  (Wrd5.Obj) = Rvl;
  goto label_114;

DEFLABEL (descend_quasiquote_106)
DEFLABEL (descend_quasiquote_6)
  INTERRUPT_CHECK (26, LABEL_37_16);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd6.uLng) == 1))
    goto label_116;
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [3]);
  (Rsp [0]) = (Wrd16.Obj);
  goto descend_quasiquote_pair_33;

DEFLABEL (label_116)
  if ((Wrd6.uLng) == 10)
    goto label_117;
  (Wrd9.Obj) = (current_block [OBJECT_37_1]);
  (Rsp [2]) = (Wrd9.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (Rsp [1]) = (Wrd11.Obj);
  (Rsp [3]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_117)
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd13.Obj) = ((Wrd15.pObj) [2]);
  (Rsp [0]) = (Wrd13.Obj);
  goto descend_quasiquote_vector_67;

DEFLABEL (descend_quasiquote_pair_105)
DEFLABEL (descend_quasiquote_pair_33)
  INTERRUPT_CHECK (26, LABEL_37_14);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_119;

DEFLABEL (label_118)
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [4]);
  (Rsp [0]) = (Wrd7.Obj);
  goto descend_quasiquote_pair__59;

DEFLABEL (label_119)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_23]))));
  (* (--Rsp)) = (Wrd12.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_156;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_155)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_31]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_37_23);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_118;
  (Wrd27.Obj) = (Rsp [1]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd28.uLng) == 1))
    goto label_154;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd24.Obj) = ((Wrd26.pObj) [1]);

DEFLABEL (label_153)
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd33.uLng) == 1))
    goto label_118;
  (Wrd37.Obj) = (Rsp [1]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd38.uLng) == 1))
    goto label_152;
  (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd34.Obj) = ((Wrd36.pObj) [1]);

DEFLABEL (label_151)
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd45.uLng) == 1))
    goto label_150;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd43.Obj) = ((Wrd44.pObj) [1]);

DEFLABEL (label_149)
  if (! ((Wrd43.Obj) == (current_block [OBJECT_37_3])))
    goto label_118;
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_27]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd57.Obj) = (Rsp [2]);
  (Wrd58.uLng) = (OBJECT_TYPE (Wrd57.Obj));
  if (! ((Wrd58.uLng) == 1))
    goto label_148;
  (Wrd55.pObj) = (OBJECT_ADDRESS (Wrd57.Obj));
  (Wrd56.Obj) = ((Wrd55.pObj) [0]);
  (* (--Rsp)) = (Wrd56.Obj);

DEFLABEL (label_147)
  (Wrd65.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_29]))));
  (* (--Rsp)) = (Wrd65.Obj);
  (Wrd66.Obj) = (current_block [OBJECT_37_5]);
  (* (--Rsp)) = (Wrd66.Obj);
  (Wrd67.Obj) = (Rsp [4]);
  (Wrd68.pObj) = (OBJECT_ADDRESS (Wrd67.Obj));
  (Wrd69.Obj) = ((Wrd68.pObj) [3]);
  (* (--Rsp)) = (Wrd69.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_37_29);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [3]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_37_27);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_122;
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [4]);
  (Rsp [0]) = (Wrd7.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 26))
    goto label_121;
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  (Wrd17.Lng) = ((Wrd19.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd17.Lng)))
    goto label_121;
  (Wrd14.Obj) = (LONG_TO_FIXNUM (Wrd17.Lng));

DEFLABEL (label_120)
  (Rsp [2]) = (Wrd14.Obj);
  goto descend_quasiquote_pair__59;

DEFLABEL (label_121)
  (Wrd10.Obj) = (Rsp [2]);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_50]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_88)
  (Wrd14.Obj) = Rvl;
  goto label_120;

DEFLABEL (label_122)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_47]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd26.Obj) = (Rsp [2]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd27.uLng) == 1))
    goto label_146;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [0]);
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_145)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_49]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd35.Obj) = (current_block [OBJECT_37_6]);
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd36.Obj) = (Rsp [4]);
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd38.Obj) = ((Wrd37.pObj) [3]);
  (* (--Rsp)) = (Wrd38.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_37_49);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [3]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_37_47);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_132;
  (Wrd7.Obj) = (Rsp [2]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd8.uLng) == 26))
    goto label_131;
  (Wrd47.Lng) = (FIXNUM_TO_LONG (Wrd7.Obj));
  if ((Wrd47.Lng) == 0)
    goto label_126;

DEFLABEL (label_125)
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [4]);
  (Rsp [0]) = (Wrd14.Obj);
  (Wrd22.Obj) = (Rsp [2]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd23.uLng) == 26))
    goto label_124;
  (Wrd26.Lng) = (FIXNUM_TO_LONG (Wrd22.Obj));
  (Wrd24.Lng) = ((Wrd26.Lng) - 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd24.Lng)))
    goto label_124;
  (Wrd21.Obj) = (LONG_TO_FIXNUM (Wrd24.Lng));

DEFLABEL (label_123)
  (Rsp [2]) = (Wrd21.Obj);
  goto descend_quasiquote_pair__59;

DEFLABEL (label_124)
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_64]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_INTERFACE_0 (34);

DEFLABEL (label_91)
  (Wrd21.Obj) = Rvl;
  goto label_123;

DEFLABEL (label_126)
  (Wrd27.Obj) = (current_block [OBJECT_37_6]);
  (Rsp [2]) = (Wrd27.Obj);
  (Wrd31.Obj) = (Rsp [1]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if (! ((Wrd32.uLng) == 1))
    goto label_130;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd28.Obj) = ((Wrd30.pObj) [1]);

DEFLABEL (label_129)
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if (! ((Wrd39.uLng) == 1))
    goto label_128;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd37.Obj) = ((Wrd38.pObj) [0]);

DEFLABEL (label_127)
  (Wrd44.Obj) = (Rsp [3]);
  (Rsp [1]) = (Wrd44.Obj);
  (Rsp [3]) = (Wrd37.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_128)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_66]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_4]), 1);

DEFLABEL (label_93)
  (Wrd37.Obj) = Rvl;
  goto label_127;

DEFLABEL (label_130)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_65]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd31.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_2]), 1);

DEFLABEL (label_92)
  (Wrd28.Obj) = Rvl;
  goto label_129;

DEFLABEL (label_131)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_63]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_INTERFACE_0 (45);

DEFLABEL (label_90)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_125;
  goto label_126;

DEFLABEL (label_132)
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_60]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (Wrd54.Obj) = (Rsp [2]);
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if (! ((Wrd55.uLng) == 1))
    goto label_144;
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [0]);
  (* (--Rsp)) = (Wrd53.Obj);

DEFLABEL (label_143)
  (Wrd62.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_62]))));
  (* (--Rsp)) = (Wrd62.Obj);
  (Wrd63.Obj) = (current_block [OBJECT_37_7]);
  (* (--Rsp)) = (Wrd63.Obj);
  (Wrd64.Obj) = (Rsp [4]);
  (Wrd65.pObj) = (OBJECT_ADDRESS (Wrd64.Obj));
  (Wrd66.Obj) = ((Wrd65.pObj) [3]);
  (* (--Rsp)) = (Wrd66.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_37_62);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [3]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_37_60);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_133;
  (Wrd49.Obj) = (Rsp [0]);
  (Wrd50.pObj) = (OBJECT_ADDRESS (Wrd49.Obj));
  (Wrd48.Obj) = ((Wrd50.pObj) [4]);
  (Rsp [0]) = (Wrd48.Obj);
  goto descend_quasiquote_pair__59;

DEFLABEL (label_133)
  (Wrd7.Obj) = (Rsp [2]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd8.uLng) == 26))
    goto label_142;
  (Wrd47.Lng) = (FIXNUM_TO_LONG (Wrd7.Obj));
  if ((Wrd47.Lng) == 0)
    goto label_137;

DEFLABEL (label_136)
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [4]);
  (Rsp [0]) = (Wrd14.Obj);
  (Wrd22.Obj) = (Rsp [2]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd23.uLng) == 26))
    goto label_135;
  (Wrd26.Lng) = (FIXNUM_TO_LONG (Wrd22.Obj));
  (Wrd24.Lng) = ((Wrd26.Lng) - 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd24.Lng)))
    goto label_135;
  (Wrd21.Obj) = (LONG_TO_FIXNUM (Wrd24.Lng));

DEFLABEL (label_134)
  (Rsp [2]) = (Wrd21.Obj);
  goto descend_quasiquote_pair__59;

DEFLABEL (label_135)
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_69]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_INTERFACE_0 (34);

DEFLABEL (label_96)
  (Wrd21.Obj) = Rvl;
  goto label_134;

DEFLABEL (label_137)
  (Wrd27.Obj) = (current_block [OBJECT_37_7]);
  (Rsp [2]) = (Wrd27.Obj);
  (Wrd31.Obj) = (Rsp [1]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if (! ((Wrd32.uLng) == 1))
    goto label_141;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd28.Obj) = ((Wrd30.pObj) [1]);

DEFLABEL (label_140)
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if (! ((Wrd39.uLng) == 1))
    goto label_139;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd37.Obj) = ((Wrd38.pObj) [0]);

DEFLABEL (label_138)
  (Wrd44.Obj) = (Rsp [3]);
  (Rsp [1]) = (Wrd44.Obj);
  (Rsp [3]) = (Wrd37.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_139)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_71]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_4]), 1);

DEFLABEL (label_98)
  (Wrd37.Obj) = Rvl;
  goto label_138;

DEFLABEL (label_141)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_70]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd31.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_2]), 1);

DEFLABEL (label_97)
  (Wrd28.Obj) = Rvl;
  goto label_140;

DEFLABEL (label_142)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_68]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_INTERFACE_0 (45);

DEFLABEL (label_95)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_136;
  goto label_137;

DEFLABEL (label_144)
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_61]))));
  (* (--Rsp)) = (Wrd59.Obj);
  (* (--Rsp)) = (Wrd54.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_4]), 1);

DEFLABEL (label_94)
  (* (--Rsp)) = Rvl;
  goto label_143;

DEFLABEL (label_146)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_48]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_4]), 1);

DEFLABEL (label_89)
  (* (--Rsp)) = Rvl;
  goto label_145;

DEFLABEL (label_148)
  (Wrd62.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_28]))));
  (* (--Rsp)) = (Wrd62.Obj);
  (* (--Rsp)) = (Wrd57.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_4]), 1);

DEFLABEL (label_86)
  (* (--Rsp)) = Rvl;
  goto label_147;

DEFLABEL (label_150)
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_26]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_2]), 1);

DEFLABEL (label_85)
  (Wrd43.Obj) = Rvl;
  goto label_149;

DEFLABEL (label_152)
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_25]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_2]), 1);

DEFLABEL (label_84)
  (Wrd34.Obj) = Rvl;
  goto label_151;

DEFLABEL (label_154)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_24]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_2]), 1);

DEFLABEL (label_83)
  (Wrd24.Obj) = Rvl;
  goto label_153;

DEFLABEL (label_156)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_30]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_4]), 1);

DEFLABEL (label_79)
  (* (--Rsp)) = Rvl;
  goto label_155;

DEFLABEL (descend_quasiquote_pair__104)
DEFLABEL (descend_quasiquote_pair__59)
  INTERRUPT_CHECK (26, LABEL_37_12);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 8));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_37_33);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_37_32])));
  Rhp += 5;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd18 = Wrd7;
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [2]);
  ((Wrd18.pObj) [2]) = (Wrd21.Obj);
  (Wrd17.Obj) = ((Wrd20.pObj) [3]);
  ((Wrd18.pObj) [3]) = (Wrd17.Obj);
  (Wrd13.Obj) = (Rsp [3]);
  ((Wrd18.pObj) [4]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  ((Wrd18.pObj) [5]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd18.pObj) [6]) = (Wrd9.Obj);
  (Rsp [3]) = (Wrd6.Obj);
  (Rsp [0]) = (Wrd17.Obj);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd29.uLng) == 1))
    goto label_158;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd25.Obj) = ((Wrd27.pObj) [0]);

DEFLABEL (label_157)
  (Rsp [1]) = (Wrd25.Obj);
  goto descend_quasiquote_6;

DEFLABEL (label_158)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_34]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_4]), 1);

DEFLABEL (label_80)
  (Wrd25.Obj) = Rvl;
  goto label_157;

DEFLABEL (descend_quasiquote_vector_103)
DEFLABEL (descend_quasiquote_vector_67)
  INTERRUPT_CHECK (26, LABEL_37_10);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_37_36);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_37_35])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd12 = Wrd7;
  (Wrd13.Obj) = (Rsp [0]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [2]);
  ((Wrd12.pObj) [2]) = (Wrd15.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd12.pObj) [4]) = (Wrd9.Obj);
  (Rsp [3]) = (Wrd6.Obj);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_37]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_38]));

DEFLABEL (continuation_60)
  INTERRUPT_CHECK (27, LABEL_37_37);
  (Rsp [1]) = Rvl;
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [3]);
  (Rsp [0]) = (Wrd6.Obj);
  goto descend_quasiquote_6;

DEFLABEL (finalize_quasiquote_102)
  CLOSURE_HEADER (LABEL_37_8);

DEFLABEL (finalize_quasiquote_75)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.Obj) = (current_block [OBJECT_37_1]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_162;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_37_6])))
    goto label_159;
  Rvl = (Rsp [2]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_159)
  if (! ((Wrd5.Obj) == (current_block [OBJECT_37_7])))
    goto label_160;
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd18.Obj) = ((Wrd20.pObj) [3]);
  (Rsp [0]) = (Wrd18.Obj);
  (Wrd21.Obj) = (current_block [OBJECT_37_8]);
  (Rsp [1]) = (Wrd21.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_160)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_40]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd5.Obj);

DEFLABEL (label_161)
  (Wrd28.Obj) = (Rsp [2]);
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [2]);
  (* (--Rsp)) = (Wrd30.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_162)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_39]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd6.Obj);
  goto label_161;

DEFLABEL (continuation_71)
  INTERRUPT_CHECK (27, LABEL_37_40);
  (Wrd10.Obj) = (Rsp [2]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (continuation_72)
  INTERRUPT_CHECK (27, LABEL_37_39);
  (Wrd8.Obj) = (Rsp [2]);
  (Wrd9.Obj) = (current_block [OBJECT_37_3]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd13.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd13.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (lambda_108)
  CLOSURE_HEADER (LABEL_37_32);

DEFLABEL (lambda_58)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 8));
  (Wrd10.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_37_44);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_37_43])));
  Rhp += 5;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd10.pObj)));
  Wrd23 = Wrd10;
  (Wrd26.Obj) = ((Wrd6.pObj) [2]);
  ((Wrd23.pObj) [2]) = (Wrd26.Obj);
  (Wrd22.Obj) = ((Wrd6.pObj) [4]);
  ((Wrd23.pObj) [3]) = (Wrd22.Obj);
  (Wrd18.Obj) = ((Wrd6.pObj) [6]);
  ((Wrd23.pObj) [4]) = (Wrd18.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  ((Wrd23.pObj) [5]) = (Wrd14.Obj);
  (Wrd12.Obj) = (Rsp [2]);
  ((Wrd23.pObj) [6]) = (Wrd12.Obj);
  (Rsp [3]) = (Wrd9.Obj);
  (Wrd27.Obj) = ((Wrd6.pObj) [5]);
  (Rsp [2]) = (Wrd27.Obj);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd38.uLng) == 1))
    goto label_164;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd30.Obj) = ((Wrd34.pObj) [1]);

DEFLABEL (label_163)
  (Rsp [1]) = (Wrd30.Obj);
  goto descend_quasiquote_6;

DEFLABEL (label_164)
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_45]))));
  (* (--Rsp)) = (Wrd44.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_2]), 1);

DEFLABEL (label_87)
  (Wrd30.Obj) = Rvl;
  goto label_163;

DEFLABEL (lambda_109)
  CLOSURE_HEADER (LABEL_37_35);

DEFLABEL (lambda_66)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.Obj) = (current_block [OBJECT_37_1]);
  if (! ((Wrd5.Obj) == (Wrd6.Obj)))
    goto label_165;
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd22.Obj) = ((Wrd24.pObj) [4]);
  (Rsp [2]) = (Wrd22.Obj);
  (Wrd25.Obj) = ((Wrd24.pObj) [3]);
  (Rsp [0]) = (Wrd25.Obj);
  goto pop_return;

DEFLABEL (label_165)
  if (! ((Wrd5.Obj) == (current_block [OBJECT_37_10])))
    goto label_166;
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [3]);
  (Rsp [0]) = (Wrd17.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_37_11]);
  (Rsp [1]) = (Wrd20.Obj);
  goto pop_return;

DEFLABEL (label_166)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_46]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [2]);
  (* (--Rsp)) = (Wrd16.Obj);
  goto finalize_quasiquote_75;

DEFLABEL (continuation_63)
  INTERRUPT_CHECK (27, LABEL_37_46);
  (Wrd9.Obj) = (current_block [OBJECT_37_3]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [3]);
  (Rsp [0]) = (Wrd10.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_37_12]);
  (Rsp [1]) = (Wrd13.Obj);
  goto pop_return;

DEFLABEL (lambda_110)
  CLOSURE_HEADER (LABEL_37_43);

DEFLABEL (lambda_57)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [6]);
  (Wrd8.Obj) = (current_block [OBJECT_37_1]);
  if ((Wrd7.Obj) == (Wrd8.Obj))
    goto label_174;

DEFLABEL (label_173)
  (Wrd9.Obj) = (Rsp [0]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [6]);
  if ((Wrd11.Obj) == (current_block [OBJECT_37_7]))
    goto label_170;
  (Wrd13.Obj) = (Rsp [1]);
  if (! ((Wrd13.Obj) == (current_block [OBJECT_37_1])))
    goto label_167;
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_51]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd41.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd41.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_57]));

DEFLABEL (continuation_40)
  INTERRUPT_CHECK (27, LABEL_37_51);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_167;
  (Wrd72.Obj) = (current_block [OBJECT_37_10]);
  (Rsp [1]) = (Wrd72.Obj);
  (Wrd75.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_52]))));
  (* (--Rsp)) = (Wrd75.Obj);
  (Wrd76.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd76.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd78.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_37_54);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_37_53])));
  Rhp += 1;
  (Wrd77.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd78.pObj)));
  Wrd79 = Wrd78;
  (Wrd80.Obj) = (Rsp [2]);
  (Wrd81.pObj) = (OBJECT_ADDRESS (Wrd80.Obj));
  (Wrd82.Obj) = ((Wrd81.pObj) [2]);
  ((Wrd79.pObj) [2]) = (Wrd82.Obj);
  (* (--Rsp)) = (Wrd77.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_55]));

DEFLABEL (continuation_50)
  INTERRUPT_CHECK (27, LABEL_37_52);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_72]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [6]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd16.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd16.Obj);
  goto finalize_quasiquote_75;

DEFLABEL (continuation_48)
  INTERRUPT_CHECK (27, LABEL_37_72);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Rsp [2]) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [3]);
  (Rsp [0]) = (Wrd10.Obj);
  goto pop_return;

DEFLABEL (label_167)
  (Wrd15.Obj) = (Rsp [1]);
  (Wrd16.Obj) = (current_block [OBJECT_37_10]);
  if (! ((Wrd15.Obj) == (Wrd16.Obj)))
    goto label_168;
  (Rsp [1]) = (Wrd16.Obj);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_58]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd29.Obj) = (Rsp [1]);
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [5]);
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd34.Obj) = ((Wrd30.pObj) [6]);
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd37.Obj) = ((Wrd30.pObj) [2]);
  (* (--Rsp)) = (Wrd37.Obj);
  goto finalize_quasiquote_75;

DEFLABEL (continuation_46)
  INTERRUPT_CHECK (27, LABEL_37_58);
  (Wrd9.Obj) = (Rsp [2]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [3]);
  (Rsp [0]) = (Wrd10.Obj);
  goto pop_return;

DEFLABEL (label_168)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_59]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_169)
  (Wrd22.Obj) = (Rsp [3]);
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [2]);
  (* (--Rsp)) = (Wrd24.Obj);
  goto finalize_quasiquote_75;

DEFLABEL (label_170)
  (Wrd42.Obj) = (Rsp [1]);
  if ((Wrd42.Obj) == (current_block [OBJECT_37_1]))
    goto label_172;

DEFLABEL (label_171)
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_56]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd47.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd48.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd48.Obj);
  goto label_169;

DEFLABEL (label_172)
  (Wrd52.Obj) = (Rsp [2]);
  if (! ((Wrd52.Obj) == (current_block [OBJECT_37_3])))
    goto label_171;
  (Wrd54.Obj) = (current_block [OBJECT_37_6]);
  (Rsp [1]) = (Wrd54.Obj);
  (Wrd55.Obj) = ((Wrd10.pObj) [5]);
  (Rsp [2]) = (Wrd55.Obj);
  (Wrd58.Obj) = ((Wrd10.pObj) [3]);
  (Rsp [0]) = (Wrd58.Obj);
  goto pop_return;

DEFLABEL (label_174)
  (Wrd61.Obj) = (Rsp [1]);
  if (! ((Wrd61.Obj) == (Wrd8.Obj)))
    goto label_173;
  (Rsp [1]) = (Wrd8.Obj);
  (Wrd64.Obj) = ((Wrd6.pObj) [4]);
  (Rsp [2]) = (Wrd64.Obj);
  (Wrd67.Obj) = ((Wrd6.pObj) [3]);
  (Rsp [0]) = (Wrd67.Obj);
  goto pop_return;

DEFLABEL (continuation_43)
  INTERRUPT_CHECK (27, LABEL_37_59);
  (Wrd9.Obj) = (current_block [OBJECT_37_3]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_67]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [5]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd18.Obj) = ((Wrd14.pObj) [6]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd21.Obj) = ((Wrd14.pObj) [2]);
  (* (--Rsp)) = (Wrd21.Obj);
  goto finalize_quasiquote_75;

DEFLABEL (continuation_42)
  INTERRUPT_CHECK (27, LABEL_37_67);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Rsp [2]) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [3]);
  (Rsp [0]) = (Wrd10.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_37_14]);
  (Rsp [1]) = (Wrd13.Obj);
  goto pop_return;

DEFLABEL (continuation_54)
  INTERRUPT_CHECK (27, LABEL_37_56);
  (Wrd9.Obj) = (current_block [OBJECT_37_3]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Wrd13.Obj) = (Rsp [0]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [5]);
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd6.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (Rsp [2]) = (Wrd10.Obj);
  (Wrd16.Obj) = ((Wrd14.pObj) [3]);
  (Rsp [0]) = (Wrd16.Obj);
  (Wrd19.Obj) = (current_block [OBJECT_37_13]);
  (Rsp [1]) = (Wrd19.Obj);
  goto pop_return;

DEFLABEL (lambda_111)
  CLOSURE_HEADER (LABEL_37_53);

DEFLABEL (lambda_49)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_37_1]);
  (Rsp [1]) = (Wrd8.Obj);
  goto finalize_quasiquote_75;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_38_4 3
#define LABEL_38_5 5
#define LABEL_38_6 7
#define LABEL_38_7 9
#define LABEL_38_9 11
#define LABEL_38_8 13
#define LABEL_38_12 15
#define LABEL_38_13 17
#define LABEL_38_14 19
#define LABEL_38_11 21
#define LABEL_38_16 23
#define LABEL_38_17 25
#define LABEL_38_18 27
#define LABEL_38_19 29
#define LABEL_38_24 31
#define LABEL_38_26 33
#define TAG_38_27 15
#define LABEL_38_20 35
#define TAG_38_21 16
#define LABEL_38_28 37
#define LABEL_38_31 39
#define LABEL_38_25 41
#define LABEL_38_22 43
#define TAG_38_23 20
#define LABEL_38_29 45
#define TAG_38_30 21
#define LABEL_38_32 47
#define LABEL_38_33 49
#define LABEL_38_34 51
#define LABEL_38_36 53
#define LABEL_38_35 55
#define LABEL_38_38 57
#define LABEL_38_37 59
#define ENVIRONMENT_LABEL_38_3 78
#define DEBUGGING_LABEL_38_2 77
#define OBJECT_38_11 76
#define OBJECT_38_10 75
#define OBJECT_38_9 74
#define OBJECT_38_8 73
#define OBJECT_38_7 72
#define OBJECT_38_6 71
#define OBJECT_38_5 70
#define OBJECT_38_4 69
#define OBJECT_38_3 68
#define OBJECT_38_2 67
#define OBJECT_38_1 66
#define OBJECT_38_0 65
#define EXECUTE_CACHE_38_15 61
#define EXECUTE_CACHE_38_10 63
#define FREE_REFERENCES_LABEL_38_0 60
#define NUMBER_OF_LINKER_SECTIONS_38_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_38 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd19;
  machine_word Wrd35;
  machine_word Wrd30;
  machine_word Wrd24;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd21;
  machine_word Wrd14;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd45;
  machine_word Wrd55;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd68;
  machine_word Wrd67;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd27;
  machine_word Wrd69;
  machine_word Wrd29;
  machine_word Wrd31;
  machine_word Wrd23;
  machine_word Wrd25;
  machine_word Wrd26;
  machine_word Wrd22;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd34;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_38_4);
      goto lambda_46;

    case 1:
      current_block = (Rpc - LABEL_38_5);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_38_6);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_38_7);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_38_9);
      goto label_48;

    case 5:
      current_block = (Rpc - LABEL_38_8);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_38_12);
      goto label_51;

    case 7:
      current_block = (Rpc - LABEL_38_13);
      goto label_49;

    case 8:
      current_block = (Rpc - LABEL_38_14);
      goto label_50;

    case 9:
      current_block = (Rpc - LABEL_38_11);
      goto continuation_6;

    case 10:
      current_block = (Rpc - LABEL_38_16);
      goto label_52;

    case 11:
      current_block = (Rpc - LABEL_38_17);
      goto label_53;

    case 12:
      current_block = (Rpc - LABEL_38_18);
      goto label_54;

    case 13:
      current_block = (Rpc - LABEL_38_19);
      goto label_55;

    case 14:
      current_block = (Rpc - LABEL_38_24);
      goto continuation_18;

    case 15:
      current_block = (Rpc - LABEL_38_26);
      goto lambda_64;

    case 16:
      current_block = (Rpc - LABEL_38_20);
      goto recur_40;

    case 17:
      current_block = (Rpc - LABEL_38_28);
      goto label_56;

    case 18:
      current_block = (Rpc - LABEL_38_31);
      goto label_57;

    case 19:
      current_block = (Rpc - LABEL_38_25);
      goto lambda_17;

    case 20:
      current_block = (Rpc - LABEL_38_22);
      goto expand_30;

    case 21:
      current_block = (Rpc - LABEL_38_29);
      goto lambda_65;

    case 22:
      current_block = (Rpc - LABEL_38_32);
      goto continuation_20;

    case 23:
      current_block = (Rpc - LABEL_38_33);
      goto continuation_35;

    case 24:
      current_block = (Rpc - LABEL_38_34);
      goto continuation_21;

    case 25:
      current_block = (Rpc - LABEL_38_36);
      goto label_58;

    case 26:
      current_block = (Rpc - LABEL_38_35);
      goto continuation_22;

    case 27:
      current_block = (Rpc - LABEL_38_38);
      goto label_59;

    case 28:
      current_block = (Rpc - LABEL_38_37);
      goto continuation_24;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_61)
DEFLABEL (lambda_46)
  INTERRUPT_CHECK (26, LABEL_38_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_38_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_38_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_38_1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_38_6);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_38_2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_38_7);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_88;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [1]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_87)
  (Wrd17.Obj) = (current_block [OBJECT_38_4]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_10]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_38_8);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_71;
  (Wrd10.Obj) = (Rsp [3]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_70;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_69)
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_68;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd16.Obj) = ((Wrd17.pObj) [1]);

DEFLABEL (label_67)
  (Wrd26.Obj) = (current_block [OBJECT_38_6]);
  (* (Rhp++)) = (Wrd26.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (Wrd25.pObj) = (& (Rhp [-2]));
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd25.pObj)));
  (Wrd31.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd31.Obj);
  (* (Rhp++)) = (Wrd23.Obj);
  (Wrd29.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd29.pObj)));
  Rsp = (& (Rsp [6]));
  goto pop_return;

DEFLABEL (label_68)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_14]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_3]), 1);

DEFLABEL (label_50)
  (Wrd16.Obj) = Rvl;
  goto label_67;

DEFLABEL (label_70)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_13]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_3]), 1);

DEFLABEL (label_49)
  (Wrd7.Obj) = Rvl;
  goto label_69;

DEFLABEL (label_71)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_11]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd38.Obj) = (Rsp [4]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if (! ((Wrd39.uLng) == 1))
    goto label_86;
  (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd37.Obj) = ((Wrd36.pObj) [1]);
  (* (--Rsp)) = (Wrd37.Obj);

DEFLABEL (label_85)
  (Wrd44.Obj) = (current_block [OBJECT_38_5]);
  (* (--Rsp)) = (Wrd44.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_10]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_38_11);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_72;
  (Wrd69.Obj) = (Rsp [3]);
  (Rsp [5]) = (Wrd69.Obj);
  Rsp = (& (Rsp [5]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_15]));

DEFLABEL (label_72)
  (Wrd10.Obj) = (Rsp [3]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_84;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_83)
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_82;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [1]);
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_81)
  (Wrd26.Obj) = (Rsp [4]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd27.uLng) == 1))
    goto label_80;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd23.Obj) = ((Wrd25.pObj) [1]);

DEFLABEL (label_79)
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd34.uLng) == 1))
    goto label_78;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [0]);
  (* (--Rsp)) = (Wrd33.Obj);

DEFLABEL (label_77)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd67.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_38_21);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_38_20])));
  Rhp += 2;
  (Wrd68.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd67.pObj)));
  (* (--Rsp)) = (Wrd68.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd65.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_38_23);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_38_22])));
  Rhp += 1;
  (Wrd66.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd65.pObj)));
  (* (--Rsp)) = (Wrd66.Obj);
  Wrd57 = Wrd65;
  (Wrd58.Obj) = (Rsp [5]);
  ((Wrd57.pObj) [2]) = (Wrd58.Obj);
  Wrd63 = Wrd67;
  (Wrd64.Obj) = (Rsp [4]);
  ((Wrd63.pObj) [2]) = (Wrd64.Obj);
  ((Wrd63.pObj) [3]) = (Wrd66.Obj);
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_24]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (Wrd42.Obj) = (Rsp [4]);
  if ((Wrd42.Obj) == (current_block [OBJECT_38_8]))
    goto label_74;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd45.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_38_27);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_38_26])));
  Rhp += 3;
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd45.pObj)));
  Wrd50 = Wrd45;
  (Wrd51.Obj) = (Rsp [7]);
  ((Wrd50.pObj) [2]) = (Wrd51.Obj);
  ((Wrd50.pObj) [3]) = (Wrd64.Obj);
  ((Wrd50.pObj) [4]) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  goto label_73;

DEFLABEL (label_74)
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_25]))));
  (* (--Rsp)) = (Wrd55.Obj);

DEFLABEL (label_73)
DEFLABEL (label_76)
  (Wrd52.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd52.Obj);
  (Wrd53.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd53.Obj);
  goto recur_40;

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_38_24);
  (Rsp [6]) = Rvl;
  Rsp = (& (Rsp [6]));
  (Wrd6.Obj) = (Rsp [0]);
  if ((Wrd6.Obj) == ((SCHEME_OBJECT) 0))
    goto label_75;
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_75)
  (Wrd10.Obj) = (Rsp [1]);
  (Rsp [3]) = (Wrd10.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_15]));

DEFLABEL (label_78)
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_19]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_7]), 1);

DEFLABEL (label_55)
  (* (--Rsp)) = Rvl;
  goto label_77;

DEFLABEL (label_80)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_18]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_3]), 1);

DEFLABEL (label_54)
  (Wrd23.Obj) = Rvl;
  goto label_79;

DEFLABEL (label_82)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_17]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_3]), 1);

DEFLABEL (label_53)
  (* (--Rsp)) = Rvl;
  goto label_81;

DEFLABEL (label_84)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_16]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_3]), 1);

DEFLABEL (label_52)
  (Wrd7.Obj) = Rvl;
  goto label_83;

DEFLABEL (label_86)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_12]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_3]), 1);

DEFLABEL (label_51)
  (* (--Rsp)) = Rvl;
  goto label_85;

DEFLABEL (label_88)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_9]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_3]), 1);

DEFLABEL (label_48)
  (* (--Rsp)) = Rvl;
  goto label_87;

DEFLABEL (lambda_64)
  CLOSURE_HEADER (LABEL_38_26);

DEFLABEL (lambda_16)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (Wrd13.Obj) = ((Wrd9.pObj) [4]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Wrd17.Obj) = (current_block [OBJECT_38_8]);
  (* (Rhp++)) = (Wrd5.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  (Wrd21.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd21.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd20.pObj) = (& (Rhp [-2]));
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));
  (Wrd28.Obj) = ((Wrd9.pObj) [3]);
  (* (Rhp++)) = (Wrd28.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (Wrd24.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd24.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (recur_62)
DEFLABEL (recur_40)
  INTERRUPT_CHECK (26, LABEL_38_20);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_95;
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [1]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_94)
  (Wrd14.Obj) = (Rsp [0]);
  if ((Wrd14.Obj) == (current_block [OBJECT_38_8]))
    goto label_90;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd18.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_38_30);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_38_29])));
  Rhp += 4;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd18.pObj)));
  Wrd25 = Wrd18;
  (Wrd26.Obj) = (Rsp [1]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [2]);
  ((Wrd25.pObj) [2]) = (Wrd28.Obj);
  ((Wrd25.pObj) [3]) = (Wrd26.Obj);
  (Wrd22.Obj) = (Rsp [3]);
  ((Wrd25.pObj) [4]) = (Wrd22.Obj);
  ((Wrd25.pObj) [5]) = (Wrd14.Obj);
  Wrd29 = Wrd17;
  goto label_89;

DEFLABEL (label_90)
  (Wrd29.Obj) = (Rsp [3]);

DEFLABEL (label_89)
DEFLABEL (label_93)
  Rsp = (& (Rsp [1]));
  (Rsp [2]) = (Wrd29.Obj);
  (Wrd31.Obj) = (Rsp [0]);
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [3]);
  (Rsp [0]) = (Wrd30.Obj);
  (Wrd36.Obj) = (Rsp [1]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 1))
    goto label_92;
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd33.Obj) = ((Wrd35.pObj) [0]);

DEFLABEL (label_91)
  (Rsp [1]) = (Wrd33.Obj);
  goto expand_30;

DEFLABEL (label_92)
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_31]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_7]), 1);

DEFLABEL (label_57)
  (Wrd33.Obj) = Rvl;
  goto label_91;

DEFLABEL (label_95)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_28]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_3]), 1);

DEFLABEL (label_56)
  (* (--Rsp)) = Rvl;
  goto label_94;

DEFLABEL (lambda_66)
DEFLABEL (lambda_17)
  INTERRUPT_CHECK (26, LABEL_38_25);
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (expand_63)
DEFLABEL (expand_30)
  INTERRUPT_CHECK (26, LABEL_38_22);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_32]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_38_9]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_10]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_38_32);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_96;
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd8.Obj);
  (Rsp [2]) = (Wrd7.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_96)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_34]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_38_10]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_10]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_38_34);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_103;
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_35]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_38_11]);
  (* (--Rsp)) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_10]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_38_35);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_97;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_97)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_37]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_102;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_101)
  (Wrd19.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd19.Obj);
  goto pop_return;

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_38_37);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_99;
  (Wrd10.Obj) = (Rsp [2]);
  (Wrd11.Obj) = (current_block [OBJECT_38_8]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd14.pObj) = (& (Rhp [-2]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd14.pObj)));
  (* (Rhp++)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd12.Obj);
  (Wrd19.pObj) = (& (Rhp [-2]));
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd19.pObj)));
  (Wrd24.Obj) = (Rsp [1]);
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [2]);
  (* (Rhp++)) = (Wrd26.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (Wrd22.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd22.pObj)));
  goto label_98;

DEFLABEL (label_99)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_98)
DEFLABEL (label_100)
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_102)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_38]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_7]), 1);

DEFLABEL (label_59)
  (* (--Rsp)) = Rvl;
  goto label_101;

DEFLABEL (label_103)
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_105;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [0]);

DEFLABEL (label_104)
  (Wrd16.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd16.Obj);
  (Rsp [2]) = (Wrd7.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_105)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_36]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_7]), 1);

DEFLABEL (label_58)
  (Wrd7.Obj) = Rvl;
  goto label_104;

DEFLABEL (lambda_65)
  CLOSURE_HEADER (LABEL_38_29);

DEFLABEL (lambda_38)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_33]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [5]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd16.Obj) = ((Wrd9.pObj) [3]);
  (* (--Rsp)) = (Wrd16.Obj);
  goto recur_40;

DEFLABEL (continuation_35)
  INTERRUPT_CHECK (27, LABEL_38_33);
  (Wrd9.Obj) = (current_block [OBJECT_38_8]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Wrd13.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd6.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [2]);
  (* (Rhp++)) = (Wrd20.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_39_4 3
#define LABEL_39_5 5
#define LABEL_39_7 7
#define LABEL_39_8 9
#define ENVIRONMENT_LABEL_39_3 20
#define DEBUGGING_LABEL_39_2 19
#define EXECUTE_CACHE_39_11 11
#define EXECUTE_CACHE_39_10 13
#define EXECUTE_CACHE_39_9 15
#define EXECUTE_CACHE_39_6 17
#define FREE_REFERENCES_LABEL_39_0 10
#define NUMBER_OF_LINKER_SECTIONS_39_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_39 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_39_4);
      goto lambda_3;

    case 1:
      current_block = (Rpc - LABEL_39_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_39_7);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_39_8);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_6)
DEFLABEL (lambda_3)
  INTERRUPT_CHECK (26, LABEL_39_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_39_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39_8]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_39_8);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_39_7);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_10]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_40_4 3
#define LABEL_40_5 5
#define TAG_40_6 1
#define LABEL_40_8 7
#define LABEL_40_10 9
#define LABEL_40_11 11
#define LABEL_40_12 13
#define LABEL_40_13 15
#define LABEL_40_14 17
#define LABEL_40_15 19
#define LABEL_40_16 21
#define ENVIRONMENT_LABEL_40_3 34
#define DEBUGGING_LABEL_40_2 33
#define OBJECT_40_5 32
#define OBJECT_40_4 31
#define OBJECT_40_3 30
#define OBJECT_40_2 29
#define OBJECT_40_1 28
#define OBJECT_40_0 27
#define EXECUTE_CACHE_40_9 23
#define EXECUTE_CACHE_40_7 25
#define FREE_REFERENCES_LABEL_40_0 22
#define NUMBER_OF_LINKER_SECTIONS_40_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_40 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd30;
  machine_word Wrd31;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd37;
  machine_word Wrd33;
  machine_word Wrd27;
  machine_word Wrd28;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd20;
  machine_word Wrd21;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_40_4);
      goto lambda_13;

    case 1:
      current_block = (Rpc - LABEL_40_5);
      goto lambda_22;

    case 2:
      current_block = (Rpc - LABEL_40_8);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_40_10);
      goto label_15;

    case 4:
      current_block = (Rpc - LABEL_40_11);
      goto label_16;

    case 5:
      current_block = (Rpc - LABEL_40_12);
      goto label_17;

    case 6:
      current_block = (Rpc - LABEL_40_13);
      goto continuation_4;

    case 7:
      current_block = (Rpc - LABEL_40_14);
      goto label_18;

    case 8:
      current_block = (Rpc - LABEL_40_15);
      goto label_19;

    case 9:
      current_block = (Rpc - LABEL_40_16);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_21)
DEFLABEL (lambda_13)
  INTERRUPT_CHECK (26, LABEL_40_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_40_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_40_5])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_7]));

DEFLABEL (lambda_22)
  CLOSURE_HEADER (LABEL_40_5);

DEFLABEL (lambda_12)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_40_0]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_9]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_40_8);
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [3]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_32;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd5.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_31)
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_30;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd20.Obj) = ((Wrd21.pObj) [1]);

DEFLABEL (label_29)
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd29.uLng) == 1))
    goto label_28;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd27.Obj) = ((Wrd28.pObj) [0]);

DEFLABEL (label_27)
  (Wrd37.Obj) = (current_block [OBJECT_40_3]);
  (* (Rhp++)) = (Wrd27.Obj);
  (* (Rhp++)) = (Wrd37.Obj);
  (Wrd35.pObj) = (& (Rhp [-2]));
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd35.pObj)));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_13]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd41.Obj) = (current_block [OBJECT_40_4]);
  (* (--Rsp)) = (Wrd41.Obj);
  (Wrd42.Obj) = (Rsp [3]);
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd42.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [2]);
  (* (--Rsp)) = (Wrd44.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_40_13);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Wrd13.Obj) = (current_block [OBJECT_40_3]);
  (* (Rhp++)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd11.pObj) = (& (Rhp [-2]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd11.pObj)));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [3]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_26;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd14.Obj) = ((Wrd18.pObj) [1]);

DEFLABEL (label_25)
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd31.uLng) == 1))
    goto label_24;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd29.Obj) = ((Wrd30.pObj) [0]);

DEFLABEL (label_23)
  (Wrd36.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd29.Obj);
  (* (Rhp++)) = (Wrd36.Obj);
  (Wrd38.pObj) = (& (Rhp [-2]));
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd38.pObj)));
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_16]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (Wrd43.Obj) = (current_block [OBJECT_40_5]);
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd44.Obj) = (Rsp [3]);
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd46.Obj) = ((Wrd45.pObj) [2]);
  (* (--Rsp)) = (Wrd46.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_40_16);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_24)
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_15]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40_2]), 1);

DEFLABEL (label_19)
  (Wrd29.Obj) = Rvl;
  goto label_23;

DEFLABEL (label_26)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_14]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40_1]), 1);

DEFLABEL (label_18)
  (Wrd14.Obj) = Rvl;
  goto label_25;

DEFLABEL (label_28)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_12]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40_2]), 1);

DEFLABEL (label_17)
  (Wrd27.Obj) = Rvl;
  goto label_27;

DEFLABEL (label_30)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_11]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40_1]), 1);

DEFLABEL (label_16)
  (Wrd20.Obj) = Rvl;
  goto label_29;

DEFLABEL (label_32)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_10]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40_1]), 1);

DEFLABEL (label_15)
  (Wrd5.Obj) = Rvl;
  goto label_31;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_41_4 3
#define LABEL_41_5 5
#define LABEL_41_7 7
#define LABEL_41_6 9
#define LABEL_41_10 11
#define LABEL_41_11 13
#define LABEL_41_12 15
#define LABEL_41_13 17
#define LABEL_41_14 19
#define LABEL_41_9 21
#define LABEL_41_17 23
#define LABEL_41_18 25
#define LABEL_41_19 27
#define LABEL_41_20 29
#define LABEL_41_21 31
#define LABEL_41_22 33
#define LABEL_41_23 35
#define LABEL_41_15 37
#define LABEL_41_24 39
#define LABEL_41_25 41
#define LABEL_41_26 43
#define LABEL_41_27 45
#define LABEL_41_28 47
#define ENVIRONMENT_LABEL_41_3 64
#define DEBUGGING_LABEL_41_2 63
#define OBJECT_41_9 62
#define OBJECT_41_8 61
#define OBJECT_41_7 60
#define OBJECT_41_6 59
#define OBJECT_41_5 58
#define OBJECT_41_4 57
#define OBJECT_41_3 56
#define OBJECT_41_2 55
#define OBJECT_41_1 54
#define OBJECT_41_0 53
#define EXECUTE_CACHE_41_16 49
#define EXECUTE_CACHE_41_8 51
#define FREE_REFERENCES_LABEL_41_0 48
#define NUMBER_OF_LINKER_SECTIONS_41_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_41 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd59;
  machine_word Wrd55;
  machine_word Wrd51;
  machine_word Wrd47;
  machine_word Wrd43;
  machine_word Wrd86;
  machine_word Wrd85;
  machine_word Wrd84;
  machine_word Wrd81;
  machine_word Wrd80;
  machine_word Wrd78;
  machine_word Wrd77;
  machine_word Wrd71;
  machine_word Wrd72;
  machine_word Wrd73;
  machine_word Wrd70;
  machine_word Wrd62;
  machine_word Wrd64;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd58;
  machine_word Wrd56;
  machine_word Wrd57;
  machine_word Wrd50;
  machine_word Wrd39;
  machine_word Wrd41;
  machine_word Wrd31;
  machine_word Wrd87;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd46;
  machine_word Wrd42;
  machine_word Wrd44;
  machine_word Wrd45;
  machine_word Wrd38;
  machine_word Wrd40;
  machine_word Wrd34;
  machine_word Wrd36;
  machine_word Wrd37;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd24;
  machine_word Wrd22;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd23;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_41_4);
      goto lambda_42;

    case 1:
      current_block = (Rpc - LABEL_41_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_41_7);
      goto label_44;

    case 3:
      current_block = (Rpc - LABEL_41_6);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_41_10);
      goto label_46;

    case 5:
      current_block = (Rpc - LABEL_41_11);
      goto label_45;

    case 6:
      current_block = (Rpc - LABEL_41_12);
      goto continuation_36;

    case 7:
      current_block = (Rpc - LABEL_41_13);
      goto label_47;

    case 8:
      current_block = (Rpc - LABEL_41_14);
      goto label_48;

    case 9:
      current_block = (Rpc - LABEL_41_9);
      goto continuation_4;

    case 10:
      current_block = (Rpc - LABEL_41_17);
      goto label_49;

    case 11:
      current_block = (Rpc - LABEL_41_18);
      goto label_50;

    case 12:
      current_block = (Rpc - LABEL_41_19);
      goto label_51;

    case 13:
      current_block = (Rpc - LABEL_41_20);
      goto label_52;

    case 14:
      current_block = (Rpc - LABEL_41_21);
      goto label_53;

    case 15:
      current_block = (Rpc - LABEL_41_22);
      goto label_54;

    case 16:
      current_block = (Rpc - LABEL_41_23);
      goto label_55;

    case 17:
      current_block = (Rpc - LABEL_41_15);
      goto continuation_29;

    case 18:
      current_block = (Rpc - LABEL_41_24);
      goto continuation_13;

    case 19:
      current_block = (Rpc - LABEL_41_25);
      goto label_56;

    case 20:
      current_block = (Rpc - LABEL_41_26);
      goto label_57;

    case 21:
      current_block = (Rpc - LABEL_41_27);
      goto label_58;

    case 22:
      current_block = (Rpc - LABEL_41_28);
      goto continuation_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_60)
DEFLABEL (lambda_42)
  INTERRUPT_CHECK (26, LABEL_41_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_41_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_41_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_92;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [1]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_91)
  (Wrd17.Obj) = (current_block [OBJECT_41_2]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_41_6);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_67;
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_66;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [1]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_65)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_12]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (current_block [OBJECT_41_4]);
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd20.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_36)
  INTERRUPT_CHECK (27, LABEL_41_12);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Wrd13.Obj) = (current_block [OBJECT_41_5]);
  (* (Rhp++)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd11.pObj) = (& (Rhp [-2]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd11.pObj)));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_64;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [1]);

DEFLABEL (label_63)
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd25.uLng) == 1))
    goto label_62;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd23.Obj) = ((Wrd24.pObj) [0]);

DEFLABEL (label_61)
  (Wrd33.Obj) = (current_block [OBJECT_41_5]);
  (* (Rhp++)) = (Wrd23.Obj);
  (* (Rhp++)) = (Wrd33.Obj);
  (Wrd32.pObj) = (& (Rhp [-2]));
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd32.pObj)));
  (Wrd37.Obj) = (current_block [OBJECT_41_7]);
  (* (Rhp++)) = (Wrd37.Obj);
  (* (Rhp++)) = (Wrd30.Obj);
  (Wrd36.pObj) = (& (Rhp [-2]));
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd36.pObj)));
  (* (Rhp++)) = (Wrd34.Obj);
  (* (Rhp++)) = (Wrd33.Obj);
  (Wrd40.pObj) = (& (Rhp [-2]));
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd40.pObj)));
  (Wrd45.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd45.Obj);
  (* (Rhp++)) = (Wrd38.Obj);
  (Wrd44.pObj) = (& (Rhp [-2]));
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd44.pObj)));
  (Wrd46.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd42.Obj);
  (* (Rhp++)) = (Wrd46.Obj);
  (Wrd48.pObj) = (& (Rhp [-2]));
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd48.pObj)));
  (* (--Rsp)) = (Wrd49.Obj);
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_15]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (Wrd53.Obj) = (current_block [OBJECT_41_8]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd54.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd54.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_41_15);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_62)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_14]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_6]), 1);

DEFLABEL (label_48)
  (Wrd23.Obj) = Rvl;
  goto label_61;

DEFLABEL (label_64)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_13]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 1);

DEFLABEL (label_47)
  (Wrd14.Obj) = Rvl;
  goto label_63;

DEFLABEL (label_66)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_11]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 1);

DEFLABEL (label_45)
  (* (--Rsp)) = Rvl;
  goto label_65;

DEFLABEL (label_67)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_9]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd27.Obj) = (Rsp [2]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd28.uLng) == 1))
    goto label_90;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [1]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_89)
  (Wrd33.Obj) = (current_block [OBJECT_41_3]);
  (* (--Rsp)) = (Wrd33.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_8]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_41_9);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_68;
  (Wrd87.Obj) = (Rsp [1]);
  (Rsp [3]) = (Wrd87.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_16]));

DEFLABEL (label_68)
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_88;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_87)
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_86;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [1]);
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_85)
  (Wrd26.Obj) = (Rsp [2]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd27.uLng) == 1))
    goto label_84;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd23.Obj) = ((Wrd25.pObj) [1]);

DEFLABEL (label_83)
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd34.uLng) == 1))
    goto label_82;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd32.Obj) = ((Wrd33.pObj) [0]);

DEFLABEL (label_81)
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd41.uLng) == 1))
    goto label_80;
  (Wrd40.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd39.Obj) = ((Wrd40.pObj) [1]);

DEFLABEL (label_79)
  (Wrd49.Obj) = (current_block [OBJECT_41_7]);
  (* (Rhp++)) = (Wrd49.Obj);
  (* (Rhp++)) = (Wrd39.Obj);
  (Wrd48.pObj) = (& (Rhp [-2]));
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd48.pObj)));
  (Wrd53.Obj) = (current_block [OBJECT_41_5]);
  (* (Rhp++)) = (Wrd46.Obj);
  (* (Rhp++)) = (Wrd53.Obj);
  (Wrd52.pObj) = (& (Rhp [-2]));
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd52.pObj)));
  (Wrd57.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd57.Obj);
  (* (Rhp++)) = (Wrd50.Obj);
  (Wrd56.pObj) = (& (Rhp [-2]));
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd56.pObj)));
  (Wrd58.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd54.Obj);
  (* (Rhp++)) = (Wrd58.Obj);
  (Wrd60.pObj) = (& (Rhp [-2]));
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd60.pObj)));
  (* (--Rsp)) = (Wrd61.Obj);
  (Wrd65.Obj) = (Rsp [2]);
  (Wrd66.uLng) = (OBJECT_TYPE (Wrd65.Obj));
  if (! ((Wrd66.uLng) == 1))
    goto label_78;
  (Wrd64.pObj) = (OBJECT_ADDRESS (Wrd65.Obj));
  (Wrd62.Obj) = ((Wrd64.pObj) [1]);

DEFLABEL (label_77)
  (Wrd73.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if (! ((Wrd73.uLng) == 1))
    goto label_76;
  (Wrd72.pObj) = (OBJECT_ADDRESS (Wrd62.Obj));
  (Wrd71.Obj) = ((Wrd72.pObj) [0]);

DEFLABEL (label_75)
  (Wrd78.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd71.Obj);
  (* (Rhp++)) = (Wrd78.Obj);
  (Wrd80.pObj) = (& (Rhp [-2]));
  (Wrd81.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd80.pObj)));
  (* (--Rsp)) = (Wrd81.Obj);
  (Wrd84.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_24]))));
  (* (--Rsp)) = (Wrd84.Obj);
  (Wrd85.Obj) = (current_block [OBJECT_41_4]);
  (* (--Rsp)) = (Wrd85.Obj);
  (Wrd86.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd86.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_41_24);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Wrd13.Obj) = (current_block [OBJECT_41_5]);
  (* (Rhp++)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd11.pObj) = (& (Rhp [-2]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd11.pObj)));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_74;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [1]);

DEFLABEL (label_73)
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd25.uLng) == 1))
    goto label_72;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd23.Obj) = ((Wrd24.pObj) [0]);

DEFLABEL (label_71)
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd32.uLng) == 1))
    goto label_70;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd30.Obj) = ((Wrd31.pObj) [0]);

DEFLABEL (label_69)
  (Wrd40.Obj) = (current_block [OBJECT_41_5]);
  (* (Rhp++)) = (Wrd30.Obj);
  (* (Rhp++)) = (Wrd40.Obj);
  (Wrd39.pObj) = (& (Rhp [-2]));
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd39.pObj)));
  (Wrd44.Obj) = (current_block [OBJECT_41_9]);
  (* (Rhp++)) = (Wrd44.Obj);
  (* (Rhp++)) = (Wrd37.Obj);
  (Wrd43.pObj) = (& (Rhp [-2]));
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd43.pObj)));
  (* (Rhp++)) = (Wrd41.Obj);
  (* (Rhp++)) = (Wrd40.Obj);
  (Wrd47.pObj) = (& (Rhp [-2]));
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd47.pObj)));
  (Wrd52.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd52.Obj);
  (* (Rhp++)) = (Wrd45.Obj);
  (Wrd51.pObj) = (& (Rhp [-2]));
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd51.pObj)));
  (Wrd53.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd49.Obj);
  (* (Rhp++)) = (Wrd53.Obj);
  (Wrd55.pObj) = (& (Rhp [-2]));
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd55.pObj)));
  (* (--Rsp)) = (Wrd56.Obj);
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_28]))));
  (* (--Rsp)) = (Wrd59.Obj);
  (Wrd60.Obj) = (current_block [OBJECT_41_8]);
  (* (--Rsp)) = (Wrd60.Obj);
  (Wrd61.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd61.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_41_28);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_70)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_27]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_6]), 1);

DEFLABEL (label_58)
  (Wrd30.Obj) = Rvl;
  goto label_69;

DEFLABEL (label_72)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_26]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_6]), 1);

DEFLABEL (label_57)
  (Wrd23.Obj) = Rvl;
  goto label_71;

DEFLABEL (label_74)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_25]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 1);

DEFLABEL (label_56)
  (Wrd14.Obj) = Rvl;
  goto label_73;

DEFLABEL (label_76)
  (Wrd77.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_23]))));
  (* (--Rsp)) = (Wrd77.Obj);
  (* (--Rsp)) = (Wrd62.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_6]), 1);

DEFLABEL (label_55)
  (Wrd71.Obj) = Rvl;
  goto label_75;

DEFLABEL (label_78)
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_22]))));
  (* (--Rsp)) = (Wrd70.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 1);

DEFLABEL (label_54)
  (Wrd62.Obj) = Rvl;
  goto label_77;

DEFLABEL (label_80)
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_21]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 1);

DEFLABEL (label_53)
  (Wrd39.Obj) = Rvl;
  goto label_79;

DEFLABEL (label_82)
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_20]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_6]), 1);

DEFLABEL (label_52)
  (Wrd32.Obj) = Rvl;
  goto label_81;

DEFLABEL (label_84)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_19]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 1);

DEFLABEL (label_51)
  (Wrd23.Obj) = Rvl;
  goto label_83;

DEFLABEL (label_86)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_18]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 1);

DEFLABEL (label_50)
  (* (--Rsp)) = Rvl;
  goto label_85;

DEFLABEL (label_88)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_17]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 1);

DEFLABEL (label_49)
  (Wrd7.Obj) = Rvl;
  goto label_87;

DEFLABEL (label_90)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_10]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 1);

DEFLABEL (label_46)
  (* (--Rsp)) = Rvl;
  goto label_89;

DEFLABEL (label_92)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_7]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 1);

DEFLABEL (label_44)
  (* (--Rsp)) = Rvl;
  goto label_91;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_42_4 3
#define LABEL_42_5 5
#define TAG_42_6 1
#define LABEL_42_8 7
#define LABEL_42_10 9
#define LABEL_42_11 11
#define LABEL_42_12 13
#define LABEL_42_14 15
#define LABEL_42_15 17
#define LABEL_42_13 19
#define LABEL_42_17 21
#define LABEL_42_18 23
#define LABEL_42_19 25
#define LABEL_42_20 27
#define LABEL_42_22 29
#define LABEL_42_23 31
#define LABEL_42_24 33
#define LABEL_42_26 35
#define LABEL_42_25 37
#define LABEL_42_27 39
#define LABEL_42_28 41
#define LABEL_42_30 43
#define LABEL_42_37 45
#define LABEL_42_31 47
#define LABEL_42_32 49
#define TAG_42_33 23
#define LABEL_42_35 51
#define LABEL_42_36 53
#define LABEL_42_41 55
#define LABEL_42_42 57
#define LABEL_42_39 59
#define LABEL_42_40 61
#define ENVIRONMENT_LABEL_42_3 93
#define DEBUGGING_LABEL_42_2 92
#define OBJECT_42_10 91
#define OBJECT_42_9 90
#define OBJECT_42_8 89
#define OBJECT_42_7 88
#define OBJECT_42_6 87
#define OBJECT_42_5 86
#define OBJECT_42_4 85
#define OBJECT_42_3 84
#define OBJECT_42_2 83
#define OBJECT_42_1 82
#define OBJECT_42_0 81
#define EXECUTE_CACHE_42_38 63
#define EXECUTE_CACHE_42_29 65
#define EXECUTE_CACHE_42_21 67
#define EXECUTE_CACHE_42_43 69
#define EXECUTE_CACHE_42_34 71
#define EXECUTE_CACHE_42_16 73
#define EXECUTE_CACHE_42_9 75
#define EXECUTE_CACHE_42_7 77
#define FREE_REFERENCE_42_0 80
#define FREE_REFERENCES_LABEL_42_0 62
#define NUMBER_OF_LINKER_SECTIONS_42_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_42 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd28;
  machine_word Wrd37;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd40;
  machine_word Wrd36;
  machine_word Wrd38;
  machine_word Wrd39;
  machine_word Wrd32;
  machine_word Wrd34;
  machine_word Wrd35;
  machine_word Wrd31;
  machine_word Wrd26;
  machine_word Wrd27;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd5;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_42_4);
      goto lambda_47;

    case 1:
      current_block = (Rpc - LABEL_42_5);
      goto lambda_58;

    case 2:
      current_block = (Rpc - LABEL_42_8);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_42_10);
      goto continuation_6;

    case 4:
      current_block = (Rpc - LABEL_42_11);
      goto continuation_5;

    case 5:
      current_block = (Rpc - LABEL_42_12);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_42_14);
      goto label_49;

    case 7:
      current_block = (Rpc - LABEL_42_15);
      goto label_50;

    case 8:
      current_block = (Rpc - LABEL_42_13);
      goto continuation_3;

    case 9:
      current_block = (Rpc - LABEL_42_17);
      goto continuation_10;

    case 10:
      current_block = (Rpc - LABEL_42_18);
      goto lambda_9;

    case 11:
      current_block = (Rpc - LABEL_42_19);
      goto continuation_8;

    case 12:
      current_block = (Rpc - LABEL_42_20);
      goto lambda_7;

    case 13:
      current_block = (Rpc - LABEL_42_22);
      goto continuation_37;

    case 14:
      current_block = (Rpc - LABEL_42_23);
      goto label_51;

    case 15:
      current_block = (Rpc - LABEL_42_24);
      goto label_52;

    case 16:
      current_block = (Rpc - LABEL_42_26);
      goto lambda_24;

    case 17:
      current_block = (Rpc - LABEL_42_25);
      goto continuation_32;

    case 18:
      current_block = (Rpc - LABEL_42_27);
      goto continuation_22;

    case 19:
      current_block = (Rpc - LABEL_42_28);
      goto continuation_20;

    case 20:
      current_block = (Rpc - LABEL_42_30);
      goto continuation_31;

    case 21:
      current_block = (Rpc - LABEL_42_37);
      goto label_53;

    case 22:
      current_block = (Rpc - LABEL_42_31);
      goto continuation_19;

    case 23:
      current_block = (Rpc - LABEL_42_32);
      goto lambda_62;

    case 24:
      current_block = (Rpc - LABEL_42_35);
      goto continuation_30;

    case 25:
      current_block = (Rpc - LABEL_42_36);
      goto continuation_29;

    case 26:
      current_block = (Rpc - LABEL_42_41);
      goto label_54;

    case 27:
      current_block = (Rpc - LABEL_42_42);
      goto label_55;

    case 28:
      current_block = (Rpc - LABEL_42_39);
      goto continuation_28;

    case 29:
      current_block = (Rpc - LABEL_42_40);
      goto continuation_27;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_57)
DEFLABEL (lambda_47)
  INTERRUPT_CHECK (26, LABEL_42_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_42_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_42_5])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_7]));

DEFLABEL (lambda_58)
  CLOSURE_HEADER (LABEL_42_5);

DEFLABEL (lambda_46)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_42_0]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_9]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_42_8);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_42_1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_42_10);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_11]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_42_2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_42_11);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_42_3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_42_12);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [3]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_76;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd8.Obj) = ((Wrd12.pObj) [1]);

DEFLABEL (label_75)
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd25.uLng) == 1))
    goto label_74;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [0]);
  (* (--Rsp)) = (Wrd24.Obj);

DEFLABEL (label_73)
  (Wrd30.Obj) = (current_block [OBJECT_42_5]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_16]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_42_13);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_18]))));
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_16]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_42_17);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_19]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_20]))));
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_16]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_42_19);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_22]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.pObj) = (& (Rsp [3]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd8.pObj)));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd12.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd12.Obj);
  goto lambda_24;

DEFLABEL (continuation_37)
  INTERRUPT_CHECK (27, LABEL_42_22);
  (Wrd9.Obj) = (current_block [OBJECT_42_8]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.Obj) = (Rsp [7]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [3]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_72;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd10.Obj) = ((Wrd14.pObj) [1]);

DEFLABEL (label_71)
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd27.uLng) == 1))
    goto label_70;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd25.Obj) = ((Wrd26.pObj) [1]);

DEFLABEL (label_69)
  (Wrd35.Obj) = (current_block [OBJECT_42_8]);
  (* (Rhp++)) = (Wrd35.Obj);
  (* (Rhp++)) = (Wrd25.Obj);
  (Wrd34.pObj) = (& (Rhp [-2]));
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd34.pObj)));
  (Wrd39.Obj) = (Rsp [5]);
  (* (Rhp++)) = (Wrd39.Obj);
  (* (Rhp++)) = (Wrd32.Obj);
  (Wrd38.pObj) = (& (Rhp [-2]));
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd38.pObj)));
  (Wrd40.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd36.Obj);
  (* (Rhp++)) = (Wrd40.Obj);
  (Wrd42.pObj) = (& (Rhp [-2]));
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd42.pObj)));
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_25]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd47.pObj) = (& (Rsp [4]));
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd47.pObj)));
  (* (--Rsp)) = (Wrd49.Obj);
  (Wrd50.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd50.Obj);
  (Wrd51.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd51.Obj);
  goto lambda_24;

DEFLABEL (continuation_32)
  INTERRUPT_CHECK (27, LABEL_42_25);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_30]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_42_9]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [9]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [2]);
  (* (--Rsp)) = (Wrd16.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_42_30);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Wrd13.Obj) = (current_block [OBJECT_42_8]);
  (* (Rhp++)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd11.pObj) = (& (Rhp [-2]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd11.pObj)));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_35]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_36]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_42_0]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_68;
  Wrd21 = Wrd25;

DEFLABEL (label_67)
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_16]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_42_36);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_39]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_40]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd16.Obj) = (Rsp [11]);
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [3]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 1))
    goto label_66;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd11.Obj) = ((Wrd15.pObj) [1]);

DEFLABEL (label_65)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd28.uLng) == 1))
    goto label_64;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [0]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_63)
  (Wrd33.Obj) = (current_block [OBJECT_42_4]);
  (* (--Rsp)) = (Wrd33.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_16]));

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_42_40);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_42_10]);
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_43]));

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_42_39);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_38]));

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_42_35);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Wrd14.Obj) = (Rsp [3]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd7.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  Rsp = (& (Rsp [8]));
  goto pop_return;

DEFLABEL (label_64)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_42]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_5]), 1);

DEFLABEL (label_55)
  (* (--Rsp)) = Rvl;
  goto label_63;

DEFLABEL (label_66)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_41]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_4]), 1);

DEFLABEL (label_54)
  (Wrd11.Obj) = Rvl;
  goto label_65;

DEFLABEL (label_68)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_42_37])), (Wrd22.pObj));

DEFLABEL (label_53)
  (Wrd21.Obj) = Rvl;
  goto label_67;

DEFLABEL (label_70)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_24]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_4]), 1);

DEFLABEL (label_52)
  (Wrd25.Obj) = Rvl;
  goto label_69;

DEFLABEL (label_72)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_23]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_4]), 1);

DEFLABEL (label_51)
  (Wrd10.Obj) = Rvl;
  goto label_71;

DEFLABEL (label_74)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_15]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_5]), 1);

DEFLABEL (label_50)
  (* (--Rsp)) = Rvl;
  goto label_73;

DEFLABEL (label_76)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_14]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_4]), 1);

DEFLABEL (label_49)
  (Wrd8.Obj) = Rvl;
  goto label_75;

DEFLABEL (lambda_59)
DEFLABEL (lambda_9)
  INTERRUPT_CHECK (26, LABEL_42_18);
  (Wrd5.Obj) = (current_block [OBJECT_42_6]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_21]));

DEFLABEL (lambda_60)
DEFLABEL (lambda_7)
  INTERRUPT_CHECK (26, LABEL_42_20);
  (Wrd5.Obj) = (current_block [OBJECT_42_7]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_21]));

DEFLABEL (lambda_61)
DEFLABEL (lambda_24)
  INTERRUPT_CHECK (26, LABEL_42_26);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_27]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_28]))));
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_29]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_42_28);
  (Wrd9.Obj) = (current_block [OBJECT_42_8]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_31]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [6]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd19.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_42_33);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_42_32])));
  Rhp += 1;
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd19.pObj)));
  Wrd20 = Wrd19;
  (Wrd23.Obj) = ((Wrd15.pObj) [3]);
  ((Wrd20.pObj) [2]) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_34]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_42_31);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_38]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_42_27);
  (Wrd9.Obj) = (current_block [OBJECT_42_8]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [2]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd6.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (lambda_62)
  CLOSURE_HEADER (LABEL_42_32);

DEFLABEL (lambda_18)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd8.Obj) = (Rsp [3]);
  (Wrd9.Obj) = (current_block [OBJECT_42_8]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Wrd13.Obj) = (Rsp [0]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [2]);
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd18.pObj) = (& (Rhp [-2]));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd18.pObj)));
  (Wrd23.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd23.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (Wrd22.pObj) = (& (Rhp [-2]));
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd22.pObj)));
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd20.Obj);
  (Wrd26.pObj) = (& (Rhp [-2]));
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd26.pObj)));
  (* (Rhp++)) = (Wrd24.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd32.pObj) = (& (Rhp [-2]));
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd32.pObj)));
  (Wrd37.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd37.Obj);
  (* (Rhp++)) = (Wrd30.Obj);
  (Wrd36.pObj) = (& (Rhp [-2]));
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd36.pObj)));
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd34.Obj);
  (Wrd40.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd40.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_43_4 3
#define LABEL_43_5 5
#define LABEL_43_9 7
#define LABEL_43_7 9
#define ENVIRONMENT_LABEL_43_3 22
#define DEBUGGING_LABEL_43_2 21
#define OBJECT_43_1 20
#define OBJECT_43_0 19
#define EXECUTE_CACHE_43_11 11
#define EXECUTE_CACHE_43_10 13
#define EXECUTE_CACHE_43_8 15
#define EXECUTE_CACHE_43_6 17
#define FREE_REFERENCES_LABEL_43_0 10
#define NUMBER_OF_LINKER_SECTIONS_43_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_43 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_43_4);
      goto lambda_3;

    case 1:
      current_block = (Rpc - LABEL_43_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_43_9);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_43_7);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_6)
DEFLABEL (lambda_3)
  INTERRUPT_CHECK (26, LABEL_43_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_43_0]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_43_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_43_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_8;

DEFLABEL (label_7)
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43_11]));

DEFLABEL (label_8)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_9]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_43_1]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_43_9);
  goto label_7;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_44_4 3
#define LABEL_44_5 5
#define ENVIRONMENT_LABEL_44_3 12
#define DEBUGGING_LABEL_44_2 11
#define EXECUTE_CACHE_44_7 7
#define EXECUTE_CACHE_44_6 9
#define FREE_REFERENCES_LABEL_44_0 6
#define NUMBER_OF_LINKER_SECTIONS_44_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_44 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_44_4);
      goto unspecific_expression_1;

    case 1:
      current_block = (Rpc - LABEL_44_5);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unspecific_expression_4)
DEFLABEL (unspecific_expression_1)
  INTERRUPT_CHECK (26, LABEL_44_4);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_5]))));
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_44_6]));

DEFLABEL (lambda_5)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_44_5);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_44_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_45_4 3
#define LABEL_45_5 5
#define ENVIRONMENT_LABEL_45_3 12
#define DEBUGGING_LABEL_45_2 11
#define EXECUTE_CACHE_45_7 7
#define EXECUTE_CACHE_45_6 9
#define FREE_REFERENCES_LABEL_45_0 6
#define NUMBER_OF_LINKER_SECTIONS_45_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_45 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_45_4);
      goto unassigned_expression_1;

    case 1:
      current_block = (Rpc - LABEL_45_5);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unassigned_expression_4)
DEFLABEL (unassigned_expression_1)
  INTERRUPT_CHECK (26, LABEL_45_4);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_5]))));
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_6]));

DEFLABEL (lambda_5)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_45_5);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_46_4 3
#define LABEL_46_5 5
#define LABEL_46_7 7
#define TAG_46_8 2
#define LABEL_46_10 9
#define LABEL_46_11 11
#define ENVIRONMENT_LABEL_46_3 24
#define DEBUGGING_LABEL_46_2 23
#define OBJECT_46_1 22
#define OBJECT_46_0 21
#define EXECUTE_CACHE_46_12 13
#define EXECUTE_CACHE_46_9 15
#define EXECUTE_CACHE_46_6 17
#define FREE_REFERENCE_46_0 20
#define FREE_REFERENCES_LABEL_46_0 12
#define NUMBER_OF_LINKER_SECTIONS_46_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_46 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd27;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd12;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_46_4);
      goto lambda_3;

    case 1:
      current_block = (Rpc - LABEL_46_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_46_7);
      goto lambda_9;

    case 3:
      current_block = (Rpc - LABEL_46_10);
      goto label_5;

    case 4:
      current_block = (Rpc - LABEL_46_11);
      goto label_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_8)
DEFLABEL (lambda_3)
  INTERRUPT_CHECK (26, LABEL_46_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_46_0]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_46_5);
  (Wrd5.Obj) = (Rsp [3]);
  (Rsp [2]) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_46_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_46_7])));
  Rhp += 3;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  Wrd13 = Wrd8;
  ((Wrd13.pObj) [2]) = (Wrd5.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  ((Wrd13.pObj) [3]) = (Wrd12.Obj);
  (Wrd10.Obj) = (Rsp [0]);
  ((Wrd13.pObj) [4]) = (Wrd10.Obj);
  (Rsp [3]) = (Wrd7.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_9]));

DEFLABEL (lambda_9)
  CLOSURE_HEADER (LABEL_46_7);

DEFLABEL (lambda_2)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd18.Obj) = ((Wrd6.pObj) [4]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 1))
    goto label_13;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [1]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_12)
  (Wrd28.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_46_0]));
  (Wrd31.Obj) = ((Wrd28.pObj) [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd32.uLng) == 50)
    goto label_11;
  Wrd27 = Wrd31;

DEFLABEL (label_10)
  (Rsp [3]) = (Wrd27.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_12]));

DEFLABEL (label_11)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_46_11])), (Wrd28.pObj));

DEFLABEL (label_6)
  (Wrd27.Obj) = Rvl;
  goto label_10;

DEFLABEL (label_13)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_10]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_1]), 1);

DEFLABEL (label_5)
  (* (--Rsp)) = Rvl;
  goto label_12;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_47_4 3
#define LABEL_47_5 5
#define LABEL_47_8 7
#define LABEL_47_9 9
#define LABEL_47_10 11
#define LABEL_47_7 13
#define LABEL_47_12 15
#define TAG_47_13 6
#define LABEL_47_16 17
#define LABEL_47_17 19
#define LABEL_47_18 21
#define LABEL_47_15 23
#define LABEL_47_20 25
#define ENVIRONMENT_LABEL_47_3 46
#define DEBUGGING_LABEL_47_2 45
#define OBJECT_47_2 44
#define OBJECT_47_1 43
#define OBJECT_47_0 42
#define EXECUTE_CACHE_47_22 27
#define EXECUTE_CACHE_47_21 29
#define EXECUTE_CACHE_47_19 31
#define EXECUTE_CACHE_47_14 33
#define EXECUTE_CACHE_47_11 35
#define EXECUTE_CACHE_47_6 37
#define FREE_REFERENCE_47_1 40
#define FREE_REFERENCE_47_0 41
#define FREE_REFERENCES_LABEL_47_0 26
#define NUMBER_OF_LINKER_SECTIONS_47_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_47 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd41;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd24;
  machine_word Wrd5;
  machine_word Wrd32;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_47_4);
      goto lambda_10;

    case 1:
      current_block = (Rpc - LABEL_47_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_47_8);
      goto label_12;

    case 3:
      current_block = (Rpc - LABEL_47_9);
      goto label_13;

    case 4:
      current_block = (Rpc - LABEL_47_10);
      goto label_14;

    case 5:
      current_block = (Rpc - LABEL_47_7);
      goto continuation_3;

    case 6:
      current_block = (Rpc - LABEL_47_12);
      goto lambda_20;

    case 7:
      current_block = (Rpc - LABEL_47_16);
      goto label_15;

    case 8:
      current_block = (Rpc - LABEL_47_17);
      goto label_16;

    case 9:
      current_block = (Rpc - LABEL_47_18);
      goto label_17;

    case 10:
      current_block = (Rpc - LABEL_47_15);
      goto continuation_6;

    case 11:
      current_block = (Rpc - LABEL_47_20);
      goto continuation_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_19)
DEFLABEL (lambda_10)
  INTERRUPT_CHECK (26, LABEL_47_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_47_0]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_47_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_47_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_26;
  Wrd8 = Wrd12;

DEFLABEL (label_25)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd20.Obj) = (Rsp [5]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 1))
    goto label_24;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [1]);

DEFLABEL (label_23)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd28.uLng) == 1))
    goto label_22;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [1]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_21)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_47_7);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [4]);
  (Rsp [3]) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_47_13);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_47_12])));
  Rhp += 4;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  Wrd15 = Wrd8;
  ((Wrd15.pObj) [2]) = (Wrd5.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  ((Wrd15.pObj) [3]) = (Wrd14.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  ((Wrd15.pObj) [4]) = (Wrd12.Obj);
  ((Wrd15.pObj) [5]) = Rvl;
  (Rsp [4]) = (Wrd7.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_14]));

DEFLABEL (label_22)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_10]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_1]), 1);

DEFLABEL (label_14)
  (* (--Rsp)) = Rvl;
  goto label_21;

DEFLABEL (label_24)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_9]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_1]), 1);

DEFLABEL (label_13)
  (Wrd17.Obj) = Rvl;
  goto label_23;

DEFLABEL (label_26)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_47_8])), (Wrd9.pObj));

DEFLABEL (label_12)
  (Wrd8.Obj) = Rvl;
  goto label_25;

DEFLABEL (lambda_20)
  CLOSURE_HEADER (LABEL_47_12);

DEFLABEL (lambda_8)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_15]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_47_1]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_32;
  Wrd8 = Wrd12;

DEFLABEL (label_31)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [2]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd19.Obj) = ((Wrd15.pObj) [3]);
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd27.Obj) = ((Wrd15.pObj) [4]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd28.uLng) == 1))
    goto label_30;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd20.Obj) = ((Wrd24.pObj) [1]);

DEFLABEL (label_29)
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd37.uLng) == 1))
    goto label_28;
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd36.Obj) = ((Wrd35.pObj) [0]);
  (* (--Rsp)) = (Wrd36.Obj);

DEFLABEL (label_27)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_19]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_47_15);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_20]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_21]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_47_20);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_22]));

DEFLABEL (label_28)
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_18]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_2]), 1);

DEFLABEL (label_17)
  (* (--Rsp)) = Rvl;
  goto label_27;

DEFLABEL (label_30)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_17]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_1]), 1);

DEFLABEL (label_16)
  (Wrd20.Obj) = Rvl;
  goto label_29;

DEFLABEL (label_32)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_47_16])), (Wrd9.pObj));

DEFLABEL (label_15)
  (Wrd8.Obj) = Rvl;
  goto label_31;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_48_4 3
#define LABEL_48_5 5
#define TAG_48_6 1
#define LABEL_48_8 7
#define TAG_48_9 2
#define LABEL_48_10 9
#define TAG_48_11 3
#define LABEL_48_14 11
#define ENVIRONMENT_LABEL_48_3 25
#define DEBUGGING_LABEL_48_2 24
#define OBJECT_48_0 23
#define EXECUTE_CACHE_48_16 13
#define EXECUTE_CACHE_48_15 15
#define EXECUTE_CACHE_48_13 17
#define EXECUTE_CACHE_48_12 19
#define EXECUTE_CACHE_48_7 21
#define FREE_REFERENCES_LABEL_48_0 12
#define NUMBER_OF_LINKER_SECTIONS_48_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_48 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd28;
  machine_word Wrd24;
  machine_word Wrd18;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd8;
  machine_word Wrd5;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_48_4);
      goto map_declaration_references_4;

    case 1:
      current_block = (Rpc - LABEL_48_5);
      goto lambda_8;

    case 2:
      current_block = (Rpc - LABEL_48_8);
      goto lambda_9;

    case 3:
      current_block = (Rpc - LABEL_48_10);
      goto lambda_10;

    case 4:
      current_block = (Rpc - LABEL_48_14);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (map_declaration_references_7)
DEFLABEL (map_declaration_references_4)
  INTERRUPT_CHECK (26, LABEL_48_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_48_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_48_5])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [2]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd12.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd12.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_7]));

DEFLABEL (lambda_8)
  CLOSURE_HEADER (LABEL_48_5);

DEFLABEL (lambda_3)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_48_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_48_8])));
  Rhp += 2;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  Wrd13 = Wrd8;
  (Wrd14.Obj) = (Rsp [1]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [2]);
  ((Wrd13.pObj) [2]) = (Wrd16.Obj);
  (Wrd12.Obj) = ((Wrd15.pObj) [3]);
  ((Wrd13.pObj) [3]) = (Wrd12.Obj);
  (Rsp [2]) = (Wrd7.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd19.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_48_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_48_10])));
  Rhp += 2;
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd19.pObj)));
  Wrd24 = Wrd19;
  ((Wrd24.pObj) [2]) = (Wrd16.Obj);
  ((Wrd24.pObj) [3]) = (Wrd12.Obj);
  (Wrd28.Obj) = (Rsp [3]);
  (Rsp [1]) = (Wrd28.Obj);
  (Rsp [3]) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_12]));

DEFLABEL (lambda_9)
  CLOSURE_HEADER (LABEL_48_8);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd9.Obj) = ((Wrd8.pObj) [3]);
  (Rsp [1]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_13]));

DEFLABEL (lambda_10)
  CLOSURE_HEADER (LABEL_48_10);

DEFLABEL (lambda_2)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = ((Wrd10.pObj) [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_15]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_48_14);
  (Rsp [0]) = Rvl;
  (Wrd6.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_48_0]);
  (Rsp [1]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_16]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_49_4 3
#define LABEL_49_5 5
#define LABEL_49_9 7
#define LABEL_49_7 9
#define ENVIRONMENT_LABEL_49_3 21
#define DEBUGGING_LABEL_49_2 20
#define OBJECT_49_0 19
#define EXECUTE_CACHE_49_11 11
#define EXECUTE_CACHE_49_10 13
#define EXECUTE_CACHE_49_8 15
#define EXECUTE_CACHE_49_6 17
#define FREE_REFERENCES_LABEL_49_0 10
#define NUMBER_OF_LINKER_SECTIONS_49_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
mit_syntax_so_code_49 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_49_4);
      goto classify_variable_subexpression_4;

    case 1:
      current_block = (Rpc - LABEL_49_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_49_9);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_49_7);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (classify_variable_subexpression_7)
DEFLABEL (classify_variable_subexpression_4)
  INTERRUPT_CHECK (26, LABEL_49_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_49_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_49_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_49_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_49_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_9;

DEFLABEL (label_8)
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [4]) = (Wrd7.Obj);
  Rsp = (& (Rsp [4]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_49_11]));

DEFLABEL (label_9)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_9]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_49_0]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_49_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_49_9);
  goto label_8;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4 3
#define LABEL_8 5
#define LABEL_6 7
#define LABEL_12 9
#define LABEL_7 11
#define LABEL_10 13
#define LABEL_16 15
#define LABEL_11 17
#define LABEL_14 19
#define LABEL_19 21
#define LABEL_15 23
#define LABEL_17 25
#define LABEL_18 27
#define LABEL_20 29
#define LABEL_22 31
#define LABEL_23 33
#define LABEL_24 35
#define LABEL_25 37
#define LABEL_26 39
#define LABEL_27 41
#define LABEL_28 43
#define LABEL_29 45
#define LABEL_30 47
#define LABEL_31 49
#define LABEL_32 51
#define LABEL_38 53
#define LABEL_34 55
#define LABEL_35 57
#define TAG_36 27
#define LABEL_42 59
#define LABEL_40 61
#define LABEL_41 63
#define LABEL_46 65
#define LABEL_47 67
#define LABEL_44 69
#define LABEL_48 71
#define LABEL_50 73
#define LABEL_51 75
#define LABEL_52 77
#define LABEL_53 79
#define LABEL_45 81
#define LABEL_55 83
#define LABEL_56 85
#define LABEL_57 87
#define LABEL_58 89
#define LABEL_59 91
#define LABEL_60 93
#define LABEL_49 95
#define LABEL_61 97
#define LABEL_63 99
#define LABEL_64 101
#define LABEL_65 103
#define LABEL_66 105
#define LABEL_54 107
#define LABEL_68 109
#define LABEL_62 111
#define LABEL_69 113
#define LABEL_72 115
#define LABEL_73 117
#define LABEL_67 119
#define LABEL_75 121
#define LABEL_76 123
#define LABEL_77 125
#define LABEL_78 127
#define LABEL_79 129
#define LABEL_71 131
#define LABEL_80 133
#define LABEL_81 135
#define LABEL_82 137
#define LABEL_83 139
#define LABEL_84 141
#define TAG_85 69
#define LABEL_90 143
#define LABEL_86 145
#define LABEL_88 147
#define LABEL_89 149
#define LABEL_94 151
#define LABEL_95 153
#define LABEL_96 155
#define LABEL_97 157
#define LABEL_98 159
#define LABEL_99 161
#define LABEL_100 163
#define LABEL_101 165
#define LABEL_102 167
#define LABEL_91 169
#define LABEL_106 171
#define LABEL_107 173
#define LABEL_92 175
#define LABEL_103 177
#define LABEL_104 179
#define LABEL_111 181
#define LABEL_112 183
#define LABEL_93 185
#define LABEL_109 187
#define LABEL_110 189
#define LABEL_113 191
#define LABEL_117 193
#define LABEL_115 195
#define LABEL_116 197
#define LABEL_118 199
#define LABEL_119 201
#define LABEL_120 203
#define LABEL_121 205
#define LABEL_122 207
#define LABEL_123 209
#define LABEL_124 211
#define LABEL_125 213
#define LABEL_126 215
#define LABEL_127 217
#define LABEL_128 219
#define LABEL_129 221
#define LABEL_130 223
#define LABEL_131 225
#define LABEL_137 227
#define LABEL_138 229
#define LABEL_140 231
#define LABEL_141 233
#define LABEL_142 235
#define LABEL_143 237
#define LABEL_132 239
#define LABEL_147 241
#define LABEL_133 243
#define LABEL_135 245
#define TAG_136 121
#define LABEL_150 247
#define LABEL_139 249
#define LABEL_145 251
#define LABEL_154 253
#define LABEL_146 255
#define LABEL_149 257
#define LABEL_157 259
#define LABEL_158 261
#define LABEL_152 263
#define LABEL_161 265
#define LABEL_153 267
#define LABEL_156 269
#define LABEL_163 271
#define LABEL_164 273
#define LABEL_165 275
#define LABEL_166 277
#define LABEL_167 279
#define LABEL_159 281
#define LABEL_170 283
#define LABEL_160 285
#define LABEL_168 287
#define LABEL_169 289
#define LABEL_171 291
#define LABEL_172 293
#define LABEL_173 295
#define LABEL_174 297
#define LABEL_175 299
#define LABEL_176 301
#define LABEL_177 303
#define LABEL_178 305
#define LABEL_179 307
#define LABEL_180 309
#define ENVIRONMENT_LABEL_3 474
#define DEBUGGING_LABEL_2 473
#define PURIFICATION_ROOT 472
#define OBJECT_110 471
#define OBJECT_109 470
#define OBJECT_108 469
#define OBJECT_107 468
#define OBJECT_106 467
#define OBJECT_105 466
#define OBJECT_104 465
#define OBJECT_103 464
#define OBJECT_102 463
#define OBJECT_101 462
#define OBJECT_100 461
#define OBJECT_99 460
#define OBJECT_98 459
#define OBJECT_97 458
#define OBJECT_96 457
#define OBJECT_95 456
#define OBJECT_94 455
#define OBJECT_93 454
#define OBJECT_92 453
#define OBJECT_91 452
#define OBJECT_90 451
#define OBJECT_89 450
#define OBJECT_88 449
#define OBJECT_87 448
#define OBJECT_86 447
#define OBJECT_85 446
#define OBJECT_84 445
#define OBJECT_83 444
#define OBJECT_82 443
#define OBJECT_81 442
#define OBJECT_80 441
#define OBJECT_79 440
#define OBJECT_78 439
#define OBJECT_77 438
#define OBJECT_76 437
#define OBJECT_75 436
#define OBJECT_74 435
#define OBJECT_73 434
#define OBJECT_72 433
#define OBJECT_71 432
#define OBJECT_70 431
#define OBJECT_69 430
#define OBJECT_68 429
#define OBJECT_67 428
#define OBJECT_66 427
#define OBJECT_65 426
#define OBJECT_64 425
#define OBJECT_63 424
#define OBJECT_62 423
#define OBJECT_61 422
#define OBJECT_60 421
#define OBJECT_59 420
#define OBJECT_58 419
#define OBJECT_57 418
#define OBJECT_56 417
#define OBJECT_55 416
#define OBJECT_54 415
#define OBJECT_53 414
#define OBJECT_52 413
#define OBJECT_51 412
#define OBJECT_50 411
#define OBJECT_49 410
#define OBJECT_48 409
#define OBJECT_47 408
#define OBJECT_46 407
#define OBJECT_45 406
#define OBJECT_44 405
#define OBJECT_43 404
#define OBJECT_42 403
#define OBJECT_41 402
#define OBJECT_40 401
#define OBJECT_39 400
#define OBJECT_38 399
#define OBJECT_37 398
#define OBJECT_36 397
#define OBJECT_35 396
#define OBJECT_34 395
#define OBJECT_33 394
#define OBJECT_32 393
#define OBJECT_31 392
#define OBJECT_30 391
#define OBJECT_29 390
#define OBJECT_28 389
#define OBJECT_27 388
#define OBJECT_26 387
#define OBJECT_25 386
#define OBJECT_24 385
#define OBJECT_23 384
#define OBJECT_22 383
#define OBJECT_21 382
#define OBJECT_20 381
#define OBJECT_19 380
#define OBJECT_18 379
#define OBJECT_17 378
#define OBJECT_16 377
#define OBJECT_15 376
#define OBJECT_14 375
#define OBJECT_13 374
#define OBJECT_12 373
#define OBJECT_11 372
#define OBJECT_10 371
#define OBJECT_9 370
#define OBJECT_8 369
#define OBJECT_7 368
#define OBJECT_6 367
#define OBJECT_5 366
#define OBJECT_4 365
#define OBJECT_3 364
#define OBJECT_2 363
#define OBJECT_1 362
#define OBJECT_0 361
#define EXECUTE_CACHE_162 311
#define EXECUTE_CACHE_155 313
#define EXECUTE_CACHE_151 315
#define EXECUTE_CACHE_148 317
#define EXECUTE_CACHE_144 319
#define EXECUTE_CACHE_134 321
#define EXECUTE_CACHE_114 323
#define EXECUTE_CACHE_108 325
#define EXECUTE_CACHE_105 327
#define EXECUTE_CACHE_87 329
#define EXECUTE_CACHE_74 331
#define EXECUTE_CACHE_70 333
#define EXECUTE_CACHE_43 335
#define EXECUTE_CACHE_39 337
#define EXECUTE_CACHE_37 339
#define EXECUTE_CACHE_33 341
#define EXECUTE_CACHE_21 343
#define EXECUTE_CACHE_13 345
#define EXECUTE_CACHE_9 347
#define FREE_REFERENCE_7 350
#define FREE_REFERENCE_6 351
#define FREE_REFERENCE_5 352
#define FREE_REFERENCE_4 353
#define FREE_REFERENCE_3 354
#define FREE_REFERENCE_2 355
#define FREE_REFERENCE_1 356
#define FREE_REFERENCE_0 357
#define GLOBAL_EXECUTE_CACHE_5 359
#define FREE_REFERENCES_LABEL_0 310
#define NUMBER_OF_LINKER_SECTIONS_1 3

#ifndef WANT_ONLY_DATA

SCHEME_OBJECT *
mit_syntax_so_4ba05028b71ac289 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd65;
  machine_word Wrd74;
  machine_word Wrd72;
  machine_word Wrd71;
  machine_word Wrd68;
  machine_word Wrd63;
  machine_word Wrd64;
  machine_word Wrd55;
  machine_word Wrd47;
  machine_word Wrd87;
  machine_word Wrd86;
  machine_word Wrd80;
  machine_word Wrd79;
  machine_word Wrd82;
  machine_word Wrd81;
  machine_word Wrd77;
  machine_word Wrd56;
  machine_word Wrd58;
  machine_word Wrd51;
  machine_word Wrd42;
  machine_word Wrd35;
  machine_word Wrd21;
  machine_word Wrd54;
  machine_word Wrd52;
  machine_word Wrd48;
  machine_word Wrd46;
  machine_word Wrd38;
  machine_word Wrd34;
  machine_word Wrd67;
  machine_word Wrd66;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd57;
  machine_word Wrd53;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd41;
  machine_word Wrd43;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd30;
  machine_word Wrd31;
  machine_word Wrd29;
  machine_word Wrd24;
  machine_word Wrd22;
  machine_word Wrd13;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd23;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd17;
  machine_word Wrd11;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_8);
      goto label_174;

    case 2:
      current_block = (Rpc - LABEL_6);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_12);
      goto label_175;

    case 4:
      current_block = (Rpc - LABEL_7);
      goto continuation_1;

    case 5:
      current_block = (Rpc - LABEL_10);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_16);
      goto label_176;

    case 7:
      current_block = (Rpc - LABEL_11);
      goto continuation_3;

    case 8:
      current_block = (Rpc - LABEL_14);
      goto continuation_6;

    case 9:
      current_block = (Rpc - LABEL_19);
      goto label_177;

    case 10:
      current_block = (Rpc - LABEL_15);
      goto continuation_5;

    case 11:
      current_block = (Rpc - LABEL_17);
      goto continuation_8;

    case 12:
      current_block = (Rpc - LABEL_18);
      goto continuation_7;

    case 13:
      current_block = (Rpc - LABEL_20);
      goto continuation_9;

    case 14:
      current_block = (Rpc - LABEL_22);
      goto continuation_10;

    case 15:
      current_block = (Rpc - LABEL_23);
      goto continuation_11;

    case 16:
      current_block = (Rpc - LABEL_24);
      goto continuation_12;

    case 17:
      current_block = (Rpc - LABEL_25);
      goto continuation_13;

    case 18:
      current_block = (Rpc - LABEL_26);
      goto continuation_14;

    case 19:
      current_block = (Rpc - LABEL_27);
      goto continuation_15;

    case 20:
      current_block = (Rpc - LABEL_28);
      goto continuation_16;

    case 21:
      current_block = (Rpc - LABEL_29);
      goto continuation_17;

    case 22:
      current_block = (Rpc - LABEL_30);
      goto continuation_66;

    case 23:
      current_block = (Rpc - LABEL_31);
      goto continuation_19;

    case 24:
      current_block = (Rpc - LABEL_32);
      goto lambda_18;

    case 25:
      current_block = (Rpc - LABEL_38);
      goto label_178;

    case 26:
      current_block = (Rpc - LABEL_34);
      goto continuation_67;

    case 27:
      current_block = (Rpc - LABEL_35);
      goto lambda_238;

    case 28:
      current_block = (Rpc - LABEL_42);
      goto label_179;

    case 29:
      current_block = (Rpc - LABEL_40);
      goto continuation_68;

    case 30:
      current_block = (Rpc - LABEL_41);
      goto continuation_22;

    case 31:
      current_block = (Rpc - LABEL_46);
      goto label_181;

    case 32:
      current_block = (Rpc - LABEL_47);
      goto label_180;

    case 33:
      current_block = (Rpc - LABEL_44);
      goto continuation_69;

    case 34:
      current_block = (Rpc - LABEL_48);
      goto continuation_59;

    case 35:
      current_block = (Rpc - LABEL_50);
      goto label_182;

    case 36:
      current_block = (Rpc - LABEL_51);
      goto label_183;

    case 37:
      current_block = (Rpc - LABEL_52);
      goto label_184;

    case 38:
      current_block = (Rpc - LABEL_53);
      goto label_185;

    case 39:
      current_block = (Rpc - LABEL_45);
      goto continuation_24;

    case 40:
      current_block = (Rpc - LABEL_55);
      goto label_191;

    case 41:
      current_block = (Rpc - LABEL_56);
      goto label_186;

    case 42:
      current_block = (Rpc - LABEL_57);
      goto label_187;

    case 43:
      current_block = (Rpc - LABEL_58);
      goto label_188;

    case 44:
      current_block = (Rpc - LABEL_59);
      goto label_189;

    case 45:
      current_block = (Rpc - LABEL_60);
      goto label_190;

    case 46:
      current_block = (Rpc - LABEL_49);
      goto continuation_70;

    case 47:
      current_block = (Rpc - LABEL_61);
      goto continuation_45;

    case 48:
      current_block = (Rpc - LABEL_63);
      goto label_192;

    case 49:
      current_block = (Rpc - LABEL_64);
      goto label_193;

    case 50:
      current_block = (Rpc - LABEL_65);
      goto label_194;

    case 51:
      current_block = (Rpc - LABEL_66);
      goto label_195;

    case 52:
      current_block = (Rpc - LABEL_54);
      goto continuation_26;

    case 53:
      current_block = (Rpc - LABEL_68);
      goto label_196;

    case 54:
      current_block = (Rpc - LABEL_62);
      goto continuation_71;

    case 55:
      current_block = (Rpc - LABEL_69);
      goto continuation_38;

    case 56:
      current_block = (Rpc - LABEL_72);
      goto label_197;

    case 57:
      current_block = (Rpc - LABEL_73);
      goto label_198;

    case 58:
      current_block = (Rpc - LABEL_67);
      goto continuation_28;

    case 59:
      current_block = (Rpc - LABEL_75);
      goto label_199;

    case 60:
      current_block = (Rpc - LABEL_76);
      goto label_200;

    case 61:
      current_block = (Rpc - LABEL_77);
      goto label_201;

    case 62:
      current_block = (Rpc - LABEL_78);
      goto label_202;

    case 63:
      current_block = (Rpc - LABEL_79);
      goto label_203;

    case 64:
      current_block = (Rpc - LABEL_71);
      goto continuation_72;

    case 65:
      current_block = (Rpc - LABEL_80);
      goto continuation_114;

    case 66:
      current_block = (Rpc - LABEL_81);
      goto continuation_78;

    case 67:
      current_block = (Rpc - LABEL_82);
      goto lambda_77;

    case 68:
      current_block = (Rpc - LABEL_83);
      goto continuation_115;

    case 69:
      current_block = (Rpc - LABEL_84);
      goto lambda_240;

    case 70:
      current_block = (Rpc - LABEL_90);
      goto label_204;

    case 71:
      current_block = (Rpc - LABEL_86);
      goto continuation_73;

    case 72:
      current_block = (Rpc - LABEL_88);
      goto continuation_116;

    case 73:
      current_block = (Rpc - LABEL_89);
      goto continuation_81;

    case 74:
      current_block = (Rpc - LABEL_94);
      goto label_213;

    case 75:
      current_block = (Rpc - LABEL_95);
      goto label_205;

    case 76:
      current_block = (Rpc - LABEL_96);
      goto label_206;

    case 77:
      current_block = (Rpc - LABEL_97);
      goto label_207;

    case 78:
      current_block = (Rpc - LABEL_98);
      goto label_208;

    case 79:
      current_block = (Rpc - LABEL_99);
      goto label_209;

    case 80:
      current_block = (Rpc - LABEL_100);
      goto label_210;

    case 81:
      current_block = (Rpc - LABEL_101);
      goto label_211;

    case 82:
      current_block = (Rpc - LABEL_102);
      goto label_212;

    case 83:
      current_block = (Rpc - LABEL_91);
      goto continuation_74;

    case 84:
      current_block = (Rpc - LABEL_106);
      goto label_214;

    case 85:
      current_block = (Rpc - LABEL_107);
      goto label_215;

    case 86:
      current_block = (Rpc - LABEL_92);
      goto continuation_117;

    case 87:
      current_block = (Rpc - LABEL_103);
      goto continuation_110;

    case 88:
      current_block = (Rpc - LABEL_104);
      goto lambda_109;

    case 89:
      current_block = (Rpc - LABEL_111);
      goto label_216;

    case 90:
      current_block = (Rpc - LABEL_112);
      goto label_217;

    case 91:
      current_block = (Rpc - LABEL_93);
      goto continuation_83;

    case 92:
      current_block = (Rpc - LABEL_109);
      goto continuation_118;

    case 93:
      current_block = (Rpc - LABEL_110);
      goto continuation_96;

    case 94:
      current_block = (Rpc - LABEL_113);
      goto continuation_84;

    case 95:
      current_block = (Rpc - LABEL_117);
      goto label_218;

    case 96:
      current_block = (Rpc - LABEL_115);
      goto continuation_119;

    case 97:
      current_block = (Rpc - LABEL_116);
      goto continuation_95;

    case 98:
      current_block = (Rpc - LABEL_118);
      goto continuation_120;

    case 99:
      current_block = (Rpc - LABEL_119);
      goto continuation_94;

    case 100:
      current_block = (Rpc - LABEL_120);
      goto continuation_121;

    case 101:
      current_block = (Rpc - LABEL_121);
      goto continuation_122;

    case 102:
      current_block = (Rpc - LABEL_122);
      goto continuation_123;

    case 103:
      current_block = (Rpc - LABEL_123);
      goto continuation_124;

    case 104:
      current_block = (Rpc - LABEL_124);
      goto continuation_125;

    case 105:
      current_block = (Rpc - LABEL_125);
      goto continuation_126;

    case 106:
      current_block = (Rpc - LABEL_126);
      goto continuation_127;

    case 107:
      current_block = (Rpc - LABEL_127);
      goto continuation_128;

    case 108:
      current_block = (Rpc - LABEL_128);
      goto continuation_129;

    case 109:
      current_block = (Rpc - LABEL_129);
      goto continuation_154;

    case 110:
      current_block = (Rpc - LABEL_130);
      goto continuation_137;

    case 111:
      current_block = (Rpc - LABEL_131);
      goto lambda_136;

    case 112:
      current_block = (Rpc - LABEL_137);
      goto label_219;

    case 113:
      current_block = (Rpc - LABEL_138);
      goto label_220;

    case 114:
      current_block = (Rpc - LABEL_140);
      goto label_221;

    case 115:
      current_block = (Rpc - LABEL_141);
      goto label_222;

    case 116:
      current_block = (Rpc - LABEL_142);
      goto label_223;

    case 117:
      current_block = (Rpc - LABEL_143);
      goto label_224;

    case 118:
      current_block = (Rpc - LABEL_132);
      goto continuation_156;

    case 119:
      current_block = (Rpc - LABEL_147);
      goto label_225;

    case 120:
      current_block = (Rpc - LABEL_133);
      goto continuation_155;

    case 121:
      current_block = (Rpc - LABEL_135);
      goto lambda_243;

    case 122:
      current_block = (Rpc - LABEL_150);
      goto label_226;

    case 123:
      current_block = (Rpc - LABEL_139);
      goto continuation_135;

    case 124:
      current_block = (Rpc - LABEL_145);
      goto continuation_158;

    case 125:
      current_block = (Rpc - LABEL_154);
      goto label_227;

    case 126:
      current_block = (Rpc - LABEL_146);
      goto continuation_157;

    case 127:
      current_block = (Rpc - LABEL_149);
      goto continuation_140;

    case 128:
      current_block = (Rpc - LABEL_157);
      goto label_229;

    case 129:
      current_block = (Rpc - LABEL_158);
      goto label_228;

    case 130:
      current_block = (Rpc - LABEL_152);
      goto continuation_160;

    case 131:
      current_block = (Rpc - LABEL_161);
      goto label_230;

    case 132:
      current_block = (Rpc - LABEL_153);
      goto continuation_159;

    case 133:
      current_block = (Rpc - LABEL_156);
      goto continuation_142;

    case 134:
      current_block = (Rpc - LABEL_163);
      goto label_231;

    case 135:
      current_block = (Rpc - LABEL_164);
      goto label_232;

    case 136:
      current_block = (Rpc - LABEL_165);
      goto label_233;

    case 137:
      current_block = (Rpc - LABEL_166);
      goto label_234;

    case 138:
      current_block = (Rpc - LABEL_167);
      goto label_235;

    case 139:
      current_block = (Rpc - LABEL_159);
      goto continuation_162;

    case 140:
      current_block = (Rpc - LABEL_170);
      goto label_236;

    case 141:
      current_block = (Rpc - LABEL_160);
      goto continuation_161;

    case 142:
      current_block = (Rpc - LABEL_168);
      goto continuation_164;

    case 143:
      current_block = (Rpc - LABEL_169);
      goto continuation_163;

    case 144:
      current_block = (Rpc - LABEL_171);
      goto continuation_165;

    case 145:
      current_block = (Rpc - LABEL_172);
      goto continuation_166;

    case 146:
      current_block = (Rpc - LABEL_173);
      goto continuation_167;

    case 147:
      current_block = (Rpc - LABEL_174);
      goto continuation_168;

    case 148:
      current_block = (Rpc - LABEL_175);
      goto continuation_169;

    case 149:
      current_block = (Rpc - LABEL_176);
      goto continuation_170;

    case 150:
      current_block = (Rpc - LABEL_177);
      goto continuation_171;

    case 151:
      current_block = (Rpc - LABEL_178);
      goto label_246;

    case 152:
      current_block = (Rpc - LABEL_179);
      goto label_247;

    case 153:
      current_block = (Rpc - LABEL_180);
      goto expression_173;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_173)
  (current_block [ENVIRONMENT_LABEL_3]) = (Rrb [REGBLOCK_ENV]);
  INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_179])), current_block, (& (current_block [FREE_REFERENCES_LABEL_0])), NUMBER_OF_LINKER_SECTIONS_1);

DEFLABEL (label_247)
  (* (--Rsp)) = (ULONG_TO_FIXNUM (1UL));

DEFLABEL (label_246)
  {
    static const short sections [] =
      {
	0,
	1,
	1,
	2,
	2,
	1,
	1,
	1,
	2,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	2,
	1,
	2,
	1,
	2,
	2,
	1,
	2,
	1,
	2,
	1,
	1,
	1,
	2,
	1,
	1,
	2,
	2,
	2,
	1,
	1,
	2,
	1,
	2,
	2,
	2,
	1,
	2,
	2,
	1,
	2,
	1
      };
    unsigned long counter = (OBJECT_DATUM (* Rsp));
    SCHEME_OBJECT blocks;
    SCHEME_OBJECT * sub_block;
    short section;
    if (counter > 49)
      goto label_245;
    blocks = (current_block [OBJECT_110]);
    sub_block = (OBJECT_ADDRESS (MEMORY_REF (blocks, counter)));
    (sub_block [(OBJECT_DATUM (sub_block [0]))]) = (Rrb [REGBLOCK_ENV]);
    section = (sections [counter]);
    (* Rsp) = (ULONG_TO_FIXNUM (counter + 1));
    INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_178])), sub_block, (sub_block + (2 + (OBJECT_DATUM (sub_block [1])))), section);
  }

DEFLABEL (label_245)
  Rsp += 1;
  (Wrd5.Obj) = (Rrb [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_1]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_263;
  Wrd11 = Wrd15;

DEFLABEL (label_262)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd17.Obj) = (current_block [OBJECT_2]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_7);
  (* (--Rsp)) = Rvl;
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd6.Obj) = (current_block [OBJECT_4]);
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_6);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_261;
  Wrd11 = Wrd15;

DEFLABEL (label_260)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd17.Obj) = (current_block [OBJECT_3]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_11);
  (* (--Rsp)) = Rvl;
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd6.Obj) = (current_block [OBJECT_6]);
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_10);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_259;
  Wrd11 = Wrd15;

DEFLABEL (label_258)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd17.Obj) = (current_block [OBJECT_5]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_15);
  (* (--Rsp)) = Rvl;
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd6.Obj) = (current_block [OBJECT_8]);
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_14);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_257;
  Wrd11 = Wrd15;

DEFLABEL (label_256)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd17.Obj) = (current_block [OBJECT_7]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_18);
  (* (--Rsp)) = Rvl;
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd6.Obj) = (current_block [OBJECT_11]);
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_17);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_9]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd10.Obj) = (current_block [OBJECT_10]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_20);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_12]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd10.Obj) = (current_block [OBJECT_13]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_22);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_14]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_15]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_23);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_16]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd10.Obj) = (current_block [OBJECT_17]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_18]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd10.Obj) = (current_block [OBJECT_19]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_25);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_20]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd10.Obj) = (current_block [OBJECT_21]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_26);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_22]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd10.Obj) = (current_block [OBJECT_23]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_27);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_24]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_25]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_28);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_26]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd10.Obj) = (current_block [OBJECT_27]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_29);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32]))));
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_31);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_36);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_35])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd12.Obj) = (current_block [OBJECT_30]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37]));

DEFLABEL (continuation_66)
  INTERRUPT_CHECK (27, LABEL_30);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_28]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd10.Obj) = (current_block [OBJECT_29]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13]));

DEFLABEL (continuation_67)
  INTERRUPT_CHECK (27, LABEL_34);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_31]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_32]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_68)
  INTERRUPT_CHECK (27, LABEL_40);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_35]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd10.Obj) = (current_block [OBJECT_36]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37]));

DEFLABEL (continuation_69)
  INTERRUPT_CHECK (27, LABEL_44);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_38]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_39]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40]), 3);

DEFLABEL (continuation_70)
  INTERRUPT_CHECK (27, LABEL_49);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_44]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd10.Obj) = (current_block [OBJECT_45]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37]));

DEFLABEL (continuation_71)
  INTERRUPT_CHECK (27, LABEL_62);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_47]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd10.Obj) = (current_block [OBJECT_48]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37]));

DEFLABEL (continuation_72)
  INTERRUPT_CHECK (27, LABEL_71);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_80]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82]))));
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33]));

DEFLABEL (continuation_78)
  INTERRUPT_CHECK (27, LABEL_81);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_85);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_84])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd12.Obj) = (current_block [OBJECT_51]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37]));

DEFLABEL (continuation_114)
  INTERRUPT_CHECK (27, LABEL_80);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_49]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd10.Obj) = (current_block [OBJECT_50]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37]));

DEFLABEL (continuation_115)
  INTERRUPT_CHECK (27, LABEL_83);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_88]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_52]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd10.Obj) = (current_block [OBJECT_53]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13]));

DEFLABEL (continuation_116)
  INTERRUPT_CHECK (27, LABEL_88);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_92]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_55]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_56]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40]), 3);

DEFLABEL (continuation_117)
  INTERRUPT_CHECK (27, LABEL_92);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_109]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_58]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd10.Obj) = (current_block [OBJECT_59]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13]));

DEFLABEL (continuation_118)
  INTERRUPT_CHECK (27, LABEL_109);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_60]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd10.Obj) = (current_block [OBJECT_61]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37]));

DEFLABEL (continuation_119)
  INTERRUPT_CHECK (27, LABEL_115);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_62]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd10.Obj) = (current_block [OBJECT_63]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13]));

DEFLABEL (continuation_120)
  INTERRUPT_CHECK (27, LABEL_118);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_120]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_64]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_65]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_121)
  INTERRUPT_CHECK (27, LABEL_120);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_121]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_66]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd10.Obj) = (current_block [OBJECT_67]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37]));

DEFLABEL (continuation_122)
  INTERRUPT_CHECK (27, LABEL_121);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_122]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_68]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd10.Obj) = (current_block [OBJECT_69]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21]));

DEFLABEL (continuation_123)
  INTERRUPT_CHECK (27, LABEL_122);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_123]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_70]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd10.Obj) = (current_block [OBJECT_71]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37]));

DEFLABEL (continuation_124)
  INTERRUPT_CHECK (27, LABEL_123);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_124]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_72]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd10.Obj) = (current_block [OBJECT_73]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37]));

DEFLABEL (continuation_125)
  INTERRUPT_CHECK (27, LABEL_124);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_125]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_74]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd10.Obj) = (current_block [OBJECT_75]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37]));

DEFLABEL (continuation_126)
  INTERRUPT_CHECK (27, LABEL_125);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_76]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_77]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40]), 3);

DEFLABEL (continuation_127)
  INTERRUPT_CHECK (27, LABEL_126);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_127]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_78]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd10.Obj) = (current_block [OBJECT_79]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37]));

DEFLABEL (continuation_128)
  INTERRUPT_CHECK (27, LABEL_127);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_128]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_80]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd10.Obj) = (current_block [OBJECT_81]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37]));

DEFLABEL (continuation_129)
  INTERRUPT_CHECK (27, LABEL_128);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_129]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_130]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_131]))));
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33]));

DEFLABEL (continuation_137)
  INTERRUPT_CHECK (27, LABEL_130);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_136);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_135])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd12.Obj) = (current_block [OBJECT_85]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37]));

DEFLABEL (continuation_154)
  INTERRUPT_CHECK (27, LABEL_129);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_132]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_133]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_82]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_83]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_84]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_134]));

DEFLABEL (continuation_155)
  INTERRUPT_CHECK (27, LABEL_133);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_86]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40]), 3);

DEFLABEL (continuation_156)
  INTERRUPT_CHECK (27, LABEL_132);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_145]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_146]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_83]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_255;
  Wrd12 = Wrd16;

DEFLABEL (label_254)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_148]));

DEFLABEL (continuation_157)
  INTERRUPT_CHECK (27, LABEL_146);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_87]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40]), 3);

DEFLABEL (continuation_158)
  INTERRUPT_CHECK (27, LABEL_145);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_152]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_153]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_253;
  Wrd11 = Wrd15;

DEFLABEL (label_252)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_155]));

DEFLABEL (continuation_159)
  INTERRUPT_CHECK (27, LABEL_153);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_90]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40]), 3);

DEFLABEL (continuation_160)
  INTERRUPT_CHECK (27, LABEL_152);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_159]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_160]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_89]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_251;
  Wrd12 = Wrd16;

DEFLABEL (label_250)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_162]));

DEFLABEL (continuation_161)
  INTERRUPT_CHECK (27, LABEL_160);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_92]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40]), 3);

DEFLABEL (continuation_162)
  INTERRUPT_CHECK (27, LABEL_159);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_168]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_169]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_91]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_249;
  Wrd12 = Wrd16;

DEFLABEL (label_248)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_162]));

DEFLABEL (continuation_163)
  INTERRUPT_CHECK (27, LABEL_169);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_95]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40]), 3);

DEFLABEL (continuation_164)
  INTERRUPT_CHECK (27, LABEL_168);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_171]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_93]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd10.Obj) = (current_block [OBJECT_94]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37]));

DEFLABEL (continuation_165)
  INTERRUPT_CHECK (27, LABEL_171);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_172]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_96]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd10.Obj) = (current_block [OBJECT_97]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37]));

DEFLABEL (continuation_166)
  INTERRUPT_CHECK (27, LABEL_172);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_173]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_98]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd10.Obj) = (current_block [OBJECT_99]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37]));

DEFLABEL (continuation_167)
  INTERRUPT_CHECK (27, LABEL_173);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_174]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_100]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd10.Obj) = (current_block [OBJECT_101]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21]));

DEFLABEL (continuation_168)
  INTERRUPT_CHECK (27, LABEL_174);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_175]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_102]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_103]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_169)
  INTERRUPT_CHECK (27, LABEL_175);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_176]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_104]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd10.Obj) = (current_block [OBJECT_105]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13]));

DEFLABEL (continuation_170)
  INTERRUPT_CHECK (27, LABEL_176);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_177]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_106]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd10.Obj) = (current_block [OBJECT_107]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13]));

DEFLABEL (continuation_171)
  INTERRUPT_CHECK (27, LABEL_177);
  (Wrd5.Obj) = (current_block [OBJECT_108]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_109]);
  (Rsp [2]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (label_249)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_170])), (Wrd13.pObj));

DEFLABEL (label_236)
  (Wrd12.Obj) = Rvl;
  goto label_248;

DEFLABEL (label_251)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_161])), (Wrd13.pObj));

DEFLABEL (label_230)
  (Wrd12.Obj) = Rvl;
  goto label_250;

DEFLABEL (label_253)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_154])), (Wrd12.pObj));

DEFLABEL (label_227)
  (Wrd11.Obj) = Rvl;
  goto label_252;

DEFLABEL (label_255)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_147])), (Wrd13.pObj));

DEFLABEL (label_225)
  (Wrd12.Obj) = Rvl;
  goto label_254;

DEFLABEL (label_257)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_19])), (Wrd12.pObj));

DEFLABEL (label_177)
  (Wrd11.Obj) = Rvl;
  goto label_256;

DEFLABEL (label_259)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_16])), (Wrd12.pObj));

DEFLABEL (label_176)
  (Wrd11.Obj) = Rvl;
  goto label_258;

DEFLABEL (label_261)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_12])), (Wrd12.pObj));

DEFLABEL (label_175)
  (Wrd11.Obj) = Rvl;
  goto label_260;

DEFLABEL (label_263)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_8])), (Wrd12.pObj));

DEFLABEL (label_174)
  (Wrd11.Obj) = Rvl;
  goto label_262;

DEFLABEL (lambda_239)
DEFLABEL (lambda_18)
  INTERRUPT_CHECK (26, LABEL_32);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [3]);
  (Rsp [2]) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (Rsp [3]) = (Wrd8.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_265;
  Wrd10 = Wrd14;

DEFLABEL (label_264)
  (Rsp [4]) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39]));

DEFLABEL (label_265)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_38])), (Wrd11.pObj));

DEFLABEL (label_178)
  (Wrd10.Obj) = Rvl;
  goto label_264;

DEFLABEL (lambda_238)
  CLOSURE_HEADER (LABEL_35);

DEFLABEL (lambda_64)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_319;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [1]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_318)
  (Wrd17.Obj) = (current_block [OBJECT_34]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_41);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_276;
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_275;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [1]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_274)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (current_block [OBJECT_13]);
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd20.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_59)
  INTERRUPT_CHECK (27, LABEL_48);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Wrd13.Obj) = (current_block [OBJECT_41]);
  (* (Rhp++)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd11.pObj) = (& (Rhp [-2]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd11.pObj)));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_273;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [1]);

DEFLABEL (label_272)
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd25.uLng) == 1))
    goto label_271;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd23.Obj) = ((Wrd24.pObj) [0]);

DEFLABEL (label_270)
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd32.uLng) == 1))
    goto label_269;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd30.Obj) = ((Wrd31.pObj) [0]);

DEFLABEL (label_268)
  (Wrd37.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd30.Obj);
  (* (Rhp++)) = (Wrd37.Obj);
  (Wrd39.pObj) = (& (Rhp [-2]));
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd39.pObj)));
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd44.Obj) = (Rsp [2]);
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if (! ((Wrd45.uLng) == 1))
    goto label_267;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd41.Obj) = ((Wrd43.pObj) [0]);

DEFLABEL (label_266)
  (Wrd50.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd41.Obj);
  (* (Rhp++)) = (Wrd50.Obj);
  (Wrd53.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd53.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_267)
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42]), 1);

DEFLABEL (label_185)
  (Wrd41.Obj) = Rvl;
  goto label_266;

DEFLABEL (label_269)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42]), 1);

DEFLABEL (label_184)
  (Wrd30.Obj) = Rvl;
  goto label_268;

DEFLABEL (label_271)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42]), 1);

DEFLABEL (label_183)
  (Wrd23.Obj) = Rvl;
  goto label_270;

DEFLABEL (label_273)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_182)
  (Wrd14.Obj) = Rvl;
  goto label_272;

DEFLABEL (label_275)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_180)
  (* (--Rsp)) = Rvl;
  goto label_274;

DEFLABEL (label_276)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd27.Obj) = (Rsp [2]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd28.uLng) == 1))
    goto label_317;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [1]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_316)
  (Wrd33.Obj) = (current_block [OBJECT_37]);
  (* (--Rsp)) = (Wrd33.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43]));

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_45);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_295;
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_294;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_293)
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_292;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [1]);
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_291)
  (Wrd26.Obj) = (Rsp [2]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd27.uLng) == 1))
    goto label_290;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd23.Obj) = ((Wrd25.pObj) [1]);

DEFLABEL (label_289)
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd34.uLng) == 1))
    goto label_288;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd32.Obj) = ((Wrd33.pObj) [0]);

DEFLABEL (label_287)
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd41.uLng) == 1))
    goto label_286;
  (Wrd40.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd39.Obj) = ((Wrd40.pObj) [1]);

DEFLABEL (label_285)
  (Wrd46.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd39.Obj);
  (* (Rhp++)) = (Wrd46.Obj);
  (Wrd48.pObj) = (& (Rhp [-2]));
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd48.pObj)));
  (* (--Rsp)) = (Wrd49.Obj);
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_61]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (Wrd53.Obj) = (current_block [OBJECT_10]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd54.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd54.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_45)
  INTERRUPT_CHECK (27, LABEL_61);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Wrd13.Obj) = (current_block [OBJECT_41]);
  (* (Rhp++)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd11.pObj) = (& (Rhp [-2]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd11.pObj)));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_284;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [1]);

DEFLABEL (label_283)
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd25.uLng) == 1))
    goto label_282;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd23.Obj) = ((Wrd24.pObj) [0]);

DEFLABEL (label_281)
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd32.uLng) == 1))
    goto label_280;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd30.Obj) = ((Wrd31.pObj) [0]);

DEFLABEL (label_279)
  (Wrd37.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd30.Obj);
  (* (Rhp++)) = (Wrd37.Obj);
  (Wrd39.pObj) = (& (Rhp [-2]));
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd39.pObj)));
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd44.Obj) = (Rsp [2]);
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if (! ((Wrd45.uLng) == 1))
    goto label_278;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd41.Obj) = ((Wrd43.pObj) [0]);

DEFLABEL (label_277)
  (Wrd50.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd41.Obj);
  (* (Rhp++)) = (Wrd50.Obj);
  (Wrd53.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd53.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_278)
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42]), 1);

DEFLABEL (label_195)
  (Wrd41.Obj) = Rvl;
  goto label_277;

DEFLABEL (label_280)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42]), 1);

DEFLABEL (label_194)
  (Wrd30.Obj) = Rvl;
  goto label_279;

DEFLABEL (label_282)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42]), 1);

DEFLABEL (label_193)
  (Wrd23.Obj) = Rvl;
  goto label_281;

DEFLABEL (label_284)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_192)
  (Wrd14.Obj) = Rvl;
  goto label_283;

DEFLABEL (label_286)
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_190)
  (Wrd39.Obj) = Rvl;
  goto label_285;

DEFLABEL (label_288)
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_59]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42]), 1);

DEFLABEL (label_189)
  (Wrd32.Obj) = Rvl;
  goto label_287;

DEFLABEL (label_290)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_188)
  (Wrd23.Obj) = Rvl;
  goto label_289;

DEFLABEL (label_292)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_187)
  (* (--Rsp)) = Rvl;
  goto label_291;

DEFLABEL (label_294)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_186)
  (Wrd7.Obj) = Rvl;
  goto label_293;

DEFLABEL (label_295)
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54]))));
  (* (--Rsp)) = (Wrd57.Obj);
  (Wrd61.Obj) = (Rsp [2]);
  (Wrd62.uLng) = (OBJECT_TYPE (Wrd61.Obj));
  if (! ((Wrd62.uLng) == 1))
    goto label_315;
  (Wrd59.pObj) = (OBJECT_ADDRESS (Wrd61.Obj));
  (Wrd60.Obj) = ((Wrd59.pObj) [1]);
  (* (--Rsp)) = (Wrd60.Obj);

DEFLABEL (label_314)
  (Wrd67.Obj) = (current_block [OBJECT_43]);
  (* (--Rsp)) = (Wrd67.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43]));

DEFLABEL (continuation_26)
  INTERRUPT_CHECK (27, LABEL_54);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_300;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69]))));
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_70]));

DEFLABEL (continuation_38)
  INTERRUPT_CHECK (27, LABEL_69);
  (Wrd9.Obj) = (current_block [OBJECT_41]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_299;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [1]);

DEFLABEL (label_298)
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd21.uLng) == 1))
    goto label_297;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd19.Obj) = ((Wrd20.pObj) [0]);

DEFLABEL (label_296)
  (Wrd26.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd26.Obj);
  (Wrd29.pObj) = (& (Rhp [-2]));
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd29.pObj)));
  (Wrd34.Obj) = (Rsp [0]);
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd36.Obj) = ((Wrd35.pObj) [2]);
  (* (Rhp++)) = (Wrd36.Obj);
  (* (Rhp++)) = (Wrd27.Obj);
  (Wrd32.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd32.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_297)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_73]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42]), 1);

DEFLABEL (label_198)
  (Wrd19.Obj) = Rvl;
  goto label_296;

DEFLABEL (label_299)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_197)
  (Wrd10.Obj) = Rvl;
  goto label_298;

DEFLABEL (label_300)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd16.Obj) = (Rsp [2]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 1))
    goto label_313;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [1]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_312)
  (Wrd22.Obj) = (current_block [OBJECT_46]);
  (* (--Rsp)) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43]));

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_67);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_301;
  (Wrd61.Obj) = (Rsp [1]);
  (Rsp [3]) = (Wrd61.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_74]));

DEFLABEL (label_301)
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_311;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_310)
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_309;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd16.Obj) = ((Wrd17.pObj) [1]);

DEFLABEL (label_308)
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd25.uLng) == 1))
    goto label_307;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd23.Obj) = ((Wrd24.pObj) [0]);

DEFLABEL (label_306)
  (Wrd33.Obj) = (current_block [OBJECT_41]);
  (* (Rhp++)) = (Wrd23.Obj);
  (* (Rhp++)) = (Wrd33.Obj);
  (Wrd31.pObj) = (& (Rhp [-2]));
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd31.pObj)));
  (* (--Rsp)) = (Wrd32.Obj);
  (Wrd37.Obj) = (Rsp [2]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd38.uLng) == 1))
    goto label_305;
  (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd34.Obj) = ((Wrd36.pObj) [1]);

DEFLABEL (label_304)
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd45.uLng) == 1))
    goto label_303;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd43.Obj) = ((Wrd44.pObj) [0]);

DEFLABEL (label_302)
  (Wrd50.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd43.Obj);
  (* (Rhp++)) = (Wrd50.Obj);
  (Wrd53.pObj) = (& (Rhp [-2]));
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd53.pObj)));
  (Wrd58.Obj) = (Rsp [0]);
  (Wrd59.pObj) = (OBJECT_ADDRESS (Wrd58.Obj));
  (Wrd60.Obj) = ((Wrd59.pObj) [2]);
  (* (Rhp++)) = (Wrd60.Obj);
  (* (Rhp++)) = (Wrd51.Obj);
  (Wrd56.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd56.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_303)
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_79]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42]), 1);

DEFLABEL (label_203)
  (Wrd43.Obj) = Rvl;
  goto label_302;

DEFLABEL (label_305)
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_78]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_202)
  (Wrd34.Obj) = Rvl;
  goto label_304;

DEFLABEL (label_307)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_77]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42]), 1);

DEFLABEL (label_201)
  (Wrd23.Obj) = Rvl;
  goto label_306;

DEFLABEL (label_309)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_76]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_200)
  (Wrd16.Obj) = Rvl;
  goto label_308;

DEFLABEL (label_311)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_75]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_199)
  (Wrd7.Obj) = Rvl;
  goto label_310;

DEFLABEL (label_313)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_196)
  (* (--Rsp)) = Rvl;
  goto label_312;

DEFLABEL (label_315)
  (Wrd66.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55]))));
  (* (--Rsp)) = (Wrd66.Obj);
  (* (--Rsp)) = (Wrd61.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_191)
  (* (--Rsp)) = Rvl;
  goto label_314;

DEFLABEL (label_317)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_181)
  (* (--Rsp)) = Rvl;
  goto label_316;

DEFLABEL (label_319)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_179)
  (* (--Rsp)) = Rvl;
  goto label_318;

DEFLABEL (lambda_241)
DEFLABEL (lambda_77)
  INTERRUPT_CHECK (26, LABEL_82);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_86]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_87]));

DEFLABEL (continuation_73)
  INTERRUPT_CHECK (27, LABEL_86);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_91]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_87]));

DEFLABEL (continuation_74)
  INTERRUPT_CHECK (27, LABEL_91);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Rsp [3]) = Rvl;
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_323;
  Wrd8 = Wrd12;

DEFLABEL (label_322)
  (Rsp [5]) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [4]);
  (Rsp [1]) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [6]);
  (Rsp [4]) = (Wrd15.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_5]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_321;
  Wrd17 = Wrd21;

DEFLABEL (label_320)
  (Rsp [6]) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_108]));

DEFLABEL (label_321)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_107])), (Wrd18.pObj));

DEFLABEL (label_215)
  (Wrd17.Obj) = Rvl;
  goto label_320;

DEFLABEL (label_323)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_106])), (Wrd9.pObj));

DEFLABEL (label_214)
  (Wrd8.Obj) = Rvl;
  goto label_322;

DEFLABEL (lambda_240)
  CLOSURE_HEADER (LABEL_84);

DEFLABEL (lambda_112)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_347;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [1]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_346)
  (Wrd17.Obj) = (current_block [OBJECT_54]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43]));

DEFLABEL (continuation_81)
  INTERRUPT_CHECK (27, LABEL_89);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_340;
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_339;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_338)
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_337;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd16.Obj) = ((Wrd17.pObj) [1]);

DEFLABEL (label_336)
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd25.uLng) == 1))
    goto label_335;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [1]);
  (* (--Rsp)) = (Wrd24.Obj);

DEFLABEL (label_334)
  (Wrd33.Obj) = (Rsp [2]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 1))
    goto label_333;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [1]);

DEFLABEL (label_332)
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd41.uLng) == 1))
    goto label_331;
  (Wrd40.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd39.Obj) = ((Wrd40.pObj) [1]);

DEFLABEL (label_330)
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if (! ((Wrd48.uLng) == 1))
    goto label_329;
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd39.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [0]);
  (* (--Rsp)) = (Wrd47.Obj);

DEFLABEL (label_328)
  (Wrd56.Obj) = (Rsp [3]);
  (Wrd57.uLng) = (OBJECT_TYPE (Wrd56.Obj));
  if (! ((Wrd57.uLng) == 1))
    goto label_327;
  (Wrd55.pObj) = (OBJECT_ADDRESS (Wrd56.Obj));
  (Wrd53.Obj) = ((Wrd55.pObj) [1]);

DEFLABEL (label_326)
  (Wrd64.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if (! ((Wrd64.uLng) == 1))
    goto label_325;
  (Wrd62.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd63.Obj) = ((Wrd62.pObj) [0]);
  (* (--Rsp)) = (Wrd63.Obj);

DEFLABEL (label_324)
  (Wrd71.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103]))));
  (* (--Rsp)) = (Wrd71.Obj);
  (Wrd72.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd72.Obj);
  (Wrd74.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_104]))));
  (* (--Rsp)) = (Wrd74.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_105]));

DEFLABEL (continuation_110)
  INTERRUPT_CHECK (27, LABEL_103);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_110]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_42]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_105]));

DEFLABEL (continuation_96)
  INTERRUPT_CHECK (27, LABEL_110);
  (Wrd9.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Wrd13.Obj) = (Rsp [3]);
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd11.pObj) = (& (Rhp [-2]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd11.pObj)));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (current_block [OBJECT_13]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd18.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_95)
  INTERRUPT_CHECK (27, LABEL_116);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Wrd13.Obj) = (current_block [OBJECT_41]);
  (* (Rhp++)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (Wrd17.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd20.pObj) = (& (Rhp [-2]));
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd24.pObj) = (& (Rhp [-2]));
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd24.pObj)));
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd22.Obj);
  (Wrd28.pObj) = (& (Rhp [-2]));
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd28.pObj)));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_119]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (Wrd33.Obj) = (current_block [OBJECT_53]);
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd34.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_94)
  INTERRUPT_CHECK (27, LABEL_119);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Wrd10.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd13.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd13.pObj)));
  Rsp = (& (Rsp [7]));
  goto pop_return;

DEFLABEL (label_325)
  (Wrd68.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_102]))));
  (* (--Rsp)) = (Wrd68.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42]), 1);

DEFLABEL (label_212)
  (* (--Rsp)) = Rvl;
  goto label_324;

DEFLABEL (label_327)
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101]))));
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_211)
  (Wrd53.Obj) = Rvl;
  goto label_326;

DEFLABEL (label_329)
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42]), 1);

DEFLABEL (label_210)
  (* (--Rsp)) = Rvl;
  goto label_328;

DEFLABEL (label_331)
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_99]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_209)
  (Wrd39.Obj) = Rvl;
  goto label_330;

DEFLABEL (label_333)
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_98]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_208)
  (Wrd30.Obj) = Rvl;
  goto label_332;

DEFLABEL (label_335)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_207)
  (* (--Rsp)) = Rvl;
  goto label_334;

DEFLABEL (label_337)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_206)
  (Wrd16.Obj) = Rvl;
  goto label_336;

DEFLABEL (label_339)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_205)
  (Wrd7.Obj) = Rvl;
  goto label_338;

DEFLABEL (label_340)
  (Wrd77.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93]))));
  (* (--Rsp)) = (Wrd77.Obj);
  (Wrd81.Obj) = (Rsp [2]);
  (Wrd82.uLng) = (OBJECT_TYPE (Wrd81.Obj));
  if (! ((Wrd82.uLng) == 1))
    goto label_345;
  (Wrd79.pObj) = (OBJECT_ADDRESS (Wrd81.Obj));
  (Wrd80.Obj) = ((Wrd79.pObj) [1]);
  (* (--Rsp)) = (Wrd80.Obj);

DEFLABEL (label_344)
  (Wrd87.Obj) = (current_block [OBJECT_57]);
  (* (--Rsp)) = (Wrd87.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43]));

DEFLABEL (continuation_83)
  INTERRUPT_CHECK (27, LABEL_93);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_341;
  (Wrd11.Obj) = (Rsp [1]);
  (Rsp [3]) = (Wrd11.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_74]));

DEFLABEL (label_341)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_114]));

DEFLABEL (continuation_84)
  INTERRUPT_CHECK (27, LABEL_113);
  (Wrd8.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd8.uLng) == 1))
    goto label_343;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd6.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_342)
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [2]);
  (* (Rhp++)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd6.Obj);
  (Wrd15.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd15.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_343)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_218)
  (Wrd6.Obj) = Rvl;
  goto label_342;

DEFLABEL (label_345)
  (Wrd86.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_94]))));
  (* (--Rsp)) = (Wrd86.Obj);
  (* (--Rsp)) = (Wrd81.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_213)
  (* (--Rsp)) = Rvl;
  goto label_344;

DEFLABEL (label_347)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_204)
  (* (--Rsp)) = Rvl;
  goto label_346;

DEFLABEL (lambda_242)
DEFLABEL (lambda_109)
  INTERRUPT_CHECK (26, LABEL_104);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_353;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_352)
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd14.uLng) == 1)
    goto label_348;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_70]));

DEFLABEL (label_348)
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_351;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [1]);

DEFLABEL (label_350)
  (Rsp [0]) = (Wrd16.Obj);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd30.uLng) == 1))
    goto label_349;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  Rvl = ((Wrd27.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_349)
  INVOKE_PRIMITIVE ((current_block [OBJECT_42]), 1);

DEFLABEL (label_351)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_112]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_217)
  (Wrd16.Obj) = Rvl;
  goto label_350;

DEFLABEL (label_353)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_216)
  (Wrd5.Obj) = Rvl;
  goto label_352;

DEFLABEL (lambda_244)
DEFLABEL (lambda_136)
  INTERRUPT_CHECK (26, LABEL_131);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_365;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_364)
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_363;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd15.pObj) [0]);

DEFLABEL (label_362)
  (Rsp [2]) = (Wrd14.Obj);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_139]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd25.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6]));
  (Wrd28.Obj) = ((Wrd25.pObj) [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 50)
    goto label_361;
  Wrd24 = Wrd28;

DEFLABEL (label_360)
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd30.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd31.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd35.Obj) = (Rsp [4]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd36.uLng) == 1))
    goto label_359;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd32.Obj) = ((Wrd34.pObj) [1]);

DEFLABEL (label_358)
  (Wrd43.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd43.uLng) == 1))
    goto label_357;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd41.Obj) = ((Wrd42.pObj) [1]);

DEFLABEL (label_356)
  (Wrd50.uLng) = (OBJECT_TYPE (Wrd41.Obj));
  if (! ((Wrd50.uLng) == 1))
    goto label_355;
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd41.Obj));
  (Wrd49.Obj) = ((Wrd48.pObj) [0]);
  (* (--Rsp)) = (Wrd49.Obj);

DEFLABEL (label_354)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_144]));

DEFLABEL (continuation_135)
  INTERRUPT_CHECK (27, LABEL_139);
  (Wrd5.Obj) = (Rsp [3]);
  (Rsp [1]) = (Wrd5.Obj);
  (Rsp [3]) = Rvl;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_151]));

DEFLABEL (label_355)
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42]), 1);

DEFLABEL (label_224)
  (* (--Rsp)) = Rvl;
  goto label_354;

DEFLABEL (label_357)
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_142]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_223)
  (Wrd41.Obj) = Rvl;
  goto label_356;

DEFLABEL (label_359)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_141]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_222)
  (Wrd32.Obj) = Rvl;
  goto label_358;

DEFLABEL (label_361)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_140])), (Wrd25.pObj));

DEFLABEL (label_221)
  (Wrd24.Obj) = Rvl;
  goto label_360;

DEFLABEL (label_363)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_138]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42]), 1);

DEFLABEL (label_220)
  (Wrd14.Obj) = Rvl;
  goto label_362;

DEFLABEL (label_365)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_137]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_219)
  (Wrd5.Obj) = Rvl;
  goto label_364;

DEFLABEL (lambda_243)
  CLOSURE_HEADER (LABEL_135);

DEFLABEL (lambda_152)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_149]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_383;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [1]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_382)
  (Wrd17.Obj) = (current_block [OBJECT_46]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43]));

DEFLABEL (continuation_140)
  INTERRUPT_CHECK (27, LABEL_149);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_368;
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_367;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_366)
  (Wrd20.Obj) = (Rsp [0]);
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [2]);
  (* (Rhp++)) = (Wrd22.Obj);
  (* (Rhp++)) = (Wrd7.Obj);
  (Wrd18.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd18.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_367)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_158]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_228)
  (Wrd7.Obj) = Rvl;
  goto label_366;

DEFLABEL (label_368)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_156]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd29.Obj) = (Rsp [2]);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if (! ((Wrd30.uLng) == 1))
    goto label_381;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [1]);
  (* (--Rsp)) = (Wrd28.Obj);

DEFLABEL (label_380)
  (Wrd35.Obj) = (current_block [OBJECT_88]);
  (* (--Rsp)) = (Wrd35.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43]));

DEFLABEL (continuation_142)
  INTERRUPT_CHECK (27, LABEL_156);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_369;
  (Wrd67.Obj) = (Rsp [1]);
  (Rsp [3]) = (Wrd67.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_74]));

DEFLABEL (label_369)
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_379;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_378)
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_377;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [1]);
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_376)
  (Wrd26.Obj) = (Rsp [2]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd27.uLng) == 1))
    goto label_375;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd23.Obj) = ((Wrd25.pObj) [0]);

DEFLABEL (label_374)
  (Wrd32.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd23.Obj);
  (* (Rhp++)) = (Wrd32.Obj);
  (Wrd35.pObj) = (& (Rhp [-2]));
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd35.pObj)));
  (Wrd39.Obj) = (current_block [OBJECT_41]);
  (* (Rhp++)) = (Wrd33.Obj);
  (* (Rhp++)) = (Wrd39.Obj);
  (Wrd37.pObj) = (& (Rhp [-2]));
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd37.pObj)));
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd43.Obj) = (Rsp [2]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd44.uLng) == 1))
    goto label_373;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  (Wrd40.Obj) = ((Wrd42.pObj) [1]);

DEFLABEL (label_372)
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if (! ((Wrd51.uLng) == 1))
    goto label_371;
  (Wrd50.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  (Wrd49.Obj) = ((Wrd50.pObj) [0]);

DEFLABEL (label_370)
  (Wrd56.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd49.Obj);
  (* (Rhp++)) = (Wrd56.Obj);
  (Wrd59.pObj) = (& (Rhp [-2]));
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd59.pObj)));
  (Wrd64.Obj) = (Rsp [0]);
  (Wrd65.pObj) = (OBJECT_ADDRESS (Wrd64.Obj));
  (Wrd66.Obj) = ((Wrd65.pObj) [2]);
  (* (Rhp++)) = (Wrd66.Obj);
  (* (Rhp++)) = (Wrd57.Obj);
  (Wrd62.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd62.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_371)
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167]))));
  (* (--Rsp)) = (Wrd55.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42]), 1);

DEFLABEL (label_235)
  (Wrd49.Obj) = Rvl;
  goto label_370;

DEFLABEL (label_373)
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_166]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_234)
  (Wrd40.Obj) = Rvl;
  goto label_372;

DEFLABEL (label_375)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_165]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42]), 1);

DEFLABEL (label_233)
  (Wrd23.Obj) = Rvl;
  goto label_374;

DEFLABEL (label_377)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_164]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_232)
  (* (--Rsp)) = Rvl;
  goto label_376;

DEFLABEL (label_379)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_163]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_231)
  (Wrd7.Obj) = Rvl;
  goto label_378;

DEFLABEL (label_381)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_157]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_229)
  (* (--Rsp)) = Rvl;
  goto label_380;

DEFLABEL (label_383)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_150]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33]), 1);

DEFLABEL (label_226)
  (* (--Rsp)) = Rvl;
  goto label_382;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

static const struct liarc_code_S arr_decl_mit_syntax_so_4ba05028b71ac289 [49] =
  {
    { "mit_syntax_so_code_1", 2, mit_syntax_so_code_1 },
    { "mit_syntax_so_code_2", 7, mit_syntax_so_code_2 },
    { "mit_syntax_so_code_3", 10, mit_syntax_so_code_3 },
    { "mit_syntax_so_code_4", 9, mit_syntax_so_code_4 },
    { "mit_syntax_so_code_5", 14, mit_syntax_so_code_5 },
    { "mit_syntax_so_code_6", 7, mit_syntax_so_code_6 },
    { "mit_syntax_so_code_7", 12, mit_syntax_so_code_7 },
    { "mit_syntax_so_code_8", 5, mit_syntax_so_code_8 },
    { "mit_syntax_so_code_9", 20, mit_syntax_so_code_9 },
    { "mit_syntax_so_code_10", 5, mit_syntax_so_code_10 },
    { "mit_syntax_so_code_11", 15, mit_syntax_so_code_11 },
    { "mit_syntax_so_code_12", 2, mit_syntax_so_code_12 },
    { "mit_syntax_so_code_13", 9, mit_syntax_so_code_13 },
    { "mit_syntax_so_code_14", 6, mit_syntax_so_code_14 },
    { "mit_syntax_so_code_15", 3, mit_syntax_so_code_15 },
    { "mit_syntax_so_code_16", 13, mit_syntax_so_code_16 },
    { "mit_syntax_so_code_17", 10, mit_syntax_so_code_17 },
    { "mit_syntax_so_code_18", 6, mit_syntax_so_code_18 },
    { "mit_syntax_so_code_19", 49, mit_syntax_so_code_19 },
    { "mit_syntax_so_code_20", 14, mit_syntax_so_code_20 },
    { "mit_syntax_so_code_21", 39, mit_syntax_so_code_21 },
    { "mit_syntax_so_code_22", 1, mit_syntax_so_code_22 },
    { "mit_syntax_so_code_23", 12, mit_syntax_so_code_23 },
    { "mit_syntax_so_code_24", 11, mit_syntax_so_code_24 },
    { "mit_syntax_so_code_25", 6, mit_syntax_so_code_25 },
    { "mit_syntax_so_code_26", 1, mit_syntax_so_code_26 },
    { "mit_syntax_so_code_27", 12, mit_syntax_so_code_27 },
    { "mit_syntax_so_code_28", 28, mit_syntax_so_code_28 },
    { "mit_syntax_so_code_29", 13, mit_syntax_so_code_29 },
    { "mit_syntax_so_code_30", 7, mit_syntax_so_code_30 },
    { "mit_syntax_so_code_31", 10, mit_syntax_so_code_31 },
    { "mit_syntax_so_code_32", 13, mit_syntax_so_code_32 },
    { "mit_syntax_so_code_33", 88, mit_syntax_so_code_33 },
    { "mit_syntax_so_code_34", 10, mit_syntax_so_code_34 },
    { "mit_syntax_so_code_35", 27, mit_syntax_so_code_35 },
    { "mit_syntax_so_code_36", 50, mit_syntax_so_code_36 },
    { "mit_syntax_so_code_37", 51, mit_syntax_so_code_37 },
    { "mit_syntax_so_code_38", 29, mit_syntax_so_code_38 },
    { "mit_syntax_so_code_39", 4, mit_syntax_so_code_39 },
    { "mit_syntax_so_code_40", 10, mit_syntax_so_code_40 },
    { "mit_syntax_so_code_41", 23, mit_syntax_so_code_41 },
    { "mit_syntax_so_code_42", 30, mit_syntax_so_code_42 },
    { "mit_syntax_so_code_43", 4, mit_syntax_so_code_43 },
    { "mit_syntax_so_code_44", 2, mit_syntax_so_code_44 },
    { "mit_syntax_so_code_45", 2, mit_syntax_so_code_45 },
    { "mit_syntax_so_code_46", 5, mit_syntax_so_code_46 },
    { "mit_syntax_so_code_47", 12, mit_syntax_so_code_47 },
    { "mit_syntax_so_code_48", 5, mit_syntax_so_code_48 },
    { "mit_syntax_so_code_49", 4, mit_syntax_so_code_49 }
  };

int
decl_mit_syntax_so_4ba05028b71ac289 (void)
{
  DECLARE_SUBCODE_MULTIPLE (arr_decl_mit_syntax_so_4ba05028b71ac289);
  return (0);
}

DECLARE_COMPILED_CODE ("mit-syntax.so", 154, decl_mit_syntax_so_4ba05028b71ac289, mit_syntax_so_4ba05028b71ac289)

#endif /* !WANT_ONLY_DATA */

#ifndef WANT_ONLY_CODE

static const unsigned char prog_mit_syntax_so_data_4ba05028b71ac289 [13500] =
  "\xdb\x03\x6f\xa6\x1b\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x28\x0d\xb9"
  "\x28\x0d\xba\x23\x22\x29\x22\x29\x21\x17\x2b\xbb\x1d\xb0\x82\x88"
  "\xc1\xbc\xc1\xbd\x0d\xbe\x0d\xbf\x08\x89\x0d\x1c\x24\x28\x0d\x1c"
  "\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x83\x88\x08\x28\x0d"
  "\x1c\x28\x0d\x28\x0d\x1c\x28\x0d\x28\x0d\x1c\x28\x0d\x1c\x28\x0d"
  "\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x84\x88\xb4"
  "\xb5\xb6\x0d\x1c\x0d\x1c\x0d\x1c\x08\x8b\x0d\x1c\x24\x28\x1b\x28"
  "\x0d\x1c\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x85\x88\xb4"
  "\xb5\xb6\x0d\x1c\x1b\x88\x1b\x1b\x08\x8b\x1b\x24\x28\x1b\x28\x1b"
  "\x28\x0d\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x86\x88\x28\x0d\x1c\x28\x0d\x1c\x28"
  "\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb4"
  "\x08\xb5\x0d\x0d\x24\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb5\xb6\x0d\x1c\x1b\x08\x8a"
  "\x0d\x1c\x24\x28\x1b\x28\x0d\x28\x0d\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb4\xb5\xb6\xb7"
  "\xb7\x0d\x1c\xb7\x08\x8c\x1b\x0d\x1c\x0d\x24\x28\x1b\x28\x0d\x1c"
  "\x28\x0d\x1c\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\xb4\xb5\xb6\x0d\x1c\x08\x89\x28\x1b\x28"
  "\x0d\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\xb4\xb5\xb6\x1b\x1b\xb7\x08\x8b\x1b\x1b"
  "\x24\x28\x1b\x28\x0d\x1c\x28\x1b\x28\x0d\x1c\x28\x0d\x28\x1b\x28"
  "\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x0d\x1c\x28\x0d\x1c\x23\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x28\x0d\x28\x0d"
  "\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb4\xb5\xb6\xb7\x08"
  "\x89\x1b\x24\x28\x1b\x28\x1b\x28\x0d\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb6\x1b"
  "\xb7\x08\x8a\x0d\x1c\x24\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb4\xb5\x1b\x24\x28\x0d"
  "\x1c\x28\x0d\x1c\x28\x1b\x28\xb2\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x28\x0d\x1c\x28"
  "\x0d\x1c\x28\x0d\x28\x0d\x28\xb2\x28\x0d\x1c\x28\x0d\x28\x0d\x28"
  "\x1b\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x0c\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x0d\x1c\x0d\x1c\x0d\x1b\x1b\x1b\x08\x8a\x1b"
  "\x1b\x08\x89\x0d\x1c\x08\x0d\x1c\xb4\x1b\x1b\x1b\x1b\x08\x8a\x08"
  "\x89\xb5\x0d\x1c\x24\x28\x0d\x1c\x28\x0d\x1c\x28\x1b\x28\x0d\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x08\x0d\x1c\xb4\x0d"
  "\x1b\x1b\x1b\x08\x8b\xb5\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b"
  "\x0d\x0d\x0d\x0d\x0d\x1c\x08\x0d\xb4\x0d\x1c\x1b\x1b\x1b\x1b\x08"
  "\x8a\x1b\x1b\x1b\x1b\x1b\x1b\x08\x8b\x08\x8c\xb5\x28\x1b\x28\x1b"
  "\x28\x0d\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x28\x0d"
  "\x1c\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb4\xb5\xb6\x1b"
  "\x1b\x1b\xb7\x08\x8a\x08\x89\x1b\x1b\x08\x8b\x0d\x1c\x0d\x1c\x24"
  "\x28\x1b\x28\x1b\x28\x1b\x28\x0d\x1c\x28\x0d\x1c\x28\xb2\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x08"
  "\xb4\xb5\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\xb6\x1b\x1b\xb7\x08\x89\x08\x89\x1b\x1b"
  "\x08\x8b\x1b\x0d\x1c\x24\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x0d\x1c\x28\x1b\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\xb4\xb5\xb6\x1b\x1b\xb7\x08\x89\x08\x89\x1b\x1b\x08\x8b\x1b\x1b"
  "\x24\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\xb2\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb4\xb5"
  "\x0d\x1b\x1b\x1b\x0d\x24\x28\x0d\x1c\x28\x1b\x28\x0d\x28\x1b\x28"
  "\x1b\x28\x0d\x28\x1b\x28\x1b\x28\x0d\x28\x1b\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x08\xb4"
  "\xb5\xb6\x1b\x1b\x08\x89\x1b\x1b\x08\x8b\x28\x0d\xba\x28\x1b\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x0d\x24\x28\x0d\x28\x0d\x28\x1b\x28\x0d\x28\x0d\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x08\xb4\x07\x0d\x1c\xb5\xb6\x1b\xb7\x08\x8a"
  "\x28\xb2\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\xb4\xb5\xb6\x1b\xb7\x08\x8a\x1b\x24\x28\x1b\x28\x0d\x28\x0d"
  "\x28\x1b\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x0d\x1b\x06\x07\x85\xc2\x02\x0d"
  "\x0d\x1b\x1b\x0c\x1b\x1b\x1b\x0d\x1c\x08\xb4\xb5\xb6\xb7\x1b\x1b"
  "\x1b\xb7\x08\x8a\x08\x8b\x28\xb2\x28\x1b\x28\x0d\x1c\x28\x1b\x28"
  "\x0d\x1c\x28\x0d\x1c\x28\x0d\x28\x0d\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x07\x08\x0c\xb4\xb5\x28\xb2\x28\x1b\x28\x1b\x28\x0d\x1c"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x08"
  "\xb4\xb5\x0d\xb6\x1b\x1b\xb7\x1b\xb7\x08\x8b\x08\x89\x1b\x1b\x08"
  "\x89\x1b\x1b\x08\x8c\x28\xb2\x28\x1b\x28\x1b\x28\x0d\x1c\x28\x1b"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b"
  "\x0c\x08\x1b\x1b\x1b\x0c\x0c\x1b\x0d\x0c\xb5\xb4\x28\x1b\x28\x1b"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d"
  "\x1c\x1b\x0d\x0d\x0d\x1c\x80\x0c\x0d\x0d\x0d\x1c\xb4\x08\xb5\x1b"
  "\xb6\xb7\x08\x89\x28\x1b\x28\xb2\x28\x1b\x28\x1b\x28\x0d\x28\x1b"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x1b\xb7\x08\x89\xb7\x08\x88\x1b\x08\xb4\x07\x1b\x1b\x08\x89"
  "\x1b\x1b\x08\x8a\x08\x1b\x1b\x08\x8a\xb5\x1b\x1b\x1b\x28\x1b\x28"
  "\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x0d\x1c"
  "\x08\xb4\xb5\xb6\xb7\xb7\x08\x8a\x28\xb2\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1b\x0d\xb4\x08\x1b\x1b"
  "\x1b\x1b\x08\x8a\x1b\x1b\x08\x8a\x1b\xb7\x08\x89\xb5\x0d\x1c\x28"
  "\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xc2\x0d\x08\x0d\x0d\xb4"
  "\xb5\x1b\x1b\x0d\x1c\xb6\x1b\x1b\x1b\xb7\x08\x8a\x08\x89\x1b\x1b"
  "\x08\x8b\x1b\x24\x28\xb2\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x0d"
  "\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\xb6\x08\x88\x28\x1b\x28"
  "\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x1b\x23\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb5\xb6\x1b\x0d\x1c\x1b\x1b"
  "\x08\x8a\x08\x8a\x1b\x24\x28\x1b\x28\x0d\x28\x0d\x1c\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\xb4\xb5\xb6\x1b\x1b\x1b\x1b\x08\x8a\x08\x89\x1b\x1b\x08\x8b\x1b"
  "\x1b\x24\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x0d\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c"
  "\x28\x1b\x28\x0d\x28\x0d\x1c\x28\x1b\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x28"
  "\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x17\x1c\x88\x1b\x1b\x2a\x1b\x2a\x99\x1b\x1b\x99"
  "\x0d\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x99\x1b\x2a\x1b\x2a\x99\x0d\x1b"
  "\x2a\x0d\x1b\x2a\x0d\x1b\x2a\x1b\x0d\x1b\x2a\x1b\x0d\x1c\x1b\x0d"
  "\x1c\x1b\x1b\x1b\x1b\x08\x8b\x0d\x1c\x0d\x1c\x0d\x0c\x1b\x1b\x08"
  "\x89\x1b\x2a\x0d\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x0d\x1b\x2a\x0d"
  "\x1b\x2a\x0d\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x1b\x9a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x9a\x0d\x1b\x2a\x0d\x1b\x2a\x1b\x1b\x2a\x1b"
  "\x1b\x1b\xb7\x08\x8a\x08\x89\x1b\x1b\x08\x8a\x0d\x1c\x1b\x2a\x1b"
  "\x1b\x1b\x1b\xb7\x08\x8a\x08\x89\x1b\x1b\x08\x8b\x0d\x1b\x2a\x1b"
  "\x0d\x1b\x2a\x0d\x1b\x2a\x1b\xb7\x08\x89\x0d\x1b\x2a\x1b\x08\x88"
  "\xb4\x08\xc3\x1b\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x08\x14\x1b\x1b\x88\x1b\x1b\x08\x8a\x0d\x1b\x2a\x1b\x1b\x88"
  "\x1b\x1b\x08\x8a\xb5\x1b\x1b\x1b\x9a\x1b\x2a\x1b\x2a\x1b\x2a\x9a"
  "\x1b\x0d\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x99\x1b\x2a\x1b\x2a\x99\x1b"
  "\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x99\x1b\x2a"
  "\x1b\x2a\x99\x0d\x1b\x2a\x0d\x1b\x1b\x2a\x0d\x0d\x1c\x0d\xb1\x0d"
  "\x0d\x1c\x0d\x1c\x1b\x0d\x1c\x0d\x1c\x9a\x1b\x2a\x1b\x2a\xb3\x2a"
  "\x9a\x28\x0d\x26\x1b\x1b\xb1\x1b\x1b\x1b\x1b\x1b\x24\x28\x1b\x28"
  "\x0d\x28\x0d\x28\x0d\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28"
  "\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x0d\x28\x1b\x28\x0d\x28\x1b\x28"
  "\x0d\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x02\x7c\x2f\x61\x66\x73"
  "\x2f\x63\x73\x61\x69\x6c\x2e\x6d\x69\x74\x2e\x65\x64\x75\x2f\x67"
  "\x72\x6f\x75\x70\x2f\x6d\x61\x63\x2f\x70\x72\x6f\x6a\x65\x63\x74"
  "\x73\x2f\x73\x63\x68\x65\x6d\x65\x2f\x76\x37\x2f\x64\x69\x73\x74"
  "\x2f\x73\x6e\x61\x70\x73\x68\x6f\x74\x2e\x70\x6b\x67\x2f\x32\x30"
  "\x30\x37\x30\x39\x30\x39\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d"
  "\x65\x2d\x63\x2d\x32\x30\x30\x37\x30\x39\x30\x39\x2f\x73\x72\x63"
  "\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f\x6d\x69\x74\x2d\x73\x79\x6e"
  "\x74\x61\x78\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69"
  "\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x04\x1f\x65"
  "\x72\x2d\x6d\x61\x63\x72\x6f\x2d\x74\x72\x61\x6e\x73\x66\x6f\x72"
  "\x6d\x65\x72\x2d\x3e\x65\x78\x70\x61\x6e\x64\x65\x72\x05\x1d\x73"
  "\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69\x72\x6f\x6e"
  "\x6d\x65\x6e\x74\x2f\x64\x65\x66\x69\x6e\x65\x03\x9c\x01\x06\x81"
  "\x87\x02\x9b\x01\x04\x85\x08\x05\x0d\x02\x04\x63\x61\x72\x04\x63"
  "\x64\x72\x08\x6b\x65\x79\x77\x6f\x72\x64\x0b\x65\x78\x70\x72\x65"
  "\x73\x73\x69\x6f\x6e\x0c\x73\x65\x6c\x65\x63\x74\x2d\x63\x61\x64"
  "\x72\x09\x02\x05\x0d\x73\x79\x6e\x74\x61\x78\x2d\x63\x68\x65\x63"
  "\x6b\x0a\x06\x17\x63\x6c\x61\x73\x73\x69\x66\x79\x2f\x73\x75\x62"
  "\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x0b\x07\x1f\x65\x78\x70"
  "\x72\x65\x73\x73\x69\x6f\x6e\x2d\x3e\x6b\x65\x79\x77\x6f\x72\x64"
  "\x2d\x76\x61\x6c\x75\x65\x2d\x69\x74\x65\x6d\x0c\x04\xa3\x01\x10"
  "\x81\x8b\x02\xa2\x01\x0e\x81\x93\x02\xa1\x01\x0c\x81\x93\x02\xa0"
  "\x01\x0a\x81\x8d\x02\x9f\x01\x08\x81\x8b\x02\x9e\x01\x06\x81\x8b"
  "\x02\x9d\x01\x04\x84\x06\x0f\x1e\x0d\x02\x04\x15\x6d\x61\x6b\x65"
  "\x2d\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x2d\x69\x74\x65\x6d"
  "\x0e\x03\x23\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76"
  "\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x2d\x3e\x65\x6e\x76\x69\x72\x6f"
  "\x6e\x6d\x65\x6e\x74\x04\x18\x6f\x75\x74\x70\x75\x74\x2f\x61\x63"
  "\x63\x65\x73\x73\x2d\x72\x65\x66\x65\x72\x65\x6e\x63\x65\x0f\x04"
  "\x18\x6d\x61\x6b\x65\x2d\x6b\x65\x79\x77\x6f\x72\x64\x2d\x76\x61"
  "\x6c\x75\x65\x2d\x69\x74\x65\x6d\x03\x18\x63\x6f\x6d\x70\x69\x6c"
  "\x65\x2d\x69\x74\x65\x6d\x2f\x65\x78\x70\x72\x65\x73\x73\x69\x6f"
  "\x6e\x10\x02\x17\x6f\x75\x74\x70\x75\x74\x2f\x74\x68\x65\x2d\x65"
  "\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x11\x04\x11\x74\x72\x61"
  "\x6e\x73\x66\x6f\x72\x6d\x65\x72\x2d\x65\x76\x61\x6c\x04\x13\x6f"
  "\x75\x74\x70\x75\x74\x2f\x63\x6f\x6d\x62\x69\x6e\x61\x74\x69\x6f"
  "\x6e\x09\xad\x01\x16\x81\x87\x02\xac\x01\x14\x81\x85\x02\xab\x01"
  "\x12\x81\x95\x02\xaa\x01\x10\x81\x83\x02\xa9\x01\x0e\x81\x93\x02"
  "\xa8\x01\x0c\x81\x91\x02\xa7\x01\x0a\x81\x8d\x02\xa6\x01\x08\x81"
  "\x83\x02\xa5\x01\x06\x81\x8b\x02\xa4\x01\x04\x87\x0c\x15\x2a\x12"
  "\x02\x08\x6d\x69\x74\x2d\x62\x76\x6c\x13\x02\x2b\x14\x05\x66\x6f"
  "\x72\x6d\x15\x0c\x73\x65\x6c\x65\x63\x74\x2d\x63\x64\x64\x72\x16"
  "\x02\x05\x0a\x07\x0f\x63\x6f\x6d\x70\x69\x6c\x65\x2f\x6c\x61\x6d"
  "\x62\x64\x61\x17\x04\x0e\x6f\x75\x74\x70\x75\x74\x2f\x6c\x61\x6d"
  "\x62\x64\x61\x04\xb6\x01\x14\x84\x06\xb5\x01\x12\x81\x87\x02\xb4"
  "\x01\x10\x81\x91\x02\xb3\x01\x0e\x81\x91\x02\xb2\x01\x0c\x81\x8f"
  "\x02\xb1\x01\x0a\x81\x8f\x02\xb0\x01\x08\x81\x8d\x02\xaf\x01\x06"
  "\x81\x87\x02\xae\x01\x04\x85\x08\x13\x22\x18\x02\x0b\x69\x64\x65"
  "\x6e\x74\x69\x66\x69\x65\x72\x19\x13\x14\x15\x16\x02\x05\x0a\x07"
  "\x17\x03\x13\x69\x64\x65\x6e\x74\x69\x66\x69\x65\x72\x2d\x3e\x73"
  "\x79\x6d\x62\x6f\x6c\x05\x14\x6f\x75\x74\x70\x75\x74\x2f\x6e\x61"
  "\x6d\x65\x64\x2d\x6c\x61\x6d\x62\x64\x61\x05\xc4\x01\x1e\x81\x87"
  "\x02\xc3\x01\x1c\x81\x89\x02\xc2\x01\x1a\x81\x89\x02\xc1\x01\x18"
  "\x81\x89\x02\xc0\x01\x16\x81\x87\x02\xbf\x01\x14\x81\x87\x02\xbe"
  "\x01\x12\x81\x91\x02\xbd\x01\x10\x81\x91\x02\xbc\x01\x0e\x81\x91"
  "\x02\xbb\x01\x0c\x81\x8f\x02\xba\x01\x0a\x81\x8f\x02\xb9\x01\x08"
  "\x81\x8d\x02\xb8\x01\x06\x81\x87\x02\xb7\x01\x04\x85\x08\x1d\x2e"
  "\x1a\x02\x03\x24\x6d\x61\x6b\x65\x2d\x69\x6e\x74\x65\x72\x6e\x61"
  "\x6c\x2d\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69"
  "\x72\x6f\x6e\x6d\x65\x6e\x74\x1b\x04\x14\x6d\x61\x70\x2d\x6d\x69"
  "\x74\x2d\x6c\x61\x6d\x62\x64\x61\x2d\x6c\x69\x73\x74\x1c\x07\x0e"
  "\x63\x6c\x61\x73\x73\x69\x66\x79\x2f\x62\x6f\x64\x79\x1d\x04\x0f"
  "\x62\x69\x6e\x64\x2d\x76\x61\x72\x69\x61\x62\x6c\x65\x21\x1e\x03"
  "\x12\x63\x6f\x6d\x70\x69\x6c\x65\x2d\x62\x6f\x64\x79\x2d\x69\x74"
  "\x65\x6d\x1f\x06\xcb\x01\x10\x81\x85\x02\xca\x01\x0e\x81\x91\x02"
  "\xc9\x01\x0c\x81\x8f\x02\xc8\x01\x0a\x81\x85\x02\xc7\x01\x08\x81"
  "\x8d\x02\xc6\x01\x06\x81\x8b\x02\xc5\x01\x04\x87\x0c\x0f\x1d\x20"
  "\x02\x08\x14\x6c\x61\x6d\x62\x64\x61\x2d\x6f\x70\x74\x69\x6f\x6e"
  "\x61\x6c\x2d\x74\x61\x67\x10\x6c\x61\x6d\x62\x64\x61\x2d\x72\x65"
  "\x73\x74\x2d\x74\x61\x67\x03\x03\x0c\x69\x64\x65\x6e\x74\x69\x66"
  "\x69\x65\x72\x3f\x21\x02\xd7\x01\x1a\xfd\xff\x03\xd6\x01\x18\xfd"
  "\xff\x03\xd5\x01\x16\xfd\xff\x03\xd4\x01\x14\xfd\xff\x03\xd3\x01"
  "\x12\xfd\xff\x03\xd2\x01\x10\xfd\xff\x03\xd1\x01\x0e\xfd\xff\x03"
  "\xd0\x01\x0c\xfd\xff\x03\xcf\x01\x0a\xfd\xff\x03\xce\x01\x08\xfd"
  "\xff\x03\xcd\x01\x06\xff\xff\x03\xcc\x01\x04\x84\x06\x19\x25\x22"
  "\x02\x09\x02\x2a\x23\x15\x0b\x73\x65\x6c\x65\x63\x74\x2d\x63\x64"
  "\x72\x24\x02\x05\x0a\x07\x12\x63\x6c\x61\x73\x73\x69\x66\x79\x2f"
  "\x73\x75\x62\x66\x6f\x72\x6d\x73\x04\x0f\x6d\x61\x6b\x65\x2d\x62"
  "\x6f\x64\x79\x2d\x69\x74\x65\x6d\x04\xdc\x01\x0c\x81\x89\x02\xdb"
  "\x01\x0a\x81\x93\x02\xda\x01\x08\x81\x8b\x02\xd9\x01\x06\x81\x89"
  "\x02\xd8\x01\x04\x86\x0a\x0b\x19\x25\x02\x0a\x02\x3f\x26\x09\x0d"
  "\x73\x65\x6c\x65\x63\x74\x2d\x63\x61\x64\x64\x72\x27\x0e\x73\x65"
  "\x6c\x65\x63\x74\x2d\x63\x61\x64\x64\x64\x72\x04\x05\x0a\x06\x16"
  "\x63\x6f\x6d\x70\x69\x6c\x65\x2f\x73\x75\x62\x65\x78\x70\x72\x65"
  "\x73\x73\x69\x6f\x6e\x28\x02\x12\x6f\x75\x74\x70\x75\x74\x2f\x75"
  "\x6e\x73\x70\x65\x63\x69\x66\x69\x63\x29\x05\x13\x6f\x75\x74\x70"
  "\x75\x74\x2f\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x61\x6c\x05\xf0"
  "\x01\x2a\x81\x8b\x02\xef\x01\x28\x81\x93\x02\xee\x01\x26\x81\x93"
  "\x02\xed\x01\x24\x81\x93\x02\xec\x01\x22\x81\x93\x02\xeb\x01\x20"
  "\x81\x8d\x02\xea\x01\x1e\x81\x8d\x02\xe9\x01\x1c\x81\x8d\x02\xe8"
  "\x01\x1a\x81\x8d\x02\xe7\x01\x18\x81\x89\x02\xe6\x01\x16\x81\x91"
  "\x02\xe5\x01\x14\x81\x91\x02\xe4\x01\x12\x81\x91\x02\xe3\x01\x10"
  "\x81\x8b\x02\xe2\x01\x0e\x81\x87\x02\xe1\x01\x0c\x81\x8f\x02\xe0"
  "\x01\x0a\x81\x8f\x02\xdf\x01\x08\x81\x89\x02\xde\x01\x06\x81\x87"
  "\x02\xdd\x01\x04\x85\x08\x29\x3c\x2a\x02\x0b\x06\x64\x61\x74\x75"
  "\x6d\x2b\x05\x0a\x03\x19\x73\x74\x72\x69\x70\x2d\x73\x79\x6e\x74"
  "\x61\x63\x74\x69\x63\x2d\x63\x6c\x6f\x73\x75\x72\x65\x73\x03\x10"
  "\x6f\x75\x74\x70\x75\x74\x2f\x63\x6f\x6e\x73\x74\x61\x6e\x74\x04"
  "\xf5\x01\x0c\x81\x87\x02\xf4\x01\x0a\x81\x89\x02\xf3\x01\x08\x81"
  "\x89\x02\xf2\x01\x06\x81\x87\x02\xf1\x01\x04\x85\x08\x0b\x18\x2c"
  "\x02\x0c\x15\x26\x09\x27\x03\x05\x0a\x06\x15\x63\x6c\x61\x73\x73"
  "\x69\x66\x79\x2f\x73\x75\x62\x6c\x6f\x63\x61\x74\x69\x6f\x6e\x2d"
  "\x06\x28\x02\x12\x6f\x75\x74\x70\x75\x74\x2f\x75\x6e\x61\x73\x73"
  "\x69\x67\x6e\x65\x64\x2e\x04\x12\x6f\x75\x74\x70\x75\x74\x2f\x61"
  "\x73\x73\x69\x67\x6e\x6d\x65\x6e\x74\x03\x10\x05\x19\x6f\x75\x74"
  "\x70\x75\x74\x2f\x61\x63\x63\x65\x73\x73\x2d\x61\x73\x73\x69\x67"
  "\x6e\x6d\x65\x6e\x74\x08\x84\x02\x20\x81\x89\x02\x83\x02\x1e\x81"
  "\x87\x02\x82\x02\x1c\x81\x89\x02\x81\x02\x1a\x81\x8f\x02\x80\x02"
  "\x18\x81\x8f\x02\xff\x01\x16\x81\x8f\x02\xfe\x01\x14\x81\x89\x02"
  "\xfd\x01\x12\x81\x89\x02\xfc\x01\x10\x81\x89\x02\xfb\x01\x0e\x81"
  "\x87\x02\xfa\x01\x0c\x81\x91\x02\xf9\x01\x0a\x81\x91\x02\xf8\x01"
  "\x08\x81\x8b\x02\xf7\x01\x06\x81\x87\x02\xf6\x01\x04\x85\x08\x1f"
  "\x37\x2f\x02\x0d\x06\x17\x68\x69\x73\x74\x6f\x72\x79\x2f\x61\x64"
  "\x64\x2d\x73\x75\x62\x70\x72\x6f\x62\x6c\x65\x6d\x30\x05\x12\x63"
  "\x6c\x61\x73\x73\x69\x66\x79\x2f\x6c\x6f\x63\x61\x74\x69\x6f\x6e"
  "\x31\x03\x86\x02\x06\x81\x89\x02\x85\x02\x04\x86\x0a\x05\x0d\x32"
  "\x02\x0e\x23\x56\x61\x72\x69\x61\x62\x6c\x65\x20\x72\x65\x71\x75"
  "\x69\x72\x65\x64\x20\x69\x6e\x20\x74\x68\x69\x73\x20\x63\x6f\x6e"
  "\x74\x65\x78\x74\x3a\x05\x14\x63\x6c\x61\x73\x73\x69\x66\x79\x2f"
  "\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x03\x0f\x76\x61\x72\x69"
  "\x61\x62\x6c\x65\x2d\x69\x74\x65\x6d\x3f\x33\x03\x0d\x61\x63\x63"
  "\x65\x73\x73\x2d\x69\x74\x65\x6d\x3f\x34\x03\x13\x76\x61\x72\x69"
  "\x61\x62\x6c\x65\x2d\x69\x74\x65\x6d\x2f\x6e\x61\x6d\x65\x35\x05"
  "\x0d\x73\x79\x6e\x74\x61\x78\x2d\x65\x72\x72\x6f\x72\x36\x03\x11"
  "\x61\x63\x63\x65\x73\x73\x2d\x69\x74\x65\x6d\x2f\x6e\x61\x6d\x65"
  "\x37\x03\x18\x61\x63\x63\x65\x73\x73\x2d\x69\x74\x65\x6d\x2f\x65"
  "\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x38\x08\x8f\x02\x14\x81"
  "\x85\x02\x8e\x02\x12\x81\x89\x02\x8d\x02\x10\x81\x89\x02\x8c\x02"
  "\x0e\x81\x85\x02\x8b\x02\x0c\x81\x89\x02\x8a\x02\x0a\x81\x89\x02"
  "\x89\x02\x08\x81\x89\x02\x88\x02\x06\x81\x87\x02\x87\x02\x04\x85"
  "\x08\x13\x26\x39\x02\x0f\x09\x02\x05\x0a\x06\x28\x03\x0d\x6f\x75"
  "\x74\x70\x75\x74\x2f\x64\x65\x6c\x61\x79\x04\x95\x02\x0e\x81\x87"
  "\x02\x94\x02\x0c\x81\x8f\x02\x93\x02\x0a\x81\x8f\x02\x92\x02\x08"
  "\x81\x89\x02\x91\x02\x06\x81\x87\x02\x90\x02\x04\x85\x08\x0d\x1c"
  "\x3a\x02\x10\x19\x19\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x62"
  "\x69\x6e\x64\x69\x6e\x67\x2d\x74\x68\x65\x6f\x72\x79\x3b\x02\x05"
  "\x0a\x07\x10\x63\x6c\x61\x73\x73\x69\x66\x79\x2f\x64\x65\x66\x69"
  "\x6e\x65\x3c\x03\x98\x02\x08\x81\x8b\x02\x97\x02\x06\x81\x89\x02"
  "\x96\x02\x04\x86\x0a\x07\x12\x3d\x02\x11\x27\x02\x03\x21\x73\x79"
  "\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d"
  "\x65\x6e\x74\x2f\x74\x6f\x70\x2d\x6c\x65\x76\x65\x6c\x3f\x3e\x03"
  "\x18\x6d\x61\x6b\x65\x2d\x72\x65\x73\x65\x72\x76\x65\x64\x2d\x6e"
  "\x61\x6d\x65\x2d\x69\x74\x65\x6d\x3f\x06\x0b\x05\x05\xa5\x02\x1c"
  "\x81\x8f\x02\xa4\x02\x1a\x81\x8f\x02\xa3\x02\x18\x81\x8d\x02\xa2"
  "\x02\x16\x81\x8d\x02\xa1\x02\x14\x81\x8d\x02\xa0\x02\x12\x81\x8b"
  "\x02\x9f\x02\x10\x81\x93\x02\x9e\x02\x0e\x81\x93\x02\x9d\x02\x0c"
  "\x81\x93\x02\x9c\x02\x0a\x81\x8d\x02\x9b\x02\x08\x81\x8b\x02\x9a"
  "\x02\x06\x81\x8b\x02\x99\x02\x04\x87\x0c\x1b\x2b\x40\x02\x12\x2b"
  "\x53\x79\x6e\x74\x61\x63\x74\x69\x63\x20\x62\x69\x6e\x64\x69\x6e"
  "\x67\x20\x76\x61\x6c\x75\x65\x20\x6d\x75\x73\x74\x20\x62\x65\x20"
  "\x61\x20\x6b\x65\x79\x77\x6f\x72\x64\x3a\x03\x0e\x6b\x65\x79\x77"
  "\x6f\x72\x64\x2d\x69\x74\x65\x6d\x3f\x41\x03\x0d\x69\x74\x65\x6d"
  "\x2f\x68\x69\x73\x74\x6f\x72\x79\x42\x04\x11\x69\x74\x65\x6d\x2f"
  "\x6e\x65\x77\x2d\x68\x69\x73\x74\x6f\x72\x79\x03\x14\x6b\x65\x79"
  "\x77\x6f\x72\x64\x2d\x76\x61\x6c\x75\x65\x2d\x69\x74\x65\x6d\x3f"
  "\x05\x03\x16\x68\x69\x73\x74\x6f\x72\x79\x2f\x6f\x72\x69\x67\x69"
  "\x6e\x61\x6c\x2d\x66\x6f\x72\x6d\x43\x03\x1c\x72\x65\x6e\x61\x6d"
  "\x65\x2d\x74\x6f\x70\x2d\x6c\x65\x76\x65\x6c\x2d\x69\x64\x65\x6e"
  "\x74\x69\x66\x69\x65\x72\x03\x17\x6d\x61\x6b\x65\x2d\x6e\x75\x6c"
  "\x6c\x2d\x62\x69\x6e\x64\x69\x6e\x67\x2d\x69\x74\x65\x6d\x03\x3e"
  "\x05\x36\x05\x12\x6d\x61\x6b\x65\x2d\x62\x69\x6e\x64\x69\x6e\x67"
  "\x2d\x69\x74\x65\x6d\x44\x0c\xaf\x02\x16\x81\x8b\x02\xae\x02\x14"
  "\x81\x87\x02\xad\x02\x12\x81\x89\x02\xac\x02\x10\x81\x89\x02\xab"
  "\x02\x0e\x81\x8b\x02\xaa\x02\x0c\x81\x8b\x02\xa9\x02\x0a\x81\x89"
  "\x02\xa8\x02\x08\x81\x89\x02\xa7\x02\x06\x81\x89\x02\xa6\x02\x04"
  "\x86\x0a\x15\x30\x45\x02\x13\x24\x42\x69\x6e\x64\x69\x6e\x67\x20"
  "\x76\x61\x6c\x75\x65\x20\x6d\x61\x79\x20\x6e\x6f\x74\x20\x62\x65"
  "\x20\x61\x20\x6b\x65\x79\x77\x6f\x72\x64\x3a\x03\x41\x04\x1e\x03"
  "\x42\x03\x43\x05\x44\x05\x36\x07\xb5\x02\x0e\x81\x87\x02\xb4\x02"
  "\x0c\x81\x8b\x02\xb3\x02\x0a\x81\x8b\x02\xb2\x02\x08\x81\x89\x02"
  "\xb1\x02\x06\x81\x89\x02\xb0\x02\x04\x86\x0a\x0d\x1e\x44\x02\x14"
  "\x03\x6f\x72\x43\x04\x61\x6e\x64\x42\x04\x6e\x6f\x74\x19\x23\x2b"
  "\x19\x2b\x05\x65\x6c\x73\x65\x41\x06\x62\x65\x67\x69\x6e\x1e\x14"
  "\x2b\x23\x15\x18\x73\x75\x70\x70\x6f\x72\x74\x65\x64\x2d\x73\x72"
  "\x66\x69\x2d\x66\x65\x61\x74\x75\x72\x65\x73\x46\x02\x04\x0e\x73"
  "\x79\x6e\x74\x61\x78\x2d\x6d\x61\x74\x63\x68\x3f\x47\x03\x12\x69"
  "\x6c\x6c\x2d\x66\x6f\x72\x6d\x65\x64\x2d\x73\x79\x6e\x74\x61\x78"
  "\x48\x03\x21\x04\x0e\x74\x68\x65\x72\x65\x2d\x65\x78\x69\x73\x74"
  "\x73\x3f\x05\xe6\x02\x64\x81\x85\x02\xe5\x02\x62\x81\x83\x02\xe4"
  "\x02\x60\x81\x85\x02\xe3\x02\x5e\x81\x85\x02\xe2\x02\x5c\x81\x85"
  "\x02\xe1\x02\x5a\x81\x83\x02\xe0\x02\x58\x81\x8d\x02\xdf\x02\x56"
  "\x81\x85\x02\xde\x02\x54\x81\x85\x02\xdd\x02\x52\x81\x8b\x02\xdc"
  "\x02\x50\x81\x89\x02\xdb\x02\x4e\x81\x89\x02\xda\x02\x4c\x81\x89"
  "\x02\xd9\x02\x4a\x81\x8d\x02\xd8\x02\x48\x81\x8b\x02\xd7\x02\x46"
  "\x81\x89\x02\xd6\x02\x44\x81\x89\x02\xd5\x02\x42\x81\x89\x02\xd4"
  "\x02\x40\x81\x8d\x02\xd3\x02\x3e\x81\x89\x02\xd2\x02\x3c\x81\x8b"
  "\x02\xd1\x02\x3a\x81\x89\x02\xd0\x02\x38\x81\x89\x02\xcf\x02\x36"
  "\x81\x89\x02\xce\x02\x34\x81\x89\x02\xcd\x02\x32\x81\x85\x02\xcc"
  "\x02\x30\x81\x89\x02\xcb\x02\x2e\x81\x8d\x02\xca\x02\x2c\x81\x89"
  "\x02\xc9\x02\x2a\x81\x89\x02\xc8\x02\x28\x81\x85\x02\xc7\x02\x26"
  "\x81\x83\x02\xc6\x02\x24\x81\x83\x02\xc5\x02\x22\x81\x8d\x02\xc4"
  "\x02\x20\x81\x85\x02\xc3\x02\x1e\x81\x89\x02\xc2\x02\x1c\x81\x89"
  "\x02\xc1\x02\x1a\x81\x89\x02\xc0\x02\x18\x81\x83\x02\xbf\x02\x16"
  "\x81\x83\x02\xbe\x02\x14\x81\x83\x02\xbd\x02\x12\x81\x87\x02\xbc"
  "\x02\x10\x81\x87\x02\xbb\x02\x0e\x81\x85\x02\xba\x02\x0c\x81\x89"
  "\x02\xb9\x02\x0a\x81\x89\x02\xb8\x02\x08\x81\x83\x02\xb7\x02\x06"
  "\x81\x8b\x02\xb6\x02\x04\x85\x08\x63\x7c\x49\x02\x15\x11\x63\x61"
  "\x6c\x6c\x2d\x77\x69\x74\x68\x2d\x76\x61\x6c\x75\x65\x73\x07\x6c"
  "\x61\x6d\x62\x64\x61\x4a\x09\x72\x34\x72\x73\x2d\x62\x76\x6c\x15"
  "\x14\x15\x04\x47\x03\x48\x03\xf4\x02\x1e\x81\x89\x02\xf3\x02\x1c"
  "\x81\x8b\x02\xf2\x02\x1a\x81\x89\x02\xf1\x02\x18\x81\x89\x02\xf0"
  "\x02\x16\x81\x89\x02\xef\x02\x14\x81\x89\x02\xee\x02\x12\x81\x89"
  "\x02\xed\x02\x10\x81\x89\x02\xec\x02\x0e\x81\x87\x02\xeb\x02\x0c"
  "\x81\x87\x02\xea\x02\x0a\x81\x87\x02\xe9\x02\x08\x81\x87\x02\xe8"
  "\x02\x06\x81\x89\x02\xe7\x02\x04\x85\x08\x1d\x2b\x4b\x02\x16\x1e"
  "\x11\x6d\x61\x6b\x65\x2d\x72\x65\x63\x6f\x72\x64\x2d\x74\x79\x70"
  "\x65\x13\x72\x65\x63\x6f\x72\x64\x2d\x63\x6f\x6e\x73\x74\x72\x75"
  "\x63\x74\x6f\x72\x10\x72\x65\x63\x6f\x72\x64\x2d\x61\x63\x63\x65"
  "\x73\x73\x6f\x72\x10\x72\x65\x63\x6f\x72\x64\x2d\x6d\x6f\x64\x69"
  "\x66\x69\x65\x72\x06\x71\x75\x6f\x74\x65\x4c\x11\x72\x65\x63\x6f"
  "\x72\x64\x2d\x70\x72\x65\x64\x69\x63\x61\x74\x65\x07\x64\x65\x66"
  "\x69\x6e\x65\x4d\x19\x19\x23\x19\x19\x23\x19\x19\x26\x19\x04\x47"
  "\x03\x48\x04\x0b\x61\x70\x70\x65\x6e\x64\x2d\x6d\x61\x70\x04\x04"
  "\x6d\x61\x70\x4e\x05\x9b\x03\x50\x81\x95\x02\x9a\x03\x4e\x81\x97"
  "\x02\x99\x03\x4c\x81\x95\x02\x98\x03\x4a\x81\x95\x02\x97\x03\x48"
  "\x81\x8b\x02\x96\x03\x46\x81\x8b\x02\x95\x03\x44\x81\x89\x02\x94"
  "\x03\x42\x81\x95\x02\x93\x03\x40\x81\x87\x02\x92\x03\x3e\x81\x87"
  "\x02\x91\x03\x3c\x81\x85\x02\x90\x03\x3a\x81\x85\x02\x8f\x03\x38"
  "\x81\x89\x02\x8e\x03\x36\x81\x89\x02\x8d\x03\x34\x81\x89\x02\x8c"
  "\x03\x32\x81\x87\x02\x8b\x03\x30\x81\x93\x02\x8a\x03\x2e\x81\x91"
  "\x02\x89\x03\x2c\x81\x91\x02\x88\x03\x2a\x81\x8f\x02\x87\x03\x28"
  "\x81\x8f\x02\x86\x03\x26\x81\x8f\x02\x85\x03\x24\x81\x8f\x02\x84"
  "\x03\x22\x81\x8d\x02\x83\x03\x20\x81\x8d\x02\x82\x03\x1e\x81\x8d"
  "\x02\x81\x03\x1c\x81\x8d\x02\x80\x03\x1a\x81\x8b\x02\xff\x02\x18"
  "\x81\x8b\x02\xfe\x02\x16\x81\x8b\x02\xfd\x02\x14\x81\x8b\x02\xfc"
  "\x02\x12\x81\x89\x02\xfb\x02\x10\x81\x89\x02\xfa\x02\x0e\x81\x89"
  "\x02\xf9\x02\x0c\x81\x89\x02\xf8\x02\x0a\x81\x87\x02\xf7\x02\x08"
  "\x81\x87\x02\xf6\x02\x06\x81\x89\x02\xf5\x02\x04\x85\x08\x4f\x67"
  "\x4f\x02\x17\x04\x6c\x65\x74\x50\x05\x0c\x65\x78\x70\x61\x6e\x64"
  "\x2f\x6c\x65\x74\x2a\x51\x02\x9c\x03\x04\x85\x08\x03\x0a\x52\x02"
  "\x18\x23\x19\x26\x14\x15\x18\x76\x61\x72\x69\x61\x62\x6c\x65\x2d"
  "\x62\x69\x6e\x64\x69\x6e\x67\x2d\x74\x68\x65\x6f\x72\x79\x53\x0e"
  "\x6f\x75\x74\x70\x75\x74\x2f\x6c\x65\x74\x72\x65\x63\x54\x03\x05"
  "\x0a\x03\x1b\x03\x3f\x09\x12\x63\x6c\x61\x73\x73\x69\x66\x79\x2f"
  "\x6c\x65\x74\x2d\x6c\x69\x6b\x65\x55\x04\x09\x66\x6f\x72\x2d\x65"
  "\x61\x63\x68\x56\x05\x07\xa8\x03\x1a\x81\x89\x02\xa7\x03\x18\x81"
  "\x85\x02\xa6\x03\x16\x81\x91\x02\xa5\x03\x14\x81\x8f\x02\xa4\x03"
  "\x12\x81\x8f\x02\xa3\x03\x10\x81\x8d\x02\xa2\x03\x0e\x81\x8f\x02"
  "\xa1\x03\x0c\x81\x8f\x02\xa0\x03\x0a\x81\x8b\x02\x9f\x03\x08\x81"
  "\x89\x02\x9e\x03\x06\x81\x89\x02\x9d\x03\x04\x86\x0a\x19\x2f\x57"
  "\x02\x19\x04\x4e\x02\x16\x75\x6e\x61\x73\x73\x69\x67\x6e\x65\x64"
  "\x2d\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x58\x03\xb3\x03\x18"
  "\x81\x85\x02\xb2\x03\x16\x81\x83\x02\xb1\x03\x14\x81\x83\x02\xb0"
  "\x03\x12\x83\x04\xaf\x03\x10\x81\x85\x02\xae\x03\x0e\x81\x85\x02"
  "\xad\x03\x0c\x81\x87\x02\xac\x03\x0a\x81\x87\x02\xab\x03\x08\x81"
  "\x83\x02\xaa\x03\x06\x81\x83\x02\xa9\x03\x04\x83\x04\x17\x22\x59"
  "\x02\x1a\x23\x19\x14\x15\x3b\x0b\x6f\x75\x74\x70\x75\x74\x2f\x6c"
  "\x65\x74\x5a\x03\x05\x0a\x03\x1b\x09\x55\x04\xb9\x03\x0e\x81\x8f"
  "\x02\xb8\x03\x0c\x81\x8f\x02\xb7\x03\x0a\x81\x8b\x02\xb6\x03\x08"
  "\x81\x89\x02\xb5\x03\x06\x81\x89\x02\xb4\x03\x04\x86\x0a\x0d\x1b"
  "\x5b\x02\x1b\x0b\x6c\x65\x74\x2d\x73\x79\x6e\x74\x61\x78\x5c\x05"
  "\x51\x02\xba\x03\x04\x85\x08\x03\x0a\x5d\x02\x1c\x23\x19\x14\x15"
  "\x3b\x54\x03\x05\x0a\x03\x1b\x03\x3f\x09\x55\x04\x56\x05\x07\xc6"
  "\x03\x1a\x81\x89\x02\xc5\x03\x18\x81\x85\x02\xc4\x03\x16\x81\x91"
  "\x02\xc3\x03\x14\x81\x8f\x02\xc2\x03\x12\x81\x8f\x02\xc1\x03\x10"
  "\x81\x8d\x02\xc0\x03\x0e\x81\x8f\x02\xbf\x03\x0c\x81\x8f\x02\xbe"
  "\x03\x0a\x81\x8b\x02\xbd\x03\x08\x81\x89\x02\xbc\x03\x06\x81\x89"
  "\x02\xbb\x03\x04\x86\x0a\x19\x2f\x56\x02\x1d\x13\x6e\x75\x6c\x6c"
  "\x2d\x62\x69\x6e\x64\x69\x6e\x67\x2d\x69\x74\x65\x6d\x3f\x09\x16"
  "\x3b\x12\x62\x69\x6e\x64\x69\x6e\x67\x2d\x69\x74\x65\x6d\x2f\x6e"
  "\x61\x6d\x65\x06\x05\x0b\x73\x65\x6c\x65\x63\x74\x2d\x6d\x61\x70"
  "\x54\x07\x1d\x04\x17\x64\x65\x6c\x65\x74\x65\x2d\x6d\x61\x74\x63"
  "\x68\x69\x6e\x67\x2d\x69\x74\x65\x6d\x73\x21\x05\x4e\x04\x4e\x03"
  "\x12\x73\x65\x6c\x65\x63\x74\x6f\x72\x2f\x61\x64\x64\x2d\x63\x61"
  "\x64\x72\x04\x0e\x06\x0b\x03\x13\x62\x69\x6e\x64\x69\x6e\x67\x2d"
  "\x69\x74\x65\x6d\x2f\x76\x61\x6c\x75\x65\x03\x1f\x03\x10\x0c\xe2"
  "\x03\x3a\x81\x89\x02\xe1\x03\x38\x81\x83\x02\xe0\x03\x36\x81\x85"
  "\x02\xdf\x03\x34\x83\x04\xde\x03\x32\x81\x89\x02\xdd\x03\x30\x81"
  "\x83\x02\xdc\x03\x2e\x81\x83\x02\xdb\x03\x2c\x81\x89\x02\xda\x03"
  "\x2a\x81\x8b\x02\xd9\x03\x28\x81\x87\x02\xd8\x03\x26\x81\x93\x02"
  "\xd7\x03\x24\x81\x91\x02\xd6\x03\x22\x81\x87\x02\xd5\x03\x20\x81"
  "\x87\x02\xd4\x03\x1e\x81\x87\x02\xd3\x03\x1c\x81\x97\x02\xd2\x03"
  "\x1a\x81\x97\x02\xd1\x03\x18\x81\x95\x02\xd0\x03\x16\x81\x93\x02"
  "\xcf\x03\x14\x81\x9b\x02\xce\x03\x12\x81\x9b\x02\xcd\x03\x10\x81"
  "\x93\x02\xcc\x03\x0e\x81\x8f\x02\xcb\x03\x0c\x81\x99\x02\xca\x03"
  "\x0a\x81\x99\x02\xc9\x03\x08\x81\x97\x02\xc8\x03\x06\x81\x91\x02"
  "\xc7\x03\x04\x89\x10\x39\x5b\x3f\x02\x1e\x23\x2b\x14\x15\x03\x1a"
  "\x63\x61\x70\x74\x75\x72\x65\x2d\x65\x78\x70\x61\x6e\x73\x69\x6f"
  "\x6e\x2d\x68\x69\x73\x74\x6f\x72\x79\x05\x0a\x03\xef\x03\x1c\xfd"
  "\xff\x03\xee\x03\x1a\xfd\xff\x03\xed\x03\x18\xfd\xff\x03\xec\x03"
  "\x16\xfd\xff\x03\xeb\x03\x14\xff\xff\x03\xea\x03\x12\x81\x87\x02"
  "\xe9\x03\x10\x81\x87\x02\xe8\x03\x0e\x81\x87\x02\xe7\x03\x0c\x81"
  "\x85\x02\xe6\x03\x0a\x81\x85\x02\xe5\x03\x08\x81\x85\x02\xe4\x03"
  "\x06\x81\x85\x02\xe3\x03\x04\x85\x08\x1b\x27\x5e\x02\x1f\x16\x64"
  "\x65\x63\x6c\x61\x72\x61\x74\x69\x6f\x6e\x2d\x69\x74\x65\x6d\x2f"
  "\x74\x65\x78\x74\x02\x03\x15\x62\x6f\x64\x79\x2d\x69\x74\x65\x6d"
  "\x2f\x63\x6f\x6d\x70\x6f\x6e\x65\x6e\x74\x73\x03\x1f\x65\x78\x74"
  "\x72\x61\x63\x74\x2d\x64\x65\x63\x6c\x61\x72\x61\x74\x69\x6f\x6e"
  "\x73\x2d\x66\x72\x6f\x6d\x2d\x62\x6f\x64\x79\x04\x4e\x04\x13\x63"
  "\x6f\x6d\x70\x69\x6c\x65\x2d\x62\x6f\x64\x79\x2d\x69\x74\x65\x6d"
  "\x73\x04\x0c\x6f\x75\x74\x70\x75\x74\x2f\x62\x6f\x64\x79\x06\xf6"
  "\x03\x10\x81\x87\x02\xf5\x03\x0e\x81\x87\x02\xf4\x03\x0c\x81\x8b"
  "\x02\xf3\x03\x0a\x81\x87\x02\xf2\x03\x08\x81\x85\x02\xf1\x03\x06"
  "\x81\x83\x02\xf0\x03\x04\x83\x04\x0f\x1f\x5f\x02\x20\x03\x69\x66"
  "\x60\x23\x03\x05\x0a\x03\x80\x04\x16\xfd\xff\x03\xff\x03\x14\xfd"
  "\xff\x03\xfe\x03\x12\xfd\xff\x03\xfd\x03\x10\xfd\xff\x03\xfc\x03"
  "\x0e\xff\xff\x03\xfb\x03\x0c\x81\x87\x02\xfa\x03\x0a\x81\x85\x02"
  "\xf9\x03\x08\x81\x85\x02\xf8\x03\x06\x81\x85\x02\xf7\x03\x04\x85"
  "\x08\x15\x23\x61\x02\x21\x23\x24\x02\x05\x0a\x03\x11\x73\x65\x6c"
  "\x65\x63\x74\x6f\x72\x2f\x61\x64\x64\x2d\x63\x61\x72\x03\x11\x73"
  "\x65\x6c\x65\x63\x74\x6f\x72\x2f\x61\x64\x64\x2d\x63\x64\x72\x06"
  "\x28\x04\x13\x6f\x75\x74\x70\x75\x74\x2f\x64\x69\x73\x6a\x75\x6e"
  "\x63\x74\x69\x6f\x6e\x06\x8d\x04\x1c\xfd\xff\x03\x8c\x04\x1a\xfd"
  "\xff\x03\x8b\x04\x18\xfd\xff\x03\x8a\x04\x16\xfd\xff\x03\x89\x04"
  "\x14\xfd\xff\x03\x88\x04\x12\xfd\xff\x03\x87\x04\x10\xfd\xff\x03"
  "\x86\x04\x0e\xff\xff\x03\x85\x04\x0c\x81\x8b\x02\x84\x04\x0a\x81"
  "\x89\x02\x83\x04\x08\x81\x87\x02\x82\x04\x06\x81\x87\x02\x81\x04"
  "\x04\x85\x08\x1b\x2e\x28\x02\x22\x04\x65\x71\x3f\x05\x65\x71\x76"
  "\x3f\x43\x0d\x6f\x62\x6a\x65\x63\x74\x2d\x74\x79\x70\x65\x3f\x1e"
  "\x05\x6d\x65\x6d\x71\x05\x6d\x65\x6d\x76\x4c\x60\x13\x49\x6c\x6c"
  "\x2d\x66\x6f\x72\x6d\x65\x64\x20\x63\x6c\x61\x75\x73\x65\x3a\x41"
  "\x1e\x50\x05\x74\x65\x6d\x70\x62\x14\x2b\x23\x03\x05\x0a\x03\x21"
  "\x63\x61\x6c\x6c\x2d\x77\x69\x74\x68\x2d\x73\x79\x6e\x74\x61\x78"
  "\x2d\x65\x72\x72\x6f\x72\x2d\x70\x72\x6f\x63\x65\x64\x75\x72\x65"
  "\x63\x03\x21\x03\x06\x6c\x69\x73\x74\x3f\x64\x02\x16\x75\x6e\x73"
  "\x70\x65\x63\x69\x66\x69\x63\x2d\x65\x78\x70\x72\x65\x73\x73\x69"
  "\x6f\x6e\x65\x04\x09\x66\x6f\x72\x2d\x61\x6c\x6c\x3f\x03\x09\x62"
  "\x6f\x6f\x6c\x65\x61\x6e\x3f\x09\xe5\x04\xb2\x01\x81\x85\x02\xe4"
  "\x04\xb0\x01\x81\x85\x02\xe3\x04\xae\x01\x81\x89\x02\xe2\x04\xac"
  "\x01\x81\x87\x02\xe1\x04\xaa\x01\x81\x89\x02\xe0\x04\xa8\x01\x81"
  "\x85\x02\xdf\x04\xa6\x01\x81\x85\x02\xde\x04\xa4\x01\x81\x85\x02"
  "\xdd\x04\xa2\x01\x81\x89\x02\xdc\x04\xa0\x01\x81\x85\x02\xdb\x04"
  "\x9e\x01\x81\x85\x02\xda\x04\x9c\x01\x81\x89\x02\xd9\x04\x9a\x01"
  "\x81\x89\x02\xd8\x04\x98\x01\x81\x85\x02\xd7\x04\x96\x01\x81\x83"
  "\x02\xd6\x04\x94\x01\x83\x04\xd5\x04\x92\x01\x81\x83\x02\xd4\x04"
  "\x90\x01\x81\x87\x02\xd3\x04\x8e\x01\x81\x89\x02\xd2\x04\x8c\x01"
  "\x81\x89\x02\xd1\x04\x8a\x01\x81\x83\x02\xd0\x04\x88\x01\x81\x89"
  "\x02\xcf\x04\x86\x01\x81\x89\x02\xce\x04\x84\x01\x81\x83\x02\xcd"
  "\x04\x82\x01\x81\x85\x02\xcc\x04\x80\x01\x81\x89\x02\xcb\x04\x7e"
  "\x81\x89\x02\xca\x04\x7c\x81\x89\x02\xc9\x04\x7a\x81\x83\x02\xc8"
  "\x04\x78\x81\x83\x02\xc7\x04\x76\x81\x89\x02\xc6\x04\x74\x81\x85"
  "\x02\xc5\x04\x72\x81\x85\x02\xc4\x04\x70\x81\x85\x02\xc3\x04\x6e"
  "\x81\x85\x02\xc2\x04\x6c\x81\x87\x02\xc1\x04\x6a\x81\x87\x02\xc0"
  "\x04\x68\x81\x87\x02\xbf\x04\x66\x81\x87\x02\xbe\x04\x64\x81\x83"
  "\x02\xbd\x04\x62\x81\x83\x02\xbc\x04\x60\x81\x83\x02\xbb\x04\x5e"
  "\x81\x83\x02\xba\x04\x5c\x81\x87\x02\xb9\x04\x5a\x81\x87\x02\xb8"
  "\x04\x58\x81\x87\x02\xb7\x04\x56\x81\x83\x02\xb6\x04\x54\x81\x83"
  "\x02\xb5\x04\x52\x81\x83\x02\xb4\x04\x50\x81\x87\x02\xb3\x04\x4e"
  "\x81\x87\x02\xb2\x04\x4c\x81\x83\x02\xb1\x04\x4a\x81\x83\x02\xb0"
  "\x04\x48\x81\x83\x02\xaf\x04\x46\x81\x83\x02\xae\x04\x44\x81\x8b"
  "\x02\xad\x04\x42\x81\x8b\x02\xac\x04\x40\x81\x89\x02\xab\x04\x3e"
  "\x81\x87\x02\xaa\x04\x3c\x81\x89\x02\xa9\x04\x3a\x81\x87\x02\xa8"
  "\x04\x38\x81\x8b\x02\xa7\x04\x36\x81\x87\x02\xa6\x04\x34\x81\x87"
  "\x02\xa5\x04\x32\x81\x85\x02\xa4\x04\x30\x81\x85\x02\xa3\x04\x2e"
  "\x81\x89\x02\xa2\x04\x2c\x81\x89\x02\xa1\x04\x2a\x81\x87\x02\xa0"
  "\x04\x28\x81\x87\x02\x9f\x04\x26\x81\x87\x02\x9e\x04\x24\x81\x89"
  "\x02\x9d\x04\x22\x81\x89\x02\x9c\x04\x20\x81\x87\x02\x9b\x04\x1e"
  "\x81\x87\x02\x9a\x04\x1c\x81\x87\x02\x99\x04\x1a\x81\x87\x02\x98"
  "\x04\x18\x81\x85\x02\x97\x04\x16\x81\x8b\x02\x96\x04\x14\x81\x8b"
  "\x02\x95\x04\x12\x81\x8b\x02\x94\x04\x10\x81\x89\x02\x93\x04\x0e"
  "\x81\x89\x02\x92\x04\x0c\x81\x89\x02\x91\x04\x0a\x81\x85\x02\x90"
  "\x04\x08\x81\x85\x02\x8f\x04\x06\x81\x85\x02\x8e\x04\x04\x85\x08"
  "\xb1\x01\xda\x01\x66\x02\x23\x24\x46\x6f\x72\x6d\x20\x6d\x75\x73"
  "\x74\x20\x68\x61\x76\x65\x20\x61\x74\x20\x6c\x65\x61\x73\x74\x20"
  "\x6f\x6e\x65\x20\x63\x6c\x61\x75\x73\x65\x3a\x03\x05\x36\x02\x65"
  "\x08\x13\x65\x78\x70\x61\x6e\x64\x2f\x63\x6f\x6e\x64\x2d\x63\x6c"
  "\x61\x75\x73\x65\x67\x05\xef\x04\x16\xfd\xff\x03\xee\x04\x14\xfd"
  "\xff\x03\xed\x04\x12\xfd\xff\x03\xec\x04\x10\xff\xff\x03\xeb\x04"
  "\x0e\x81\x89\x02\xea\x04\x0c\x81\x87\x02\xe9\x04\x0a\x81\x85\x02"
  "\xe8\x04\x08\x81\x85\x02\xe7\x04\x06\x81\x87\x02\xe6\x04\x04\x85"
  "\x08\x15\x26\x68\x02\x24\x50\x1e\x08\x64\x6f\x2d\x6c\x6f\x6f\x70"
  "\x23\x19\x26\x14\x15\x23\x15\x03\x05\x0a\x04\x4e\x04\x07\x61\x70"
  "\x70\x65\x6e\x64\x69\x08\x67\x06\x8a\x05\x38\x81\x8b\x02\x89\x05"
  "\x36\x81\x95\x02\x88\x05\x34\x81\x95\x02\x87\x05\x32\x81\x95\x02"
  "\x86\x05\x30\x81\x8d\x02\x85\x05\x2e\x81\x85\x02\x84\x05\x2c\x81"
  "\x83\x02\x83\x05\x2a\x81\x83\x02\x82\x05\x28\x83\x04\x81\x05\x26"
  "\x81\x8b\x02\x80\x05\x24\x81\x83\x02\xff\x04\x22\x81\x83\x02\xfe"
  "\x04\x20\x81\x83\x02\xfd\x04\x1e\x81\x83\x02\xfc\x04\x1c\x83\x04"
  "\xfb\x04\x1a\x81\x8f\x02\xfa\x04\x18\x81\x8f\x02\xf9\x04\x16\x81"
  "\x8f\x02\xf8\x04\x14\x81\x8d\x02\xf7\x04\x12\x81\x8b\x02\xf6\x04"
  "\x10\x81\x89\x02\xf5\x04\x0e\x81\x87\x02\xf4\x04\x0c\x81\x87\x02"
  "\xf3\x04\x0a\x81\x85\x02\xf2\x04\x08\x81\x85\x02\xf1\x04\x06\x81"
  "\x85\x02\xf0\x04\x04\x85\x08\x37\x4c\x6a\x02\x25\x50\x16\x49\x6c"
  "\x6c\x2d\x66\x6f\x72\x6d\x65\x64\x20\x3d\x3e\x20\x63\x6c\x61\x75"
  "\x73\x65\x3a\x60\x41\x62\x18\x49\x6c\x6c\x2d\x66\x6f\x72\x6d\x65"
  "\x64\x20\x45\x4c\x53\x45\x20\x63\x6c\x61\x75\x73\x65\x3a\x17\x4d"
  "\x69\x73\x70\x6c\x61\x63\x65\x64\x20\x45\x4c\x53\x45\x20\x63\x6c"
  "\x61\x75\x73\x65\x3a\x1e\x03\x3d\x3e\x13\x49\x6c\x6c\x2d\x66\x6f"
  "\x72\x6d\x65\x64\x20\x63\x6c\x61\x75\x73\x65\x3a\x03\x21\x03\x64"
  "\x05\x36\x04\xbc\x05\x66\x81\x91\x02\xbb\x05\x64\x81\x91\x02\xba"
  "\x05\x62\x81\x91\x02\xb9\x05\x60\x81\x8f\x02\xb8\x05\x5e\x81\x8f"
  "\x02\xb7\x05\x5c\x81\x8f\x02\xb6\x05\x5a\x81\x8f\x02\xb5\x05\x58"
  "\x81\x8d\x02\xb4\x05\x56\x81\x91\x02\xb3\x05\x54\x81\x91\x02\xb2"
  "\x05\x52\x81\x8f\x02\xb1\x05\x50\x81\x8f\x02\xb0\x05\x4e\x81\x8f"
  "\x02\xaf\x05\x4c\x81\x91\x02\xae\x05\x4a\x81\x91\x02\xad\x05\x48"
  "\x81\x8f\x02\xac\x05\x46\x81\x8f\x02\xab\x05\x44\x81\x8f\x02\xaa"
  "\x05\x42\x81\x8d\x02\xa9\x05\x40\x81\x8d\x02\xa8\x05\x3e\x81\x8d"
  "\x02\xa7\x05\x3c\x81\x8d\x02\xa6\x05\x3a\x81\x8d\x02\xa5\x05\x38"
  "\x81\x8d\x02\xa4\x05\x36\x81\x8d\x02\xa3\x05\x34\x81\x8d\x02\xa2"
  "\x05\x32\x81\x8d\x02\xa1\x05\x30\x81\x8d\x02\xa0\x05\x2e\x81\x91"
  "\x02\x9f\x05\x2c\x81\x8f\x02\x9e\x05\x2a\x81\x8f\x02\x9d\x05\x28"
  "\x81\x8f\x02\x9c\x05\x26\x81\x8d\x02\x9b\x05\x24\x81\x8d\x02\x9a"
  "\x05\x22\x81\x8f\x02\x99\x05\x20\x81\x8f\x02\x98\x05\x1e\x81\x8d"
  "\x02\x97\x05\x1c\x81\x8d\x02\x96\x05\x1a\x81\x8d\x02\x95\x05\x18"
  "\x81\x8d\x02\x94\x05\x16\x81\x8f\x02\x93\x05\x14\x81\x8f\x02\x92"
  "\x05\x12\x81\x8d\x02\x91\x05\x10\x81\x8d\x02\x90\x05\x0e\x81\x8d"
  "\x02\x8f\x05\x0c\x81\x8f\x02\x8e\x05\x0a\x88\x0e\x8d\x05\x08\x81"
  "\x8f\x02\x8c\x05\x06\x81\x8d\x02\x8b\x05\x04\x81\x8d\x02\x65\x7c"
  "\x62\x02\x26\x05\x63\x6f\x6e\x73\x41\x69\x0d\x6c\x69\x73\x74\x2d"
  "\x3e\x76\x65\x63\x74\x6f\x72\x07\x76\x65\x63\x74\x6f\x72\x05\x6c"
  "\x69\x73\x74\x6b\x17\x2c\x40\x20\x69\x6e\x20\x69\x6c\x6c\x65\x67"
  "\x61\x6c\x20\x63\x6f\x6e\x74\x65\x78\x74\x3a\x11\x75\x6e\x71\x75"
  "\x6f\x74\x65\x2d\x73\x70\x6c\x69\x63\x69\x6e\x67\x08\x75\x6e\x71"
  "\x75\x6f\x74\x65\x0b\x71\x75\x61\x73\x69\x71\x75\x6f\x74\x65\x6c"
  "\x4c\x03\x63\x03\x05\x0a\x03\x21\x03\x0d\x76\x65\x63\x74\x6f\x72"
  "\x2d\x3e\x6c\x69\x73\x74\x04\x4e\x03\x64\x08\xef\x05\x68\x81\x89"
  "\x02\xee\x05\x66\x81\x85\x02\xed\x05\x64\x81\x87\x02\xec\x05\x62"
  "\x81\x89\x02\xeb\x05\x60\x81\x8d\x02\xea\x05\x5e\x81\x89\x02\xe9"
  "\x05\x5c\x81\x89\x02\xe8\x05\x5a\x81\x89\x02\xe7\x05\x58\x81\x89"
  "\x02\xe6\x05\x56\x81\x89\x02\xe5\x05\x54\x81\x87\x02\xe4\x05\x52"
  "\x81\x87\x02\xe3\x05\x50\x81\x87\x02\xe2\x05\x4e\x81\x8d\x02\xe1"
  "\x05\x4c\x81\x89\x02\xe0\x05\x4a\x81\x89\x02\xdf\x05\x48\x81\x89"
  "\x02\xde\x05\x46\x81\x89\x02\xdd\x05\x44\x81\x8b\x02\xdc\x05\x42"
  "\x81\x89\x02\xdb\x05\x40\x81\x87\x02\xda\x05\x3e\x81\x87\x02\xd9"
  "\x05\x3c\x81\x87\x02\xd8\x05\x3a\x81\x8d\x02\xd7\x05\x38\x81\x89"
  "\x02\xd6\x05\x36\x81\x8b\x02\xd5\x05\x34\x81\x89\x02\xd4\x05\x32"
  "\x81\x87\x02\xd3\x05\x30\x81\x87\x02\xd2\x05\x2e\x81\x89\x02\xd1"
  "\x05\x2c\x81\x87\x02\xd0\x05\x2a\x81\x89\x02\xcf\x05\x28\x81\x87"
  "\x02\xce\x05\x26\x81\x85\x02\xcd\x05\x24\x81\x85\x02\xcc\x05\x22"
  "\x81\x85\x02\xcb\x05\x20\x81\x87\x02\xca\x05\x1e\x81\x89\x02\xc9"
  "\x05\x1c\x81\x89\x02\xc8\x05\x1a\x81\x89\x02\xc7\x05\x18\x81\x8b"
  "\x02\xc6\x05\x16\x81\x89\x02\xc5\x05\x14\x81\x8b\x02\xc4\x05\x12"
  "\x81\x89\x02\xc3\x05\x10\x81\x89\x02\xc2\x05\x0e\x81\x89\x02\xc1"
  "\x05\x0c\x81\x89\x02\xc0\x05\x0a\x81\x89\x02\xbf\x05\x08\x81\x85"
  "\x02\xbe\x05\x06\x81\x8f\x02\xbd\x05\x04\x85\x08\x67\x88\x01\x64"
  "\x02\x27\x19\x19\x23\x2b\x23\x15\x23\x15\x42\x50\x1e\x04\x47\x03"
  "\x48\x03\x8c\x06\x3c\x81\x87\x02\x8b\x06\x3a\x81\x89\x02\x8a\x06"
  "\x38\x81\x87\x02\x89\x06\x36\x81\x87\x02\x88\x06\x34\x81\x87\x02"
  "\x87\x06\x32\x81\x85\x02\x86\x06\x30\x81\x87\x02\x85\x06\x2e\x81"
  "\x85\x02\x84\x06\x2c\x81\x87\x02\x83\x06\x2a\x83\x04\x82\x06\x28"
  "\x81\x87\x02\x81\x06\x26\x81\x87\x02\x80\x06\x24\x81\x87\x02\xff"
  "\x05\x22\x81\x85\x02\xfe\x05\x20\x81\x95\x02\xfd\x05\x1e\x81\x8f"
  "\x02\xfc\x05\x1c\x81\x8f\x02\xfb\x05\x1a\x81\x8d\x02\xfa\x05\x18"
  "\x81\x8d\x02\xf9\x05\x16\x81\x8d\x02\xf8\x05\x14\x81\x8d\x02\xf7"
  "\x05\x12\x81\x8d\x02\xf6\x05\x10\x81\x8f\x02\xf5\x05\x0e\x81\x8d"
  "\x02\xf4\x05\x0c\x81\x8f\x02\xf3\x05\x0a\x81\x8b\x02\xf2\x05\x08"
  "\x81\x89\x02\xf1\x05\x06\x81\x87\x02\xf0\x05\x04\x85\x08\x3b\x4f"
  "\x63\x02\x28\x03\x37\x03\x38\x04\x0f\x03\x10\x05\x90\x06\x0a\x81"
  "\x87\x02\x8f\x06\x08\x81\x85\x02\x8e\x06\x06\x81\x83\x02\x8d\x06"
  "\x04\x83\x04\x09\x15\x21\x02\x29\x41\x06\x64\x65\x6c\x61\x79\x41"
  "\x03\x05\x0a\x03\x9a\x06\x16\x81\x87\x02\x99\x06\x14\x81\x87\x02"
  "\x98\x06\x12\x81\x87\x02\x97\x06\x10\x81\x87\x02\x96\x06\x0e\x81"
  "\x85\x02\x95\x06\x0c\x81\x85\x02\x94\x06\x0a\x81\x85\x02\x93\x06"
  "\x08\x81\x85\x02\x92\x06\x06\x81\x85\x02\x91\x06\x04\x85\x08\x15"
  "\x23\x10\x02\x2a\x13\x69\x6e\x74\x65\x67\x72\x61\x74\x65\x2d\x6f"
  "\x70\x65\x72\x61\x74\x6f\x72\x1e\x0a\x69\x6e\x74\x65\x67\x72\x61"
  "\x74\x65\x4d\x19\x23\x19\x14\x15\x19\x08\x64\x65\x63\x6c\x61\x72"
  "\x65\x0f\x04\x47\x03\x48\x03\xb1\x06\x30\x81\x8b\x02\xb0\x06\x2e"
  "\x81\x8b\x02\xaf\x06\x2c\x81\x8b\x02\xae\x06\x2a\x81\x8b\x02\xad"
  "\x06\x28\x81\x8b\x02\xac\x06\x26\x81\x8b\x02\xab\x06\x24\x81\x8b"
  "\x02\xaa\x06\x22\x81\x8b\x02\xa9\x06\x20\x81\x8b\x02\xa8\x06\x1e"
  "\x81\x8b\x02\xa7\x06\x1c\x81\x8b\x02\xa6\x06\x1a\x81\x89\x02\xa5"
  "\x06\x18\x81\x89\x02\xa4\x06\x16\x81\x89\x02\xa3\x06\x14\x81\x8b"
  "\x02\xa2\x06\x12\x81\x8b\x02\xa1\x06\x10\x81\x8b\x02\xa0\x06\x0e"
  "\x81\x89\x02\x9f\x06\x0c\x81\x8b\x02\x9e\x06\x0a\x81\x89\x02\x9d"
  "\x06\x08\x81\x8b\x02\x9c\x06\x06\x81\x87\x02\x9b\x06\x04\x85\x08"
  "\x2f\x41\x6d\x02\x2b\x05\x63\x6f\x6e\x73\x13\x73\x68\x61\x6c\x6c"
  "\x6f\x77\x2d\x66\x6c\x75\x69\x64\x2d\x62\x69\x6e\x64\x09\x6f\x75"
  "\x74\x2d\x74\x65\x6d\x70\x08\x69\x6e\x2d\x74\x65\x6d\x70\x50\x4a"
  "\x05\x73\x65\x74\x21\x6e\x23\x15\x26\x14\x15\x6b\x02\x03\x05\x0a"
  "\x04\x4e\x06\x4e\x05\x4e\x03\x1a\x6d\x61\x6b\x65\x2d\x73\x79\x6e"
  "\x74\x68\x65\x74\x69\x63\x2d\x69\x64\x65\x6e\x74\x69\x66\x69\x65"
  "\x72\x02\x65\x04\x69\x09\xcf\x06\x3e\x81\x99\x02\xce\x06\x3c\x81"
  "\x97\x02\xcd\x06\x3a\x81\x9b\x02\xcc\x06\x38\x81\x9b\x02\xcb\x06"
  "\x36\x81\x95\x02\xca\x06\x34\x81\x93\x02\xc9\x06\x32\x81\x89\x02"
  "\xc8\x06\x30\x81\x8b\x02\xc7\x06\x2e\x81\x99\x02\xc6\x06\x2c\x81"
  "\x93\x02\xc5\x06\x2a\x81\x89\x02\xc4\x06\x28\x81\x87\x02\xc3\x06"
  "\x26\x81\x93\x02\xc2\x06\x24\x81\x87\x02\xc1\x06\x22\x81\x93\x02"
  "\xc0\x06\x20\x81\x93\x02\xbf\x06\x1e\x81\x91\x02\xbe\x06\x1c\x83"
  "\x04\xbd\x06\x1a\x81\x8f\x02\xbc\x06\x18\x83\x04\xbb\x06\x16\x81"
  "\x8d\x02\xba\x06\x14\x81\x8b\x02\xb9\x06\x12\x81\x8d\x02\xb8\x06"
  "\x10\x81\x8d\x02\xb7\x06\x0e\x81\x89\x02\xb6\x06\x0c\x81\x87\x02"
  "\xb5\x06\x0a\x81\x85\x02\xb4\x06\x08\x81\x85\x02\xb3\x06\x06\x81"
  "\x85\x02\xb2\x06\x04\x85\x08\x3d\x5e\x6b\x02\x2c\x25\x54\x68\x69"
  "\x73\x20\x66\x6f\x72\x6d\x20\x61\x6c\x6c\x6f\x77\x65\x64\x20\x6f"
  "\x6e\x6c\x79\x20\x61\x74\x20\x74\x6f\x70\x20\x6c\x65\x76\x65\x6c"
  "\x3a\x05\x0a\x03\x3e\x05\x36\x02\x11\x05\xd3\x06\x0a\x81\x87\x02"
  "\xd2\x06\x08\x81\x87\x02\xd1\x06\x06\x81\x87\x02\xd0\x06\x04\x85"
  "\x08\x09\x17\x69\x02\x2d\x03\x0f\x63\x6f\x6d\x70\x69\x6c\x65\x72"
  "\x2d\x3e\x66\x6f\x72\x6d\x3e\x02\x29\x03\xd5\x06\x06\x85\x08\xd4"
  "\x06\x04\x82\x02\x05\x0d\x29\x02\x2e\x03\x3e\x02\x2e\x03\xd7\x06"
  "\x06\x85\x08\xd6\x06\x04\x82\x02\x05\x0d\x3e\x02\x2f\x23\x07\x73"
  "\x79\x6d\x62\x6f\x6c\x2e\x23\x2b\x24\x02\x05\x0a\x04\x16\x6d\x61"
  "\x6b\x65\x2d\x64\x65\x63\x6c\x61\x72\x61\x74\x69\x6f\x6e\x2d\x69"
  "\x74\x65\x6d\x06\x1b\x6d\x61\x70\x2d\x64\x65\x63\x6c\x61\x72\x61"
  "\x74\x69\x6f\x6e\x2d\x72\x65\x66\x65\x72\x65\x6e\x63\x65\x73\x24"
  "\x04\xdc\x06\x0c\x81\x89\x02\xdb\x06\x0a\x81\x87\x02\xda\x06\x08"
  "\x81\x83\x02\xd9\x06\x06\x81\x89\x02\xd8\x06\x04\x86\x0a\x0b\x19"
  "\x11\x02\x30\x23\x2e\x23\x2b\x14\x15\x16\x09\x03\x05\x0a\x07\x1d"
  "\x04\x0e\x06\x24\x03\x1f\x04\x15\x6f\x75\x74\x70\x75\x74\x2f\x6c"
  "\x6f\x63\x61\x6c\x2d\x64\x65\x63\x6c\x61\x72\x65\x07\xe8\x06\x1a"
  "\x81\x85\x02\xe7\x06\x18\x81\x83\x02\xe6\x06\x16\x81\x8b\x02\xe5"
  "\x06\x14\x81\x8b\x02\xe4\x06\x12\x81\x85\x02\xe3\x06\x10\x81\x83"
  "\x02\xe2\x06\x0e\x81\x89\x02\xe1\x06\x0c\x81\x93\x02\xe0\x06\x0a"
  "\x81\x93\x02\xdf\x06\x08\x81\x8b\x02\xde\x06\x06\x81\x89\x02\xdd"
  "\x06\x04\x86\x0a\x19\x2f\x2e\x02\x31\x18\x49\x6c\x6c\x2d\x66\x6f"
  "\x72\x6d\x65\x64\x20\x64\x65\x63\x6c\x61\x72\x61\x74\x69\x6f\x6e"
  "\x3a\x05\x54\x06\x14\x70\x72\x6f\x63\x65\x73\x73\x2d\x64\x65\x63"
  "\x6c\x61\x72\x61\x74\x69\x6f\x6e\x06\x20\x63\x6c\x61\x73\x73\x69"
  "\x66\x79\x2f\x76\x61\x72\x69\x61\x62\x6c\x65\x2d\x73\x75\x62\x65"
  "\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x54\x06\x30\x05\x36\x06\xed"
  "\x06\x0c\x81\x87\x02\xec\x06\x0a\x81\x87\x02\xeb\x06\x08\x81\x87"
  "\x02\xea\x06\x06\x81\x87\x02\xe9\x06\x04\x86\x0a\x0b\x1a\x30\x02"
  "\x32\x23\x56\x61\x72\x69\x61\x62\x6c\x65\x20\x72\x65\x71\x75\x69"
  "\x72\x65\x64\x20\x69\x6e\x20\x74\x68\x69\x73\x20\x63\x6f\x6e\x74"
  "\x65\x78\x74\x3a\x06\x0b\x03\x33\x05\x36\x03\x35\x05\xf1\x06\x0a"
  "\x81\x8b\x02\xf0\x06\x08\x81\x8b\x02\xef\x06\x06\x81\x89\x02\xee"
  "\x06\x04\x86\x0a\x09\x16\x36\x32\x35\x35\x36\x04\x30\x04\x54\x24"
  "\x0e\x6c\x6f\x63\x61\x6c\x2d\x64\x65\x63\x6c\x61\x72\x65\x2e\x04"
  "\x0f\x11\x04\x58\x65\x3e\x04\x29\x04\x10\x74\x68\x65\x2d\x65\x6e"
  "\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x69\x04\x0a\x66\x6c\x75\x69"
  "\x64\x2d\x6c\x65\x74\x6b\x04\x12\x64\x65\x66\x69\x6e\x65\x2d\x69"
  "\x6e\x74\x65\x67\x72\x61\x62\x6c\x65\x6d\x04\x38\x0c\x63\x6f\x6e"
  "\x73\x2d\x73\x74\x72\x65\x61\x6d\x10\x04\x37\x0c\x65\x6e\x76\x69"
  "\x72\x6f\x6e\x6d\x65\x6e\x74\x6d\x34\x05\x6e\x61\x6d\x65\x6b\x19"
  "\x19\x14\x15\x11\x6d\x61\x6b\x65\x2d\x61\x63\x63\x65\x73\x73\x2d"
  "\x69\x74\x65\x6d\x69\x0e\x3c\x61\x63\x63\x65\x73\x73\x2d\x69\x74"
  "\x65\x6d\x3e\x65\x07\x61\x63\x63\x65\x73\x73\x0c\x61\x63\x63\x65"
  "\x73\x73\x2d\x69\x74\x65\x6d\x6b\x6d\x21\x04\x09\x61\x6e\x64\x2d"
  "\x6c\x65\x74\x2a\x63\x04\x6c\x64\x04\x67\x62\x0a\x03\x64\x6f\x6a"
  "\x04\x05\x63\x6f\x6e\x64\x68\x04\x05\x63\x61\x73\x65\x66\x04\x43"
  "\x28\x04\x42\x61\x04\x1f\x51\x55\x5f\x04\x5e\x04\x3f\x04\x0e\x6c"
  "\x65\x74\x72\x65\x63\x2d\x73\x79\x6e\x74\x61\x78\x56\x04\x0c\x6c"
  "\x65\x74\x2a\x2d\x73\x79\x6e\x74\x61\x78\x5d\x04\x5c\x5b\x04\x23"
  "\x19\x26\x14\x15\x17\x6e\x6f\x72\x6d\x61\x6c\x69\x7a\x65\x2d\x6c"
  "\x65\x74\x2d\x62\x69\x6e\x64\x69\x6e\x67\x73\x6d\x59\x04\x19\x23"
  "\x19\x26\x14\x15\x07\x6c\x65\x74\x72\x65\x63\x57\x04\x50\x05\x6c"
  "\x65\x74\x2a\x52\x04\x13\x64\x65\x66\x69\x6e\x65\x2d\x72\x65\x63"
  "\x6f\x72\x64\x2d\x74\x79\x70\x65\x4f\x04\x19\x08\x72\x65\x63\x65"
  "\x69\x76\x65\x4b\x04\x19\x11\x6c\x6f\x63\x61\x6c\x2d\x61\x73\x73"
  "\x69\x67\x6e\x6d\x65\x6e\x74\x46\x04\x6d\x69\x74\x08\x6d\x69\x74"
  "\x2f\x67\x6e\x75\x07\x73\x72\x66\x69\x2d\x30\x07\x73\x72\x66\x69"
  "\x2d\x31\x07\x73\x72\x66\x69\x2d\x32\x07\x73\x72\x66\x69\x2d\x36"
  "\x07\x73\x72\x66\x69\x2d\x38\x07\x73\x72\x66\x69\x2d\x39\x08\x73"
  "\x72\x66\x69\x2d\x32\x33\x08\x73\x72\x66\x69\x2d\x32\x37\x08\x73"
  "\x72\x66\x69\x2d\x33\x30\x08\x73\x72\x66\x69\x2d\x36\x32\x08\x73"
  "\x72\x66\x69\x2d\x36\x39\x0d\x2b\x13\x14\x15\x0c\x63\x6f\x6e\x64"
  "\x2d\x65\x78\x70\x61\x6e\x64\x49\x04\x19\x13\x14\x15\x53\x3b\x3c"
  "\x44\x04\x45\x04\x40\x04\x4d\x0e\x64\x65\x66\x69\x6e\x65\x2d\x73"
  "\x79\x6e\x74\x61\x78\x3d\x04\x41\x3a\x04\x31\x2d\x39\x04\x32\x04"
  "\x6e\x2f\x04\x4c\x2c\x04\x60\x2a\x04\x1e\x25\x04\x1c\x17\x22\x04"
  "\x20\x04\x0d\x6e\x61\x6d\x65\x64\x2d\x6c\x61\x6d\x62\x64\x61\x1a"
  "\x04\x1f\x6e\x6f\x6e\x2d\x68\x79\x67\x69\x65\x6e\x69\x63\x2d\x6d"
  "\x61\x63\x72\x6f\x2d\x74\x72\x61\x6e\x73\x66\x6f\x72\x6d\x65\x72"
  "\x4a\x18\x04\x15\x65\x72\x2d\x6d\x61\x63\x72\x6f\x2d\x74\x72\x61"
  "\x6e\x73\x66\x6f\x72\x6d\x65\x72\x29\x6e\x6f\x6e\x2d\x68\x79\x67"
  "\x69\x65\x6e\x69\x63\x2d\x6d\x61\x63\x72\x6f\x2d\x74\x72\x61\x6e"
  "\x73\x66\x6f\x72\x6d\x65\x72\x2d\x3e\x65\x78\x70\x61\x6e\x64\x65"
  "\x72\x6e\x16\x72\x73\x63\x2d\x6d\x61\x63\x72\x6f\x2d\x74\x72\x61"
  "\x6e\x73\x66\x6f\x72\x6d\x65\x72\x15\x73\x63\x2d\x6d\x61\x63\x72"
  "\x6f\x2d\x74\x72\x61\x6e\x73\x66\x6f\x72\x6d\x65\x72\x20\x72\x73"
  "\x63\x2d\x6d\x61\x63\x72\x6f\x2d\x74\x72\x61\x6e\x73\x66\x6f\x72"
  "\x6d\x65\x72\x2d\x3e\x65\x78\x70\x61\x6e\x64\x65\x72\x6c\x1f\x73"
  "\x63\x2d\x6d\x61\x63\x72\x6f\x2d\x74\x72\x61\x6e\x73\x66\x6f\x72"
  "\x6d\x65\x72\x2d\x3e\x65\x78\x70\x61\x6e\x64\x65\x72\x6b\x0c\x14"
  "\x74\x72\x61\x6e\x73\x66\x6f\x72\x6d\x65\x72\x2d\x6b\x65\x79\x77"
  "\x6f\x72\x64\x6a\x1c\x64\x65\x66\x69\x6e\x65\x2d\x65\x72\x2d\x6d"
  "\x61\x63\x72\x6f\x2d\x74\x72\x61\x6e\x73\x66\x6f\x72\x6d\x65\x72"
  "\x68\x12\x04\x0d\x04\x04\x05\x10\x64\x65\x66\x69\x6e\x65\x2d\x6d"
  "\x75\x6c\x74\x69\x70\x6c\x65\x02\x6b\x6c\x6e\x53\x5a\x27\x65\x09"
  "\x04\x6a\x05\x12\x64\x65\x66\x69\x6e\x65\x2d\x63\x6c\x61\x73\x73"
  "\x69\x66\x69\x65\x72\x05\x10\x64\x65\x66\x69\x6e\x65\x2d\x63\x6f"
  "\x6d\x70\x69\x6c\x65\x72\x03\x14\x63\x6c\x61\x73\x73\x69\x66\x69"
  "\x65\x72\x2d\x3e\x6b\x65\x79\x77\x6f\x72\x64\x05\x68\x07\x3c\x04"
  "\x47\x02\x58\x03\x48\x03\x1b\x04\x4e\x09\x55\x03\x6d\x05\x0f\x6d"
  "\x61\x6b\x65\x2d\x69\x74\x65\x6d\x2d\x74\x79\x70\x65\x06\x0b\x04"
  "\x11\x69\x74\x65\x6d\x2d\x63\x6f\x6e\x73\x74\x72\x75\x63\x74\x6f"
  "\x72\x05\x69\x03\x0f\x69\x74\x65\x6d\x2d\x70\x72\x65\x64\x69\x63"
  "\x61\x74\x65\x04\x0e\x69\x74\x65\x6d\x2d\x61\x63\x63\x65\x73\x73"
  "\x6f\x72\x14\x9a\x01\xb6\x02\x80\x80\x04\x99\x01\xb4\x02\x81\x81"
  "\x02\x98\x01\xb2\x02\x81\x81\x02\x97\x01\xb0\x02\x81\x83\x02\x96"
  "\x01\xae\x02\x81\x83\x02\x95\x01\xac\x02\x81\x83\x02\x94\x01\xaa"
  "\x02\x81\x83\x02\x93\x01\xa8\x02\x81\x83\x02\x92\x01\xa6\x02\x81"
  "\x83\x02\x91\x01\xa4\x02\x81\x83\x02\x90\x01\xa2\x02\x81\x85\x02"
  "\x8f\x01\xa0\x02\x81\x83\x02\x8e\x01\x9e\x02\x81\x85\x02\x8d\x01"
  "\x9c\x02\x81\x89\x02\x8c\x01\x9a\x02\x81\x83\x02\x8b\x01\x98\x02"
  "\x81\x8b\x02\x8a\x01\x96\x02\x81\x8b\x02\x89\x01\x94\x02\x81\x8b"
  "\x02\x88\x01\x92\x02\x81\x89\x02\x87\x01\x90\x02\x81\x89\x02\x86"
  "\x01\x8e\x02\x81\x89\x02\x85\x01\x8c\x02\x81\x85\x02\x84\x01\x8a"
  "\x02\x81\x89\x02\x83\x01\x88\x02\x81\x83\x02\x82\x01\x86\x02\x81"
  "\x89\x02\x81\x01\x84\x02\x81\x8b\x02\x80\x01\x82\x02\x81\x89\x02"
  "\x7f\x80\x02\x81\x85\x02\x7e\xfe\x01\x81\x87\x02\x7d\xfc\x01\x81"
  "\x83\x02\x7c\xfa\x01\x81\x89\x02\x7b\xf8\x01\x81\x8b\x02\x7a\xf6"
  "\x01\x81\x89\x02\x79\xf4\x01\x81\x85\x02\x78\xf2\x01\x81\x89\x02"
  "\x77\xf0\x01\x81\x83\x02\x76\xee\x01\x81\x91\x02\x75\xec\x01\x81"
  "\x91\x02\x74\xea\x01\x81\x91\x02\x73\xe8\x01\x81\x8b\x02\x72\xe6"
  "\x01\x81\x89\x02\x71\xe4\x01\x81\x89\x02\x70\xe2\x01\x86\x0a\x6f"
  "\xe0\x01\x81\x85\x02\x6e\xde\x01\x81\x83\x02\x6d\xdc\x01\x81\x83"
  "\x02\x6c\xda\x01\x81\x83\x02\x6b\xd8\x01\x81\x83\x02\x6a\xd6\x01"
  "\x81\x83\x02\x69\xd4\x01\x81\x83\x02\x68\xd2\x01\x81\x83\x02\x67"
  "\xd0\x01\x81\x83\x02\x66\xce\x01\x81\x83\x02\x65\xcc\x01\x81\x83"
  "\x02\x64\xca\x01\x81\x93\x02\x63\xc8\x01\x81\x83\x02\x62\xc6\x01"
  "\x81\x93\x02\x61\xc4\x01\x81\x83\x02\x60\xc2\x01\x81\x89\x02\x5f"
  "\xc0\x01\x81\x89\x02\x5e\xbe\x01\x81\x91\x02\x5d\xbc\x01\x81\x83"
  "\x02\x5c\xba\x01\x81\x89\x02\x5b\xb8\x01\x81\x83\x02\x5a\xb6\x01"
  "\x81\x83\x02\x59\xb4\x01\x83\x04\x58\xb2\x01\x81\x8f\x02\x57\xb0"
  "\x01\x81\x83\x02\x56\xae\x01\x81\x8f\x02\x55\xac\x01\x81\x8f\x02"
  "\x54\xaa\x01\x81\x8b\x02\x53\xa8\x01\x81\x8d\x02\x52\xa6\x01\x81"
  "\x8d\x02\x51\xa4\x01\x81\x8b\x02\x50\xa2\x01\x81\x8b\x02\x4f\xa0"
  "\x01\x81\x8b\x02\x4e\x9e\x01\x81\x89\x02\x4d\x9c\x01\x81\x89\x02"
  "\x4c\x9a\x01\x81\x89\x02\x4b\x98\x01\x81\x8b\x02\x4a\x96\x01\x81"
  "\x89\x02\x49\x94\x01\x81\x83\x02\x48\x92\x01\x81\x89\x02\x47\x90"
  "\x01\x81\x8b\x02\x46\x8e\x01\x81\x89\x02\x45\x8c\x01\x81\x83\x02"
  "\x44\x8a\x01\x86\x0a\x43\x88\x01\x81\x85\x02\x42\x86\x01\x81\x83"
  "\x02\x41\x84\x01\x81\x83\x02\x40\x82\x01\x81\x8b\x02\x3f\x80\x01"
  "\x81\x8b\x02\x3e\x7e\x81\x89\x02\x3d\x7c\x81\x89\x02\x3c\x7a\x81"
  "\x89\x02\x3b\x78\x81\x89\x02\x3a\x76\x81\x8b\x02\x39\x74\x81\x8b"
  "\x02\x38\x72\x81\x89\x02\x37\x70\x81\x83\x02\x36\x6e\x81\x8b\x02"
  "\x35\x6c\x81\x89\x02\x34\x6a\x81\x8b\x02\x33\x68\x81\x8b\x02\x32"
  "\x66\x81\x8b\x02\x31\x64\x81\x8b\x02\x30\x62\x81\x8b\x02\x2f\x60"
  "\x81\x83\x02\x2e\x5e\x81\x8b\x02\x2d\x5c\x81\x8b\x02\x2c\x5a\x81"
  "\x8b\x02\x2b\x58\x81\x89\x02\x2a\x56\x81\x89\x02\x29\x54\x81\x8b"
  "\x02\x28\x52\x81\x89\x02\x27\x50\x81\x8b\x02\x26\x4e\x81\x8b\x02"
  "\x25\x4c\x81\x8b\x02\x24\x4a\x81\x8b\x02\x23\x48\x81\x8b\x02\x22"
  "\x46\x81\x83\x02\x21\x44\x81\x89\x02\x20\x42\x81\x8b\x02\x1f\x40"
  "\x81\x89\x02\x1e\x3e\x81\x83\x02\x1d\x3c\x81\x8b\x02\x1c\x3a\x81"
  "\x89\x02\x1b\x38\x81\x83\x02\x1a\x36\x81\x8b\x02\x19\x34\x86\x0a"
  "\x18\x32\x81\x85\x02\x17\x30\x81\x83\x02\x16\x2e\x81\x83\x02\x15"
  "\x2c\x81\x83\x02\x14\x2a\x81\x83\x02\x13\x28\x81\x83\x02\x12\x26"
  "\x81\x83\x02\x11\x24\x81\x83\x02\x10\x22\x81\x83\x02\x0f\x20\x81"
  "\x83\x02\x0e\x1e\x81\x83\x02\x0d\x1c\x81\x85\x02\x0c\x1a\x81\x83"
  "\x02\x0b\x18\x81\x85\x02\x0a\x16\x81\x87\x02\x09\x14\x81\x83\x02"
  "\x08\x12\x81\x85\x02\x07\x10\x81\x87\x02\x06\x0e\x81\x83\x02\x05"
  "\x0c\x81\x85\x02\x04\x0a\x81\x87\x02\x03\x08\x81\x83\x02\x02\x06"
  "\x81\x87\x02\x01\x04\x81\x83\x02\xb5\x02\xdb\x03";

SCHEME_OBJECT *
mit_syntax_so_data_4ba05028b71ac289 (entry_count_t dispatch_base)
{
  SCHEME_OBJECT ccb;
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES_FOR_DATA ();

  ccb = (unstackify (((unsigned char *) (& (prog_mit_syntax_so_data_4ba05028b71ac289 [0]))), (sizeof (prog_mit_syntax_so_data_4ba05028b71ac289)), dispatch_base));
  current_block = (OBJECT_ADDRESS (ccb));
  return (& (current_block [LABEL_180]));
}

DECLARE_COMPILED_DATA_NS ("mit-syntax.so", mit_syntax_so_data_4ba05028b71ac289)

#endif /* !WANT_ONLY_CODE */

DECLARE_DYNAMIC_INITIALIZATION ("mit-syntax.so", "22976760a9c4e445")
