/* Emacs: this is -*- C -*- code, */
/* generated 2007-09-09T13:45:13-0400 by Liar version UNKNOWN. */

#include "liarc.h"

#define LABEL_1_4 3
#define ENVIRONMENT_LABEL_1_3 5
#define DEBUGGING_LABEL_1_2 4
#define FREE_REFERENCES_LABEL_1_0 4
#define NUMBER_OF_LINKER_SECTIONS_1_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_1_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_1_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_2_4 3
#define ENVIRONMENT_LABEL_2_3 5
#define DEBUGGING_LABEL_2_2 4
#define FREE_REFERENCES_LABEL_2_0 4
#define NUMBER_OF_LINKER_SECTIONS_2_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_2_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_2_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_3_4 3
#define ENVIRONMENT_LABEL_3_3 5
#define DEBUGGING_LABEL_3_2 4
#define FREE_REFERENCES_LABEL_3_0 4
#define NUMBER_OF_LINKER_SECTIONS_3_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_3_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_3_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4_4 3
#define ENVIRONMENT_LABEL_4_3 5
#define DEBUGGING_LABEL_4_2 4
#define FREE_REFERENCES_LABEL_4_0 4
#define NUMBER_OF_LINKER_SECTIONS_4_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_4_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_5_4 3
#define ENVIRONMENT_LABEL_5_3 5
#define DEBUGGING_LABEL_5_2 4
#define FREE_REFERENCES_LABEL_5_0 4
#define NUMBER_OF_LINKER_SECTIONS_5_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_5_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_5_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_6_4 3
#define ENVIRONMENT_LABEL_6_3 5
#define DEBUGGING_LABEL_6_2 4
#define FREE_REFERENCES_LABEL_6_0 4
#define NUMBER_OF_LINKER_SECTIONS_6_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_6_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_6_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_7_4 3
#define ENVIRONMENT_LABEL_7_3 5
#define DEBUGGING_LABEL_7_2 4
#define FREE_REFERENCES_LABEL_7_0 4
#define NUMBER_OF_LINKER_SECTIONS_7_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_7 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_7_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_7_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_8_4 3
#define ENVIRONMENT_LABEL_8_3 5
#define DEBUGGING_LABEL_8_2 4
#define FREE_REFERENCES_LABEL_8_0 4
#define NUMBER_OF_LINKER_SECTIONS_8_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_8_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_8_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_9_4 3
#define ENVIRONMENT_LABEL_9_3 5
#define DEBUGGING_LABEL_9_2 4
#define FREE_REFERENCES_LABEL_9_0 4
#define NUMBER_OF_LINKER_SECTIONS_9_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_9_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_9_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_10_4 3
#define LABEL_10_5 5
#define ENVIRONMENT_LABEL_10_3 9
#define DEBUGGING_LABEL_10_2 8
#define FREE_REFERENCE_10_0 7
#define FREE_REFERENCES_LABEL_10_0 6
#define NUMBER_OF_LINKER_SECTIONS_10_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_10 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_10_4);
      goto Z__make_decoded_time_0;

    case 1:
      current_block = (Rpc - LABEL_10_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__make_decoded_time_4)
DEFLABEL (Z__make_decoded_time_0)
  INTERRUPT_CHECK (26, LABEL_10_4);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_10_0]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_6;
  Wrd6 = Wrd10;

DEFLABEL (label_5)
  (Wrd25.Obj) = (MAKE_OBJECT (0, 10));
  (Wrd26.Obj) = (Rsp [0]);
  (Wrd27.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd25.Obj);
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd26.Obj);
  (* (Rhp++)) = (Wrd27.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.Obj) = (Rsp [3]);
  (Wrd21.Obj) = (Rsp [4]);
  (Wrd22.Obj) = (Rsp [5]);
  (* (Rhp++)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd20.Obj);
  (* (Rhp++)) = (Wrd21.Obj);
  (* (Rhp++)) = (Wrd22.Obj);
  (Wrd16.Obj) = (Rsp [6]);
  (Wrd17.Obj) = (Rsp [7]);
  (Wrd18.Obj) = (Rsp [8]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (Wrd14.pObj) = (& (Rhp [-11]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd14.pObj)));
  Rsp = (& (Rsp [9]));
  goto pop_return;

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_10_5])), (Wrd7.pObj));

DEFLABEL (label_2)
  (Wrd6.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_11_4 3
#define LABEL_11_6 5
#define LABEL_11_5 7
#define LABEL_11_9 9
#define LABEL_11_8 11
#define LABEL_11_11 13
#define LABEL_11_10 15
#define LABEL_11_13 17
#define LABEL_11_12 19
#define LABEL_11_15 21
#define LABEL_11_14 23
#define LABEL_11_17 25
#define LABEL_11_16 27
#define LABEL_11_19 29
#define LABEL_11_18 31
#define LABEL_11_21 33
#define LABEL_11_20 35
#define LABEL_11_23 37
#define LABEL_11_22 39
#define LABEL_11_24 41
#define ENVIRONMENT_LABEL_11_3 58
#define DEBUGGING_LABEL_11_2 57
#define OBJECT_11_8 56
#define OBJECT_11_7 55
#define OBJECT_11_6 54
#define OBJECT_11_5 53
#define OBJECT_11_4 52
#define OBJECT_11_3 51
#define OBJECT_11_2 50
#define OBJECT_11_1 49
#define OBJECT_11_0 48
#define FREE_REFERENCE_11_1 43
#define FREE_REFERENCE_11_0 44
#define GLOBAL_EXECUTE_CACHE_11_7 46
#define FREE_REFERENCES_LABEL_11_0 42
#define NUMBER_OF_LINKER_SECTIONS_11_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_11 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd22;
  machine_word Wrd26;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_11_4);
      goto allocate_decoded_time_9;

    case 1:
      current_block = (Rpc - LABEL_11_6);
      goto label_11;

    case 2:
      current_block = (Rpc - LABEL_11_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_11_9);
      goto label_12;

    case 4:
      current_block = (Rpc - LABEL_11_8);
      goto continuation_1;

    case 5:
      current_block = (Rpc - LABEL_11_11);
      goto label_13;

    case 6:
      current_block = (Rpc - LABEL_11_10);
      goto continuation_2;

    case 7:
      current_block = (Rpc - LABEL_11_13);
      goto label_14;

    case 8:
      current_block = (Rpc - LABEL_11_12);
      goto continuation_3;

    case 9:
      current_block = (Rpc - LABEL_11_15);
      goto label_15;

    case 10:
      current_block = (Rpc - LABEL_11_14);
      goto continuation_4;

    case 11:
      current_block = (Rpc - LABEL_11_17);
      goto label_16;

    case 12:
      current_block = (Rpc - LABEL_11_16);
      goto continuation_5;

    case 13:
      current_block = (Rpc - LABEL_11_19);
      goto label_17;

    case 14:
      current_block = (Rpc - LABEL_11_18);
      goto continuation_6;

    case 15:
      current_block = (Rpc - LABEL_11_21);
      goto label_18;

    case 16:
      current_block = (Rpc - LABEL_11_20);
      goto continuation_7;

    case 17:
      current_block = (Rpc - LABEL_11_23);
      goto label_19;

    case 18:
      current_block = (Rpc - LABEL_11_22);
      goto continuation_8;

    case 19:
      current_block = (Rpc - LABEL_11_24);
      goto label_20;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (allocate_decoded_time_22)
DEFLABEL (allocate_decoded_time_9)
  INTERRUPT_CHECK (26, LABEL_11_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_11_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_42;
  Wrd9 = Wrd13;

DEFLABEL (label_41)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_11_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_11_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_11_1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_40;
  Wrd9 = Wrd13;

DEFLABEL (label_39)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_11_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_11_8);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_11_2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_38;
  Wrd9 = Wrd13;

DEFLABEL (label_37)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_11_7]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_11_10);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_11_3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_36;
  Wrd9 = Wrd13;

DEFLABEL (label_35)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_11_7]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_11_12);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_11_4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_34;
  Wrd9 = Wrd13;

DEFLABEL (label_33)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_11_7]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_11_14);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_11_5]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_32;
  Wrd9 = Wrd13;

DEFLABEL (label_31)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_11_7]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_11_16);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_18]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_11_6]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_30;
  Wrd9 = Wrd13;

DEFLABEL (label_29)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_11_7]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_11_18);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_20]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_11_7]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_28;
  Wrd9 = Wrd13;

DEFLABEL (label_27)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_11_7]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_11_20);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_22]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_11_8]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_26;
  Wrd9 = Wrd13;

DEFLABEL (label_25)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_11_7]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_11_22);
  (* (--Rsp)) = Rvl;
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11_1]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_24;
  Wrd6 = Wrd10;

DEFLABEL (label_23)
  (Wrd12.Obj) = (* (Rsp++));
  (Wrd13.Obj) = (* (Rsp++));
  (Wrd14.Obj) = (* (Rsp++));
  (Wrd15.Obj) = (* (Rsp++));
  (Wrd16.Obj) = (* (Rsp++));
  (Wrd17.Obj) = (* (Rsp++));
  (Wrd18.Obj) = (* (Rsp++));
  (Wrd19.Obj) = (* (Rsp++));
  (Wrd20.Obj) = (* (Rsp++));
  (Wrd26.Obj) = (MAKE_OBJECT (0, 10));
  (* (Rhp++)) = (Wrd26.Obj);
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd20.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd12.Obj);
  (Wrd22.pObj) = (& (Rhp [-11]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd22.pObj)));
  goto pop_return;

DEFLABEL (label_24)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_11_24])), (Wrd7.pObj));

DEFLABEL (label_20)
  (Wrd6.Obj) = Rvl;
  goto label_23;

DEFLABEL (label_26)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_11_23])), (Wrd10.pObj));

DEFLABEL (label_19)
  (Wrd9.Obj) = Rvl;
  goto label_25;

DEFLABEL (label_28)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_11_21])), (Wrd10.pObj));

DEFLABEL (label_18)
  (Wrd9.Obj) = Rvl;
  goto label_27;

DEFLABEL (label_30)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_11_19])), (Wrd10.pObj));

DEFLABEL (label_17)
  (Wrd9.Obj) = Rvl;
  goto label_29;

DEFLABEL (label_32)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_11_17])), (Wrd10.pObj));

DEFLABEL (label_16)
  (Wrd9.Obj) = Rvl;
  goto label_31;

DEFLABEL (label_34)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_11_15])), (Wrd10.pObj));

DEFLABEL (label_15)
  (Wrd9.Obj) = Rvl;
  goto label_33;

DEFLABEL (label_36)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_11_13])), (Wrd10.pObj));

DEFLABEL (label_14)
  (Wrd9.Obj) = Rvl;
  goto label_35;

DEFLABEL (label_38)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_11_11])), (Wrd10.pObj));

DEFLABEL (label_13)
  (Wrd9.Obj) = Rvl;
  goto label_37;

DEFLABEL (label_40)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_11_9])), (Wrd10.pObj));

DEFLABEL (label_12)
  (Wrd9.Obj) = Rvl;
  goto label_39;

DEFLABEL (label_42)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_11_6])), (Wrd10.pObj));

DEFLABEL (label_11)
  (Wrd9.Obj) = Rvl;
  goto label_41;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_12_4 3
#define ENVIRONMENT_LABEL_12_3 7
#define DEBUGGING_LABEL_12_2 6
#define OBJECT_12_1 5
#define OBJECT_12_0 4
#define FREE_REFERENCES_LABEL_12_0 4
#define NUMBER_OF_LINKER_SECTIONS_12_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_12 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_12_4);
      goto decoded_time_second_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (decoded_time_second_3)
DEFLABEL (decoded_time_second_0)
  INTERRUPT_CHECK (26, LABEL_12_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_12_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_13_4 3
#define ENVIRONMENT_LABEL_13_3 7
#define DEBUGGING_LABEL_13_2 6
#define OBJECT_13_1 5
#define OBJECT_13_0 4
#define FREE_REFERENCES_LABEL_13_0 4
#define NUMBER_OF_LINKER_SECTIONS_13_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_13 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_13_4);
      goto decoded_time_minute_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (decoded_time_minute_3)
DEFLABEL (decoded_time_minute_0)
  INTERRUPT_CHECK (26, LABEL_13_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_13_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_13_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_14_4 3
#define ENVIRONMENT_LABEL_14_3 7
#define DEBUGGING_LABEL_14_2 6
#define OBJECT_14_1 5
#define OBJECT_14_0 4
#define FREE_REFERENCES_LABEL_14_0 4
#define NUMBER_OF_LINKER_SECTIONS_14_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_14 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_14_4);
      goto decoded_time_hour_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (decoded_time_hour_3)
DEFLABEL (decoded_time_hour_0)
  INTERRUPT_CHECK (26, LABEL_14_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_14_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [4]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_15_4 3
#define ENVIRONMENT_LABEL_15_3 7
#define DEBUGGING_LABEL_15_2 6
#define OBJECT_15_1 5
#define OBJECT_15_0 4
#define FREE_REFERENCES_LABEL_15_0 4
#define NUMBER_OF_LINKER_SECTIONS_15_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_15 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_15_4);
      goto decoded_time_day_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (decoded_time_day_3)
DEFLABEL (decoded_time_day_0)
  INTERRUPT_CHECK (26, LABEL_15_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_15_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_15_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [5]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_16_4 3
#define ENVIRONMENT_LABEL_16_3 7
#define DEBUGGING_LABEL_16_2 6
#define OBJECT_16_1 5
#define OBJECT_16_0 4
#define FREE_REFERENCES_LABEL_16_0 4
#define NUMBER_OF_LINKER_SECTIONS_16_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_16 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_16_4);
      goto decoded_time_month_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (decoded_time_month_3)
DEFLABEL (decoded_time_month_0)
  INTERRUPT_CHECK (26, LABEL_16_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_16_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_16_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [6]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_17_4 3
#define ENVIRONMENT_LABEL_17_3 7
#define DEBUGGING_LABEL_17_2 6
#define OBJECT_17_1 5
#define OBJECT_17_0 4
#define FREE_REFERENCES_LABEL_17_0 4
#define NUMBER_OF_LINKER_SECTIONS_17_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_17 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_17_4);
      goto decoded_time_year_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (decoded_time_year_3)
DEFLABEL (decoded_time_year_0)
  INTERRUPT_CHECK (26, LABEL_17_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_17_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [7]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_18_4 3
#define ENVIRONMENT_LABEL_18_3 7
#define DEBUGGING_LABEL_18_2 6
#define OBJECT_18_1 5
#define OBJECT_18_0 4
#define FREE_REFERENCES_LABEL_18_0 4
#define NUMBER_OF_LINKER_SECTIONS_18_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_18 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_18_4);
      goto decoded_time_day_of_week_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (decoded_time_day_of_week_3)
DEFLABEL (decoded_time_day_of_week_0)
  INTERRUPT_CHECK (26, LABEL_18_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_18_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_18_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [8]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_19_4 3
#define ENVIRONMENT_LABEL_19_3 7
#define DEBUGGING_LABEL_19_2 6
#define OBJECT_19_1 5
#define OBJECT_19_0 4
#define FREE_REFERENCES_LABEL_19_0 4
#define NUMBER_OF_LINKER_SECTIONS_19_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_19 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_19_4);
      goto decoded_time_daylight_savings_time_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (decoded_time_daylight_savings_time_3)
DEFLABEL (decoded_time_daylight_savings_time_0)
  INTERRUPT_CHECK (26, LABEL_19_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_19_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 8L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [9]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_20_4 3
#define ENVIRONMENT_LABEL_20_3 7
#define DEBUGGING_LABEL_20_2 6
#define OBJECT_20_1 5
#define OBJECT_20_0 4
#define FREE_REFERENCES_LABEL_20_0 4
#define NUMBER_OF_LINKER_SECTIONS_20_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_20 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_20_4);
      goto decoded_time_zone_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (decoded_time_zone_3)
DEFLABEL (decoded_time_zone_0)
  INTERRUPT_CHECK (26, LABEL_20_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_20_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_20_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 9L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [10]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_21_4 3
#define ENVIRONMENT_LABEL_21_3 8
#define DEBUGGING_LABEL_21_2 7
#define OBJECT_21_2 6
#define OBJECT_21_1 5
#define OBJECT_21_0 4
#define FREE_REFERENCES_LABEL_21_0 4
#define NUMBER_OF_LINKER_SECTIONS_21_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_21 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_21_4);
      goto set_decoded_time_day_of_weekB_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (set_decoded_time_day_of_weekB_3)
DEFLABEL (set_decoded_time_day_of_weekB_0)
  INTERRUPT_CHECK (26, LABEL_21_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_21_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd19.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_2]), 3);

DEFLABEL (label_5)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd17.Lng))))
    goto label_4;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd15.pObj) [8]) = (Wrd10.Obj);
  Rvl = (current_block [OBJECT_21_1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_22_4 3
#define ENVIRONMENT_LABEL_22_3 8
#define DEBUGGING_LABEL_22_2 7
#define OBJECT_22_2 6
#define OBJECT_22_1 5
#define OBJECT_22_0 4
#define FREE_REFERENCES_LABEL_22_0 4
#define NUMBER_OF_LINKER_SECTIONS_22_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_22 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_22_4);
      goto set_decoded_time_zoneB_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (set_decoded_time_zoneB_3)
DEFLABEL (set_decoded_time_zoneB_0)
  INTERRUPT_CHECK (26, LABEL_22_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_22_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd19.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_22_2]), 3);

DEFLABEL (label_5)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 9L) < ((unsigned long) (Wrd17.Lng))))
    goto label_4;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd15.pObj) [10]) = (Wrd10.Obj);
  Rvl = (current_block [OBJECT_22_1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_23_4 3
#define LABEL_23_5 5
#define LABEL_23_6 7
#define LABEL_23_7 9
#define LABEL_23_8 11
#define ENVIRONMENT_LABEL_23_3 19
#define DEBUGGING_LABEL_23_2 18
#define OBJECT_23_3 17
#define OBJECT_23_2 16
#define OBJECT_23_1 15
#define OBJECT_23_0 14
#define FREE_REFERENCE_23_0 13
#define FREE_REFERENCES_LABEL_23_0 12
#define NUMBER_OF_LINKER_SECTIONS_23_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_23 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd32;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd26;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd27;
  machine_word Wrd24;
  machine_word Wrd52;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd9;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_23_4);
      goto decoded_timeP_4;

    case 1:
      current_block = (Rpc - LABEL_23_5);
      goto label_6;

    case 2:
      current_block = (Rpc - LABEL_23_6);
      goto label_7;

    case 3:
      current_block = (Rpc - LABEL_23_7);
      goto label_8;

    case 4:
      current_block = (Rpc - LABEL_23_8);
      goto label_9;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (decoded_timeP_11)
DEFLABEL (decoded_timeP_4)
  INTERRUPT_CHECK (26, LABEL_23_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 10)
    goto label_14;

DEFLABEL (label_13)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_12)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_14)
  if (! ((Wrd6.uLng) == 10))
    goto label_22;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd9.Obj) = (MAKE_OBJECT (26, (Wrd13.uLng)));

DEFLABEL (label_21)
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd20.uLng) == 26))
    goto label_20;
  (Wrd52.Lng) = (FIXNUM_TO_LONG (Wrd9.Obj));
  if ((Wrd52.Lng) == 0)
    goto label_13;

DEFLABEL (label_19)
  (Wrd27.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_23_0]));
  (Wrd30.Obj) = ((Wrd27.pObj) [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd31.uLng) == 50)
    goto label_18;
  Wrd26 = Wrd30;

DEFLABEL (label_17)
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd41.Obj) = (Rsp [1]);
  (Wrd42.uLng) = (OBJECT_TYPE (Wrd41.Obj));
  if (! ((Wrd42.uLng) == 10))
    goto label_16;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd41.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [0]);
  (Wrd40.Lng) = (FIXNUM_TO_LONG (Wrd39.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd40.Lng))))
    goto label_16;
  (Wrd32.Obj) = ((Wrd38.pObj) [1]);

DEFLABEL (label_15)
  (Wrd48.Obj) = (* (Rsp++));
  if (! ((Wrd32.Obj) == (Wrd48.Obj)))
    goto label_13;
  Rvl = (current_block [OBJECT_23_3]);
  goto label_12;

DEFLABEL (label_16)
  (Wrd43.Obj) = (Rsp [1]);
  (Wrd44.Obj) = (current_block [OBJECT_23_1]);
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_8]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_23_2]), 2);

DEFLABEL (label_9)
  (Wrd32.Obj) = Rvl;
  goto label_15;

DEFLABEL (label_18)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_23_7])), (Wrd27.pObj));

DEFLABEL (label_8)
  (Wrd26.Obj) = Rvl;
  goto label_17;

DEFLABEL (label_20)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_6]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_INTERFACE_0 (45);

DEFLABEL (label_7)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_19;
  goto label_13;

DEFLABEL (label_22)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_5]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_23_0]), 1);

DEFLABEL (label_6)
  (Wrd9.Obj) = Rvl;
  goto label_21;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_24_4 3
#define LABEL_24_7 5
#define LABEL_24_8 7
#define LABEL_24_5 9
#define LABEL_24_12 11
#define LABEL_24_10 13
#define LABEL_24_20 15
#define LABEL_24_21 17
#define LABEL_24_22 19
#define LABEL_24_15 21
#define LABEL_24_23 23
#define LABEL_24_24 25
#define LABEL_24_16 27
#define LABEL_24_17 29
#define TAG_24_18 13
#define LABEL_24_25 31
#define ENVIRONMENT_LABEL_24_3 60
#define DEBUGGING_LABEL_24_2 59
#define OBJECT_24_11 58
#define OBJECT_24_10 57
#define OBJECT_24_9 56
#define OBJECT_24_8 55
#define OBJECT_24_7 54
#define OBJECT_24_6 53
#define OBJECT_24_5 52
#define OBJECT_24_4 51
#define OBJECT_24_3 50
#define OBJECT_24_2 49
#define OBJECT_24_1 48
#define OBJECT_24_0 47
#define EXECUTE_CACHE_24_26 33
#define EXECUTE_CACHE_24_19 35
#define EXECUTE_CACHE_24_14 37
#define EXECUTE_CACHE_24_13 39
#define EXECUTE_CACHE_24_11 41
#define EXECUTE_CACHE_24_9 43
#define EXECUTE_CACHE_24_6 45
#define FREE_REFERENCES_LABEL_24_0 32
#define NUMBER_OF_LINKER_SECTIONS_24_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_24 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd61;
  machine_word Wrd57;
  machine_word Wrd56;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd72;
  machine_word Wrd71;
  machine_word Wrd70;
  machine_word Wrd74;
  machine_word Wrd73;
  machine_word Wrd6;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd27;
  machine_word Wrd5;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_24_4);
      goto make_decoded_time_19;

    case 1:
      current_block = (Rpc - LABEL_24_7);
      goto continuation_4;

    case 2:
      current_block = (Rpc - LABEL_24_8);
      goto continuation_3;

    case 3:
      current_block = (Rpc - LABEL_24_5);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_24_12);
      goto continuation_17;

    case 5:
      current_block = (Rpc - LABEL_24_10);
      goto continuation_5;

    case 6:
      current_block = (Rpc - LABEL_24_20);
      goto continuation_10;

    case 7:
      current_block = (Rpc - LABEL_24_21);
      goto continuation_14;

    case 8:
      current_block = (Rpc - LABEL_24_22);
      goto label_23;

    case 9:
      current_block = (Rpc - LABEL_24_15);
      goto continuation_8;

    case 10:
      current_block = (Rpc - LABEL_24_23);
      goto label_22;

    case 11:
      current_block = (Rpc - LABEL_24_24);
      goto label_21;

    case 12:
      current_block = (Rpc - LABEL_24_16);
      goto continuation_7;

    case 13:
      current_block = (Rpc - LABEL_24_17);
      goto lambda_26;

    case 14:
      current_block = (Rpc - LABEL_24_25);
      goto continuation_9;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_decoded_time_25)
DEFLABEL (make_decoded_time_19)
  INTERRUPT_CHECK (26, LABEL_24_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_24_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_24_5);
  (Wrd5.Obj) = (Rsp [6]);
  if ((Wrd5.Obj) == (current_block [OBJECT_24_2]))
    goto label_28;
  (* (--Rsp)) = (Wrd5.Obj);
  goto label_27;

DEFLABEL (label_28)
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_27)
DEFLABEL (label_41)
  (Wrd8.Obj) = (Rsp [0]);
  if ((Wrd8.Obj) == ((SCHEME_OBJECT) 0))
    goto label_40;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_8]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_14]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_24_8);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_40;
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_7]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (Wrd43.Obj) = (current_block [OBJECT_24_0]);
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd44.Obj) = (current_block [OBJECT_24_1]);
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd45.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd45.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_9]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_24_7);

DEFLABEL (label_40)
  (Wrd14.Obj) = (Rsp [0]);
  if ((Wrd14.Obj) == ((SCHEME_OBJECT) 0))
    goto label_29;
  (Wrd16.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [4]);
  (Rsp [2]) = (Wrd17.Obj);
  (Rsp [8]) = (Wrd14.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_12]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_13]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_24_12);
  (Wrd5.Obj) = (Rsp [3]);
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [5]);
  (Rsp [3]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [7]);
  (Rsp [5]) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_24_4]);
  (Rsp [7]) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [6]);
  (Rsp [4]) = (Wrd9.Obj);
  (Rsp [6]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_11]));

DEFLABEL (label_29)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_10]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd29.Obj) = (current_block [OBJECT_24_3]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_24_4]);
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd31.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd32.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd32.Obj);
  (Wrd33.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd35.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd36.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd36.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_11]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_24_10);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_15]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_16]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd13.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_24_18);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_24_17])));
  Rhp += 1;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd13.pObj)));
  ((Wrd13.pObj) [2]) = Rvl;
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_19]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_24_16);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_25]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_26]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_24_25);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_30;
  (Wrd15.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_24_10]), 2);

DEFLABEL (label_30)
  (Wrd7.Obj) = (current_block [OBJECT_24_11]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_20]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [11]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [11]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [11]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_13]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_24_20);
  (Rsp [2]) = Rvl;
  (Wrd73.Obj) = (Rsp [0]);
  (Wrd74.uLng) = (OBJECT_TYPE (Wrd73.Obj));
  if ((Wrd74.uLng) == 10)
    goto label_32;

DEFLABEL (label_31)
  INVOKE_PRIMITIVE ((current_block [OBJECT_24_5]), 3);

DEFLABEL (label_32)
  (Wrd70.pObj) = (OBJECT_ADDRESS (Wrd73.Obj));
  (Wrd71.Obj) = ((Wrd70.pObj) [0]);
  (Wrd72.Lng) = (FIXNUM_TO_LONG (Wrd71.Obj));
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd72.Lng))))
    goto label_31;
  ((Wrd70.pObj) [8]) = Rvl;
  Rsp = (& (Rsp [4]));

DEFLABEL (label_39)
  (Wrd37.Obj) = (Rsp [0]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd38.uLng) == 10))
    goto label_38;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [0]);
  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd35.Obj));
  if (! (((unsigned long) 9L) < ((unsigned long) (Wrd36.Lng))))
    goto label_38;
  (Wrd7.Obj) = ((Wrd34.pObj) [10]);
  if (! ((Wrd7.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_34;

DEFLABEL (label_33)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [8]));
  goto pop_return;

DEFLABEL (label_34)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_21]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_24_8]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd24.Obj) = (Rsp [2]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd25.uLng) == 10))
    goto label_37;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [0]);
  (Wrd23.Lng) = (FIXNUM_TO_LONG (Wrd22.Obj));
  if (! (((unsigned long) 9L) < ((unsigned long) (Wrd23.Lng))))
    goto label_37;
  (Wrd17.Obj) = ((Wrd21.pObj) [10]);
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_36)
  INVOKE_INTERFACE_0 (35);

DEFLABEL (continuation_14)
  (Wrd45.Obj) = Rvl;
  (Wrd54.Obj) = (Rsp [0]);
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if (! ((Wrd55.uLng) == 10))
    goto label_35;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd52.Obj) = ((Wrd51.pObj) [0]);
  (Wrd53.Lng) = (FIXNUM_TO_LONG (Wrd52.Obj));
  if (! (((unsigned long) 9L) < ((unsigned long) (Wrd53.Lng))))
    goto label_35;
  ((Wrd51.pObj) [10]) = Rvl;
  goto label_33;

DEFLABEL (label_35)
  (Wrd56.Obj) = (Rsp [0]);
  (Wrd57.Obj) = (current_block [OBJECT_24_6]);
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_22]))));
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd57.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_24_5]), 3);

DEFLABEL (label_23)
  goto label_33;

DEFLABEL (label_37)
  (Wrd26.Obj) = (Rsp [2]);
  (Wrd27.Obj) = (current_block [OBJECT_24_6]);
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_24]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_24_7]), 2);

DEFLABEL (label_21)
  (* (--Rsp)) = Rvl;
  goto label_36;

DEFLABEL (label_38)
  (Wrd39.Obj) = (Rsp [0]);
  (Wrd40.Obj) = (current_block [OBJECT_24_6]);
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_23]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_24_7]), 2);

DEFLABEL (label_22)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_33;
  goto label_34;

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_24_15);
  goto label_39;

DEFLABEL (lambda_26)
  CLOSURE_HEADER (LABEL_24_17);

DEFLABEL (lambda_6)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_24_9]), 1);

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_25_4 3
#define LABEL_25_5 5
#define LABEL_25_7 7
#define LABEL_25_6 9
#define LABEL_25_13 11
#define LABEL_25_8 13
#define LABEL_25_10 15
#define LABEL_25_11 17
#define LABEL_25_14 19
#define LABEL_25_16 21
#define LABEL_25_17 23
#define LABEL_25_19 25
#define ENVIRONMENT_LABEL_25_3 45
#define DEBUGGING_LABEL_25_2 44
#define OBJECT_25_6 43
#define OBJECT_25_5 42
#define OBJECT_25_4 41
#define OBJECT_25_3 40
#define OBJECT_25_2 39
#define OBJECT_25_1 38
#define OBJECT_25_0 37
#define EXECUTE_CACHE_25_20 27
#define EXECUTE_CACHE_25_18 29
#define EXECUTE_CACHE_25_15 31
#define EXECUTE_CACHE_25_12 33
#define EXECUTE_CACHE_25_9 35
#define FREE_REFERENCES_LABEL_25_0 26
#define NUMBER_OF_LINKER_SECTIONS_25_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_25 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_25_4);
      goto check_decoded_time_args_13;

    case 1:
      current_block = (Rpc - LABEL_25_5);
      goto continuation_5;

    case 2:
      current_block = (Rpc - LABEL_25_7);
      goto lambda_1;

    case 3:
      current_block = (Rpc - LABEL_25_6);
      goto continuation_6;

    case 4:
      current_block = (Rpc - LABEL_25_13);
      goto lambda_4;

    case 5:
      current_block = (Rpc - LABEL_25_8);
      goto continuation_0;

    case 6:
      current_block = (Rpc - LABEL_25_10);
      goto continuation_8;

    case 7:
      current_block = (Rpc - LABEL_25_11);
      goto continuation_7;

    case 8:
      current_block = (Rpc - LABEL_25_14);
      goto continuation_2;

    case 9:
      current_block = (Rpc - LABEL_25_16);
      goto continuation_9;

    case 10:
      current_block = (Rpc - LABEL_25_17);
      goto continuation_3;

    case 11:
      current_block = (Rpc - LABEL_25_19);
      goto continuation_10;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (check_decoded_time_args_16)
DEFLABEL (check_decoded_time_args_13)
  INTERRUPT_CHECK (26, LABEL_25_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.pObj) = (& (Rsp [1]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd8.pObj)));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd11.Obj);
  goto lambda_1;

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_25_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.pObj) = (& (Rsp [1]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd8.pObj)));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_25_0]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_25_1]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd13.Obj);
  Rdl = (& (Rsp [4]));
  goto lambda_4;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_25_6);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.pObj) = (& (Rsp [1]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd8.pObj)));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_11]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_12]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_25_11);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_25_1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd6.Obj);
  Rdl = (& (Rsp [4]));
  goto lambda_4;

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_25_10);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.pObj) = (& (Rsp [1]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd8.pObj)));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_25_4]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_25_5]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd13.Obj);
  Rdl = (& (Rsp [4]));
  goto lambda_4;

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_25_16);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_19]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.pObj) = (& (Rsp [1]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd8.pObj)));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_25_6]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_25_5]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd13.Obj);
  Rdl = (& (Rsp [4]));
  goto lambda_4;

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_25_19);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_25_6]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_25_5]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  Rdl = (& (Rsp [11]));
  goto lambda_4;

DEFLABEL (lambda_17)
DEFLABEL (lambda_1)
  INTERRUPT_CHECK (26, LABEL_25_7);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_9]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_25_8);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_19;
  Rvl = (current_block [OBJECT_25_3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_19)
  (Wrd9.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_25_2]);
  (Rsp [1]) = (Wrd10.Obj);
  (Wrd12.Obj) = (Rsp [2]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd11.Obj) = ((Wrd13.pObj) [6]);
  (Rsp [2]) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_15]));

DEFLABEL (lambda_18)
DEFLABEL (lambda_4)
  DLINK_INTERRUPT_CHECK (25, LABEL_25_13);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_14]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [5]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd11.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  goto lambda_1;

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_25_14);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_17]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_18]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_25_17);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_20;
  Rvl = (current_block [OBJECT_25_3]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_20)
  (Wrd10.Obj) = (Rsp [3]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [6]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_20]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_26_4 3
#define LABEL_26_8 5
#define LABEL_26_5 7
#define LABEL_26_10 9
#define LABEL_26_11 11
#define LABEL_26_6 13
#define LABEL_26_13 15
#define LABEL_26_7 17
#define LABEL_26_18 19
#define LABEL_26_19 21
#define LABEL_26_14 23
#define LABEL_26_20 25
#define LABEL_26_12 27
#define LABEL_26_22 29
#define LABEL_26_15 31
#define LABEL_26_16 33
#define LABEL_26_26 35
#define LABEL_26_27 37
#define LABEL_26_28 39
#define LABEL_26_29 41
#define LABEL_26_30 43
#define LABEL_26_31 45
#define LABEL_26_17 47
#define LABEL_26_23 49
#define LABEL_26_21 51
#define LABEL_26_24 53
#define LABEL_26_32 55
#define ENVIRONMENT_LABEL_26_3 75
#define DEBUGGING_LABEL_26_2 74
#define OBJECT_26_10 73
#define OBJECT_26_9 72
#define OBJECT_26_8 71
#define OBJECT_26_7 70
#define OBJECT_26_6 69
#define OBJECT_26_5 68
#define OBJECT_26_4 67
#define OBJECT_26_3 66
#define OBJECT_26_2 65
#define OBJECT_26_1 64
#define OBJECT_26_0 63
#define EXECUTE_CACHE_26_33 57
#define EXECUTE_CACHE_26_25 59
#define EXECUTE_CACHE_26_9 61
#define FREE_REFERENCES_LABEL_26_0 56
#define NUMBER_OF_LINKER_SECTIONS_26_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_26 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd70;
  machine_word Wrd72;
  machine_word Wrd66;
  machine_word Wrd57;
  machine_word Wrd54;
  machine_word Wrd58;
  machine_word Wrd61;
  machine_word Wrd63;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd73;
  machine_word Wrd33;
  machine_word Wrd74;
  machine_word Wrd18;
  machine_word Wrd5;
  machine_word Wrd49;
  machine_word Wrd53;
  machine_word Wrd51;
  machine_word Wrd46;
  machine_word Wrd34;
  machine_word Wrd42;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd24;
  machine_word Wrd19;
  machine_word Wrd10;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd13;
  machine_word Wrd43;
  machine_word Wrd48;
  machine_word Wrd52;
  machine_word Wrd50;
  machine_word Wrd47;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd35;
  machine_word Wrd36;
  machine_word Wrd39;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd29;
  machine_word Wrd30;
  machine_word Wrd6;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd28;
  machine_word Wrd23;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_26_4);
      goto compute_day_of_week_30;

    case 1:
      current_block = (Rpc - LABEL_26_8);
      goto label_32;

    case 2:
      current_block = (Rpc - LABEL_26_5);
      goto continuation_29;

    case 3:
      current_block = (Rpc - LABEL_26_10);
      goto continuation_19;

    case 4:
      current_block = (Rpc - LABEL_26_11);
      goto label_44;

    case 5:
      current_block = (Rpc - LABEL_26_6);
      goto continuation_13;

    case 6:
      current_block = (Rpc - LABEL_26_13);
      goto label_33;

    case 7:
      current_block = (Rpc - LABEL_26_7);
      goto continuation_12;

    case 8:
      current_block = (Rpc - LABEL_26_18);
      goto label_34;

    case 9:
      current_block = (Rpc - LABEL_26_19);
      goto label_35;

    case 10:
      current_block = (Rpc - LABEL_26_14);
      goto continuation_8;

    case 11:
      current_block = (Rpc - LABEL_26_20);
      goto label_37;

    case 12:
      current_block = (Rpc - LABEL_26_12);
      goto continuation_6;

    case 13:
      current_block = (Rpc - LABEL_26_22);
      goto label_36;

    case 14:
      current_block = (Rpc - LABEL_26_15);
      goto continuation_7;

    case 15:
      current_block = (Rpc - LABEL_26_16);
      goto continuation_17;

    case 16:
      current_block = (Rpc - LABEL_26_26);
      goto label_38;

    case 17:
      current_block = (Rpc - LABEL_26_27);
      goto label_39;

    case 18:
      current_block = (Rpc - LABEL_26_28);
      goto label_40;

    case 19:
      current_block = (Rpc - LABEL_26_29);
      goto label_41;

    case 20:
      current_block = (Rpc - LABEL_26_30);
      goto label_42;

    case 21:
      current_block = (Rpc - LABEL_26_31);
      goto label_43;

    case 22:
      current_block = (Rpc - LABEL_26_17);
      goto continuation_16;

    case 23:
      current_block = (Rpc - LABEL_26_23);
      goto continuation_3;

    case 24:
      current_block = (Rpc - LABEL_26_21);
      goto continuation_1;

    case 25:
      current_block = (Rpc - LABEL_26_24);
      goto continuation_2;

    case 26:
      current_block = (Rpc - LABEL_26_32);
      goto continuation_18;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (compute_day_of_week_46)
DEFLABEL (compute_day_of_week_30)
  INTERRUPT_CHECK (26, LABEL_26_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_26_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_6]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_7]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (current_block [OBJECT_26_1]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd21.Obj) = (Rsp [6]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 26))
    goto label_83;
  (Wrd25.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  (Wrd23.Lng) = ((Wrd25.Lng) - 2L);
  if (! (LONG_TO_FIXNUM_P (Wrd23.Lng)))
    goto label_83;
  (Wrd28.Obj) = (LONG_TO_FIXNUM (Wrd23.Lng));
  (* (--Rsp)) = (Wrd28.Obj);

DEFLABEL (label_82)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_26_9]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_26_7);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_17]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_26_6]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd19.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd19.uLng) == 26))
    goto label_81;
  (Wrd24.Lng) = (FIXNUM_TO_LONG (Rvl));
  if (multiply_with_overflow ((Wrd24.Lng), 13, (& (Wrd20.Lng))))
    goto label_81;
  (Wrd17.Obj) = (LONG_TO_FIXNUM (Wrd20.Lng));

DEFLABEL (label_80)
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd29.uLng) == 26))
    goto label_79;
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  (Wrd30.Lng) = ((Wrd31.Lng) - 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd30.Lng)))
    goto label_79;
  (Wrd32.Obj) = (LONG_TO_FIXNUM (Wrd30.Lng));
  (* (--Rsp)) = (Wrd32.Obj);

DEFLABEL (label_78)
  INVOKE_INTERFACE_0 (35);

DEFLABEL (continuation_16)
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_26_25]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_26_16);
  (* (--Rsp)) = Rvl;
  (Wrd11.Obj) = (Rsp [7]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 26))
    goto label_77;
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd11.Obj));
  {
    long temp = ((Wrd15.Lng) & 3L);
    (Wrd13.Lng) = (((Wrd15.Lng) >= 0) ? temp : (temp == 0) ? 0 : (temp | (LEFT_SHIFT ((-1L), 2))));
  }
  (Wrd10.Obj) = (LONG_TO_FIXNUM (Wrd13.Lng));

DEFLABEL (label_76)
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd18.uLng) == 26))
    goto label_75;
  (Wrd74.Lng) = (FIXNUM_TO_LONG (Wrd10.Obj));
  if ((Wrd74.Lng) == 0)
    goto label_66;

DEFLABEL (label_65)
  (Wrd24.Obj) = (current_block [OBJECT_26_9]);
  (* (--Rsp)) = (Wrd24.Obj);

DEFLABEL (label_64)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_10]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_32]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd31.Obj) = (current_block [OBJECT_26_10]);
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd32.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_INTERFACE_0 (35);

DEFLABEL (continuation_18)
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_26_25]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_26_10);
  (Wrd30.Obj) = Rvl;
  (Wrd29.Obj) = (* (Rsp++));
  (Wrd37.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd37.uLng) == 26))
    goto label_63;
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if (! ((Wrd38.uLng) == 26))
    goto label_63;
  (Wrd40.Lng) = (FIXNUM_TO_LONG (Rvl));
  (Wrd41.Lng) = (FIXNUM_TO_LONG (Wrd29.Obj));
  if (multiply_with_overflow ((Wrd40.Lng), (Wrd41.Lng), (& (Wrd39.Lng))))
    goto label_63;
  (Wrd36.Obj) = (LONG_TO_FIXNUM (Wrd39.Lng));

DEFLABEL (label_62)
  (Rsp [1]) = (Wrd36.Obj);
  (Wrd44.Obj) = (Rsp [0]);
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if ((Wrd45.uLng) == 26)
    goto label_48;

DEFLABEL (label_47)
  INVOKE_INTERFACE_0 (40);

DEFLABEL (label_48)
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd47.uLng) == 26))
    goto label_47;
  (Wrd50.Lng) = (FIXNUM_TO_LONG (Wrd44.Obj));
  (Wrd52.Lng) = (FIXNUM_TO_LONG (Wrd36.Obj));
  (Wrd48.Lng) = ((Wrd50.Lng) - (Wrd52.Lng));
  if (! (LONG_TO_FIXNUM_P (Wrd48.Lng)))
    goto label_47;
  (Wrd43.Obj) = (LONG_TO_FIXNUM (Wrd48.Lng));
  Rsp = (& (Rsp [3]));
  (* (--Rsp)) = (Wrd43.Obj);

DEFLABEL (label_61)
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd13.Obj) = (Rsp [6]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 26))
    goto label_60;
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  (Wrd15.Lng) = (FIXNUM_QUOTIENT ((Wrd17.Lng), 100L));
  if (! (LONG_TO_FIXNUM_P (Wrd15.Lng)))
    goto label_60;
  (Wrd20.Obj) = (LONG_TO_FIXNUM (Wrd15.Lng));
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_59)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_14]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_15]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_26_5]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd28.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_INTERFACE_0 (35);

DEFLABEL (continuation_7)
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_26_25]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_26_14);
  (* (--Rsp)) = Rvl;
  (Wrd36.Obj) = (Rsp [1]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 26))
    goto label_58;
  (Wrd42.Lng) = (FIXNUM_TO_LONG (Wrd36.Obj));
  if (multiply_with_overflow ((Wrd42.Lng), 2, (& (Wrd38.Lng))))
    goto label_58;
  (Wrd35.Obj) = (LONG_TO_FIXNUM (Wrd38.Lng));

DEFLABEL (label_57)
  (Rsp [1]) = (Wrd35.Obj);
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd45.Obj));
  if ((Wrd46.uLng) == 26)
    goto label_50;

DEFLABEL (label_49)
  INVOKE_INTERFACE_0 (40);

DEFLABEL (label_50)
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd48.uLng) == 26))
    goto label_49;
  (Wrd51.Lng) = (FIXNUM_TO_LONG (Wrd45.Obj));
  (Wrd53.Lng) = (FIXNUM_TO_LONG (Wrd35.Obj));
  (Wrd49.Lng) = ((Wrd51.Lng) - (Wrd53.Lng));
  if (! (LONG_TO_FIXNUM_P (Wrd49.Lng)))
    goto label_49;
  (Wrd44.Obj) = (LONG_TO_FIXNUM (Wrd49.Lng));
  Rsp = (& (Rsp [3]));
  (* (--Rsp)) = (Wrd44.Obj);

DEFLABEL (label_56)
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_21]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd13.Obj) = (Rsp [7]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 26))
    goto label_55;
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  (Wrd15.Lng) = (FIXNUM_REMAINDER ((Wrd17.Lng), 100L));
  (Wrd20.Obj) = (LONG_TO_FIXNUM (Wrd15.Lng));
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_54)
  (Wrd21.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_23]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_24]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd28.Obj) = (current_block [OBJECT_26_5]);
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_INTERFACE_0 (35);

DEFLABEL (continuation_2)
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_26_25]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_26_23);
  (Rsp [1]) = Rvl;
  (Wrd9.Obj) = (Rsp [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 26)
    goto label_52;

DEFLABEL (label_51)
  INVOKE_INTERFACE_0 (43);

DEFLABEL (label_52)
  (Wrd12.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd12.uLng) == 26))
    goto label_51;
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd9.Obj));
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Rvl));
  (Wrd13.Lng) = ((Wrd15.Lng) + (Wrd17.Lng));
  if (! (LONG_TO_FIXNUM_P (Wrd13.Lng)))
    goto label_51;
  (Wrd8.Obj) = (LONG_TO_FIXNUM (Wrd13.Lng));
  Rsp = (& (Rsp [3]));
  (* (--Rsp)) = (Wrd8.Obj);

DEFLABEL (label_53)
  (Wrd5.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_26_33]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_26_5);
  (Rsp [1]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_26_3]);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_26_9]));

DEFLABEL (label_55)
  (Wrd8.Obj) = (Rsp [7]);
  (Wrd9.Obj) = (current_block [OBJECT_26_4]);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_22]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_INTERFACE_0 (56);

DEFLABEL (label_36)
  (* (--Rsp)) = Rvl;
  goto label_54;

DEFLABEL (label_58)
  (Wrd30.Obj) = (current_block [OBJECT_26_2]);
  (Wrd31.Obj) = (Rsp [1]);
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_20]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_INTERFACE_0 (41);

DEFLABEL (label_37)
  (Wrd35.Obj) = Rvl;
  goto label_57;

DEFLABEL (label_60)
  (Wrd8.Obj) = (Rsp [6]);
  (Wrd9.Obj) = (current_block [OBJECT_26_4]);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_13]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_INTERFACE_0 (55);

DEFLABEL (label_33)
  (* (--Rsp)) = Rvl;
  goto label_59;

DEFLABEL (label_63)
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_11]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_INTERFACE_0 (41);

DEFLABEL (label_44)
  (Wrd36.Obj) = Rvl;
  goto label_62;

DEFLABEL (label_66)
  (Wrd39.Obj) = (Rsp [7]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if (! ((Wrd40.uLng) == 26))
    goto label_74;
  (Wrd43.Lng) = (FIXNUM_TO_LONG (Wrd39.Obj));
  (Wrd41.Lng) = (FIXNUM_REMAINDER ((Wrd43.Lng), 100L));
  (Wrd38.Obj) = (LONG_TO_FIXNUM (Wrd41.Lng));

DEFLABEL (label_73)
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if (! ((Wrd46.uLng) == 26))
    goto label_72;
  (Wrd73.Lng) = (FIXNUM_TO_LONG (Wrd38.Obj));
  if ((Wrd73.Lng) == 0)
    goto label_68;

DEFLABEL (label_67)
  (Wrd52.Obj) = (current_block [OBJECT_26_2]);
  (* (--Rsp)) = (Wrd52.Obj);
  goto label_64;

DEFLABEL (label_68)
  (Wrd59.Obj) = (Rsp [7]);
  (Wrd60.uLng) = (OBJECT_TYPE (Wrd59.Obj));
  if (! ((Wrd60.uLng) == 26))
    goto label_71;
  (Wrd63.Lng) = (FIXNUM_TO_LONG (Wrd59.Obj));
  (Wrd61.Lng) = (FIXNUM_REMAINDER ((Wrd63.Lng), 400L));
  (Wrd58.Obj) = (LONG_TO_FIXNUM (Wrd61.Lng));

DEFLABEL (label_70)
  (Wrd66.uLng) = (OBJECT_TYPE (Wrd58.Obj));
  if (! ((Wrd66.uLng) == 26))
    goto label_69;
  (Wrd72.Lng) = (FIXNUM_TO_LONG (Wrd58.Obj));
  if ((Wrd72.Lng) == 0)
    goto label_67;
  goto label_65;

DEFLABEL (label_69)
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_31]))));
  (* (--Rsp)) = (Wrd70.Obj);
  (* (--Rsp)) = (Wrd58.Obj);
  INVOKE_INTERFACE_0 (45);

DEFLABEL (label_43)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_65;
  goto label_67;

DEFLABEL (label_71)
  (Wrd53.Obj) = (Rsp [7]);
  (Wrd54.Obj) = (current_block [OBJECT_26_8]);
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_30]))));
  (* (--Rsp)) = (Wrd57.Obj);
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  INVOKE_INTERFACE_0 (56);

DEFLABEL (label_42)
  (Wrd58.Obj) = Rvl;
  goto label_70;

DEFLABEL (label_72)
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_29]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_INTERFACE_0 (45);

DEFLABEL (label_41)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_67;
  goto label_68;

DEFLABEL (label_74)
  (Wrd33.Obj) = (Rsp [7]);
  (Wrd34.Obj) = (current_block [OBJECT_26_4]);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_28]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_INTERFACE_0 (56);

DEFLABEL (label_40)
  (Wrd38.Obj) = Rvl;
  goto label_73;

DEFLABEL (label_75)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_27]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_INTERFACE_0 (45);

DEFLABEL (label_39)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_65;
  goto label_66;

DEFLABEL (label_77)
  (Wrd5.Obj) = (Rsp [7]);
  (Wrd6.Obj) = (current_block [OBJECT_26_5]);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_26]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = (Wrd6.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_INTERFACE_0 (56);

DEFLABEL (label_38)
  (Wrd10.Obj) = Rvl;
  goto label_76;

DEFLABEL (label_79)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_19]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_INTERFACE_0 (34);

DEFLABEL (label_35)
  (* (--Rsp)) = Rvl;
  goto label_78;

DEFLABEL (label_81)
  (Wrd12.Obj) = (current_block [OBJECT_26_7]);
  (Wrd13.Obj) = (Rsp [3]);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_18]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_INTERFACE_0 (41);

DEFLABEL (label_34)
  (Wrd17.Obj) = Rvl;
  goto label_80;

DEFLABEL (label_83)
  (Wrd16.Obj) = (Rsp [6]);
  (Wrd17.Obj) = (current_block [OBJECT_26_2]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_8]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_INTERFACE_0 (40);

DEFLABEL (label_32)
  (* (--Rsp)) = Rvl;
  goto label_82;

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_26_21);
  (* (--Rsp)) = Rvl;
  goto label_53;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_26_12);
  (* (--Rsp)) = Rvl;
  goto label_56;

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_26_6);
  (* (--Rsp)) = Rvl;
  goto label_61;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_27_4 3
#define LABEL_27_5 5
#define LABEL_27_8 7
#define LABEL_27_9 9
#define LABEL_27_10 11
#define LABEL_27_11 13
#define LABEL_27_7 15
#define LABEL_27_12 17
#define LABEL_27_13 19
#define ENVIRONMENT_LABEL_27_3 31
#define DEBUGGING_LABEL_27_2 30
#define OBJECT_27_4 29
#define OBJECT_27_3 28
#define OBJECT_27_2 27
#define OBJECT_27_1 26
#define OBJECT_27_0 25
#define EXECUTE_CACHE_27_6 21
#define FREE_REFERENCE_27_0 24
#define FREE_REFERENCES_LABEL_27_0 20
#define NUMBER_OF_LINKER_SECTIONS_27_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_27 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd30;
  machine_word Wrd17;
  machine_word Wrd24;
  machine_word Wrd43;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd61;
  machine_word Wrd57;
  machine_word Wrd56;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd45;
  machine_word Wrd28;
  machine_word Wrd19;
  machine_word Wrd15;
  machine_word Wrd27;
  machine_word Wrd23;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_27_4);
      goto universal_time__local_decoded_time_8;

    case 1:
      current_block = (Rpc - LABEL_27_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_27_8);
      goto label_10;

    case 3:
      current_block = (Rpc - LABEL_27_9);
      goto label_11;

    case 4:
      current_block = (Rpc - LABEL_27_10);
      goto continuation_5;

    case 5:
      current_block = (Rpc - LABEL_27_11);
      goto label_14;

    case 6:
      current_block = (Rpc - LABEL_27_7);
      goto continuation_2;

    case 7:
      current_block = (Rpc - LABEL_27_12);
      goto label_13;

    case 8:
      current_block = (Rpc - LABEL_27_13);
      goto label_12;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (universal_time__local_decoded_time_16)
DEFLABEL (universal_time__local_decoded_time_8)
  INTERRUPT_CHECK (26, LABEL_27_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_27_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_27_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_26;
  Wrd9 = Wrd13;

DEFLABEL (label_25)
  Wrd8 = Wrd9;
  (Wrd20.Obj) = (Rsp [2]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 26))
    goto label_24;
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd22.uLng) == 26))
    goto label_24;
  (Wrd25.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  (Wrd26.Lng) = (FIXNUM_TO_LONG (Wrd9.Obj));
  (Wrd23.Lng) = ((Wrd25.Lng) - (Wrd26.Lng));
  if (! (LONG_TO_FIXNUM_P (Wrd23.Lng)))
    goto label_24;
  (Wrd27.Obj) = (LONG_TO_FIXNUM (Wrd23.Lng));
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_23)
  (Wrd28.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_27_0]), 2);

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_27_7);
  (Wrd37.Obj) = (Rsp [0]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd38.uLng) == 10))
    goto label_22;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [0]);
  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd35.Obj));
  if (! (((unsigned long) 9L) < ((unsigned long) (Wrd36.Lng))))
    goto label_22;
  (Wrd7.Obj) = ((Wrd34.pObj) [10]);
  if (! ((Wrd7.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_18;

DEFLABEL (label_17)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_18)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_10]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_27_4]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd24.Obj) = (Rsp [2]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd25.uLng) == 10))
    goto label_21;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [0]);
  (Wrd23.Lng) = (FIXNUM_TO_LONG (Wrd22.Obj));
  if (! (((unsigned long) 9L) < ((unsigned long) (Wrd23.Lng))))
    goto label_21;
  (Wrd17.Obj) = ((Wrd21.pObj) [10]);
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_20)
  INVOKE_INTERFACE_0 (35);

DEFLABEL (continuation_5)
  (Wrd45.Obj) = Rvl;
  (Wrd54.Obj) = (Rsp [0]);
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if (! ((Wrd55.uLng) == 10))
    goto label_19;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd52.Obj) = ((Wrd51.pObj) [0]);
  (Wrd53.Lng) = (FIXNUM_TO_LONG (Wrd52.Obj));
  if (! (((unsigned long) 9L) < ((unsigned long) (Wrd53.Lng))))
    goto label_19;
  ((Wrd51.pObj) [10]) = Rvl;
  goto label_17;

DEFLABEL (label_19)
  (Wrd56.Obj) = (Rsp [0]);
  (Wrd57.Obj) = (current_block [OBJECT_27_1]);
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_11]))));
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd57.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_27_2]), 3);

DEFLABEL (label_14)
  goto label_17;

DEFLABEL (label_21)
  (Wrd26.Obj) = (Rsp [2]);
  (Wrd27.Obj) = (current_block [OBJECT_27_1]);
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_13]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_27_3]), 2);

DEFLABEL (label_12)
  (* (--Rsp)) = Rvl;
  goto label_20;

DEFLABEL (label_22)
  (Wrd39.Obj) = (Rsp [0]);
  (Wrd40.Obj) = (current_block [OBJECT_27_1]);
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_12]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_27_3]), 2);

DEFLABEL (label_13)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_17;
  goto label_18;

DEFLABEL (label_24)
  (Wrd15.Obj) = (Rsp [2]);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_9]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_INTERFACE_0 (40);

DEFLABEL (label_11)
  (* (--Rsp)) = Rvl;
  goto label_23;

DEFLABEL (label_26)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_27_8])), (Wrd10.pObj));

DEFLABEL (label_10)
  (Wrd9.Obj) = Rvl;
  goto label_25;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_28_4 3
#define LABEL_28_5 5
#define LABEL_28_8 7
#define LABEL_28_9 9
#define LABEL_28_10 11
#define LABEL_28_11 13
#define LABEL_28_7 15
#define LABEL_28_12 17
#define LABEL_28_13 19
#define ENVIRONMENT_LABEL_28_3 31
#define DEBUGGING_LABEL_28_2 30
#define OBJECT_28_4 29
#define OBJECT_28_3 28
#define OBJECT_28_2 27
#define OBJECT_28_1 26
#define OBJECT_28_0 25
#define EXECUTE_CACHE_28_6 21
#define FREE_REFERENCE_28_0 24
#define FREE_REFERENCES_LABEL_28_0 20
#define NUMBER_OF_LINKER_SECTIONS_28_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_28 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd30;
  machine_word Wrd17;
  machine_word Wrd24;
  machine_word Wrd43;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd61;
  machine_word Wrd57;
  machine_word Wrd56;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd45;
  machine_word Wrd28;
  machine_word Wrd19;
  machine_word Wrd15;
  machine_word Wrd27;
  machine_word Wrd23;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_28_4);
      goto universal_time__global_decoded_time_8;

    case 1:
      current_block = (Rpc - LABEL_28_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_28_8);
      goto label_10;

    case 3:
      current_block = (Rpc - LABEL_28_9);
      goto label_11;

    case 4:
      current_block = (Rpc - LABEL_28_10);
      goto continuation_5;

    case 5:
      current_block = (Rpc - LABEL_28_11);
      goto label_14;

    case 6:
      current_block = (Rpc - LABEL_28_7);
      goto continuation_2;

    case 7:
      current_block = (Rpc - LABEL_28_12);
      goto label_13;

    case 8:
      current_block = (Rpc - LABEL_28_13);
      goto label_12;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (universal_time__global_decoded_time_16)
DEFLABEL (universal_time__global_decoded_time_8)
  INTERRUPT_CHECK (26, LABEL_28_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_28_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_28_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_28_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_26;
  Wrd9 = Wrd13;

DEFLABEL (label_25)
  Wrd8 = Wrd9;
  (Wrd20.Obj) = (Rsp [2]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 26))
    goto label_24;
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd22.uLng) == 26))
    goto label_24;
  (Wrd25.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  (Wrd26.Lng) = (FIXNUM_TO_LONG (Wrd9.Obj));
  (Wrd23.Lng) = ((Wrd25.Lng) - (Wrd26.Lng));
  if (! (LONG_TO_FIXNUM_P (Wrd23.Lng)))
    goto label_24;
  (Wrd27.Obj) = (LONG_TO_FIXNUM (Wrd23.Lng));
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_23)
  (Wrd28.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_28_0]), 2);

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_28_7);
  (Wrd37.Obj) = (Rsp [0]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd38.uLng) == 10))
    goto label_22;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [0]);
  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd35.Obj));
  if (! (((unsigned long) 9L) < ((unsigned long) (Wrd36.Lng))))
    goto label_22;
  (Wrd7.Obj) = ((Wrd34.pObj) [10]);
  if (! ((Wrd7.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_18;

DEFLABEL (label_17)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_18)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_10]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_28_4]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd24.Obj) = (Rsp [2]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd25.uLng) == 10))
    goto label_21;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [0]);
  (Wrd23.Lng) = (FIXNUM_TO_LONG (Wrd22.Obj));
  if (! (((unsigned long) 9L) < ((unsigned long) (Wrd23.Lng))))
    goto label_21;
  (Wrd17.Obj) = ((Wrd21.pObj) [10]);
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_20)
  INVOKE_INTERFACE_0 (35);

DEFLABEL (continuation_5)
  (Wrd45.Obj) = Rvl;
  (Wrd54.Obj) = (Rsp [0]);
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if (! ((Wrd55.uLng) == 10))
    goto label_19;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd52.Obj) = ((Wrd51.pObj) [0]);
  (Wrd53.Lng) = (FIXNUM_TO_LONG (Wrd52.Obj));
  if (! (((unsigned long) 9L) < ((unsigned long) (Wrd53.Lng))))
    goto label_19;
  ((Wrd51.pObj) [10]) = Rvl;
  goto label_17;

DEFLABEL (label_19)
  (Wrd56.Obj) = (Rsp [0]);
  (Wrd57.Obj) = (current_block [OBJECT_28_1]);
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_11]))));
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd57.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_28_2]), 3);

DEFLABEL (label_14)
  goto label_17;

DEFLABEL (label_21)
  (Wrd26.Obj) = (Rsp [2]);
  (Wrd27.Obj) = (current_block [OBJECT_28_1]);
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_13]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_28_3]), 2);

DEFLABEL (label_12)
  (* (--Rsp)) = Rvl;
  goto label_20;

DEFLABEL (label_22)
  (Wrd39.Obj) = (Rsp [0]);
  (Wrd40.Obj) = (current_block [OBJECT_28_1]);
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_12]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_28_3]), 2);

DEFLABEL (label_13)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_17;
  goto label_18;

DEFLABEL (label_24)
  (Wrd15.Obj) = (Rsp [2]);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_9]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_INTERFACE_0 (40);

DEFLABEL (label_11)
  (* (--Rsp)) = Rvl;
  goto label_23;

DEFLABEL (label_26)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_28_8])), (Wrd10.pObj));

DEFLABEL (label_10)
  (Wrd9.Obj) = Rvl;
  goto label_25;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_29_5 3
#define LABEL_29_6 5
#define LABEL_29_7 7
#define LABEL_29_8 9
#define LABEL_29_4 11
#define LABEL_29_10 13
#define LABEL_29_9 15
#define LABEL_29_12 17
#define ENVIRONMENT_LABEL_29_3 29
#define DEBUGGING_LABEL_29_2 28
#define OBJECT_29_4 27
#define OBJECT_29_3 26
#define OBJECT_29_2 25
#define OBJECT_29_1 24
#define OBJECT_29_0 23
#define EXECUTE_CACHE_29_11 19
#define FREE_REFERENCE_29_0 22
#define FREE_REFERENCES_LABEL_29_0 18
#define NUMBER_OF_LINKER_SECTIONS_29_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_29 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd10;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd7;
  machine_word Wrd59;
  machine_word Wrd75;
  machine_word Wrd71;
  machine_word Wrd70;
  machine_word Wrd67;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd69;
  machine_word Wrd68;
  machine_word Wrd51;
  machine_word Wrd48;
  machine_word Wrd52;
  machine_word Wrd54;
  machine_word Wrd55;
  machine_word Wrd53;
  machine_word Wrd46;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd31;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd41;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_29_5);
      goto continuation_2;

    case 1:
      current_block = (Rpc - LABEL_29_6);
      goto label_12;

    case 2:
      current_block = (Rpc - LABEL_29_7);
      goto label_13;

    case 3:
      current_block = (Rpc - LABEL_29_8);
      goto label_14;

    case 4:
      current_block = (Rpc - LABEL_29_4);
      goto decoded_time__universal_time_8;

    case 5:
      current_block = (Rpc - LABEL_29_10);
      goto label_10;

    case 6:
      current_block = (Rpc - LABEL_29_9);
      goto continuation_7;

    case 7:
      current_block = (Rpc - LABEL_29_12);
      goto label_11;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (decoded_time__universal_time_16)
DEFLABEL (decoded_time__universal_time_8)
  INTERRUPT_CHECK (26, LABEL_29_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd23.Obj) = (Rsp [1]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 10))
    goto label_30;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) 9L) < ((unsigned long) (Wrd22.Lng))))
    goto label_30;
  (Wrd10.Obj) = ((Wrd20.pObj) [10]);
  if ((Wrd10.Obj) == ((SCHEME_OBJECT) 0))
    goto label_29;

DEFLABEL (label_28)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_5]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_29_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_29_5);
  (* (--Rsp)) = Rvl;
  (Wrd41.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd41.uLng) == 10))
    goto label_27;
  (Wrd37.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd38.Obj) = ((Wrd37.pObj) [0]);
  (Wrd39.Lng) = (FIXNUM_TO_LONG (Wrd38.Obj));
  if (! (((unsigned long) 9L) < ((unsigned long) (Wrd39.Lng))))
    goto label_27;
  (Wrd31.Obj) = ((Wrd37.pObj) [10]);

DEFLABEL (label_26)
  (Wrd53.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if (! ((Wrd53.uLng) == 26))
    goto label_25;
  (Wrd55.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (multiply_with_overflow ((Wrd55.Lng), 3600, (& (Wrd54.Lng))))
    goto label_25;
  (Wrd52.Obj) = (LONG_TO_FIXNUM (Wrd54.Lng));

DEFLABEL (label_24)
  (Wrd68.Obj) = (Rsp [0]);
  (Wrd69.uLng) = (OBJECT_TYPE (Wrd68.Obj));
  if (! ((Wrd69.uLng) == 10))
    goto label_23;
  (Wrd65.pObj) = (OBJECT_ADDRESS (Wrd68.Obj));
  (Wrd66.Obj) = ((Wrd65.pObj) [0]);
  (Wrd67.Lng) = (FIXNUM_TO_LONG (Wrd66.Obj));
  if (! (((unsigned long) 9L) < ((unsigned long) (Wrd67.Lng))))
    goto label_23;
  ((Wrd65.pObj) [10]) = (Wrd52.Obj);

DEFLABEL (label_22)
  (Wrd59.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd59.Obj);

DEFLABEL (label_21)
  INVOKE_PRIMITIVE ((current_block [OBJECT_29_4]), 1);

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_29_9);
  (* (--Rsp)) = Rvl;
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_29_0]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_20;
  Wrd6 = Wrd10;

DEFLABEL (label_19)
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd13.Obj) = (Rsp [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 26)
    goto label_18;

DEFLABEL (label_17)
  INVOKE_INTERFACE_0 (43);

DEFLABEL (label_18)
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if (! ((Wrd16.uLng) == 26))
    goto label_17;
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd6.Obj));
  (Wrd17.Lng) = ((Wrd19.Lng) + (Wrd21.Lng));
  if (! (LONG_TO_FIXNUM_P (Wrd17.Lng)))
    goto label_17;
  Rvl = (LONG_TO_FIXNUM (Wrd17.Lng));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_20)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_29_12])), (Wrd7.pObj));

DEFLABEL (label_11)
  (Wrd6.Obj) = Rvl;
  goto label_19;

DEFLABEL (label_23)
  (Wrd70.Obj) = (Rsp [0]);
  (Wrd71.Obj) = (current_block [OBJECT_29_0]);
  (Wrd75.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_8]))));
  (* (--Rsp)) = (Wrd75.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd71.Obj);
  (* (--Rsp)) = (Wrd70.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_29_3]), 3);

DEFLABEL (label_14)
  goto label_22;

DEFLABEL (label_25)
  (Wrd48.Obj) = (current_block [OBJECT_29_2]);
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_7]))));
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd31.Obj);
  INVOKE_INTERFACE_0 (41);

DEFLABEL (label_13)
  (Wrd52.Obj) = Rvl;
  goto label_24;

DEFLABEL (label_27)
  (Wrd42.Obj) = (Rsp [0]);
  (Wrd43.Obj) = (current_block [OBJECT_29_0]);
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_6]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_29_1]), 2);

DEFLABEL (label_12)
  (Wrd31.Obj) = Rvl;
  goto label_26;

DEFLABEL (label_29)
  (Wrd12.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd12.Obj);
  goto label_21;

DEFLABEL (label_30)
  (Wrd25.Obj) = (Rsp [1]);
  (Wrd26.Obj) = (current_block [OBJECT_29_0]);
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_10]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_29_1]), 2);

DEFLABEL (label_10)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_29;
  goto label_28;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_30_4 3
#define LABEL_30_5 5
#define LABEL_30_6 7
#define ENVIRONMENT_LABEL_30_3 12
#define DEBUGGING_LABEL_30_2 11
#define OBJECT_30_0 10
#define FREE_REFERENCE_30_0 9
#define FREE_REFERENCES_LABEL_30_0 8
#define NUMBER_OF_LINKER_SECTIONS_30_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_30 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd20;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_30_4);
      goto get_universal_time_1;

    case 1:
      current_block = (Rpc - LABEL_30_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_30_6);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (get_universal_time_5)
DEFLABEL (get_universal_time_1)
  INTERRUPT_CHECK (26, LABEL_30_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_30_0]), 0);

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_30_5);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_30_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_9;
  Wrd5 = Wrd9;

DEFLABEL (label_8)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd13.uLng) == 26)
    goto label_7;

DEFLABEL (label_6)
  INVOKE_INTERFACE_0 (43);

DEFLABEL (label_7)
  (Wrd14.Obj) = (Rsp [1]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 26))
    goto label_6;
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  (Wrd16.Lng) = ((Wrd18.Lng) + (Wrd20.Lng));
  if (! (LONG_TO_FIXNUM_P (Wrd16.Lng)))
    goto label_6;
  Rvl = (LONG_TO_FIXNUM (Wrd16.Lng));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_9)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_30_6])), (Wrd6.pObj));

DEFLABEL (label_3)
  (Wrd5.Obj) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_31_4 3
#define LABEL_31_5 5
#define ENVIRONMENT_LABEL_31_3 12
#define DEBUGGING_LABEL_31_2 11
#define EXECUTE_CACHE_31_7 7
#define EXECUTE_CACHE_31_6 9
#define FREE_REFERENCES_LABEL_31_0 6
#define NUMBER_OF_LINKER_SECTIONS_31_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_31 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_31_4);
      goto local_decoded_time_1;

    case 1:
      current_block = (Rpc - LABEL_31_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (local_decoded_time_4)
DEFLABEL (local_decoded_time_1)
  INTERRUPT_CHECK (26, LABEL_31_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_31_5);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_32_4 3
#define LABEL_32_5 5
#define ENVIRONMENT_LABEL_32_3 12
#define DEBUGGING_LABEL_32_2 11
#define EXECUTE_CACHE_32_7 7
#define EXECUTE_CACHE_32_6 9
#define FREE_REFERENCES_LABEL_32_0 6
#define NUMBER_OF_LINKER_SECTIONS_32_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_32 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_32_4);
      goto global_decoded_time_1;

    case 1:
      current_block = (Rpc - LABEL_32_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (global_decoded_time_4)
DEFLABEL (global_decoded_time_1)
  INTERRUPT_CHECK (26, LABEL_32_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_32_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_32_5);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_32_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_33_5 3
#define LABEL_33_4 5
#define LABEL_33_6 7
#define LABEL_33_7 9
#define LABEL_33_8 11
#define LABEL_33_9 13
#define LABEL_33_10 15
#define LABEL_33_12 17
#define LABEL_33_14 19
#define ENVIRONMENT_LABEL_33_3 39
#define DEBUGGING_LABEL_33_2 38
#define OBJECT_33_10 37
#define OBJECT_33_9 36
#define OBJECT_33_8 35
#define OBJECT_33_7 34
#define OBJECT_33_6 33
#define OBJECT_33_5 32
#define OBJECT_33_4 31
#define OBJECT_33_3 30
#define OBJECT_33_2 29
#define OBJECT_33_1 28
#define OBJECT_33_0 27
#define EXECUTE_CACHE_33_15 21
#define EXECUTE_CACHE_33_13 23
#define EXECUTE_CACHE_33_11 25
#define FREE_REFERENCES_LABEL_33_0 20
#define NUMBER_OF_LINKER_SECTIONS_33_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_33 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd27;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd35;
  machine_word Wrd25;
  machine_word Wrd52;
  machine_word Wrd49;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd47;
  machine_word Wrd44;
  machine_word Wrd62;
  machine_word Wrd59;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd57;
  machine_word Wrd54;
  machine_word Wrd72;
  machine_word Wrd69;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd67;
  machine_word Wrd64;
  machine_word Wrd82;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd77;
  machine_word Wrd74;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_33_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_33_4);
      goto time_zoneP_9;

    case 2:
      current_block = (Rpc - LABEL_33_6);
      goto label_14;

    case 3:
      current_block = (Rpc - LABEL_33_7);
      goto label_13;

    case 4:
      current_block = (Rpc - LABEL_33_8);
      goto label_12;

    case 5:
      current_block = (Rpc - LABEL_33_9);
      goto label_11;

    case 6:
      current_block = (Rpc - LABEL_33_10);
      goto continuation_6;

    case 7:
      current_block = (Rpc - LABEL_33_12);
      goto continuation_7;

    case 8:
      current_block = (Rpc - LABEL_33_14);
      goto label_15;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (time_zoneP_17)
DEFLABEL (time_zoneP_9)
  INTERRUPT_CHECK (26, LABEL_33_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd74.Obj) = (current_block [OBJECT_33_0]);
  (Wrd77.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 26L) < ((unsigned long) (Wrd77.Lng))))
    goto label_36;
  (Wrd10.uLng) = (OBJECT_DATUM (Wrd74.Obj));
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd10.Obj) == (Wrd12.Obj))
    goto label_29;

DEFLABEL (label_35)
  (Wrd64.Obj) = (current_block [OBJECT_33_2]);
  (Wrd67.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 14L) < ((unsigned long) (Wrd67.Lng))))
    goto label_34;
  (Wrd14.uLng) = (OBJECT_DATUM (Wrd64.Obj));
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd14.Obj) == (Wrd16.Obj))
    goto label_29;

DEFLABEL (label_33)
  (Wrd54.Obj) = (current_block [OBJECT_33_3]);
  (Wrd57.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 58L) < ((unsigned long) (Wrd57.Lng))))
    goto label_32;
  (Wrd18.uLng) = (OBJECT_DATUM (Wrd54.Obj));
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd18.Obj) == (Wrd20.Obj))
    goto label_29;

DEFLABEL (label_31)
  (Wrd44.Obj) = (current_block [OBJECT_33_4]);
  (Wrd47.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd47.Lng))))
    goto label_30;
  (Wrd22.uLng) = (OBJECT_DATUM (Wrd44.Obj));
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd22.Obj) == (Wrd24.Obj))
    goto label_29;

DEFLABEL (label_28)
  (Wrd25.Obj) = (current_block [OBJECT_33_5]);
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd35.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 60L) < ((unsigned long) (Wrd35.Lng)))
    goto label_18;
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 2);

DEFLABEL (label_18)
  (Wrd29.uLng) = (OBJECT_DATUM (Wrd25.Obj));
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd29.Obj) == (Wrd31.Obj))
    goto label_20;
  (Wrd27.Obj) = (current_block [OBJECT_33_7]);
  goto label_19;

DEFLABEL (label_20)
  (Wrd27.Obj) = (current_block [OBJECT_33_6]);

DEFLABEL (label_19)
DEFLABEL (label_27)
  Rsp = (& (Rsp [3]));
  if (! ((Wrd27.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_22;

DEFLABEL (label_21)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_22)
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_10]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (Wrd42.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd42.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_11]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_33_10);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_23;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_23)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_12]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_33_8]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_33_9]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_13]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_33_12);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_24;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_24)
  (Wrd13.Obj) = (Rsp [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 26))
    goto label_26;
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (multiply_with_overflow ((Wrd19.Lng), 3600, (& (Wrd15.Lng))))
    goto label_26;
  (Wrd12.Obj) = (LONG_TO_FIXNUM (Wrd15.Lng));

DEFLABEL (label_25)
  (Rsp [0]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_15]));

DEFLABEL (label_26)
  (Wrd7.Obj) = (current_block [OBJECT_33_10]);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_14]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_INTERFACE_0 (41);

DEFLABEL (label_15)
  (Wrd12.Obj) = Rvl;
  goto label_25;

DEFLABEL (label_29)
  Rsp = (& (Rsp [2]));
  goto label_22;

DEFLABEL (label_30)
  (Wrd49.Obj) = (Rsp [0]);
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_9]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 2);

DEFLABEL (label_11)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_28;
  goto label_29;

DEFLABEL (label_32)
  (Wrd59.Obj) = (Rsp [0]);
  (Wrd62.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_8]))));
  (* (--Rsp)) = (Wrd62.Obj);
  (* (--Rsp)) = (Wrd59.Obj);
  (* (--Rsp)) = (Wrd54.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 2);

DEFLABEL (label_12)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_31;
  goto label_29;

DEFLABEL (label_34)
  (Wrd69.Obj) = (Rsp [0]);
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_7]))));
  (* (--Rsp)) = (Wrd72.Obj);
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd64.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 2);

DEFLABEL (label_13)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_33;
  goto label_29;

DEFLABEL (label_36)
  (Wrd82.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_6]))));
  (* (--Rsp)) = (Wrd82.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd74.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 2);

DEFLABEL (label_14)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_35;
  goto label_29;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_33_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_21;
  goto label_22;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_34_4 3
#define LABEL_34_5 5
#define ENVIRONMENT_LABEL_34_3 10
#define DEBUGGING_LABEL_34_2 9
#define OBJECT_34_2 8
#define OBJECT_34_1 7
#define OBJECT_34_0 6
#define FREE_REFERENCES_LABEL_34_0 6
#define NUMBER_OF_LINKER_SECTIONS_34_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_34 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd25;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_34_4);
      goto decoded_time_daylight_savings_timeP_1;

    case 1:
      current_block = (Rpc - LABEL_34_5);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (decoded_time_daylight_savings_timeP_5)
DEFLABEL (decoded_time_daylight_savings_timeP_1)
  INTERRUPT_CHECK (26, LABEL_34_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 8L) < ((unsigned long) (Wrd13.Lng))))
    goto label_11;
  (Wrd5.Obj) = ((Wrd11.pObj) [9]);

DEFLABEL (label_10)
  (Rsp [0]) = (Wrd5.Obj);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd23.uLng) == 26)
    goto label_6;
  INVOKE_INTERFACE_0 (44);

DEFLABEL (label_6)
  (Wrd25.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  if ((Wrd25.Lng) > 0)
    goto label_8;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_7;

DEFLABEL (label_8)
  Rvl = (current_block [OBJECT_34_2]);

DEFLABEL (label_7)
DEFLABEL (label_9)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_11)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_34_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_1]), 2);

DEFLABEL (label_3)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_35_4 3
#define LABEL_35_6 5
#define LABEL_35_5 7
#define LABEL_35_9 9
#define LABEL_35_11 11
#define LABEL_35_8 13
#define LABEL_35_12 15
#define LABEL_35_14 17
#define LABEL_35_15 19
#define LABEL_35_13 21
#define ENVIRONMENT_LABEL_35_3 42
#define DEBUGGING_LABEL_35_2 41
#define OBJECT_35_7 40
#define OBJECT_35_6 39
#define OBJECT_35_5 38
#define OBJECT_35_4 37
#define OBJECT_35_3 36
#define OBJECT_35_2 35
#define OBJECT_35_1 34
#define OBJECT_35_0 33
#define EXECUTE_CACHE_35_18 23
#define EXECUTE_CACHE_35_17 25
#define EXECUTE_CACHE_35_16 27
#define EXECUTE_CACHE_35_10 29
#define EXECUTE_CACHE_35_7 31
#define FREE_REFERENCES_LABEL_35_0 22
#define NUMBER_OF_LINKER_SECTIONS_35_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_35 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd28;
  machine_word Wrd50;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd37;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd34;
  machine_word Wrd31;
  machine_word Wrd23;
  machine_word Wrd10;
  machine_word Wrd14;
  machine_word Wrd7;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd11;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_35_4);
      goto decoded_time_date_string_10;

    case 1:
      current_block = (Rpc - LABEL_35_6);
      goto label_12;

    case 2:
      current_block = (Rpc - LABEL_35_5);
      goto continuation_7;

    case 3:
      current_block = (Rpc - LABEL_35_9);
      goto label_13;

    case 4:
      current_block = (Rpc - LABEL_35_11);
      goto continuation_1;

    case 5:
      current_block = (Rpc - LABEL_35_8);
      goto continuation_5;

    case 6:
      current_block = (Rpc - LABEL_35_12);
      goto label_14;

    case 7:
      current_block = (Rpc - LABEL_35_14);
      goto label_15;

    case 8:
      current_block = (Rpc - LABEL_35_15);
      goto continuation_2;

    case 9:
      current_block = (Rpc - LABEL_35_13);
      goto continuation_9;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (decoded_time_date_string_17)
DEFLABEL (decoded_time_date_string_10)
  INTERRUPT_CHECK (26, LABEL_35_4);
  (Wrd5.Obj) = (current_block [OBJECT_35_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_5]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd18.Obj) = (Rsp [2]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_27;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd17.Lng))))
    goto label_27;
  (Wrd11.Obj) = ((Wrd15.pObj) [5]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_26)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_7]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_35_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_35_3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_8]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd18.Obj) = (Rsp [4]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_25;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd17.Lng))))
    goto label_25;
  (Wrd11.Obj) = ((Wrd15.pObj) [6]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_24)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_10]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_35_8);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_11]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [5]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_23;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd16.Lng))))
    goto label_23;
  (Wrd10.Obj) = ((Wrd14.pObj) [8]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_22)
  (Wrd24.Obj) = (Rsp [0]);
  if ((Wrd24.Obj) == ((SCHEME_OBJECT) 0))
    goto label_18;
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_15]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_16]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_35_15);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_35_3]);
  (Rsp [1]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_17]));

DEFLABEL (label_18)
  (Wrd31.Obj) = (current_block [OBJECT_35_6]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd31.Obj);

DEFLABEL (label_21)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_13]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd44.Obj) = (Rsp [6]);
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if (! ((Wrd45.uLng) == 10))
    goto label_20;
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd42.Obj) = ((Wrd41.pObj) [0]);
  (Wrd43.Lng) = (FIXNUM_TO_LONG (Wrd42.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd43.Lng))))
    goto label_20;
  (Wrd37.Obj) = ((Wrd41.pObj) [7]);
  (* (--Rsp)) = (Wrd37.Obj);

DEFLABEL (label_19)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_7]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_35_13);
  (Rsp [5]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_18]));

DEFLABEL (label_20)
  (Wrd46.Obj) = (Rsp [6]);
  (Wrd47.Obj) = (current_block [OBJECT_35_7]);
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_14]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd46.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_2]), 2);

DEFLABEL (label_15)
  (* (--Rsp)) = Rvl;
  goto label_19;

DEFLABEL (label_23)
  (Wrd19.Obj) = (Rsp [5]);
  (Wrd20.Obj) = (current_block [OBJECT_35_5]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_12]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_2]), 2);

DEFLABEL (label_14)
  (* (--Rsp)) = Rvl;
  goto label_22;

DEFLABEL (label_25)
  (Wrd20.Obj) = (Rsp [4]);
  (Wrd21.Obj) = (current_block [OBJECT_35_4]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_9]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_2]), 2);

DEFLABEL (label_13)
  (* (--Rsp)) = Rvl;
  goto label_24;

DEFLABEL (label_27)
  (Wrd20.Obj) = (Rsp [2]);
  (Wrd21.Obj) = (current_block [OBJECT_35_1]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_6]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_2]), 2);

DEFLABEL (label_12)
  (* (--Rsp)) = Rvl;
  goto label_26;

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_35_11);
  (* (--Rsp)) = Rvl;
  goto label_21;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_36_4 3
#define LABEL_36_5 5
#define LABEL_36_6 7
#define LABEL_36_7 9
#define LABEL_36_8 11
#define LABEL_36_11 13
#define LABEL_36_9 15
#define LABEL_36_12 17
#define LABEL_36_14 19
#define LABEL_36_15 21
#define LABEL_36_16 23
#define LABEL_36_13 25
#define LABEL_36_17 27
#define LABEL_36_18 29
#define ENVIRONMENT_LABEL_36_3 48
#define DEBUGGING_LABEL_36_2 47
#define OBJECT_36_11 46
#define OBJECT_36_10 45
#define OBJECT_36_9 44
#define OBJECT_36_8 43
#define OBJECT_36_7 42
#define OBJECT_36_6 41
#define OBJECT_36_5 40
#define OBJECT_36_4 39
#define OBJECT_36_3 38
#define OBJECT_36_2 37
#define OBJECT_36_1 36
#define OBJECT_36_0 35
#define EXECUTE_CACHE_36_19 31
#define EXECUTE_CACHE_36_10 33
#define FREE_REFERENCES_LABEL_36_0 30
#define NUMBER_OF_LINKER_SECTIONS_36_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_36 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd34;
  machine_word Wrd40;
  machine_word Wrd42;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd51;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd57;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd64;
  machine_word Wrd59;
  machine_word Wrd69;
  machine_word Wrd66;
  machine_word Wrd56;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd37;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd23;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_36_4);
      goto decoded_time_time_string_16;

    case 1:
      current_block = (Rpc - LABEL_36_5);
      goto label_18;

    case 2:
      current_block = (Rpc - LABEL_36_6);
      goto label_19;

    case 3:
      current_block = (Rpc - LABEL_36_7);
      goto label_20;

    case 4:
      current_block = (Rpc - LABEL_36_8);
      goto label_21;

    case 5:
      current_block = (Rpc - LABEL_36_11);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_36_9);
      goto continuation_9;

    case 7:
      current_block = (Rpc - LABEL_36_12);
      goto label_25;

    case 8:
      current_block = (Rpc - LABEL_36_14);
      goto label_22;

    case 9:
      current_block = (Rpc - LABEL_36_15);
      goto label_24;

    case 10:
      current_block = (Rpc - LABEL_36_16);
      goto label_23;

    case 11:
      current_block = (Rpc - LABEL_36_13);
      goto continuation_6;

    case 12:
      current_block = (Rpc - LABEL_36_17);
      goto continuation_12;

    case 13:
      current_block = (Rpc - LABEL_36_18);
      goto label_26;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (decoded_time_time_string_28)
DEFLABEL (decoded_time_time_string_16)
  INTERRUPT_CHECK (26, LABEL_36_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_58;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_58;
  (Wrd7.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_57)
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_56;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd29.Lng))))
    goto label_56;
  (Wrd23.Obj) = ((Wrd27.pObj) [2]);
  (* (--Rsp)) = (Wrd23.Obj);

DEFLABEL (label_55)
  (Wrd46.Obj) = (Rsp [2]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if (! ((Wrd47.uLng) == 10))
    goto label_54;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [0]);
  (Wrd45.Lng) = (FIXNUM_TO_LONG (Wrd44.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd45.Lng))))
    goto label_54;
  (Wrd37.Obj) = ((Wrd43.pObj) [4]);

DEFLABEL (label_53)
  (Rsp [2]) = (Wrd37.Obj);
  (Wrd53.Obj) = (Rsp [0]);
  (Wrd54.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if (! ((Wrd54.uLng) == 26))
    goto label_52;
  (Wrd56.Lng) = (FIXNUM_TO_LONG (Wrd53.Obj));
  if ((Wrd56.Lng) < 10L)
    goto label_30;

DEFLABEL (label_31)
  (Wrd59.Obj) = (current_block [OBJECT_36_5]);
  (* (--Rsp)) = (Wrd59.Obj);
  goto label_29;

DEFLABEL (label_30)
  (Wrd64.Obj) = (current_block [OBJECT_36_6]);
  (* (--Rsp)) = (Wrd64.Obj);

DEFLABEL (label_29)
DEFLABEL (label_51)
  (Wrd62.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_9]))));
  (* (--Rsp)) = (Wrd62.Obj);
  (Wrd63.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd63.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_10]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_36_9);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [3]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd6.uLng) == 26))
    goto label_50;
  (Wrd8.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  if ((Wrd8.Lng) < 10L)
    goto label_33;

DEFLABEL (label_34)
  (Wrd11.Obj) = (current_block [OBJECT_36_5]);
  (* (--Rsp)) = (Wrd11.Obj);
  goto label_32;

DEFLABEL (label_33)
  (Wrd57.Obj) = (current_block [OBJECT_36_6]);
  (* (--Rsp)) = (Wrd57.Obj);

DEFLABEL (label_32)
DEFLABEL (label_49)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_13]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_11]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [7]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 26))
    goto label_48;
  (Wrd56.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if ((Wrd56.Lng) == 0)
    goto label_47;

DEFLABEL (label_46)
  (Wrd25.Obj) = (Rsp [7]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 26))
    goto label_45;
  (Wrd28.Lng) = (FIXNUM_TO_LONG (Wrd25.Obj));
  if ((Wrd28.Lng) < 13L)
    goto label_44;

DEFLABEL (label_43)
  (Wrd38.Obj) = (Rsp [7]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if (! ((Wrd39.uLng) == 26))
    goto label_42;
  (Wrd42.Lng) = (FIXNUM_TO_LONG (Wrd38.Obj));
  (Wrd40.Lng) = ((Wrd42.Lng) - 12L);
  if (! (LONG_TO_FIXNUM_P (Wrd40.Lng)))
    goto label_42;
  (Wrd32.Obj) = (LONG_TO_FIXNUM (Wrd40.Lng));

DEFLABEL (label_41)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd32.Obj);

DEFLABEL (label_40)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_10]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_36_13);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_10]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_36_17);
  (Rsp [4]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_36_9]);
  (Rsp [5]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [6]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd8.uLng) == 26))
    goto label_39;
  (Wrd10.Lng) = (FIXNUM_TO_LONG (Wrd7.Obj));
  if ((Wrd10.Lng) < 12L)
    goto label_36;

DEFLABEL (label_37)
  (Wrd13.Obj) = (current_block [OBJECT_36_10]);
  goto label_35;

DEFLABEL (label_36)
  (Wrd13.Obj) = (current_block [OBJECT_36_11]);

DEFLABEL (label_35)
DEFLABEL (label_38)
  (Rsp [6]) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_19]));

DEFLABEL (label_39)
  (Wrd15.Obj) = (current_block [OBJECT_36_8]);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_18]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_26)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_37;
  goto label_36;

DEFLABEL (label_42)
  (Wrd33.Obj) = (Rsp [7]);
  (Wrd34.Obj) = (current_block [OBJECT_36_8]);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_16]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_INTERFACE_0 (40);

DEFLABEL (label_23)
  (Wrd32.Obj) = Rvl;
  goto label_41;

DEFLABEL (label_44)
  (Wrd46.Obj) = (Rsp [7]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd46.Obj);
  goto label_40;

DEFLABEL (label_45)
  (Wrd48.Obj) = (current_block [OBJECT_36_7]);
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_15]))));
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_24)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_43;
  goto label_44;

DEFLABEL (label_47)
  (Wrd54.Obj) = (current_block [OBJECT_36_8]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd54.Obj);
  goto label_40;

DEFLABEL (label_48)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_14]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_INTERFACE_0 (45);

DEFLABEL (label_22)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_46;
  goto label_47;

DEFLABEL (label_50)
  (Wrd59.Obj) = (current_block [OBJECT_36_4]);
  (Wrd62.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_12]))));
  (* (--Rsp)) = (Wrd62.Obj);
  (* (--Rsp)) = (Wrd59.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_25)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_34;
  goto label_33;

DEFLABEL (label_52)
  (Wrd66.Obj) = (current_block [OBJECT_36_4]);
  (Wrd69.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_8]))));
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd66.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_21)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_31;
  goto label_30;

DEFLABEL (label_54)
  (Wrd48.Obj) = (Rsp [2]);
  (Wrd49.Obj) = (current_block [OBJECT_36_3]);
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_7]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_1]), 2);

DEFLABEL (label_20)
  (Wrd37.Obj) = Rvl;
  goto label_53;

DEFLABEL (label_56)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.Obj) = (current_block [OBJECT_36_2]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_6]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_1]), 2);

DEFLABEL (label_19)
  (* (--Rsp)) = Rvl;
  goto label_55;

DEFLABEL (label_58)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_36_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_1]), 2);

DEFLABEL (label_18)
  (* (--Rsp)) = Rvl;
  goto label_57;

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_36_11);
  (* (--Rsp)) = Rvl;
  goto label_40;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_37_4 3
#define LABEL_37_5 5
#define ENVIRONMENT_LABEL_37_3 12
#define DEBUGGING_LABEL_37_2 11
#define EXECUTE_CACHE_37_7 7
#define EXECUTE_CACHE_37_6 9
#define FREE_REFERENCES_LABEL_37_0 6
#define NUMBER_OF_LINKER_SECTIONS_37_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_37 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_37_4);
      goto universal_time__local_time_string_1;

    case 1:
      current_block = (Rpc - LABEL_37_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (universal_time__local_time_string_4)
DEFLABEL (universal_time__local_time_string_1)
  INTERRUPT_CHECK (26, LABEL_37_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_37_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_38_4 3
#define LABEL_38_5 5
#define ENVIRONMENT_LABEL_38_3 12
#define DEBUGGING_LABEL_38_2 11
#define EXECUTE_CACHE_38_7 7
#define EXECUTE_CACHE_38_6 9
#define FREE_REFERENCES_LABEL_38_0 6
#define NUMBER_OF_LINKER_SECTIONS_38_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_38 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_38_4);
      goto universal_time__global_time_string_1;

    case 1:
      current_block = (Rpc - LABEL_38_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (universal_time__global_time_string_4)
DEFLABEL (universal_time__global_time_string_1)
  INTERRUPT_CHECK (26, LABEL_38_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_38_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_39_4 3
#define LABEL_39_5 5
#define ENVIRONMENT_LABEL_39_3 12
#define DEBUGGING_LABEL_39_2 11
#define EXECUTE_CACHE_39_7 7
#define EXECUTE_CACHE_39_6 9
#define FREE_REFERENCES_LABEL_39_0 6
#define NUMBER_OF_LINKER_SECTIONS_39_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_39 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_39_4);
      goto file_time__local_time_string_1;

    case 1:
      current_block = (Rpc - LABEL_39_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (file_time__local_time_string_4)
DEFLABEL (file_time__local_time_string_1)
  INTERRUPT_CHECK (26, LABEL_39_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_39_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_40_4 3
#define LABEL_40_5 5
#define ENVIRONMENT_LABEL_40_3 12
#define DEBUGGING_LABEL_40_2 11
#define EXECUTE_CACHE_40_7 7
#define EXECUTE_CACHE_40_6 9
#define FREE_REFERENCES_LABEL_40_0 6
#define NUMBER_OF_LINKER_SECTIONS_40_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_40 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_40_4);
      goto file_time__global_time_string_1;

    case 1:
      current_block = (Rpc - LABEL_40_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (file_time__global_time_string_4)
DEFLABEL (file_time__global_time_string_1)
  INTERRUPT_CHECK (26, LABEL_40_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_40_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_41_4 3
#define LABEL_41_6 5
#define LABEL_41_5 7
#define LABEL_41_9 9
#define LABEL_41_8 11
#define LABEL_41_11 13
#define LABEL_41_10 15
#define LABEL_41_13 17
#define LABEL_41_12 19
#define LABEL_41_16 21
#define LABEL_41_15 23
#define LABEL_41_19 25
#define LABEL_41_20 27
#define LABEL_41_21 29
#define LABEL_41_18 31
#define LABEL_41_22 33
#define LABEL_41_23 35
#define LABEL_41_29 37
#define LABEL_41_25 39
#define LABEL_41_27 41
#define LABEL_41_32 43
#define LABEL_41_26 45
#define ENVIRONMENT_LABEL_41_3 77
#define DEBUGGING_LABEL_41_2 76
#define OBJECT_41_12 75
#define OBJECT_41_11 74
#define OBJECT_41_10 73
#define OBJECT_41_9 72
#define OBJECT_41_8 71
#define OBJECT_41_7 70
#define OBJECT_41_6 69
#define OBJECT_41_5 68
#define OBJECT_41_4 67
#define OBJECT_41_3 66
#define OBJECT_41_2 65
#define OBJECT_41_1 64
#define OBJECT_41_0 63
#define EXECUTE_CACHE_41_33 47
#define EXECUTE_CACHE_41_30 49
#define EXECUTE_CACHE_41_28 51
#define EXECUTE_CACHE_41_31 53
#define EXECUTE_CACHE_41_24 55
#define EXECUTE_CACHE_41_17 57
#define EXECUTE_CACHE_41_14 59
#define EXECUTE_CACHE_41_7 61
#define FREE_REFERENCES_LABEL_41_0 46
#define NUMBER_OF_LINKER_SECTIONS_41_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_41 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd13;
  machine_word Wrd28;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd59;
  machine_word Wrd56;
  machine_word Wrd53;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd37;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd34;
  machine_word Wrd31;
  machine_word Wrd65;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd5;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd10;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_41_4);
      goto decoded_time__string_22;

    case 1:
      current_block = (Rpc - LABEL_41_6);
      goto label_24;

    case 2:
      current_block = (Rpc - LABEL_41_5);
      goto continuation_15;

    case 3:
      current_block = (Rpc - LABEL_41_9);
      goto label_25;

    case 4:
      current_block = (Rpc - LABEL_41_8);
      goto continuation_13;

    case 5:
      current_block = (Rpc - LABEL_41_11);
      goto label_26;

    case 6:
      current_block = (Rpc - LABEL_41_10);
      goto continuation_11;

    case 7:
      current_block = (Rpc - LABEL_41_13);
      goto label_27;

    case 8:
      current_block = (Rpc - LABEL_41_12);
      goto continuation_9;

    case 9:
      current_block = (Rpc - LABEL_41_16);
      goto label_28;

    case 10:
      current_block = (Rpc - LABEL_41_15);
      goto continuation_7;

    case 11:
      current_block = (Rpc - LABEL_41_19);
      goto label_29;

    case 12:
      current_block = (Rpc - LABEL_41_20);
      goto continuation_17;

    case 13:
      current_block = (Rpc - LABEL_41_21);
      goto continuation_1;

    case 14:
      current_block = (Rpc - LABEL_41_18);
      goto continuation_5;

    case 15:
      current_block = (Rpc - LABEL_41_22);
      goto label_30;

    case 16:
      current_block = (Rpc - LABEL_41_23);
      goto label_31;

    case 17:
      current_block = (Rpc - LABEL_41_29);
      goto continuation_2;

    case 18:
      current_block = (Rpc - LABEL_41_25);
      goto continuation_20;

    case 19:
      current_block = (Rpc - LABEL_41_27);
      goto continuation_18;

    case 20:
      current_block = (Rpc - LABEL_41_32);
      goto label_32;

    case 21:
      current_block = (Rpc - LABEL_41_26);
      goto continuation_19;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (decoded_time__string_34)
DEFLABEL (decoded_time__string_22)
  INTERRUPT_CHECK (26, LABEL_41_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_58;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_58;
  (Wrd10.Obj) = ((Wrd14.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_57)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_7]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_41_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_41_2]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_8]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd18.Obj) = (Rsp [3]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_56;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd17.Lng))))
    goto label_56;
  (Wrd11.Obj) = ((Wrd15.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_55)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_7]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_41_8);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_41_2]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_10]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd18.Obj) = (Rsp [5]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_54;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd17.Lng))))
    goto label_54;
  (Wrd11.Obj) = ((Wrd15.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_53)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_7]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_41_10);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_41_5]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_12]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd18.Obj) = (Rsp [7]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_52;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd17.Lng))))
    goto label_52;
  (Wrd11.Obj) = ((Wrd15.pObj) [7]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_51)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_14]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_41_12);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_41_5]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_15]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd18.Obj) = (Rsp [9]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_50;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd17.Lng))))
    goto label_50;
  (Wrd11.Obj) = ((Wrd15.pObj) [6]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_49)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_17]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_41_15);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_41_5]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_18]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd18.Obj) = (Rsp [11]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_48;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd17.Lng))))
    goto label_48;
  (Wrd11.Obj) = ((Wrd15.pObj) [5]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_47)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_14]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_41_18);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_21]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [12]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_46;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd16.Lng))))
    goto label_46;
  (Wrd10.Obj) = ((Wrd14.pObj) [8]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_45)
  (Wrd24.Obj) = (Rsp [0]);
  if ((Wrd24.Obj) == ((SCHEME_OBJECT) 0))
    goto label_35;
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_29]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_30]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_41_29);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_41_12]);
  (Rsp [1]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_31]));

DEFLABEL (label_35)
  (Wrd31.Obj) = (current_block [OBJECT_41_10]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd31.Obj);

DEFLABEL (label_44)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_20]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd44.Obj) = (Rsp [13]);
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if (! ((Wrd45.uLng) == 10))
    goto label_43;
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd42.Obj) = ((Wrd41.pObj) [0]);
  (Wrd43.Lng) = (FIXNUM_TO_LONG (Wrd42.Obj));
  if (! (((unsigned long) 9L) < ((unsigned long) (Wrd43.Lng))))
    goto label_43;
  (Wrd37.Obj) = ((Wrd41.pObj) [10]);
  (* (--Rsp)) = (Wrd37.Obj);

DEFLABEL (label_42)
  (Wrd51.Obj) = (Rsp [0]);
  if ((Wrd51.Obj) == ((SCHEME_OBJECT) 0))
    goto label_40;
  (Wrd53.Obj) = (current_block [OBJECT_41_5]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_25]))));
  (* (--Rsp)) = (Wrd56.Obj);
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_26]))));
  (* (--Rsp)) = (Wrd59.Obj);
  (Wrd62.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_27]))));
  (* (--Rsp)) = (Wrd62.Obj);
  (Wrd63.Obj) = (Rsp [18]);
  (* (--Rsp)) = (Wrd63.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_28]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_41_27);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_39;
  (Wrd13.Obj) = (Rsp [3]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 26))
    goto label_38;
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  (Wrd15.Lng) = ((Wrd17.Lng) - 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd15.Lng)))
    goto label_38;
  (Wrd8.Obj) = (LONG_TO_FIXNUM (Wrd15.Lng));

DEFLABEL (label_37)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd8.Obj);

DEFLABEL (label_36)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_33]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_41_25);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_31]));

DEFLABEL (label_38)
  (Wrd9.Obj) = (Rsp [3]);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_32]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_INTERFACE_0 (34);

DEFLABEL (label_32)
  (Wrd8.Obj) = Rvl;
  goto label_37;

DEFLABEL (label_39)
  (Wrd19.Obj) = (Rsp [3]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd19.Obj);
  goto label_36;

DEFLABEL (label_40)
  (Wrd65.Obj) = (current_block [OBJECT_41_10]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_41)
  (Rsp [12]) = (Wrd65.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_24]));

DEFLABEL (label_43)
  (Wrd46.Obj) = (Rsp [13]);
  (Wrd47.Obj) = (current_block [OBJECT_41_11]);
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_23]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd46.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 2);

DEFLABEL (label_31)
  (* (--Rsp)) = Rvl;
  goto label_42;

DEFLABEL (label_46)
  (Wrd19.Obj) = (Rsp [12]);
  (Wrd20.Obj) = (current_block [OBJECT_41_9]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_22]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 2);

DEFLABEL (label_30)
  (* (--Rsp)) = Rvl;
  goto label_45;

DEFLABEL (label_48)
  (Wrd20.Obj) = (Rsp [11]);
  (Wrd21.Obj) = (current_block [OBJECT_41_8]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_19]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 2);

DEFLABEL (label_29)
  (* (--Rsp)) = Rvl;
  goto label_47;

DEFLABEL (label_50)
  (Wrd20.Obj) = (Rsp [9]);
  (Wrd21.Obj) = (current_block [OBJECT_41_7]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_16]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 2);

DEFLABEL (label_28)
  (* (--Rsp)) = Rvl;
  goto label_49;

DEFLABEL (label_52)
  (Wrd20.Obj) = (Rsp [7]);
  (Wrd21.Obj) = (current_block [OBJECT_41_6]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_13]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 2);

DEFLABEL (label_27)
  (* (--Rsp)) = Rvl;
  goto label_51;

DEFLABEL (label_54)
  (Wrd20.Obj) = (Rsp [5]);
  (Wrd21.Obj) = (current_block [OBJECT_41_4]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_11]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 2);

DEFLABEL (label_26)
  (* (--Rsp)) = Rvl;
  goto label_53;

DEFLABEL (label_56)
  (Wrd20.Obj) = (Rsp [3]);
  (Wrd21.Obj) = (current_block [OBJECT_41_3]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_9]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 2);

DEFLABEL (label_25)
  (* (--Rsp)) = Rvl;
  goto label_55;

DEFLABEL (label_58)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_41_0]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_6]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 2);

DEFLABEL (label_24)
  (* (--Rsp)) = Rvl;
  goto label_57;

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_41_26);
  (* (--Rsp)) = Rvl;
  goto label_36;

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_41_20);
  (Wrd65.Obj) = Rvl;
  goto label_41;

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_41_21);
  (* (--Rsp)) = Rvl;
  goto label_44;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_42_4 3
#define LABEL_42_7 5
#define LABEL_42_9 7
#define LABEL_42_10 9
#define LABEL_42_11 11
#define LABEL_42_12 13
#define LABEL_42_13 15
#define LABEL_42_14 17
#define LABEL_42_15 19
#define LABEL_42_16 21
#define LABEL_42_17 23
#define LABEL_42_18 25
#define LABEL_42_19 27
#define LABEL_42_20 29
#define LABEL_42_24 31
#define LABEL_42_25 33
#define LABEL_42_26 35
#define LABEL_42_27 37
#define LABEL_42_29 39
#define LABEL_42_5 41
#define LABEL_42_6 43
#define LABEL_42_31 45
#define LABEL_42_32 47
#define LABEL_42_36 49
#define LABEL_42_34 51
#define LABEL_42_35 53
#define LABEL_42_41 55
#define LABEL_42_28 57
#define LABEL_42_42 59
#define LABEL_42_21 61
#define LABEL_42_22 63
#define LABEL_42_38 65
#define LABEL_42_45 67
#define LABEL_42_39 69
#define LABEL_42_44 71
#define LABEL_42_48 73
#define LABEL_42_49 75
#define LABEL_42_50 77
#define LABEL_42_47 79
#define LABEL_42_51 81
#define LABEL_42_52 83
#define LABEL_42_53 85
#define LABEL_42_54 87
#define LABEL_42_55 89
#define LABEL_42_56 91
#define LABEL_42_57 93
#define LABEL_42_58 95
#define LABEL_42_59 97
#define LABEL_42_61 99
#define LABEL_42_62 101
#define ENVIRONMENT_LABEL_42_3 149
#define DEBUGGING_LABEL_42_2 148
#define OBJECT_42_17 147
#define OBJECT_42_16 146
#define OBJECT_42_15 145
#define OBJECT_42_14 144
#define OBJECT_42_13 143
#define OBJECT_42_12 142
#define OBJECT_42_11 141
#define OBJECT_42_10 140
#define OBJECT_42_9 139
#define OBJECT_42_8 138
#define OBJECT_42_7 137
#define OBJECT_42_6 136
#define OBJECT_42_5 135
#define OBJECT_42_4 134
#define OBJECT_42_3 133
#define OBJECT_42_2 132
#define OBJECT_42_1 131
#define OBJECT_42_0 130
#define EXECUTE_CACHE_42_65 103
#define EXECUTE_CACHE_42_64 105
#define EXECUTE_CACHE_42_63 107
#define EXECUTE_CACHE_42_60 109
#define EXECUTE_CACHE_42_46 111
#define EXECUTE_CACHE_42_43 113
#define EXECUTE_CACHE_42_40 115
#define EXECUTE_CACHE_42_37 117
#define EXECUTE_CACHE_42_33 119
#define EXECUTE_CACHE_42_30 121
#define EXECUTE_CACHE_42_23 123
#define EXECUTE_CACHE_42_8 125
#define FREE_REFERENCE_42_1 128
#define FREE_REFERENCE_42_0 129
#define FREE_REFERENCES_LABEL_42_0 102
#define NUMBER_OF_LINKER_SECTIONS_42_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_42 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd32;
  machine_word Wrd29;
  machine_word Wrd52;
  machine_word Wrd53;
  machine_word Wrd43;
  machine_word Wrd37;
  machine_word Wrd38;
  machine_word Wrd23;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd19;
  machine_word Wrd8;
  machine_word Wrd14;
  machine_word Wrd9;
  machine_word Wrd83;
  machine_word Wrd77;
  machine_word Wrd76;
  machine_word Wrd79;
  machine_word Wrd78;
  machine_word Wrd74;
  machine_word Wrd73;
  machine_word Wrd72;
  machine_word Wrd69;
  machine_word Wrd65;
  machine_word Wrd62;
  machine_word Wrd51;
  machine_word Wrd54;
  machine_word Wrd59;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd60;
  machine_word Wrd50;
  machine_word Wrd42;
  machine_word Wrd44;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd39;
  machine_word Wrd31;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd35;
  machine_word Wrd30;
  machine_word Wrd22;
  machine_word Wrd24;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd85;
  machine_word Wrd95;
  machine_word Wrd94;
  machine_word Wrd93;
  machine_word Wrd90;
  machine_word Wrd88;
  machine_word Wrd99;
  machine_word Wrd101;
  machine_word Wrd103;
  machine_word Wrd102;
  machine_word Wrd199;
  machine_word Wrd201;
  machine_word Wrd197;
  machine_word Wrd196;
  machine_word Wrd188;
  machine_word Wrd190;
  machine_word Wrd192;
  machine_word Wrd191;
  machine_word Wrd187;
  machine_word Wrd186;
  machine_word Wrd184;
  machine_word Wrd183;
  machine_word Wrd177;
  machine_word Wrd178;
  machine_word Wrd179;
  machine_word Wrd176;
  machine_word Wrd168;
  machine_word Wrd170;
  machine_word Wrd172;
  machine_word Wrd171;
  machine_word Wrd167;
  machine_word Wrd166;
  machine_word Wrd164;
  machine_word Wrd163;
  machine_word Wrd157;
  machine_word Wrd158;
  machine_word Wrd159;
  machine_word Wrd156;
  machine_word Wrd150;
  machine_word Wrd151;
  machine_word Wrd152;
  machine_word Wrd149;
  machine_word Wrd141;
  machine_word Wrd143;
  machine_word Wrd145;
  machine_word Wrd144;
  machine_word Wrd140;
  machine_word Wrd139;
  machine_word Wrd137;
  machine_word Wrd136;
  machine_word Wrd128;
  machine_word Wrd130;
  machine_word Wrd132;
  machine_word Wrd131;
  machine_word Wrd126;
  machine_word Wrd125;
  machine_word Wrd127;
  machine_word Wrd123;
  machine_word Wrd117;
  machine_word Wrd118;
  machine_word Wrd119;
  machine_word Wrd116;
  machine_word Wrd108;
  machine_word Wrd110;
  machine_word Wrd112;
  machine_word Wrd111;
  machine_word Wrd18;
  machine_word Wrd12;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_42_4);
      goto string__decoded_time_64;

    case 1:
      current_block = (Rpc - LABEL_42_7);
      goto label_66;

    case 2:
      current_block = (Rpc - LABEL_42_9);
      goto continuation_18;

    case 3:
      current_block = (Rpc - LABEL_42_10);
      goto label_74;

    case 4:
      current_block = (Rpc - LABEL_42_11);
      goto label_75;

    case 5:
      current_block = (Rpc - LABEL_42_12);
      goto label_76;

    case 6:
      current_block = (Rpc - LABEL_42_13);
      goto label_77;

    case 7:
      current_block = (Rpc - LABEL_42_14);
      goto label_78;

    case 8:
      current_block = (Rpc - LABEL_42_15);
      goto label_79;

    case 9:
      current_block = (Rpc - LABEL_42_16);
      goto label_80;

    case 10:
      current_block = (Rpc - LABEL_42_17);
      goto label_81;

    case 11:
      current_block = (Rpc - LABEL_42_18);
      goto label_82;

    case 12:
      current_block = (Rpc - LABEL_42_19);
      goto continuation_15;

    case 13:
      current_block = (Rpc - LABEL_42_20);
      goto continuation_3;

    case 14:
      current_block = (Rpc - LABEL_42_24);
      goto label_67;

    case 15:
      current_block = (Rpc - LABEL_42_25);
      goto label_68;

    case 16:
      current_block = (Rpc - LABEL_42_26);
      goto label_69;

    case 17:
      current_block = (Rpc - LABEL_42_27);
      goto label_70;

    case 18:
      current_block = (Rpc - LABEL_42_29);
      goto label_71;

    case 19:
      current_block = (Rpc - LABEL_42_5);
      goto continuation_2;

    case 20:
      current_block = (Rpc - LABEL_42_6);
      goto continuation_1;

    case 21:
      current_block = (Rpc - LABEL_42_31);
      goto continuation_37;

    case 22:
      current_block = (Rpc - LABEL_42_32);
      goto continuation_36;

    case 23:
      current_block = (Rpc - LABEL_42_36);
      goto continuation_40;

    case 24:
      current_block = (Rpc - LABEL_42_34);
      goto continuation_39;

    case 25:
      current_block = (Rpc - LABEL_42_35);
      goto continuation_38;

    case 26:
      current_block = (Rpc - LABEL_42_41);
      goto lambda_0;

    case 27:
      current_block = (Rpc - LABEL_42_28);
      goto continuation_14;

    case 28:
      current_block = (Rpc - LABEL_42_42);
      goto label_72;

    case 29:
      current_block = (Rpc - LABEL_42_21);
      goto continuation_17;

    case 30:
      current_block = (Rpc - LABEL_42_22);
      goto continuation_16;

    case 31:
      current_block = (Rpc - LABEL_42_38);
      goto continuation_54;

    case 32:
      current_block = (Rpc - LABEL_42_45);
      goto label_73;

    case 33:
      current_block = (Rpc - LABEL_42_39);
      goto continuation_53;

    case 34:
      current_block = (Rpc - LABEL_42_44);
      goto continuation_52;

    case 35:
      current_block = (Rpc - LABEL_42_48);
      goto label_83;

    case 36:
      current_block = (Rpc - LABEL_42_49);
      goto label_84;

    case 37:
      current_block = (Rpc - LABEL_42_50);
      goto continuation_44;

    case 38:
      current_block = (Rpc - LABEL_42_47);
      goto continuation_50;

    case 39:
      current_block = (Rpc - LABEL_42_51);
      goto label_85;

    case 40:
      current_block = (Rpc - LABEL_42_52);
      goto label_86;

    case 41:
      current_block = (Rpc - LABEL_42_53);
      goto label_87;

    case 42:
      current_block = (Rpc - LABEL_42_54);
      goto label_88;

    case 43:
      current_block = (Rpc - LABEL_42_55);
      goto label_89;

    case 44:
      current_block = (Rpc - LABEL_42_56);
      goto continuation_56;

    case 45:
      current_block = (Rpc - LABEL_42_57);
      goto continuation_55;

    case 46:
      current_block = (Rpc - LABEL_42_58);
      goto continuation_60;

    case 47:
      current_block = (Rpc - LABEL_42_59);
      goto continuation_59;

    case 48:
      current_block = (Rpc - LABEL_42_61);
      goto continuation_58;

    case 49:
      current_block = (Rpc - LABEL_42_62);
      goto continuation_57;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (string__decoded_time_91)
DEFLABEL (string__decoded_time_64)
  INTERRUPT_CHECK (26, LABEL_42_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_42_0]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_42_0]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_150;
  Wrd12 = Wrd16;

DEFLABEL (label_149)
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd18.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_42_6);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_20]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_33]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_42_20);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == (current_block [OBJECT_42_5])))
    goto label_134;
  (Wrd88.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_21]))));
  (* (--Rsp)) = (Wrd88.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd90.Obj) = (current_block [OBJECT_42_6]);
  (* (--Rsp)) = (Wrd90.Obj);
  (Wrd93.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_22]))));
  (* (--Rsp)) = (Wrd93.Obj);
  (Wrd94.Obj) = (current_block [OBJECT_42_7]);
  (* (--Rsp)) = (Wrd94.Obj);
  (Wrd95.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd95.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_23]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_42_22);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_8]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_42_21);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_9]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_33]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_42_9);
  if (Rvl == (current_block [OBJECT_42_1]))
    goto label_94;

DEFLABEL (label_93)
  Rsp = (& (Rsp [2]));
  goto lambda_0;

DEFLABEL (label_94)
  (Wrd111.Obj) = (Rsp [0]);
  (Wrd112.uLng) = (OBJECT_TYPE (Wrd111.Obj));
  if (! ((Wrd112.uLng) == 1))
    goto label_133;
  (Wrd110.pObj) = (OBJECT_ADDRESS (Wrd111.Obj));
  (Wrd108.Obj) = ((Wrd110.pObj) [1]);

DEFLABEL (label_132)
  (Wrd119.uLng) = (OBJECT_TYPE (Wrd108.Obj));
  if (! ((Wrd119.uLng) == 1))
    goto label_131;
  (Wrd118.pObj) = (OBJECT_ADDRESS (Wrd108.Obj));
  (Wrd117.Obj) = ((Wrd118.pObj) [0]);

DEFLABEL (label_130)
  (Wrd127.Obj) = (current_block [OBJECT_42_4]);
  (* (Rhp++)) = (Wrd117.Obj);
  (* (Rhp++)) = (Wrd127.Obj);
  (Wrd125.pObj) = (& (Rhp [-2]));
  (Wrd126.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd125.pObj)));
  (* (--Rsp)) = (Wrd126.Obj);
  (Wrd131.Obj) = (Rsp [1]);
  (Wrd132.uLng) = (OBJECT_TYPE (Wrd131.Obj));
  if (! ((Wrd132.uLng) == 1))
    goto label_129;
  (Wrd130.pObj) = (OBJECT_ADDRESS (Wrd131.Obj));
  (Wrd128.Obj) = ((Wrd130.pObj) [0]);

DEFLABEL (label_128)
  (Wrd137.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd128.Obj);
  (* (Rhp++)) = (Wrd137.Obj);
  (Wrd139.pObj) = (& (Rhp [-2]));
  (Wrd140.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd139.pObj)));
  (* (--Rsp)) = (Wrd140.Obj);
  (Wrd144.Obj) = (Rsp [2]);
  (Wrd145.uLng) = (OBJECT_TYPE (Wrd144.Obj));
  if (! ((Wrd145.uLng) == 1))
    goto label_127;
  (Wrd143.pObj) = (OBJECT_ADDRESS (Wrd144.Obj));
  (Wrd141.Obj) = ((Wrd143.pObj) [1]);

DEFLABEL (label_126)
  (Wrd152.uLng) = (OBJECT_TYPE (Wrd141.Obj));
  if (! ((Wrd152.uLng) == 1))
    goto label_125;
  (Wrd151.pObj) = (OBJECT_ADDRESS (Wrd141.Obj));
  (Wrd150.Obj) = ((Wrd151.pObj) [1]);

DEFLABEL (label_124)
  (Wrd159.uLng) = (OBJECT_TYPE (Wrd150.Obj));
  if (! ((Wrd159.uLng) == 1))
    goto label_123;
  (Wrd158.pObj) = (OBJECT_ADDRESS (Wrd150.Obj));
  (Wrd157.Obj) = ((Wrd158.pObj) [0]);

DEFLABEL (label_122)
  (Wrd164.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd157.Obj);
  (* (Rhp++)) = (Wrd164.Obj);
  (Wrd166.pObj) = (& (Rhp [-2]));
  (Wrd167.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd166.pObj)));
  (* (--Rsp)) = (Wrd167.Obj);
  (Wrd171.Obj) = (Rsp [2]);
  (Wrd172.uLng) = (OBJECT_TYPE (Wrd171.Obj));
  if (! ((Wrd172.uLng) == 1))
    goto label_121;
  (Wrd170.pObj) = (OBJECT_ADDRESS (Wrd171.Obj));
  (Wrd168.Obj) = ((Wrd170.pObj) [1]);

DEFLABEL (label_120)
  (Wrd179.uLng) = (OBJECT_TYPE (Wrd168.Obj));
  if (! ((Wrd179.uLng) == 1))
    goto label_119;
  (Wrd178.pObj) = (OBJECT_ADDRESS (Wrd168.Obj));
  (Wrd177.Obj) = ((Wrd178.pObj) [0]);

DEFLABEL (label_118)
  (Wrd184.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd177.Obj);
  (* (Rhp++)) = (Wrd184.Obj);
  (Wrd186.pObj) = (& (Rhp [-2]));
  (Wrd187.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd186.pObj)));
  (* (--Rsp)) = (Wrd187.Obj);
  (Wrd191.Obj) = (Rsp [2]);
  (Wrd192.uLng) = (OBJECT_TYPE (Wrd191.Obj));
  if (! ((Wrd192.uLng) == 1))
    goto label_117;
  (Wrd190.pObj) = (OBJECT_ADDRESS (Wrd191.Obj));
  (Wrd188.Obj) = ((Wrd190.pObj) [0]);

DEFLABEL (label_116)
  (Wrd197.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd188.Obj);
  (* (Rhp++)) = (Wrd197.Obj);
  (Wrd201.pObj) = (& (Rhp [-2]));
  (Wrd199.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd201.pObj)));
  Rsp = (& (Rsp [3]));
  (* (--Rsp)) = (Wrd199.Obj);

DEFLABEL (label_115)
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_31]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd9.Obj) = (current_block [OBJECT_42_14]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_32]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_42_7]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_23]));

DEFLABEL (continuation_36)
  INTERRUPT_CHECK (27, LABEL_42_32);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_8]));

DEFLABEL (continuation_37)
  INTERRUPT_CHECK (27, LABEL_42_31);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_34]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_42_15]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_35]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_33]));

DEFLABEL (continuation_38)
  INTERRUPT_CHECK (27, LABEL_42_35);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_40]));

DEFLABEL (continuation_39)
  INTERRUPT_CHECK (27, LABEL_42_34);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_114;

DEFLABEL (label_113)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_38]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_39]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_42_13]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_23]));

DEFLABEL (continuation_53)
  INTERRUPT_CHECK (27, LABEL_42_39);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_46]));

DEFLABEL (continuation_54)
  INTERRUPT_CHECK (27, LABEL_42_38);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_44]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_112;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [0]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_111)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_46]));

DEFLABEL (continuation_52)
  INTERRUPT_CHECK (27, LABEL_42_44);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_47]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_110;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd8.Obj) = ((Wrd10.pObj) [1]);

DEFLABEL (label_109)
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd19.uLng) == 1))
    goto label_108;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_107)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_46]));

DEFLABEL (continuation_50)
  INTERRUPT_CHECK (27, LABEL_42_47);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_50]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_106;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd8.Obj) = ((Wrd10.pObj) [1]);

DEFLABEL (label_105)
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd19.uLng) == 1))
    goto label_104;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd17.Obj) = ((Wrd18.pObj) [1]);

DEFLABEL (label_103)
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd24.uLng) == 1)
    goto label_96;
  (Wrd26.Obj) = (current_block [OBJECT_42_13]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_95)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_56]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_57]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (Wrd33.Obj) = (current_block [OBJECT_42_17]);
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd34.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_23]));

DEFLABEL (continuation_55)
  INTERRUPT_CHECK (27, LABEL_42_57);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_60]));

DEFLABEL (continuation_56)
  INTERRUPT_CHECK (27, LABEL_42_56);
  (Rsp [4]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_58]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_59]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_42_5]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_23]));

DEFLABEL (continuation_59)
  INTERRUPT_CHECK (27, LABEL_42_59);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_63]));

DEFLABEL (continuation_60)
  INTERRUPT_CHECK (27, LABEL_42_58);
  (Rsp [6]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_61]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_62]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_42_1]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_23]));

DEFLABEL (continuation_57)
  INTERRUPT_CHECK (27, LABEL_42_62);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_65]));

DEFLABEL (continuation_58)
  INTERRUPT_CHECK (27, LABEL_42_61);
  (Rsp [5]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_64]));

DEFLABEL (label_96)
  (Wrd38.Obj) = (Rsp [4]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if (! ((Wrd39.uLng) == 1))
    goto label_102;
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd35.Obj) = ((Wrd37.pObj) [1]);

DEFLABEL (label_101)
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd46.uLng) == 1))
    goto label_100;
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd44.Obj) = ((Wrd45.pObj) [1]);

DEFLABEL (label_99)
  (Wrd53.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if (! ((Wrd53.uLng) == 1))
    goto label_98;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd52.Obj) = ((Wrd51.pObj) [0]);
  (* (--Rsp)) = (Wrd52.Obj);

DEFLABEL (label_97)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_46]));

DEFLABEL (continuation_44)
  INTERRUPT_CHECK (27, LABEL_42_50);
  (* (--Rsp)) = Rvl;
  goto label_95;

DEFLABEL (label_98)
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_55]))));
  (* (--Rsp)) = (Wrd57.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_3]), 1);

DEFLABEL (label_89)
  (* (--Rsp)) = Rvl;
  goto label_97;

DEFLABEL (label_100)
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_54]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_2]), 1);

DEFLABEL (label_88)
  (Wrd44.Obj) = Rvl;
  goto label_99;

DEFLABEL (label_102)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_53]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_2]), 1);

DEFLABEL (label_87)
  (Wrd35.Obj) = Rvl;
  goto label_101;

DEFLABEL (label_104)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_52]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_2]), 1);

DEFLABEL (label_86)
  (Wrd17.Obj) = Rvl;
  goto label_103;

DEFLABEL (label_106)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_51]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_2]), 1);

DEFLABEL (label_85)
  (Wrd8.Obj) = Rvl;
  goto label_105;

DEFLABEL (label_108)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_49]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_3]), 1);

DEFLABEL (label_84)
  (* (--Rsp)) = Rvl;
  goto label_107;

DEFLABEL (label_110)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_48]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_2]), 1);

DEFLABEL (label_83)
  (Wrd8.Obj) = Rvl;
  goto label_109;

DEFLABEL (label_112)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_45]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_3]), 1);

DEFLABEL (label_73)
  (* (--Rsp)) = Rvl;
  goto label_111;

DEFLABEL (label_114)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_36]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (current_block [OBJECT_42_16]);
  (* (--Rsp)) = (Wrd19.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_37]));

DEFLABEL (continuation_40)
  INTERRUPT_CHECK (27, LABEL_42_36);
  goto label_113;

DEFLABEL (label_117)
  (Wrd196.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_18]))));
  (* (--Rsp)) = (Wrd196.Obj);
  (* (--Rsp)) = (Wrd191.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_3]), 1);

DEFLABEL (label_82)
  (Wrd188.Obj) = Rvl;
  goto label_116;

DEFLABEL (label_119)
  (Wrd183.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_17]))));
  (* (--Rsp)) = (Wrd183.Obj);
  (* (--Rsp)) = (Wrd168.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_3]), 1);

DEFLABEL (label_81)
  (Wrd177.Obj) = Rvl;
  goto label_118;

DEFLABEL (label_121)
  (Wrd176.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_16]))));
  (* (--Rsp)) = (Wrd176.Obj);
  (* (--Rsp)) = (Wrd171.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_2]), 1);

DEFLABEL (label_80)
  (Wrd168.Obj) = Rvl;
  goto label_120;

DEFLABEL (label_123)
  (Wrd163.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_15]))));
  (* (--Rsp)) = (Wrd163.Obj);
  (* (--Rsp)) = (Wrd150.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_3]), 1);

DEFLABEL (label_79)
  (Wrd157.Obj) = Rvl;
  goto label_122;

DEFLABEL (label_125)
  (Wrd156.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_14]))));
  (* (--Rsp)) = (Wrd156.Obj);
  (* (--Rsp)) = (Wrd141.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_2]), 1);

DEFLABEL (label_78)
  (Wrd150.Obj) = Rvl;
  goto label_124;

DEFLABEL (label_127)
  (Wrd149.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_13]))));
  (* (--Rsp)) = (Wrd149.Obj);
  (* (--Rsp)) = (Wrd144.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_2]), 1);

DEFLABEL (label_77)
  (Wrd141.Obj) = Rvl;
  goto label_126;

DEFLABEL (label_129)
  (Wrd136.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_12]))));
  (* (--Rsp)) = (Wrd136.Obj);
  (* (--Rsp)) = (Wrd131.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_3]), 1);

DEFLABEL (label_76)
  (Wrd128.Obj) = Rvl;
  goto label_128;

DEFLABEL (label_131)
  (Wrd123.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_11]))));
  (* (--Rsp)) = (Wrd123.Obj);
  (* (--Rsp)) = (Wrd108.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_3]), 1);

DEFLABEL (label_75)
  (Wrd117.Obj) = Rvl;
  goto label_130;

DEFLABEL (label_133)
  (Wrd116.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_10]))));
  (* (--Rsp)) = (Wrd116.Obj);
  (* (--Rsp)) = (Wrd111.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_2]), 1);

DEFLABEL (label_74)
  (Wrd108.Obj) = Rvl;
  goto label_132;

DEFLABEL (label_134)
  if (Rvl == (current_block [OBJECT_42_8]))
    goto label_148;
  if (! (Rvl == (current_block [OBJECT_42_9])))
    goto label_93;
  (Wrd25.Obj) = (Rsp [1]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 1))
    goto label_147;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd22.Obj) = ((Wrd24.pObj) [0]);

DEFLABEL (label_146)
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd35.uLng) == 30))
    goto label_145;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [1]);
  (Wrd31.Obj) = (MAKE_OBJECT (26, (Wrd34.uLng)));

DEFLABEL (label_144)
  if (! ((Wrd31.Obj) == (current_block [OBJECT_42_5])))
    goto label_93;
  (Wrd45.Obj) = (Rsp [1]);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd45.Obj));
  if (! ((Wrd46.uLng) == 1))
    goto label_143;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd42.Obj) = ((Wrd44.pObj) [0]);

DEFLABEL (label_142)
  (Wrd60.uLng) = (OBJECT_TYPE (Wrd42.Obj));
  if (! ((Wrd60.uLng) == 30))
    goto label_141;
  (Wrd57.pObj) = (OBJECT_ADDRESS (Wrd42.Obj));
  (Wrd58.Obj) = ((Wrd57.pObj) [1]);
  (Wrd59.Lng) = (FIXNUM_TO_LONG (Wrd58.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd59.Lng))))
    goto label_141;
  (Wrd54.uLng) = ((unsigned long) (((unsigned char *) (Wrd57.pChr)) [(3 + (ADDRESS_UNITS_PER_OBJECT * 2))]));
  (Wrd51.Obj) = (MAKE_OBJECT (2, (Wrd54.uLng)));

DEFLABEL (label_140)
  if (! ((Wrd51.Obj) == (current_block [OBJECT_42_12])))
    goto label_93;
  (Wrd69.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_19]))));
  (* (--Rsp)) = (Wrd69.Obj);
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_28]))));
  (* (--Rsp)) = (Wrd72.Obj);
  (Wrd73.Obj) = (current_block [OBJECT_42_7]);
  (* (--Rsp)) = (Wrd73.Obj);
  (Wrd74.Obj) = (current_block [OBJECT_42_13]);
  (* (--Rsp)) = (Wrd74.Obj);
  (Wrd78.Obj) = (Rsp [5]);
  (Wrd79.uLng) = (OBJECT_TYPE (Wrd78.Obj));
  if (! ((Wrd79.uLng) == 1))
    goto label_139;
  (Wrd76.pObj) = (OBJECT_ADDRESS (Wrd78.Obj));
  (Wrd77.Obj) = ((Wrd76.pObj) [0]);
  (* (--Rsp)) = (Wrd77.Obj);

DEFLABEL (label_138)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_30]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_42_28);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_42_1]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_137;
  Wrd5 = Wrd9;

DEFLABEL (label_136)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_43]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_42_19);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_93;
  Rsp = (& (Rsp [1]));
  (Wrd102.Obj) = (Rsp [0]);
  (Wrd103.uLng) = (OBJECT_TYPE (Wrd102.Obj));
  if ((Wrd103.uLng) == 1)
    goto label_135;
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_2]), 1);

DEFLABEL (label_135)
  (Wrd101.pObj) = (OBJECT_ADDRESS (Wrd102.Obj));
  (Wrd99.Obj) = ((Wrd101.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd99.Obj);
  goto label_115;

DEFLABEL (label_137)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_42_42])), (Wrd6.pObj));

DEFLABEL (label_72)
  (Wrd5.Obj) = Rvl;
  goto label_136;

DEFLABEL (label_139)
  (Wrd83.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_29]))));
  (* (--Rsp)) = (Wrd83.Obj);
  (* (--Rsp)) = (Wrd78.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_3]), 1);

DEFLABEL (label_71)
  (* (--Rsp)) = Rvl;
  goto label_138;

DEFLABEL (label_141)
  (Wrd62.Obj) = (current_block [OBJECT_42_7]);
  (Wrd65.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_27]))));
  (* (--Rsp)) = (Wrd65.Obj);
  (* (--Rsp)) = (Wrd62.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_11]), 2);

DEFLABEL (label_70)
  (Wrd51.Obj) = Rvl;
  goto label_140;

DEFLABEL (label_143)
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_26]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_3]), 1);

DEFLABEL (label_69)
  (Wrd42.Obj) = Rvl;
  goto label_142;

DEFLABEL (label_145)
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_25]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_10]), 1);

DEFLABEL (label_68)
  (Wrd31.Obj) = Rvl;
  goto label_144;

DEFLABEL (label_147)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_24]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_3]), 1);

DEFLABEL (label_67)
  (Wrd22.Obj) = Rvl;
  goto label_146;

DEFLABEL (label_148)
  (Wrd85.Obj) = (Rsp [1]);
  Rsp = (& (Rsp [3]));
  (* (--Rsp)) = (Wrd85.Obj);
  goto label_115;

DEFLABEL (label_150)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_42_7])), (Wrd13.pObj));

DEFLABEL (label_66)
  (Wrd12.Obj) = Rvl;
  goto label_149;

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_42_5);
  (* (--Rsp)) = Rvl;
  goto label_115;

DEFLABEL (lambda_92)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_42_41);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_42_16]);
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_37]));

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_43_4 3
#define LABEL_43_5 5
#define ENVIRONMENT_LABEL_43_3 12
#define DEBUGGING_LABEL_43_2 11
#define EXECUTE_CACHE_43_7 7
#define EXECUTE_CACHE_43_6 9
#define FREE_REFERENCES_LABEL_43_0 6
#define NUMBER_OF_LINKER_SECTIONS_43_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_43 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_43_4);
      goto string__universal_time_1;

    case 1:
      current_block = (Rpc - LABEL_43_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (string__universal_time_4)
DEFLABEL (string__universal_time_1)
  INTERRUPT_CHECK (26, LABEL_43_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_43_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_44_4 3
#define LABEL_44_5 5
#define ENVIRONMENT_LABEL_44_3 12
#define DEBUGGING_LABEL_44_2 11
#define EXECUTE_CACHE_44_7 7
#define EXECUTE_CACHE_44_6 9
#define FREE_REFERENCES_LABEL_44_0 6
#define NUMBER_OF_LINKER_SECTIONS_44_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_44 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_44_4);
      goto string__file_time_1;

    case 1:
      current_block = (Rpc - LABEL_44_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (string__file_time_4)
DEFLABEL (string__file_time_1)
  INTERRUPT_CHECK (26, LABEL_44_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_44_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_44_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_44_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_45_4 3
#define LABEL_45_7 5
#define LABEL_45_5 7
#define LABEL_45_10 9
#define LABEL_45_11 11
#define LABEL_45_9 13
#define LABEL_45_13 15
#define LABEL_45_16 17
#define LABEL_45_18 19
#define LABEL_45_14 21
#define LABEL_45_17 23
#define LABEL_45_22 25
#define LABEL_45_21 27
#define ENVIRONMENT_LABEL_45_3 52
#define DEBUGGING_LABEL_45_2 51
#define OBJECT_45_7 50
#define OBJECT_45_6 49
#define OBJECT_45_5 48
#define OBJECT_45_4 47
#define OBJECT_45_3 46
#define OBJECT_45_2 45
#define OBJECT_45_1 44
#define OBJECT_45_0 43
#define EXECUTE_CACHE_45_23 29
#define EXECUTE_CACHE_45_20 31
#define EXECUTE_CACHE_45_19 33
#define EXECUTE_CACHE_45_15 35
#define EXECUTE_CACHE_45_12 37
#define EXECUTE_CACHE_45_8 39
#define EXECUTE_CACHE_45_6 41
#define FREE_REFERENCES_LABEL_45_0 28
#define NUMBER_OF_LINKER_SECTIONS_45_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_45 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd24;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd25;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd12;
  machine_word Wrd27;
  machine_word Wrd23;
  machine_word Wrd33;
  machine_word Wrd29;
  machine_word Wrd32;
  machine_word Wrd28;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd15;
  machine_word Wrd18;
  machine_word Wrd22;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd9;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_45_4);
      goto time_zone__string_15;

    case 1:
      current_block = (Rpc - LABEL_45_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_45_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_45_10);
      goto label_17;

    case 4:
      current_block = (Rpc - LABEL_45_11);
      goto label_18;

    case 5:
      current_block = (Rpc - LABEL_45_9);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_45_13);
      goto continuation_6;

    case 7:
      current_block = (Rpc - LABEL_45_16);
      goto label_19;

    case 8:
      current_block = (Rpc - LABEL_45_18);
      goto label_20;

    case 9:
      current_block = (Rpc - LABEL_45_14);
      goto continuation_5;

    case 10:
      current_block = (Rpc - LABEL_45_17);
      goto continuation_12;

    case 11:
      current_block = (Rpc - LABEL_45_22);
      goto label_21;

    case 12:
      current_block = (Rpc - LABEL_45_21);
      goto continuation_10;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (time_zone__string_23)
DEFLABEL (time_zone__string_15)
  INTERRUPT_CHECK (26, LABEL_45_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_45_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_37;
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_7]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd37.Obj) = (current_block [OBJECT_45_0]);
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd38.Obj) = (current_block [OBJECT_45_1]);
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd39.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd39.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_45_7);

DEFLABEL (label_37)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 26))
    goto label_36;
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  (Wrd18.Lng) = (0 - (Wrd22.Lng));
  if (! (LONG_TO_FIXNUM_P (Wrd18.Lng)))
    goto label_36;
  (Wrd15.Obj) = (LONG_TO_FIXNUM (Wrd18.Lng));

DEFLABEL (label_35)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd28.uLng) == 26))
    goto label_34;
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (multiply_with_overflow ((Wrd32.Lng), 60, (& (Wrd29.Lng))))
    goto label_34;
  (Wrd33.Obj) = (LONG_TO_FIXNUM (Wrd29.Lng));
  (* (--Rsp)) = (Wrd33.Obj);

DEFLABEL (label_33)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_12]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_45_9);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_13]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_45_3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_14]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_15]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_45_14);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_20]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_45_13);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd6.uLng) == 26))
    goto label_32;
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  if ((Wrd27.Lng) < 0)
    goto label_25;

DEFLABEL (label_26)
  (Wrd12.Obj) = (current_block [OBJECT_45_4]);
  (* (--Rsp)) = (Wrd12.Obj);
  goto label_24;

DEFLABEL (label_25)
  (Wrd25.Obj) = (current_block [OBJECT_45_5]);
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_24)
DEFLABEL (label_31)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_17]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_30;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [1]);
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_29)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_19]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_45_17);
  (Rsp [2]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_21]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (Rsp [2]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_28;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [0]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_27)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_19]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_45_21);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_23]));

DEFLABEL (label_28)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_22]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_45_7]), 1);

DEFLABEL (label_21)
  (* (--Rsp)) = Rvl;
  goto label_27;

DEFLABEL (label_30)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_18]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_45_6]), 1);

DEFLABEL (label_20)
  (* (--Rsp)) = Rvl;
  goto label_29;

DEFLABEL (label_32)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_16]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_INTERFACE_0 (42);

DEFLABEL (label_19)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_26;
  goto label_25;

DEFLABEL (label_34)
  (Wrd23.Obj) = (current_block [OBJECT_45_3]);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_11]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_INTERFACE_0 (41);

DEFLABEL (label_18)
  (* (--Rsp)) = Rvl;
  goto label_33;

DEFLABEL (label_36)
  (Wrd10.Obj) = (current_block [OBJECT_45_2]);
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_10]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_INTERFACE_0 (40);

DEFLABEL (label_17)
  (Wrd15.Obj) = Rvl;
  goto label_35;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_46_4 3
#define LABEL_46_8 5
#define LABEL_46_5 7
#define LABEL_46_12 9
#define LABEL_46_6 11
#define TAG_46_7 4
#define LABEL_46_13 13
#define LABEL_46_15 15
#define LABEL_46_16 17
#define LABEL_46_20 19
#define LABEL_46_10 21
#define LABEL_46_21 23
#define LABEL_46_17 25
#define LABEL_46_24 27
#define LABEL_46_25 29
#define LABEL_46_18 31
#define LABEL_46_28 33
#define LABEL_46_26 35
#define LABEL_46_29 37
#define LABEL_46_30 39
#define LABEL_46_31 41
#define ENVIRONMENT_LABEL_46_3 74
#define DEBUGGING_LABEL_46_2 73
#define OBJECT_46_13 72
#define OBJECT_46_12 71
#define OBJECT_46_11 70
#define OBJECT_46_10 69
#define OBJECT_46_9 68
#define OBJECT_46_8 67
#define OBJECT_46_7 66
#define OBJECT_46_6 65
#define OBJECT_46_5 64
#define OBJECT_46_4 63
#define OBJECT_46_3 62
#define OBJECT_46_2 61
#define OBJECT_46_1 60
#define OBJECT_46_0 59
#define EXECUTE_CACHE_46_27 43
#define EXECUTE_CACHE_46_23 45
#define EXECUTE_CACHE_46_22 47
#define EXECUTE_CACHE_46_19 49
#define EXECUTE_CACHE_46_14 51
#define EXECUTE_CACHE_46_11 53
#define EXECUTE_CACHE_46_9 55
#define FREE_REFERENCE_46_0 58
#define FREE_REFERENCES_LABEL_46_0 42
#define NUMBER_OF_LINKER_SECTIONS_46_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_46 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd31;
  machine_word Wrd27;
  machine_word Wrd22;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd19;
  machine_word Wrd24;
  machine_word Wrd14;
  machine_word Wrd46;
  machine_word Wrd41;
  machine_word Wrd38;
  machine_word Wrd57;
  machine_word Wrd56;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd18;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd15;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd12;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_46_4);
      goto string__time_zone_24;

    case 1:
      current_block = (Rpc - LABEL_46_8);
      goto label_26;

    case 2:
      current_block = (Rpc - LABEL_46_5);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_46_12);
      goto label_27;

    case 4:
      current_block = (Rpc - LABEL_46_6);
      goto lambda_36;

    case 5:
      current_block = (Rpc - LABEL_46_13);
      goto label_28;

    case 6:
      current_block = (Rpc - LABEL_46_15);
      goto continuation_7;

    case 7:
      current_block = (Rpc - LABEL_46_16);
      goto continuation_8;

    case 8:
      current_block = (Rpc - LABEL_46_20);
      goto continuation_4;

    case 9:
      current_block = (Rpc - LABEL_46_10);
      goto continuation_3;

    case 10:
      current_block = (Rpc - LABEL_46_21);
      goto label_29;

    case 11:
      current_block = (Rpc - LABEL_46_17);
      goto continuation_10;

    case 12:
      current_block = (Rpc - LABEL_46_24);
      goto label_30;

    case 13:
      current_block = (Rpc - LABEL_46_25);
      goto label_31;

    case 14:
      current_block = (Rpc - LABEL_46_18);
      goto continuation_9;

    case 15:
      current_block = (Rpc - LABEL_46_28);
      goto continuation_14;

    case 16:
      current_block = (Rpc - LABEL_46_26);
      goto continuation_13;

    case 17:
      current_block = (Rpc - LABEL_46_29);
      goto continuation_15;

    case 18:
      current_block = (Rpc - LABEL_46_30);
      goto label_32;

    case 19:
      current_block = (Rpc - LABEL_46_31);
      goto label_33;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (string__time_zone_35)
DEFLABEL (string__time_zone_24)
  INTERRUPT_CHECK (26, LABEL_46_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_46_7);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_46_6])));
  Rhp += 1;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd10 = Wrd9;
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_46_0]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_65;
  Wrd12 = Wrd16;

DEFLABEL (label_64)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_46_5);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_60;
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_10]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_46_10);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_20]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd38.Obj) = (current_block [OBJECT_46_3]);
  (Wrd41.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 26L) < ((unsigned long) (Wrd41.Lng))))
    goto label_59;
  (Wrd11.uLng) = (OBJECT_DATUM (Wrd38.Obj));
  (Wrd13.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd11.Obj) == (Wrd13.Obj))
    goto label_58;

DEFLABEL (label_57)
  (Wrd14.Obj) = (current_block [OBJECT_46_5]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd24.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 14L) < ((unsigned long) (Wrd24.Lng)))
    goto label_37;
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_4]), 2);

DEFLABEL (label_37)
  (Wrd18.uLng) = (OBJECT_DATUM (Wrd14.Obj));
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd18.Obj) == (Wrd20.Obj))
    goto label_39;
  (Wrd16.Obj) = (current_block [OBJECT_46_7]);
  goto label_38;

DEFLABEL (label_39)
  (Wrd16.Obj) = (current_block [OBJECT_46_6]);

DEFLABEL (label_38)
DEFLABEL (label_56)
  Rsp = (& (Rsp [3]));
  if ((Wrd16.Obj) == ((SCHEME_OBJECT) 0))
    goto label_54;

DEFLABEL (label_55)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_15]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (current_block [OBJECT_46_9]);
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd35.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd36.Obj) = (current_block [OBJECT_46_10]);
  (* (--Rsp)) = (Wrd36.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_23]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_46_15);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_54;

DEFLABEL (label_53)
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_17]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (Wrd53.Obj) = (current_block [OBJECT_46_2]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_18]))));
  (* (--Rsp)) = (Wrd56.Obj);
  (Wrd57.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd57.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_19]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_46_18);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_27]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_46_17);
  (* (--Rsp)) = Rvl;
  (Wrd9.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd9.uLng) == 1))
    goto label_52;
  (Wrd6.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd7.Obj) = ((Wrd6.pObj) [0]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_51)
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_50;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [1]);

DEFLABEL (label_49)
  (Rsp [1]) = (Wrd14.Obj);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_26]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_46_11]);
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd28.Obj) = (current_block [OBJECT_46_12]);
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_23]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_46_26);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_48;

DEFLABEL (label_47)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_29]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_46_13]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_INTERFACE_0 (35);

DEFLABEL (continuation_15)
  (Wrd5.Obj) = Rvl;
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 26))
    goto label_46;
  (Wrd14.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd14.uLng) == 26))
    goto label_46;
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Rvl));
  (Wrd15.Lng) = ((Wrd17.Lng) + (Wrd18.Lng));
  if (! (LONG_TO_FIXNUM_P (Wrd15.Lng)))
    goto label_46;
  (Wrd11.Obj) = (LONG_TO_FIXNUM (Wrd15.Lng));

DEFLABEL (label_45)
  (Rsp [1]) = (Wrd11.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 26))
    goto label_44;
  (Wrd41.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if (! ((Wrd41.Lng) < 0))
    goto label_41;

DEFLABEL (label_40)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_41)
  (Wrd26.Obj) = (current_block [OBJECT_46_12]);
  (Rsp [1]) = (Wrd26.Obj);
  (Wrd27.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd27.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd29.Obj) = (Rsp [1]);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if ((Wrd30.uLng) == 26)
    goto label_43;

DEFLABEL (label_42)
  INVOKE_INTERFACE_0 (40);

DEFLABEL (label_43)
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd29.Obj));
  (Wrd31.Lng) = (0 - (Wrd35.Lng));
  if (! (LONG_TO_FIXNUM_P (Wrd31.Lng)))
    goto label_42;
  Rvl = (LONG_TO_FIXNUM (Wrd31.Lng));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_44)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_31]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_INTERFACE_0 (42);

DEFLABEL (label_33)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_41;
  goto label_40;

DEFLABEL (label_46)
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_30]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_INTERFACE_0 (43);

DEFLABEL (label_32)
  (Wrd11.Obj) = Rvl;
  goto label_45;

DEFLABEL (label_48)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_28]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (current_block [OBJECT_46_8]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_22]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_46_28);
  goto label_47;

DEFLABEL (label_50)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_25]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_0]), 1);

DEFLABEL (label_31)
  (Wrd14.Obj) = Rvl;
  goto label_49;

DEFLABEL (label_52)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_24]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_1]), 1);

DEFLABEL (label_30)
  (* (--Rsp)) = Rvl;
  goto label_51;

DEFLABEL (label_54)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_16]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd29.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_46_8]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_22]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_46_16);
  goto label_53;

DEFLABEL (label_58)
  Rsp = (& (Rsp [2]));
  goto label_55;

DEFLABEL (label_59)
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_21]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (* (--Rsp)) = Rvl;
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_4]), 2);

DEFLABEL (label_29)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_57;
  goto label_58;

DEFLABEL (label_60)
  (Wrd11.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd11.uLng) == 1))
    goto label_63;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_62)
  (Rsp [1]) = (Wrd7.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd20.Obj) = (Rsp [0]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 1))
    goto label_61;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  Rvl = ((Wrd18.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_61)
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_1]), 1);

DEFLABEL (label_63)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_12]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_0]), 1);

DEFLABEL (label_27)
  (Wrd7.Obj) = Rvl;
  goto label_62;

DEFLABEL (label_65)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_46_8])), (Wrd13.pObj));

DEFLABEL (label_26)
  (Wrd12.Obj) = Rvl;
  goto label_64;

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_46_20);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_54;
  goto label_55;

DEFLABEL (lambda_36)
  CLOSURE_HEADER (LABEL_46_6);

DEFLABEL (lambda_1)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_67;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd8.Obj) = ((Wrd10.pObj) [0]);

DEFLABEL (label_66)
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_14]));

DEFLABEL (label_67)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_13]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_1]), 1);

DEFLABEL (label_28)
  (Wrd8.Obj) = Rvl;
  goto label_66;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_47_4 3
#define LABEL_47_7 5
#define LABEL_47_5 7
#define LABEL_47_11 9
#define LABEL_47_6 11
#define LABEL_47_9 13
#define LABEL_47_15 15
#define LABEL_47_10 17
#define LABEL_47_13 19
#define LABEL_47_18 21
#define LABEL_47_14 23
#define LABEL_47_16 25
#define LABEL_47_20 27
#define LABEL_47_17 29
#define LABEL_47_19 31
#define LABEL_47_24 33
#define LABEL_47_23 35
#define LABEL_47_27 37
#define LABEL_47_26 39
#define ENVIRONMENT_LABEL_47_3 65
#define DEBUGGING_LABEL_47_2 64
#define OBJECT_47_10 63
#define OBJECT_47_9 62
#define OBJECT_47_8 61
#define OBJECT_47_7 60
#define OBJECT_47_6 59
#define OBJECT_47_5 58
#define OBJECT_47_4 57
#define OBJECT_47_3 56
#define OBJECT_47_2 55
#define OBJECT_47_1 54
#define OBJECT_47_0 53
#define EXECUTE_CACHE_47_28 41
#define EXECUTE_CACHE_47_25 43
#define EXECUTE_CACHE_47_21 45
#define EXECUTE_CACHE_47_22 47
#define EXECUTE_CACHE_47_12 49
#define EXECUTE_CACHE_47_8 51
#define FREE_REFERENCES_LABEL_47_0 40
#define NUMBER_OF_LINKER_SECTIONS_47_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_47 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd7;
  machine_word Wrd11;
  machine_word Wrd17;
  machine_word Wrd18;
  machine_word Wrd28;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd12;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd16;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_47_4);
      goto decoded_time__ctime_string_18;

    case 1:
      current_block = (Rpc - LABEL_47_7);
      goto label_20;

    case 2:
      current_block = (Rpc - LABEL_47_5);
      goto continuation_15;

    case 3:
      current_block = (Rpc - LABEL_47_11);
      goto label_21;

    case 4:
      current_block = (Rpc - LABEL_47_6);
      goto continuation_14;

    case 5:
      current_block = (Rpc - LABEL_47_9);
      goto continuation_12;

    case 6:
      current_block = (Rpc - LABEL_47_15);
      goto label_22;

    case 7:
      current_block = (Rpc - LABEL_47_10);
      goto continuation_11;

    case 8:
      current_block = (Rpc - LABEL_47_13);
      goto continuation_9;

    case 9:
      current_block = (Rpc - LABEL_47_18);
      goto label_23;

    case 10:
      current_block = (Rpc - LABEL_47_14);
      goto continuation_8;

    case 11:
      current_block = (Rpc - LABEL_47_16);
      goto continuation_6;

    case 12:
      current_block = (Rpc - LABEL_47_20);
      goto label_24;

    case 13:
      current_block = (Rpc - LABEL_47_17);
      goto continuation_5;

    case 14:
      current_block = (Rpc - LABEL_47_19);
      goto continuation_3;

    case 15:
      current_block = (Rpc - LABEL_47_24);
      goto label_25;

    case 16:
      current_block = (Rpc - LABEL_47_23);
      goto continuation_1;

    case 17:
      current_block = (Rpc - LABEL_47_27);
      goto label_26;

    case 18:
      current_block = (Rpc - LABEL_47_26);
      goto continuation_17;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (decoded_time__ctime_string_28)
DEFLABEL (decoded_time__ctime_string_18)
  INTERRUPT_CHECK (26, LABEL_47_4);
  (Wrd5.Obj) = (current_block [OBJECT_47_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_5]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_47_1]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_47_2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_6]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd23.Obj) = (Rsp [5]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 10))
    goto label_42;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd22.Lng))))
    goto label_42;
  (Wrd16.Obj) = ((Wrd20.pObj) [2]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_41)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_8]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_47_6);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_12]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_47_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_47_5]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_9]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_47_1]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_47_2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_10]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd23.Obj) = (Rsp [7]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 10))
    goto label_40;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd22.Lng))))
    goto label_40;
  (Wrd16.Obj) = ((Wrd20.pObj) [3]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_39)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_8]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_47_10);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_12]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_47_9);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_47_5]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_13]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_47_1]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_47_2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_14]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd23.Obj) = (Rsp [9]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 10))
    goto label_38;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd22.Lng))))
    goto label_38;
  (Wrd16.Obj) = ((Wrd20.pObj) [4]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_37)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_8]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_47_14);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_12]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_47_13);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_47_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_16]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_47_2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_17]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd22.Obj) = (Rsp [10]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd23.uLng) == 10))
    goto label_36;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd21.Lng))))
    goto label_36;
  (Wrd15.Obj) = ((Wrd19.pObj) [5]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_35)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_8]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_47_17);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_22]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_47_16);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_47_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_19]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd18.Obj) = (Rsp [10]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_34;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd17.Lng))))
    goto label_34;
  (Wrd11.Obj) = ((Wrd15.pObj) [6]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_33)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_21]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_47_19);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_47_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_23]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd18.Obj) = (Rsp [12]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_32;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd17.Lng))))
    goto label_32;
  (Wrd11.Obj) = ((Wrd15.pObj) [8]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_31)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_25]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_47_23);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_26]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [13]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_30;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd16.Lng))))
    goto label_30;
  (Wrd10.Obj) = ((Wrd14.pObj) [7]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_29)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_8]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_47_26);
  (Rsp [12]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_28]));

DEFLABEL (label_30)
  (Wrd19.Obj) = (Rsp [13]);
  (Wrd20.Obj) = (current_block [OBJECT_47_10]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_27]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_4]), 2);

DEFLABEL (label_26)
  (* (--Rsp)) = Rvl;
  goto label_29;

DEFLABEL (label_32)
  (Wrd20.Obj) = (Rsp [12]);
  (Wrd21.Obj) = (current_block [OBJECT_47_9]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_24]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_4]), 2);

DEFLABEL (label_25)
  (* (--Rsp)) = Rvl;
  goto label_31;

DEFLABEL (label_34)
  (Wrd20.Obj) = (Rsp [10]);
  (Wrd21.Obj) = (current_block [OBJECT_47_8]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_20]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_4]), 2);

DEFLABEL (label_24)
  (* (--Rsp)) = Rvl;
  goto label_33;

DEFLABEL (label_36)
  (Wrd24.Obj) = (Rsp [10]);
  (Wrd25.Obj) = (current_block [OBJECT_47_7]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_18]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_4]), 2);

DEFLABEL (label_23)
  (* (--Rsp)) = Rvl;
  goto label_35;

DEFLABEL (label_38)
  (Wrd25.Obj) = (Rsp [9]);
  (Wrd26.Obj) = (current_block [OBJECT_47_6]);
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_15]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_4]), 2);

DEFLABEL (label_22)
  (* (--Rsp)) = Rvl;
  goto label_37;

DEFLABEL (label_40)
  (Wrd25.Obj) = (Rsp [7]);
  (Wrd26.Obj) = (current_block [OBJECT_47_2]);
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_11]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_4]), 2);

DEFLABEL (label_21)
  (* (--Rsp)) = Rvl;
  goto label_39;

DEFLABEL (label_42)
  (Wrd25.Obj) = (Rsp [5]);
  (Wrd26.Obj) = (current_block [OBJECT_47_3]);
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_7]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_4]), 2);

DEFLABEL (label_20)
  (* (--Rsp)) = Rvl;
  goto label_41;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_48_5 3
#define LABEL_48_6 5
#define LABEL_48_4 7
#define LABEL_48_8 9
#define LABEL_48_13 11
#define LABEL_48_11 13
#define LABEL_48_17 15
#define LABEL_48_14 17
#define LABEL_48_15 19
#define LABEL_48_19 21
#define LABEL_48_21 23
#define LABEL_48_22 25
#define LABEL_48_23 27
#define LABEL_48_25 29
#define LABEL_48_26 31
#define LABEL_48_24 33
#define LABEL_48_20 35
#define LABEL_48_31 37
#define LABEL_48_32 39
#define LABEL_48_28 41
#define LABEL_48_29 43
#define LABEL_48_30 45
#define LABEL_48_33 47
#define LABEL_48_39 49
#define LABEL_48_34 51
#define LABEL_48_36 53
#define LABEL_48_37 55
#define LABEL_48_38 57
#define LABEL_48_40 59
#define LABEL_48_45 61
#define LABEL_48_41 63
#define LABEL_48_42 65
#define LABEL_48_43 67
#define LABEL_48_44 69
#define LABEL_48_48 71
#define LABEL_48_49 73
#define ENVIRONMENT_LABEL_48_3 111
#define DEBUGGING_LABEL_48_2 110
#define OBJECT_48_14 109
#define OBJECT_48_13 108
#define OBJECT_48_12 107
#define OBJECT_48_11 106
#define OBJECT_48_10 105
#define OBJECT_48_9 104
#define OBJECT_48_8 103
#define OBJECT_48_7 102
#define OBJECT_48_6 101
#define OBJECT_48_5 100
#define OBJECT_48_4 99
#define OBJECT_48_3 98
#define OBJECT_48_2 97
#define OBJECT_48_1 96
#define OBJECT_48_0 95
#define EXECUTE_CACHE_48_47 75
#define EXECUTE_CACHE_48_46 77
#define EXECUTE_CACHE_48_35 79
#define EXECUTE_CACHE_48_27 81
#define EXECUTE_CACHE_48_18 83
#define EXECUTE_CACHE_48_16 85
#define EXECUTE_CACHE_48_12 87
#define EXECUTE_CACHE_48_10 89
#define EXECUTE_CACHE_48_9 91
#define EXECUTE_CACHE_48_7 93
#define FREE_REFERENCES_LABEL_48_0 74
#define NUMBER_OF_LINKER_SECTIONS_48_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_48 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd34;
  machine_word Wrd29;
  machine_word Wrd30;
  machine_word Wrd15;
  machine_word Wrd60;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd56;
  machine_word Wrd53;
  machine_word Wrd47;
  machine_word Wrd48;
  machine_word Wrd49;
  machine_word Wrd46;
  machine_word Wrd38;
  machine_word Wrd40;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd37;
  machine_word Wrd6;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd7;
  machine_word Wrd12;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd8;
  machine_word Wrd5;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_48_5);
      goto continuation_4;

    case 1:
      current_block = (Rpc - LABEL_48_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_48_4);
      goto ctime_string__decoded_time_44;

    case 3:
      current_block = (Rpc - LABEL_48_8);
      goto continuation_5;

    case 4:
      current_block = (Rpc - LABEL_48_13);
      goto continuation_8;

    case 5:
      current_block = (Rpc - LABEL_48_11);
      goto continuation_6;

    case 6:
      current_block = (Rpc - LABEL_48_17);
      goto lambda_2;

    case 7:
      current_block = (Rpc - LABEL_48_14);
      goto continuation_10;

    case 8:
      current_block = (Rpc - LABEL_48_15);
      goto continuation_9;

    case 9:
      current_block = (Rpc - LABEL_48_19);
      goto continuation_11;

    case 10:
      current_block = (Rpc - LABEL_48_21);
      goto label_48;

    case 11:
      current_block = (Rpc - LABEL_48_22);
      goto label_49;

    case 12:
      current_block = (Rpc - LABEL_48_23);
      goto label_50;

    case 13:
      current_block = (Rpc - LABEL_48_25);
      goto label_46;

    case 14:
      current_block = (Rpc - LABEL_48_26);
      goto label_47;

    case 15:
      current_block = (Rpc - LABEL_48_24);
      goto continuation_16;

    case 16:
      current_block = (Rpc - LABEL_48_20);
      goto continuation_28;

    case 17:
      current_block = (Rpc - LABEL_48_31);
      goto label_51;

    case 18:
      current_block = (Rpc - LABEL_48_32);
      goto label_52;

    case 19:
      current_block = (Rpc - LABEL_48_28);
      goto continuation_24;

    case 20:
      current_block = (Rpc - LABEL_48_29);
      goto continuation_23;

    case 21:
      current_block = (Rpc - LABEL_48_30);
      goto continuation_31;

    case 22:
      current_block = (Rpc - LABEL_48_33);
      goto continuation_20;

    case 23:
      current_block = (Rpc - LABEL_48_39);
      goto label_53;

    case 24:
      current_block = (Rpc - LABEL_48_34);
      goto continuation_19;

    case 25:
      current_block = (Rpc - LABEL_48_36);
      goto continuation_39;

    case 26:
      current_block = (Rpc - LABEL_48_37);
      goto continuation_38;

    case 27:
      current_block = (Rpc - LABEL_48_38);
      goto continuation_18;

    case 28:
      current_block = (Rpc - LABEL_48_40);
      goto continuation_35;

    case 29:
      current_block = (Rpc - LABEL_48_45);
      goto label_54;

    case 30:
      current_block = (Rpc - LABEL_48_41);
      goto continuation_34;

    case 31:
      current_block = (Rpc - LABEL_48_42);
      goto continuation_22;

    case 32:
      current_block = (Rpc - LABEL_48_43);
      goto continuation_21;

    case 33:
      current_block = (Rpc - LABEL_48_44);
      goto continuation_33;

    case 34:
      current_block = (Rpc - LABEL_48_48);
      goto continuation_37;

    case 35:
      current_block = (Rpc - LABEL_48_49);
      goto continuation_36;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (ctime_string__decoded_time_56)
DEFLABEL (ctime_string__decoded_time_44)
  INTERRUPT_CHECK (26, LABEL_48_4);
  (Wrd5.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == (current_block [OBJECT_48_2]))
    goto label_59;
  (* (--Rsp)) = (Wrd5.Obj);
  goto label_58;

DEFLABEL (label_59)
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_58)
DEFLABEL (label_75)
  (Wrd8.Obj) = (Rsp [0]);
  if ((Wrd8.Obj) == ((SCHEME_OBJECT) 0))
    goto label_73;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_6]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_10]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_48_6);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_74;

DEFLABEL (label_73)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_8]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (current_block [OBJECT_48_3]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (current_block [OBJECT_48_4]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd19.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_9]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_48_8);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_11]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_12]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_48_11);
  if (Rvl == (current_block [OBJECT_48_5]))
    goto label_72;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_13]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.pObj) = (& (Rsp [3]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd10.pObj)));
  (* (--Rsp)) = (Wrd12.Obj);
  Rdl = (& (Rsp [1]));
  goto lambda_2;

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_48_13);

DEFLABEL (label_72)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_14]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd18.Obj) = (current_block [OBJECT_48_6]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_15]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_48_7]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_16]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_48_15);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_9]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_48_14);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_19]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_12]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_48_19);
  (* (--Rsp)) = Rvl;
  if (Rvl == (current_block [OBJECT_48_7]))
    goto label_66;
  if (Rvl == (current_block [OBJECT_48_11]))
    goto label_60;
  (Wrd10.pObj) = (& (Rsp [4]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd10.pObj)));
  (Rsp [3]) = (Wrd12.Obj);
  Rdl = (& (Rsp [6]));
  Rsp = (& (Rsp [3]));
  goto lambda_2;

DEFLABEL (label_60)
  (Wrd15.Obj) = (current_block [OBJECT_48_12]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_24]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd22.Obj) = (Rsp [3]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd23.uLng) == 1))
    goto label_65;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd19.Obj) = ((Wrd21.pObj) [1]);

DEFLABEL (label_64)
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd30.uLng) == 1))
    goto label_62;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [0]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_61)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_27]));

DEFLABEL (label_62)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_26]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_10]), 1);

DEFLABEL (label_47)
DEFLABEL (label_63)
  (* (--Rsp)) = Rvl;
  goto label_61;

DEFLABEL (label_65)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_25]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_9]), 1);

DEFLABEL (label_46)
  (Wrd19.Obj) = Rvl;
  goto label_64;

DEFLABEL (label_66)
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_20]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd41.Obj) = (Rsp [2]);
  (Wrd42.uLng) = (OBJECT_TYPE (Wrd41.Obj));
  if (! ((Wrd42.uLng) == 1))
    goto label_71;
  (Wrd40.pObj) = (OBJECT_ADDRESS (Wrd41.Obj));
  (Wrd38.Obj) = ((Wrd40.pObj) [1]);

DEFLABEL (label_70)
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if (! ((Wrd49.uLng) == 1))
    goto label_69;
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd47.Obj) = ((Wrd48.pObj) [1]);

DEFLABEL (label_68)
  (Wrd56.uLng) = (OBJECT_TYPE (Wrd47.Obj));
  if (! ((Wrd56.uLng) == 1))
    goto label_67;
  (Wrd54.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  (Wrd55.Obj) = ((Wrd54.pObj) [0]);
  (* (--Rsp)) = (Wrd55.Obj);
  goto label_61;

DEFLABEL (label_67)
  (Wrd60.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_23]))));
  (* (--Rsp)) = (Wrd60.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_10]), 1);

DEFLABEL (label_50)
  goto label_63;

DEFLABEL (label_69)
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_22]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_9]), 1);

DEFLABEL (label_49)
  (Wrd47.Obj) = Rvl;
  goto label_68;

DEFLABEL (label_71)
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_21]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_9]), 1);

DEFLABEL (label_48)
  (Wrd38.Obj) = Rvl;
  goto label_70;

DEFLABEL (label_74)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_5]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_48_0]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_48_1]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd28.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_7]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_48_5);
  goto label_73;

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_48_24);
  (Rsp [1]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_28]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_29]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_48_13]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_16]));

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_48_29);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_35]));

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_48_28);
  (Rsp [5]) = Rvl;
  (Wrd6.Obj) = (Rsp [4]);
  (Rsp [6]) = (Wrd6.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_33]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_34]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_48_11]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_16]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_48_34);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_27]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_48_33);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_38]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_77;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [0]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_76)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_27]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_48_38);
  (Rsp [3]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_42]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_43]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_48_14]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_16]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_48_43);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_47]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_48_42);
  (Rsp [5]) = Rvl;
  (Wrd6.Obj) = (* (Rsp++));
  (Rsp [3]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_46]));

DEFLABEL (label_77)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_39]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_10]), 1);

DEFLABEL (label_53)
  (* (--Rsp)) = Rvl;
  goto label_76;

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_48_20);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_30]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_83;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd8.Obj) = ((Wrd10.pObj) [1]);

DEFLABEL (label_82)
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd19.uLng) == 1))
    goto label_81;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_80)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_27]));

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_48_30);
  (Rsp [1]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_36]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_37]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_48_13]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_16]));

DEFLABEL (continuation_38)
  INTERRUPT_CHECK (27, LABEL_48_37);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_35]));

DEFLABEL (continuation_39)
  INTERRUPT_CHECK (27, LABEL_48_36);
  (Rsp [5]) = Rvl;
  (Wrd6.Obj) = (Rsp [4]);
  (Rsp [6]) = (Wrd6.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_40]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_41]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_48_11]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_16]));

DEFLABEL (continuation_34)
  INTERRUPT_CHECK (27, LABEL_48_41);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_27]));

DEFLABEL (continuation_35)
  INTERRUPT_CHECK (27, LABEL_48_40);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_44]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_79;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [0]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_78)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_27]));

DEFLABEL (continuation_33)
  INTERRUPT_CHECK (27, LABEL_48_44);
  (Rsp [3]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_48]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_49]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_48_14]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_16]));

DEFLABEL (continuation_36)
  INTERRUPT_CHECK (27, LABEL_48_49);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_47]));

DEFLABEL (continuation_37)
  INTERRUPT_CHECK (27, LABEL_48_48);
  (Rsp [5]) = Rvl;
  (Wrd6.Obj) = (* (Rsp++));
  (Rsp [3]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_46]));

DEFLABEL (label_79)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_45]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_10]), 1);

DEFLABEL (label_54)
  (* (--Rsp)) = Rvl;
  goto label_78;

DEFLABEL (label_81)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_32]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_10]), 1);

DEFLABEL (label_52)
  (* (--Rsp)) = Rvl;
  goto label_80;

DEFLABEL (label_83)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_31]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_9]), 1);

DEFLABEL (label_51)
  (Wrd8.Obj) = Rvl;
  goto label_82;

DEFLABEL (lambda_57)
DEFLABEL (lambda_2)
  DLINK_INTERRUPT_CHECK (25, LABEL_48_17);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [0]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_48_8]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_18]));

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_49_4 3
#define LABEL_49_5 5
#define ENVIRONMENT_LABEL_49_3 12
#define DEBUGGING_LABEL_49_2 11
#define EXECUTE_CACHE_49_7 7
#define EXECUTE_CACHE_49_6 9
#define FREE_REFERENCES_LABEL_49_0 6
#define NUMBER_OF_LINKER_SECTIONS_49_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_49 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_49_4);
      goto universal_time__local_ctime_string_1;

    case 1:
      current_block = (Rpc - LABEL_49_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (universal_time__local_ctime_string_4)
DEFLABEL (universal_time__local_ctime_string_1)
  INTERRUPT_CHECK (26, LABEL_49_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_49_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_49_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_49_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_50_4 3
#define LABEL_50_5 5
#define ENVIRONMENT_LABEL_50_3 12
#define DEBUGGING_LABEL_50_2 11
#define EXECUTE_CACHE_50_7 7
#define EXECUTE_CACHE_50_6 9
#define FREE_REFERENCES_LABEL_50_0 6
#define NUMBER_OF_LINKER_SECTIONS_50_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_50 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_50_4);
      goto universal_time__global_ctime_string_1;

    case 1:
      current_block = (Rpc - LABEL_50_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (universal_time__global_ctime_string_4)
DEFLABEL (universal_time__global_ctime_string_1)
  INTERRUPT_CHECK (26, LABEL_50_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_50_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_50_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_50_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_51_4 3
#define LABEL_51_5 5
#define ENVIRONMENT_LABEL_51_3 13
#define DEBUGGING_LABEL_51_2 12
#define OBJECT_51_0 11
#define EXECUTE_CACHE_51_7 7
#define EXECUTE_CACHE_51_6 9
#define FREE_REFERENCES_LABEL_51_0 6
#define NUMBER_OF_LINKER_SECTIONS_51_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_51 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_51_4);
      goto ctime_string__universal_time_3;

    case 1:
      current_block = (Rpc - LABEL_51_5);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (ctime_string__universal_time_6)
DEFLABEL (ctime_string__universal_time_3)
  INTERRUPT_CHECK (26, LABEL_51_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  if ((Wrd8.Obj) == (current_block [OBJECT_51_0]))
    goto label_8;
  (* (--Rsp)) = (Wrd8.Obj);
  goto label_7;

DEFLABEL (label_8)
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_7)
DEFLABEL (label_9)
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_51_6]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_51_5);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_51_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_52_4 3
#define LABEL_52_5 5
#define ENVIRONMENT_LABEL_52_3 12
#define DEBUGGING_LABEL_52_2 11
#define EXECUTE_CACHE_52_7 7
#define EXECUTE_CACHE_52_6 9
#define FREE_REFERENCES_LABEL_52_0 6
#define NUMBER_OF_LINKER_SECTIONS_52_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_52 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_52_4);
      goto file_time__local_ctime_string_1;

    case 1:
      current_block = (Rpc - LABEL_52_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (file_time__local_ctime_string_4)
DEFLABEL (file_time__local_ctime_string_1)
  INTERRUPT_CHECK (26, LABEL_52_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_52_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_52_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_52_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_53_4 3
#define LABEL_53_5 5
#define ENVIRONMENT_LABEL_53_3 12
#define DEBUGGING_LABEL_53_2 11
#define EXECUTE_CACHE_53_7 7
#define EXECUTE_CACHE_53_6 9
#define FREE_REFERENCES_LABEL_53_0 6
#define NUMBER_OF_LINKER_SECTIONS_53_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_53 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_53_4);
      goto file_time__global_ctime_string_1;

    case 1:
      current_block = (Rpc - LABEL_53_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (file_time__global_ctime_string_4)
DEFLABEL (file_time__global_ctime_string_1)
  INTERRUPT_CHECK (26, LABEL_53_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_53_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_53_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_53_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_54_4 3
#define LABEL_54_5 5
#define ENVIRONMENT_LABEL_54_3 13
#define DEBUGGING_LABEL_54_2 12
#define OBJECT_54_0 11
#define EXECUTE_CACHE_54_7 7
#define EXECUTE_CACHE_54_6 9
#define FREE_REFERENCES_LABEL_54_0 6
#define NUMBER_OF_LINKER_SECTIONS_54_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_54 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_54_4);
      goto ctime_string__file_time_3;

    case 1:
      current_block = (Rpc - LABEL_54_5);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (ctime_string__file_time_6)
DEFLABEL (ctime_string__file_time_3)
  INTERRUPT_CHECK (26, LABEL_54_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  if ((Wrd8.Obj) == (current_block [OBJECT_54_0]))
    goto label_8;
  (* (--Rsp)) = (Wrd8.Obj);
  goto label_7;

DEFLABEL (label_8)
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_7)
DEFLABEL (label_9)
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54_6]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_54_5);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_55_4 3
#define LABEL_55_8 5
#define LABEL_55_5 7
#define LABEL_55_6 9
#define ENVIRONMENT_LABEL_55_3 21
#define DEBUGGING_LABEL_55_2 20
#define OBJECT_55_2 19
#define OBJECT_55_1 18
#define OBJECT_55_0 17
#define EXECUTE_CACHE_55_10 11
#define EXECUTE_CACHE_55_9 13
#define EXECUTE_CACHE_55_7 15
#define FREE_REFERENCES_LABEL_55_0 10
#define NUMBER_OF_LINKER_SECTIONS_55_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_55 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_55_4);
      goto iso8601_string__decoded_time_4;

    case 1:
      current_block = (Rpc - LABEL_55_8);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_55_5);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_55_6);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (iso8601_string__decoded_time_7)
DEFLABEL (iso8601_string__decoded_time_4)
  INTERRUPT_CHECK (26, LABEL_55_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_55_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_55_6);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_55_10]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_55_5);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_10;
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55_8]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_55_0]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_55_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_55_8);

DEFLABEL (label_10)
  (Wrd7.Obj) = (current_block [OBJECT_55_1]);
  (Rsp [1]) = (Wrd7.Obj);
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 10)
    goto label_9;

DEFLABEL (label_8)
  INVOKE_PRIMITIVE ((current_block [OBJECT_55_2]), 2);

DEFLABEL (label_9)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd17.Lng))))
    goto label_8;
  Rvl = ((Wrd15.pObj) [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_56_4 3
#define LABEL_56_6 5
#define LABEL_56_5 7
#define LABEL_56_9 9
#define LABEL_56_8 11
#define LABEL_56_11 13
#define LABEL_56_10 15
#define LABEL_56_13 17
#define LABEL_56_12 19
#define LABEL_56_15 21
#define LABEL_56_14 23
#define LABEL_56_17 25
#define LABEL_56_19 27
#define LABEL_56_16 29
#define LABEL_56_20 31
#define LABEL_56_23 33
#define LABEL_56_25 35
#define LABEL_56_22 37
#define ENVIRONMENT_LABEL_56_3 62
#define DEBUGGING_LABEL_56_2 61
#define OBJECT_56_11 60
#define OBJECT_56_10 59
#define OBJECT_56_9 58
#define OBJECT_56_8 57
#define OBJECT_56_7 56
#define OBJECT_56_6 55
#define OBJECT_56_5 54
#define OBJECT_56_4 53
#define OBJECT_56_3 52
#define OBJECT_56_2 51
#define OBJECT_56_1 50
#define OBJECT_56_0 49
#define EXECUTE_CACHE_56_26 39
#define EXECUTE_CACHE_56_24 41
#define EXECUTE_CACHE_56_21 43
#define EXECUTE_CACHE_56_18 45
#define EXECUTE_CACHE_56_7 47
#define FREE_REFERENCES_LABEL_56_0 38
#define NUMBER_OF_LINKER_SECTIONS_56_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_56 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd13;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd28;
  machine_word Wrd34;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd5;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd10;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_56_4);
      goto decoded_time__iso8601_string_17;

    case 1:
      current_block = (Rpc - LABEL_56_6);
      goto label_19;

    case 2:
      current_block = (Rpc - LABEL_56_5);
      goto continuation_11;

    case 3:
      current_block = (Rpc - LABEL_56_9);
      goto label_20;

    case 4:
      current_block = (Rpc - LABEL_56_8);
      goto continuation_9;

    case 5:
      current_block = (Rpc - LABEL_56_11);
      goto label_21;

    case 6:
      current_block = (Rpc - LABEL_56_10);
      goto continuation_7;

    case 7:
      current_block = (Rpc - LABEL_56_13);
      goto label_22;

    case 8:
      current_block = (Rpc - LABEL_56_12);
      goto continuation_5;

    case 9:
      current_block = (Rpc - LABEL_56_15);
      goto label_23;

    case 10:
      current_block = (Rpc - LABEL_56_14);
      goto continuation_3;

    case 11:
      current_block = (Rpc - LABEL_56_17);
      goto label_24;

    case 12:
      current_block = (Rpc - LABEL_56_19);
      goto continuation_13;

    case 13:
      current_block = (Rpc - LABEL_56_16);
      goto continuation_1;

    case 14:
      current_block = (Rpc - LABEL_56_20);
      goto label_25;

    case 15:
      current_block = (Rpc - LABEL_56_23);
      goto continuation_14;

    case 16:
      current_block = (Rpc - LABEL_56_25);
      goto label_26;

    case 17:
      current_block = (Rpc - LABEL_56_22);
      goto continuation_15;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (decoded_time__iso8601_string_28)
DEFLABEL (decoded_time__iso8601_string_17)
  INTERRUPT_CHECK (26, LABEL_56_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_48;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_48;
  (Wrd10.Obj) = ((Wrd14.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_47)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_56_7]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_56_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_56_2]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_8]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd18.Obj) = (Rsp [3]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_46;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd17.Lng))))
    goto label_46;
  (Wrd11.Obj) = ((Wrd15.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_45)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_56_7]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_56_8);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_56_2]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_10]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd18.Obj) = (Rsp [5]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_44;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd17.Lng))))
    goto label_44;
  (Wrd11.Obj) = ((Wrd15.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_43)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_56_7]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_56_10);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_56_5]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_12]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd18.Obj) = (Rsp [7]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_42;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd17.Lng))))
    goto label_42;
  (Wrd11.Obj) = ((Wrd15.pObj) [5]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_41)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_56_7]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_56_12);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_56_7]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_14]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd18.Obj) = (Rsp [9]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_40;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd17.Lng))))
    goto label_40;
  (Wrd11.Obj) = ((Wrd15.pObj) [6]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_39)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_56_7]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_56_14);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_56_7]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_16]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd18.Obj) = (Rsp [11]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_38;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd17.Lng))))
    goto label_38;
  (Wrd11.Obj) = ((Wrd15.pObj) [7]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_37)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_56_18]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_56_16);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_19]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [12]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_36;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 9L) < ((unsigned long) (Wrd16.Lng))))
    goto label_36;
  (Wrd10.Obj) = ((Wrd14.pObj) [10]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_35)
  (Wrd24.Obj) = (Rsp [0]);
  if ((Wrd24.Obj) == ((SCHEME_OBJECT) 0))
    goto label_33;
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_22]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_23]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd32.Obj) = (Rsp [15]);
  (* (--Rsp)) = (Wrd32.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_56_24]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_56_23);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_32;
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 26))
    goto label_31;
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  (Wrd15.Lng) = ((Wrd17.Lng) - 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd15.Lng)))
    goto label_31;
  (Wrd5.Obj) = (LONG_TO_FIXNUM (Wrd15.Lng));

DEFLABEL (label_30)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_29)
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_56_26]));

DEFLABEL (label_31)
  (Wrd9.Obj) = (Rsp [1]);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_25]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_INTERFACE_0 (34);

DEFLABEL (label_26)
  (Wrd5.Obj) = Rvl;
  goto label_30;

DEFLABEL (label_32)
  (Wrd5.Obj) = (Rsp [1]);
  goto label_30;

DEFLABEL (label_33)
  (Wrd34.Obj) = (current_block [OBJECT_56_11]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_34)
  (Rsp [11]) = (Wrd34.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_56_21]));

DEFLABEL (label_36)
  (Wrd19.Obj) = (Rsp [12]);
  (Wrd20.Obj) = (current_block [OBJECT_56_10]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_20]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_56_1]), 2);

DEFLABEL (label_25)
  (* (--Rsp)) = Rvl;
  goto label_35;

DEFLABEL (label_38)
  (Wrd20.Obj) = (Rsp [11]);
  (Wrd21.Obj) = (current_block [OBJECT_56_9]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_17]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_56_1]), 2);

DEFLABEL (label_24)
  (* (--Rsp)) = Rvl;
  goto label_37;

DEFLABEL (label_40)
  (Wrd20.Obj) = (Rsp [9]);
  (Wrd21.Obj) = (current_block [OBJECT_56_8]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_15]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_56_1]), 2);

DEFLABEL (label_23)
  (* (--Rsp)) = Rvl;
  goto label_39;

DEFLABEL (label_42)
  (Wrd20.Obj) = (Rsp [7]);
  (Wrd21.Obj) = (current_block [OBJECT_56_6]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_13]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_56_1]), 2);

DEFLABEL (label_22)
  (* (--Rsp)) = Rvl;
  goto label_41;

DEFLABEL (label_44)
  (Wrd20.Obj) = (Rsp [5]);
  (Wrd21.Obj) = (current_block [OBJECT_56_4]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_11]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_56_1]), 2);

DEFLABEL (label_21)
  (* (--Rsp)) = Rvl;
  goto label_43;

DEFLABEL (label_46)
  (Wrd20.Obj) = (Rsp [3]);
  (Wrd21.Obj) = (current_block [OBJECT_56_3]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_9]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_56_1]), 2);

DEFLABEL (label_20)
  (* (--Rsp)) = Rvl;
  goto label_45;

DEFLABEL (label_48)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_56_0]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_6]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_56_1]), 2);

DEFLABEL (label_19)
  (* (--Rsp)) = Rvl;
  goto label_47;

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_56_22);
  (Wrd5.Obj) = Rvl;
  goto label_29;

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_56_19);
  (Wrd34.Obj) = Rvl;
  goto label_34;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_57_4 3
#define LABEL_57_5 5
#define ENVIRONMENT_LABEL_57_3 12
#define DEBUGGING_LABEL_57_2 11
#define EXECUTE_CACHE_57_7 7
#define EXECUTE_CACHE_57_6 9
#define FREE_REFERENCES_LABEL_57_0 6
#define NUMBER_OF_LINKER_SECTIONS_57_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_57 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_57_4);
      goto universal_time__local_iso8601_string_1;

    case 1:
      current_block = (Rpc - LABEL_57_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (universal_time__local_iso8601_string_4)
DEFLABEL (universal_time__local_iso8601_string_1)
  INTERRUPT_CHECK (26, LABEL_57_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_57_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_57_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_57_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_58_4 3
#define LABEL_58_5 5
#define ENVIRONMENT_LABEL_58_3 12
#define DEBUGGING_LABEL_58_2 11
#define EXECUTE_CACHE_58_7 7
#define EXECUTE_CACHE_58_6 9
#define FREE_REFERENCES_LABEL_58_0 6
#define NUMBER_OF_LINKER_SECTIONS_58_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_58 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_58_4);
      goto universal_time__global_iso8601_string_1;

    case 1:
      current_block = (Rpc - LABEL_58_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (universal_time__global_iso8601_string_4)
DEFLABEL (universal_time__global_iso8601_string_1)
  INTERRUPT_CHECK (26, LABEL_58_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_58_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_58_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_58_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_59_4 3
#define LABEL_59_5 5
#define ENVIRONMENT_LABEL_59_3 12
#define DEBUGGING_LABEL_59_2 11
#define EXECUTE_CACHE_59_7 7
#define EXECUTE_CACHE_59_6 9
#define FREE_REFERENCES_LABEL_59_0 6
#define NUMBER_OF_LINKER_SECTIONS_59_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_59 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_59_4);
      goto iso8601_string__universal_time_1;

    case 1:
      current_block = (Rpc - LABEL_59_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (iso8601_string__universal_time_4)
DEFLABEL (iso8601_string__universal_time_1)
  INTERRUPT_CHECK (26, LABEL_59_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_59_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_59_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_59_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_59_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_60_4 3
#define LABEL_60_5 5
#define ENVIRONMENT_LABEL_60_3 12
#define DEBUGGING_LABEL_60_2 11
#define EXECUTE_CACHE_60_7 7
#define EXECUTE_CACHE_60_6 9
#define FREE_REFERENCES_LABEL_60_0 6
#define NUMBER_OF_LINKER_SECTIONS_60_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_60 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_60_4);
      goto file_time__local_iso8601_string_1;

    case 1:
      current_block = (Rpc - LABEL_60_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (file_time__local_iso8601_string_4)
DEFLABEL (file_time__local_iso8601_string_1)
  INTERRUPT_CHECK (26, LABEL_60_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_60_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_60_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_60_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_61_4 3
#define LABEL_61_5 5
#define ENVIRONMENT_LABEL_61_3 12
#define DEBUGGING_LABEL_61_2 11
#define EXECUTE_CACHE_61_7 7
#define EXECUTE_CACHE_61_6 9
#define FREE_REFERENCES_LABEL_61_0 6
#define NUMBER_OF_LINKER_SECTIONS_61_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_61 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_61_4);
      goto file_time__global_iso8601_string_1;

    case 1:
      current_block = (Rpc - LABEL_61_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (file_time__global_iso8601_string_4)
DEFLABEL (file_time__global_iso8601_string_1)
  INTERRUPT_CHECK (26, LABEL_61_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_61_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_61_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_61_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_61_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_62_4 3
#define LABEL_62_5 5
#define ENVIRONMENT_LABEL_62_3 12
#define DEBUGGING_LABEL_62_2 11
#define EXECUTE_CACHE_62_7 7
#define EXECUTE_CACHE_62_6 9
#define FREE_REFERENCES_LABEL_62_0 6
#define NUMBER_OF_LINKER_SECTIONS_62_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_62 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_62_4);
      goto iso8601_string__file_time_1;

    case 1:
      current_block = (Rpc - LABEL_62_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (iso8601_string__file_time_4)
DEFLABEL (iso8601_string__file_time_1)
  INTERRUPT_CHECK (26, LABEL_62_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_62_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_63_4 3
#define LABEL_63_5 5
#define LABEL_63_7 7
#define LABEL_63_11 9
#define TAG_63_12 3
#define LABEL_63_13 11
#define LABEL_63_9 13
#define LABEL_63_14 15
#define LABEL_63_16 17
#define TAG_63_17 7
#define LABEL_63_18 19
#define LABEL_63_20 21
#define TAG_63_21 9
#define LABEL_63_22 23
#define LABEL_63_23 25
#define LABEL_63_24 27
#define LABEL_63_26 29
#define TAG_63_27 13
#define LABEL_63_28 31
#define LABEL_63_30 33
#define LABEL_63_31 35
#define LABEL_63_38 37
#define LABEL_63_39 39
#define LABEL_63_40 41
#define LABEL_63_41 43
#define LABEL_63_42 45
#define LABEL_63_43 47
#define LABEL_63_44 49
#define LABEL_63_32 51
#define LABEL_63_45 53
#define LABEL_63_46 55
#define LABEL_63_47 57
#define LABEL_63_48 59
#define LABEL_63_49 61
#define LABEL_63_50 63
#define LABEL_63_51 65
#define LABEL_63_52 67
#define LABEL_63_53 69
#define LABEL_63_55 71
#define LABEL_63_34 73
#define LABEL_63_36 75
#define TAG_63_37 36
#define LABEL_63_35 77
#define LABEL_63_56 79
#define ENVIRONMENT_LABEL_63_3 107
#define DEBUGGING_LABEL_63_2 106
#define OBJECT_63_6 105
#define OBJECT_63_5 104
#define OBJECT_63_4 103
#define OBJECT_63_3 102
#define OBJECT_63_2 101
#define OBJECT_63_1 100
#define OBJECT_63_0 99
#define EXECUTE_CACHE_63_54 81
#define EXECUTE_CACHE_63_33 83
#define EXECUTE_CACHE_63_29 85
#define EXECUTE_CACHE_63_25 87
#define EXECUTE_CACHE_63_19 89
#define EXECUTE_CACHE_63_15 91
#define EXECUTE_CACHE_63_10 93
#define EXECUTE_CACHE_63_8 95
#define EXECUTE_CACHE_63_6 97
#define FREE_REFERENCES_LABEL_63_0 80
#define NUMBER_OF_LINKER_SECTIONS_63_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_63 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd157;
  machine_word Wrd154;
  machine_word Wrd153;
  machine_word Wrd144;
  machine_word Wrd150;
  machine_word Wrd149;
  machine_word Wrd148;
  machine_word Wrd152;
  machine_word Wrd141;
  machine_word Wrd140;
  machine_word Wrd175;
  machine_word Wrd172;
  machine_word Wrd171;
  machine_word Wrd160;
  machine_word Wrd168;
  machine_word Wrd167;
  machine_word Wrd166;
  machine_word Wrd170;
  machine_word Wrd169;
  machine_word Wrd136;
  machine_word Wrd135;
  machine_word Wrd132;
  machine_word Wrd129;
  machine_word Wrd128;
  machine_word Wrd117;
  machine_word Wrd125;
  machine_word Wrd124;
  machine_word Wrd123;
  machine_word Wrd127;
  machine_word Wrd126;
  machine_word Wrd116;
  machine_word Wrd113;
  machine_word Wrd112;
  machine_word Wrd103;
  machine_word Wrd109;
  machine_word Wrd108;
  machine_word Wrd107;
  machine_word Wrd111;
  machine_word Wrd110;
  machine_word Wrd100;
  machine_word Wrd97;
  machine_word Wrd96;
  machine_word Wrd87;
  machine_word Wrd93;
  machine_word Wrd92;
  machine_word Wrd91;
  machine_word Wrd95;
  machine_word Wrd94;
  machine_word Wrd84;
  machine_word Wrd81;
  machine_word Wrd80;
  machine_word Wrd71;
  machine_word Wrd77;
  machine_word Wrd76;
  machine_word Wrd75;
  machine_word Wrd79;
  machine_word Wrd78;
  machine_word Wrd68;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd55;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd52;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd37;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd237;
  machine_word Wrd159;
  machine_word Wrd240;
  machine_word Wrd242;
  machine_word Wrd241;
  machine_word Wrd239;
  machine_word Wrd238;
  machine_word Wrd231;
  machine_word Wrd224;
  machine_word Wrd225;
  machine_word Wrd228;
  machine_word Wrd230;
  machine_word Wrd229;
  machine_word Wrd227;
  machine_word Wrd226;
  machine_word Wrd219;
  machine_word Wrd212;
  machine_word Wrd208;
  machine_word Wrd213;
  machine_word Wrd215;
  machine_word Wrd218;
  machine_word Wrd214;
  machine_word Wrd207;
  machine_word Wrd204;
  machine_word Wrd203;
  machine_word Wrd192;
  machine_word Wrd200;
  machine_word Wrd199;
  machine_word Wrd198;
  machine_word Wrd202;
  machine_word Wrd201;
  machine_word Wrd191;
  machine_word Wrd188;
  machine_word Wrd187;
  machine_word Wrd178;
  machine_word Wrd184;
  machine_word Wrd183;
  machine_word Wrd182;
  machine_word Wrd186;
  machine_word Wrd185;
  machine_word Wrd26;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd23;
  machine_word Wrd24;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd10;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_63_4);
      goto parse_8601_date_time_52;

    case 1:
      current_block = (Rpc - LABEL_63_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_63_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_63_11);
      goto lambda_36;

    case 4:
      current_block = (Rpc - LABEL_63_13);
      goto continuation_37;

    case 5:
      current_block = (Rpc - LABEL_63_9);
      goto continuation_2;

    case 6:
      current_block = (Rpc - LABEL_63_14);
      goto continuation_3;

    case 7:
      current_block = (Rpc - LABEL_63_16);
      goto lambda_72;

    case 8:
      current_block = (Rpc - LABEL_63_18);
      goto continuation_45;

    case 9:
      current_block = (Rpc - LABEL_63_20);
      goto lambda_25;

    case 10:
      current_block = (Rpc - LABEL_63_22);
      goto continuation_26;

    case 11:
      current_block = (Rpc - LABEL_63_23);
      goto continuation_38;

    case 12:
      current_block = (Rpc - LABEL_63_24);
      goto continuation_4;

    case 13:
      current_block = (Rpc - LABEL_63_26);
      goto lambda_74;

    case 14:
      current_block = (Rpc - LABEL_63_28);
      goto continuation_30;

    case 15:
      current_block = (Rpc - LABEL_63_30);
      goto continuation_39;

    case 16:
      current_block = (Rpc - LABEL_63_31);
      goto continuation_6;

    case 17:
      current_block = (Rpc - LABEL_63_38);
      goto continuation_22;

    case 18:
      current_block = (Rpc - LABEL_63_39);
      goto label_64;

    case 19:
      current_block = (Rpc - LABEL_63_40);
      goto label_65;

    case 20:
      current_block = (Rpc - LABEL_63_41);
      goto label_66;

    case 21:
      current_block = (Rpc - LABEL_63_42);
      goto label_67;

    case 22:
      current_block = (Rpc - LABEL_63_43);
      goto label_68;

    case 23:
      current_block = (Rpc - LABEL_63_44);
      goto continuation_16;

    case 24:
      current_block = (Rpc - LABEL_63_32);
      goto continuation_5;

    case 25:
      current_block = (Rpc - LABEL_63_45);
      goto label_54;

    case 26:
      current_block = (Rpc - LABEL_63_46);
      goto label_55;

    case 27:
      current_block = (Rpc - LABEL_63_47);
      goto label_56;

    case 28:
      current_block = (Rpc - LABEL_63_48);
      goto label_57;

    case 29:
      current_block = (Rpc - LABEL_63_49);
      goto label_58;

    case 30:
      current_block = (Rpc - LABEL_63_50);
      goto label_59;

    case 31:
      current_block = (Rpc - LABEL_63_51);
      goto label_60;

    case 32:
      current_block = (Rpc - LABEL_63_52);
      goto label_61;

    case 33:
      current_block = (Rpc - LABEL_63_53);
      goto label_63;

    case 34:
      current_block = (Rpc - LABEL_63_55);
      goto label_62;

    case 35:
      current_block = (Rpc - LABEL_63_34);
      goto continuation_27;

    case 36:
      current_block = (Rpc - LABEL_63_36);
      goto lambda_75;

    case 37:
      current_block = (Rpc - LABEL_63_35);
      goto continuation_40;

    case 38:
      current_block = (Rpc - LABEL_63_56);
      goto continuation_42;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (parse_8601_date_time_70)
DEFLABEL (parse_8601_date_time_52)
  INTERRUPT_CHECK (26, LABEL_63_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_63_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_63_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_63_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_63_7);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_77;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_63_12);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_63_11])));
  Rhp += 2;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd12 = Wrd9;
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
  ((Wrd12.pObj) [3]) = Rvl;
  (Rsp [0]) = (Wrd8.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_13]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_63_6]));

DEFLABEL (continuation_37)
  INTERRUPT_CHECK (27, LABEL_63_13);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_63_17);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_63_16])));
  Rhp += 4;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [3]);
  ((Wrd14.pObj) [2]) = (Wrd15.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd14.pObj) [4]) = (Wrd11.Obj);
  ((Wrd14.pObj) [5]) = Rvl;
  (Rsp [0]) = (Wrd6.Obj);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_18]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (current_block [OBJECT_63_0]);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_63_19]));

DEFLABEL (continuation_45)
  INTERRUPT_CHECK (27, LABEL_63_18);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_76;
  (Wrd7.Obj) = (Rsp [0]);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (Wrd10.pObj) = (& (Rhp [-1]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd10.pObj)));
  (Rsp [2]) = (Wrd8.Obj);
  (Rsp [3]) = (Wrd7.Obj);
  Rsp = (& (Rsp [1]));
  goto lambda_36;

DEFLABEL (label_76)
  (Wrd15.Obj) = (Rsp [0]);
  (Rsp [3]) = (Wrd15.Obj);
  Rsp = (& (Rsp [3]));
  goto lambda_44;

DEFLABEL (label_77)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_9]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_63_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_63_9);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (lambda_71)
DEFLABEL (lambda_36)
  INTERRUPT_CHECK (26, LABEL_63_11);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_63_15]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_63_14);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_78;
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_78)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_63_21);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_63_20])));
  Rhp += 4;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd18 = Wrd9;
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [2]);
  ((Wrd18.pObj) [2]) = (Wrd21.Obj);
  (Wrd17.Obj) = ((Wrd20.pObj) [3]);
  ((Wrd18.pObj) [3]) = (Wrd17.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd18.pObj) [4]) = (Wrd13.Obj);
  ((Wrd18.pObj) [5]) = Rvl;
  (Rsp [0]) = (Wrd8.Obj);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_22]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_63_6]));

DEFLABEL (continuation_26)
  INTERRUPT_CHECK (27, LABEL_63_22);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_63_27);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_63_26])));
  Rhp += 4;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [2]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd14.pObj) [4]) = (Wrd11.Obj);
  ((Wrd14.pObj) [5]) = Rvl;
  (Rsp [0]) = (Wrd6.Obj);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_28]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_63_29]));

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_63_28);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_79;
  (Wrd7.Obj) = (Rsp [1]);
  (Rsp [5]) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (Rsp [3]) = (Wrd8.Obj);
  (Rsp [4]) = Rvl;
  Rsp = (& (Rsp [3]));
  goto lambda_25;

DEFLABEL (label_79)
  (Wrd11.Obj) = (Rsp [1]);
  (Rsp [5]) = (Wrd11.Obj);
  Rsp = (& (Rsp [5]));
  goto lambda_29;

DEFLABEL (lambda_72)
  CLOSURE_HEADER (LABEL_63_16);

DEFLABEL (lambda_44)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_23]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_63_10]));

DEFLABEL (continuation_38)
  INTERRUPT_CHECK (27, LABEL_63_23);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_30]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_63_1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_63_19]));

DEFLABEL (continuation_39)
  INTERRUPT_CHECK (27, LABEL_63_30);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_80;
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (Wrd8.pObj) = (& (Rhp [-1]));
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd8.pObj)));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [4]);
  (* (--Rsp)) = (Wrd15.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd18.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_63_37);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_63_36])));
  Rhp += 2;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd18.pObj)));
  Wrd23 = Wrd18;
  (Wrd26.Obj) = ((Wrd14.pObj) [2]);
  ((Wrd23.pObj) [2]) = (Wrd26.Obj);
  (Wrd22.Obj) = ((Wrd14.pObj) [3]);
  ((Wrd23.pObj) [3]) = (Wrd22.Obj);
  (Rsp [2]) = (Wrd17.Obj);
  goto lambda_36;

DEFLABEL (label_80)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_35]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [3]);
  (* (--Rsp)) = (Wrd32.Obj);
  (Wrd35.Obj) = ((Wrd31.pObj) [2]);
  (* (--Rsp)) = (Wrd35.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_63_10]));

DEFLABEL (continuation_40)
  INTERRUPT_CHECK (27, LABEL_63_35);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_73)
DEFLABEL (lambda_25)
  INTERRUPT_CHECK (26, LABEL_63_20);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_24]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_63_25]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_63_24);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_81;
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_81)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_31]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_32]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [5]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd20.Obj) = ((Wrd16.pObj) [4]);
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd23.Obj) = ((Wrd16.pObj) [3]);
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_63_33]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_63_32);
  (* (--Rsp)) = Rvl;
  (Wrd15.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd15.uLng) == 10))
    goto label_113;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd13.Lng))))
    goto label_113;
  (Wrd7.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_112)
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_111;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd29.Lng))))
    goto label_111;
  (Wrd23.Obj) = ((Wrd27.pObj) [1]);
  (* (--Rsp)) = (Wrd23.Obj);

DEFLABEL (label_110)
  (Wrd46.Obj) = (Rsp [2]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if (! ((Wrd47.uLng) == 10))
    goto label_109;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [0]);
  (Wrd45.Lng) = (FIXNUM_TO_LONG (Wrd44.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd45.Lng))))
    goto label_109;
  (Wrd37.Obj) = ((Wrd43.pObj) [3]);

DEFLABEL (label_108)
  (Rsp [2]) = (Wrd37.Obj);
  (Wrd62.Obj) = (Rsp [0]);
  (Wrd63.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if (! ((Wrd63.uLng) == 10))
    goto label_107;
  (Wrd59.pObj) = (OBJECT_ADDRESS (Wrd62.Obj));
  (Wrd60.Obj) = ((Wrd59.pObj) [0]);
  (Wrd61.Lng) = (FIXNUM_TO_LONG (Wrd60.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd61.Lng))))
    goto label_107;
  (Wrd55.Obj) = ((Wrd59.pObj) [3]);
  (* (--Rsp)) = (Wrd55.Obj);

DEFLABEL (label_106)
  (Wrd78.Obj) = (Rsp [2]);
  (Wrd79.uLng) = (OBJECT_TYPE (Wrd78.Obj));
  if (! ((Wrd79.uLng) == 10))
    goto label_105;
  (Wrd75.pObj) = (OBJECT_ADDRESS (Wrd78.Obj));
  (Wrd76.Obj) = ((Wrd75.pObj) [0]);
  (Wrd77.Lng) = (FIXNUM_TO_LONG (Wrd76.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd77.Lng))))
    goto label_105;
  (Wrd71.Obj) = ((Wrd75.pObj) [1]);
  (* (--Rsp)) = (Wrd71.Obj);

DEFLABEL (label_104)
  (Wrd94.Obj) = (Rsp [3]);
  (Wrd95.uLng) = (OBJECT_TYPE (Wrd94.Obj));
  if (! ((Wrd95.uLng) == 10))
    goto label_103;
  (Wrd91.pObj) = (OBJECT_ADDRESS (Wrd94.Obj));
  (Wrd92.Obj) = ((Wrd91.pObj) [0]);
  (Wrd93.Lng) = (FIXNUM_TO_LONG (Wrd92.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd93.Lng))))
    goto label_103;
  (Wrd87.Obj) = ((Wrd91.pObj) [2]);
  (* (--Rsp)) = (Wrd87.Obj);

DEFLABEL (label_102)
  (Wrd110.Obj) = (Rsp [4]);
  (Wrd111.uLng) = (OBJECT_TYPE (Wrd110.Obj));
  if (! ((Wrd111.uLng) == 10))
    goto label_101;
  (Wrd107.pObj) = (OBJECT_ADDRESS (Wrd110.Obj));
  (Wrd108.Obj) = ((Wrd107.pObj) [0]);
  (Wrd109.Lng) = (FIXNUM_TO_LONG (Wrd108.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd109.Lng))))
    goto label_101;
  (Wrd103.Obj) = ((Wrd107.pObj) [3]);
  (* (--Rsp)) = (Wrd103.Obj);

DEFLABEL (label_100)
  (Wrd126.Obj) = (Rsp [4]);
  (Wrd127.uLng) = (OBJECT_TYPE (Wrd126.Obj));
  if (! ((Wrd127.uLng) == 10))
    goto label_99;
  (Wrd123.pObj) = (OBJECT_ADDRESS (Wrd126.Obj));
  (Wrd124.Obj) = ((Wrd123.pObj) [0]);
  (Wrd125.Lng) = (FIXNUM_TO_LONG (Wrd124.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd125.Lng))))
    goto label_99;
  (Wrd117.Obj) = ((Wrd123.pObj) [1]);

DEFLABEL (label_98)
  (Rsp [5]) = (Wrd117.Obj);
  (Wrd135.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_44]))));
  (* (--Rsp)) = (Wrd135.Obj);
  (Wrd136.Obj) = (Rsp [7]);
  if ((Wrd136.Obj) == ((SCHEME_OBJECT) 0))
    goto label_97;
  (Wrd140.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_38]))));
  (* (--Rsp)) = (Wrd140.Obj);
  (Wrd141.Obj) = (current_block [OBJECT_63_6]);
  (* (--Rsp)) = (Wrd141.Obj);
  (Wrd152.uLng) = (OBJECT_TYPE (Wrd136.Obj));
  if (! ((Wrd152.uLng) == 10))
    goto label_96;
  (Wrd148.pObj) = (OBJECT_ADDRESS (Wrd136.Obj));
  (Wrd149.Obj) = ((Wrd148.pObj) [0]);
  (Wrd150.Lng) = (FIXNUM_TO_LONG (Wrd149.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd150.Lng))))
    goto label_96;
  (Wrd144.Obj) = ((Wrd148.pObj) [3]);
  (* (--Rsp)) = (Wrd144.Obj);

DEFLABEL (label_95)
  INVOKE_INTERFACE_0 (35);

DEFLABEL (continuation_22)
  (* (--Rsp)) = Rvl;
  (Wrd185.Obj) = (Rsp [8]);
  (Wrd186.uLng) = (OBJECT_TYPE (Wrd185.Obj));
  if (! ((Wrd186.uLng) == 10))
    goto label_94;
  (Wrd182.pObj) = (OBJECT_ADDRESS (Wrd185.Obj));
  (Wrd183.Obj) = ((Wrd182.pObj) [0]);
  (Wrd184.Lng) = (FIXNUM_TO_LONG (Wrd183.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd184.Lng))))
    goto label_94;
  (Wrd178.Obj) = ((Wrd182.pObj) [2]);
  (* (--Rsp)) = (Wrd178.Obj);

DEFLABEL (label_93)
  (Wrd201.Obj) = (Rsp [9]);
  (Wrd202.uLng) = (OBJECT_TYPE (Wrd201.Obj));
  if (! ((Wrd202.uLng) == 10))
    goto label_92;
  (Wrd198.pObj) = (OBJECT_ADDRESS (Wrd201.Obj));
  (Wrd199.Obj) = ((Wrd198.pObj) [0]);
  (Wrd200.Lng) = (FIXNUM_TO_LONG (Wrd199.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd200.Lng))))
    goto label_92;
  (Wrd192.Obj) = ((Wrd198.pObj) [1]);

DEFLABEL (label_91)
  (Wrd214.uLng) = (OBJECT_TYPE (Wrd192.Obj));
  if (! ((Wrd214.uLng) == 26))
    goto label_90;
  (Wrd218.Lng) = (FIXNUM_TO_LONG (Wrd192.Obj));
  (Wrd215.Lng) = (0 - (Wrd218.Lng));
  if (! (LONG_TO_FIXNUM_P (Wrd215.Lng)))
    goto label_90;
  (Wrd213.Obj) = (LONG_TO_FIXNUM (Wrd215.Lng));

DEFLABEL (label_89)
  (Wrd219.Obj) = (* (Rsp++));
  (Wrd226.uLng) = (OBJECT_TYPE (Wrd213.Obj));
  if (! ((Wrd226.uLng) == 26))
    goto label_88;
  (Wrd227.uLng) = (OBJECT_TYPE (Wrd219.Obj));
  if (! ((Wrd227.uLng) == 26))
    goto label_88;
  (Wrd229.Lng) = (FIXNUM_TO_LONG (Wrd213.Obj));
  (Wrd230.Lng) = (FIXNUM_TO_LONG (Wrd219.Obj));
  if (multiply_with_overflow ((Wrd229.Lng), (Wrd230.Lng), (& (Wrd228.Lng))))
    goto label_88;
  (Wrd225.Obj) = (LONG_TO_FIXNUM (Wrd228.Lng));

DEFLABEL (label_87)
  (Wrd231.Obj) = (* (Rsp++));
  (Wrd238.uLng) = (OBJECT_TYPE (Wrd225.Obj));
  if (! ((Wrd238.uLng) == 26))
    goto label_86;
  (Wrd239.uLng) = (OBJECT_TYPE (Wrd231.Obj));
  if (! ((Wrd239.uLng) == 26))
    goto label_86;
  (Wrd241.Lng) = (FIXNUM_TO_LONG (Wrd225.Obj));
  (Wrd242.Lng) = (FIXNUM_TO_LONG (Wrd231.Obj));
  (Wrd240.Lng) = ((Wrd241.Lng) + (Wrd242.Lng));
  if (! (LONG_TO_FIXNUM_P (Wrd240.Lng)))
    goto label_86;
  (Wrd159.Obj) = (LONG_TO_FIXNUM (Wrd240.Lng));

DEFLABEL (label_85)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_84)
  (Rsp [6]) = (Wrd159.Obj);
  (Wrd169.Obj) = (Rsp [4]);
  (Wrd170.uLng) = (OBJECT_TYPE (Wrd169.Obj));
  if (! ((Wrd170.uLng) == 10))
    goto label_83;
  (Wrd166.pObj) = (OBJECT_ADDRESS (Wrd169.Obj));
  (Wrd167.Obj) = ((Wrd166.pObj) [0]);
  (Wrd168.Lng) = (FIXNUM_TO_LONG (Wrd167.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd168.Lng))))
    goto label_83;
  (Wrd160.Obj) = ((Wrd166.pObj) [2]);

DEFLABEL (label_82)
  (Rsp [4]) = (Wrd160.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_63_54]));

DEFLABEL (label_83)
  (Wrd171.Obj) = (Rsp [4]);
  (Wrd172.Obj) = (current_block [OBJECT_63_2]);
  (Wrd175.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_53]))));
  (* (--Rsp)) = (Wrd175.Obj);
  (* (--Rsp)) = (Wrd172.Obj);
  (* (--Rsp)) = (Wrd171.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_63_3]), 2);

DEFLABEL (label_63)
  (Wrd160.Obj) = Rvl;
  goto label_82;

DEFLABEL (label_86)
  (Wrd237.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_43]))));
  (* (--Rsp)) = (Wrd237.Obj);
  (* (--Rsp)) = (Wrd231.Obj);
  (* (--Rsp)) = (Wrd225.Obj);
  INVOKE_INTERFACE_0 (43);

DEFLABEL (label_68)
  (Wrd159.Obj) = Rvl;
  goto label_85;

DEFLABEL (label_88)
  (Wrd224.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_42]))));
  (* (--Rsp)) = (Wrd224.Obj);
  (* (--Rsp)) = (Wrd219.Obj);
  (* (--Rsp)) = (Wrd213.Obj);
  INVOKE_INTERFACE_0 (41);

DEFLABEL (label_67)
  (Wrd225.Obj) = Rvl;
  goto label_87;

DEFLABEL (label_90)
  (Wrd208.Obj) = (current_block [OBJECT_63_4]);
  (Wrd212.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_41]))));
  (* (--Rsp)) = (Wrd212.Obj);
  (* (--Rsp)) = (Wrd192.Obj);
  (* (--Rsp)) = (Wrd208.Obj);
  INVOKE_INTERFACE_0 (40);

DEFLABEL (label_66)
  (Wrd213.Obj) = Rvl;
  goto label_89;

DEFLABEL (label_92)
  (Wrd203.Obj) = (Rsp [9]);
  (Wrd204.Obj) = (current_block [OBJECT_63_4]);
  (Wrd207.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_40]))));
  (* (--Rsp)) = (Wrd207.Obj);
  (* (--Rsp)) = (Wrd204.Obj);
  (* (--Rsp)) = (Wrd203.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_63_3]), 2);

DEFLABEL (label_65)
  (Wrd192.Obj) = Rvl;
  goto label_91;

DEFLABEL (label_94)
  (Wrd187.Obj) = (Rsp [8]);
  (Wrd188.Obj) = (current_block [OBJECT_63_2]);
  (Wrd191.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_39]))));
  (* (--Rsp)) = (Wrd191.Obj);
  (* (--Rsp)) = (Wrd188.Obj);
  (* (--Rsp)) = (Wrd187.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_63_3]), 2);

DEFLABEL (label_64)
  (* (--Rsp)) = Rvl;
  goto label_93;

DEFLABEL (label_96)
  (Wrd153.Obj) = (Rsp [9]);
  (Wrd154.Obj) = (current_block [OBJECT_63_5]);
  (Wrd157.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_55]))));
  (* (--Rsp)) = (Wrd157.Obj);
  (* (--Rsp)) = (Wrd154.Obj);
  (* (--Rsp)) = (Wrd153.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_63_3]), 2);

DEFLABEL (label_62)
  (* (--Rsp)) = Rvl;
  goto label_95;

DEFLABEL (label_97)
  (Wrd159.Obj) = ((SCHEME_OBJECT) 0);
  goto label_85;

DEFLABEL (label_99)
  (Wrd128.Obj) = (Rsp [4]);
  (Wrd129.Obj) = (current_block [OBJECT_63_4]);
  (Wrd132.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_52]))));
  (* (--Rsp)) = (Wrd132.Obj);
  (* (--Rsp)) = (Wrd129.Obj);
  (* (--Rsp)) = (Wrd128.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_63_3]), 2);

DEFLABEL (label_61)
  (Wrd117.Obj) = Rvl;
  goto label_98;

DEFLABEL (label_101)
  (Wrd112.Obj) = (Rsp [4]);
  (Wrd113.Obj) = (current_block [OBJECT_63_5]);
  (Wrd116.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_51]))));
  (* (--Rsp)) = (Wrd116.Obj);
  (* (--Rsp)) = (Wrd113.Obj);
  (* (--Rsp)) = (Wrd112.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_63_3]), 2);

DEFLABEL (label_60)
  (* (--Rsp)) = Rvl;
  goto label_100;

DEFLABEL (label_103)
  (Wrd96.Obj) = (Rsp [3]);
  (Wrd97.Obj) = (current_block [OBJECT_63_2]);
  (Wrd100.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_50]))));
  (* (--Rsp)) = (Wrd100.Obj);
  (* (--Rsp)) = (Wrd97.Obj);
  (* (--Rsp)) = (Wrd96.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_63_3]), 2);

DEFLABEL (label_59)
  (* (--Rsp)) = Rvl;
  goto label_102;

DEFLABEL (label_105)
  (Wrd80.Obj) = (Rsp [2]);
  (Wrd81.Obj) = (current_block [OBJECT_63_4]);
  (Wrd84.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_49]))));
  (* (--Rsp)) = (Wrd84.Obj);
  (* (--Rsp)) = (Wrd81.Obj);
  (* (--Rsp)) = (Wrd80.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_63_3]), 2);

DEFLABEL (label_58)
  (* (--Rsp)) = Rvl;
  goto label_104;

DEFLABEL (label_107)
  (Wrd64.Obj) = (Rsp [0]);
  (Wrd65.Obj) = (current_block [OBJECT_63_5]);
  (Wrd68.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_48]))));
  (* (--Rsp)) = (Wrd68.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  (* (--Rsp)) = (Wrd64.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_63_3]), 2);

DEFLABEL (label_57)
  (* (--Rsp)) = Rvl;
  goto label_106;

DEFLABEL (label_109)
  (Wrd48.Obj) = (Rsp [2]);
  (Wrd49.Obj) = (current_block [OBJECT_63_5]);
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_47]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_63_3]), 2);

DEFLABEL (label_56)
  (Wrd37.Obj) = Rvl;
  goto label_108;

DEFLABEL (label_111)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.Obj) = (current_block [OBJECT_63_4]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_46]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_63_3]), 2);

DEFLABEL (label_55)
  (* (--Rsp)) = Rvl;
  goto label_110;

DEFLABEL (label_113)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_63_2]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_45]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_63_3]), 2);

DEFLABEL (label_54)
  (* (--Rsp)) = Rvl;
  goto label_112;

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_63_44);
  (Wrd159.Obj) = Rvl;
  goto label_84;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_63_31);
  (Wrd12.Obj) = (MAKE_OBJECT (0, 1));
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd8.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (lambda_74)
  CLOSURE_HEADER (LABEL_63_26);

DEFLABEL (lambda_29)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_34]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_63_10]));

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_63_34);
  (Wrd10.Obj) = (MAKE_OBJECT (0, 1));
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (Wrd6.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [4]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = ((Wrd13.pObj) [3]);
  (Rsp [2]) = (Wrd15.Obj);
  goto lambda_25;

DEFLABEL (lambda_75)
  CLOSURE_HEADER (LABEL_63_36);

DEFLABEL (lambda_43)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_56]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_63_10]));

DEFLABEL (continuation_42)
  INTERRUPT_CHECK (27, LABEL_63_56);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_64_4 3
#define LABEL_64_5 5
#define LABEL_64_7 7
#define TAG_64_8 2
#define LABEL_64_9 9
#define LABEL_64_11 11
#define LABEL_64_13 13
#define TAG_64_14 5
#define LABEL_64_15 15
#define LABEL_64_16 17
#define TAG_64_17 7
#define LABEL_64_18 19
#define LABEL_64_19 21
#define LABEL_64_21 23
#define LABEL_64_23 25
#define LABEL_64_24 27
#define TAG_64_25 12
#define LABEL_64_26 29
#define LABEL_64_36 31
#define LABEL_64_27 33
#define LABEL_64_39 35
#define LABEL_64_29 37
#define LABEL_64_30 39
#define LABEL_64_31 41
#define LABEL_64_32 43
#define TAG_64_33 20
#define LABEL_64_34 45
#define LABEL_64_40 47
#define LABEL_64_42 49
#define TAG_64_43 23
#define LABEL_64_44 51
#define LABEL_64_41 53
#define LABEL_64_46 55
#define LABEL_64_56 57
#define LABEL_64_47 59
#define LABEL_64_37 61
#define LABEL_64_49 63
#define LABEL_64_50 65
#define LABEL_64_51 67
#define LABEL_64_52 69
#define TAG_64_53 33
#define LABEL_64_54 71
#define LABEL_64_55 73
#define LABEL_64_59 75
#define LABEL_64_60 77
#define LABEL_64_62 79
#define LABEL_64_63 81
#define LABEL_64_65 83
#define LABEL_64_57 85
#define LABEL_64_66 87
#define LABEL_64_67 89
#define LABEL_64_68 91
#define LABEL_64_69 93
#define LABEL_64_71 95
#define TAG_64_72 46
#define LABEL_64_70 97
#define LABEL_64_73 99
#define LABEL_64_74 101
#define ENVIRONMENT_LABEL_64_3 133
#define DEBUGGING_LABEL_64_2 132
#define OBJECT_64_2 131
#define OBJECT_64_1 130
#define OBJECT_64_0 129
#define EXECUTE_CACHE_64_64 103
#define EXECUTE_CACHE_64_61 105
#define EXECUTE_CACHE_64_58 107
#define EXECUTE_CACHE_64_48 109
#define EXECUTE_CACHE_64_45 111
#define EXECUTE_CACHE_64_38 113
#define EXECUTE_CACHE_64_35 115
#define EXECUTE_CACHE_64_28 117
#define EXECUTE_CACHE_64_22 119
#define EXECUTE_CACHE_64_20 121
#define EXECUTE_CACHE_64_12 123
#define EXECUTE_CACHE_64_10 125
#define EXECUTE_CACHE_64_6 127
#define FREE_REFERENCES_LABEL_64_0 102
#define NUMBER_OF_LINKER_SECTIONS_64_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_64 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd29;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd19;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd12;
  machine_word Wrd5;
  machine_word Wrd15;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_64_4);
      goto parse_8601_date_78;

    case 1:
      current_block = (Rpc - LABEL_64_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_64_7);
      goto lambda_51;

    case 3:
      current_block = (Rpc - LABEL_64_9);
      goto continuation_52;

    case 4:
      current_block = (Rpc - LABEL_64_11);
      goto continuation_1;

    case 5:
      current_block = (Rpc - LABEL_64_13);
      goto lambda_56;

    case 6:
      current_block = (Rpc - LABEL_64_15);
      goto continuation_57;

    case 7:
      current_block = (Rpc - LABEL_64_16);
      goto lambda_84;

    case 8:
      current_block = (Rpc - LABEL_64_18);
      goto continuation_25;

    case 9:
      current_block = (Rpc - LABEL_64_19);
      goto continuation_53;

    case 10:
      current_block = (Rpc - LABEL_64_21);
      goto continuation_65;

    case 11:
      current_block = (Rpc - LABEL_64_23);
      goto continuation_2;

    case 12:
      current_block = (Rpc - LABEL_64_24);
      goto lambda_29;

    case 13:
      current_block = (Rpc - LABEL_64_26);
      goto continuation_30;

    case 14:
      current_block = (Rpc - LABEL_64_36);
      goto continuation_67;

    case 15:
      current_block = (Rpc - LABEL_64_27);
      goto continuation_66;

    case 16:
      current_block = (Rpc - LABEL_64_39);
      goto lambda_64;

    case 17:
      current_block = (Rpc - LABEL_64_29);
      goto continuation_3;

    case 18:
      current_block = (Rpc - LABEL_64_30);
      goto continuation_27;

    case 19:
      current_block = (Rpc - LABEL_64_31);
      goto continuation_26;

    case 20:
      current_block = (Rpc - LABEL_64_32);
      goto lambda_86;

    case 21:
      current_block = (Rpc - LABEL_64_34);
      goto continuation_39;

    case 22:
      current_block = (Rpc - LABEL_64_40);
      goto continuation_58;

    case 23:
      current_block = (Rpc - LABEL_64_42);
      goto lambda_8;

    case 24:
      current_block = (Rpc - LABEL_64_44);
      goto continuation_9;

    case 25:
      current_block = (Rpc - LABEL_64_41);
      goto continuation_4;

    case 26:
      current_block = (Rpc - LABEL_64_46);
      goto continuation_31;

    case 27:
      current_block = (Rpc - LABEL_64_56);
      goto continuation_41;

    case 28:
      current_block = (Rpc - LABEL_64_47);
      goto continuation_40;

    case 29:
      current_block = (Rpc - LABEL_64_37);
      goto continuation_68;

    case 30:
      current_block = (Rpc - LABEL_64_49);
      goto continuation_59;

    case 31:
      current_block = (Rpc - LABEL_64_50);
      goto continuation_6;

    case 32:
      current_block = (Rpc - LABEL_64_51);
      goto continuation_5;

    case 33:
      current_block = (Rpc - LABEL_64_52);
      goto lambda_89;

    case 34:
      current_block = (Rpc - LABEL_64_54);
      goto continuation_17;

    case 35:
      current_block = (Rpc - LABEL_64_55);
      goto continuation_32;

    case 36:
      current_block = (Rpc - LABEL_64_59);
      goto continuation_69;

    case 37:
      current_block = (Rpc - LABEL_64_60);
      goto continuation_60;

    case 38:
      current_block = (Rpc - LABEL_64_62);
      goto continuation_10;

    case 39:
      current_block = (Rpc - LABEL_64_63);
      goto continuation_18;

    case 40:
      current_block = (Rpc - LABEL_64_65);
      goto continuation_33;

    case 41:
      current_block = (Rpc - LABEL_64_57);
      goto continuation_42;

    case 42:
      current_block = (Rpc - LABEL_64_66);
      goto continuation_61;

    case 43:
      current_block = (Rpc - LABEL_64_67);
      goto continuation_11;

    case 44:
      current_block = (Rpc - LABEL_64_68);
      goto continuation_34;

    case 45:
      current_block = (Rpc - LABEL_64_69);
      goto continuation_43;

    case 46:
      current_block = (Rpc - LABEL_64_71);
      goto lambda_90;

    case 47:
      current_block = (Rpc - LABEL_64_70);
      goto continuation_12;

    case 48:
      current_block = (Rpc - LABEL_64_73);
      goto continuation_35;

    case 49:
      current_block = (Rpc - LABEL_64_74);
      goto continuation_13;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (parse_8601_date_81)
DEFLABEL (parse_8601_date_78)
  INTERRUPT_CHECK (26, LABEL_64_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_64_5);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_64_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_64_7])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  ((Wrd10.pObj) [3]) = Rvl;
  (Rsp [0]) = (Wrd6.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_9]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_10]));

DEFLABEL (continuation_52)
  INTERRUPT_CHECK (27, LABEL_64_9);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_91;
  (Wrd16.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd16.Obj);
  Rsp = (& (Rsp [2]));
  goto lambda_51;

DEFLABEL (label_91)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_64_14);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_64_13])));
  Rhp += 1;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  ((Wrd9.pObj) [2]) = Rvl;
  (Rsp [0]) = (Wrd8.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_15]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_6]));

DEFLABEL (continuation_57)
  INTERRUPT_CHECK (27, LABEL_64_15);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_21]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_64_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_22]));

DEFLABEL (continuation_65)
  INTERRUPT_CHECK (27, LABEL_64_21);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_92;
  goto lambda_64;

DEFLABEL (label_92)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_27]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_28]));

DEFLABEL (continuation_66)
  INTERRUPT_CHECK (27, LABEL_64_27);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_94;

DEFLABEL (label_93)
  Rsp = (& (Rsp [1]));
  goto lambda_64;

DEFLABEL (label_94)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_36]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_64_0]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_22]));

DEFLABEL (continuation_67)
  INTERRUPT_CHECK (27, LABEL_64_36);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_93;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_37]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_38]));

DEFLABEL (continuation_68)
  INTERRUPT_CHECK (27, LABEL_64_37);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_95;
  Rsp = (& (Rsp [2]));
  goto lambda_64;

DEFLABEL (label_95)
  (Wrd7.Obj) = (Rsp [3]);
  (Rsp [4]) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_59]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_20]));

DEFLABEL (continuation_69)
  INTERRUPT_CHECK (27, LABEL_64_59);
  (Rsp [5]) = Rvl;
  Rsp = (& (Rsp [4]));
  goto lambda_56;

DEFLABEL (lambda_82)
DEFLABEL (lambda_51)
  INTERRUPT_CHECK (26, LABEL_64_7);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_11]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_12]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_64_11);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_64_17);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_64_16])));
  Rhp += 2;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd11 = Wrd6;
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [2]);
  ((Wrd11.pObj) [2]) = (Wrd14.Obj);
  (Wrd10.Obj) = ((Wrd13.pObj) [3]);
  ((Wrd11.pObj) [3]) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_18]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_10]));

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_64_18);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_96;
  (Wrd18.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd18.Obj);
  Rsp = (& (Rsp [2]));
  goto lambda_24;

DEFLABEL (label_96)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_64_25);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_64_24])));
  Rhp += 1;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  ((Wrd9.pObj) [2]) = Rvl;
  (Rsp [0]) = (Wrd8.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_26]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_6]));

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_64_26);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_64_33);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_64_32])));
  Rhp += 4;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [3]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd14.pObj) [4]) = (Wrd11.Obj);
  ((Wrd14.pObj) [5]) = Rvl;
  (Rsp [0]) = (Wrd6.Obj);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_34]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (current_block [OBJECT_64_1]);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_35]));

DEFLABEL (continuation_39)
  INTERRUPT_CHECK (27, LABEL_64_34);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_97;
  (Wrd13.Obj) = (Rsp [0]);
  (Rsp [3]) = (Wrd13.Obj);
  Rsp = (& (Rsp [3]));
  goto lambda_38;

DEFLABEL (label_97)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_47]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [4]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_48]));

DEFLABEL (continuation_40)
  INTERRUPT_CHECK (27, LABEL_64_47);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_99;

DEFLABEL (label_98)
  (Wrd14.Obj) = (Rsp [1]);
  (Rsp [4]) = (Wrd14.Obj);
  Rsp = (& (Rsp [4]));
  goto lambda_38;

DEFLABEL (label_99)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_56]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_64_0]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [6]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_22]));

DEFLABEL (continuation_41)
  INTERRUPT_CHECK (27, LABEL_64_56);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_98;
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_57]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (Rsp [5]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [2]);
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_58]));

DEFLABEL (continuation_42)
  INTERRUPT_CHECK (27, LABEL_64_57);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_100;
  (Wrd13.Obj) = (Rsp [2]);
  (Rsp [5]) = (Wrd13.Obj);
  Rsp = (& (Rsp [5]));
  goto lambda_38;

DEFLABEL (label_100)
  (Wrd7.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_69]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd12.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_20]));

DEFLABEL (continuation_43)
  INTERRUPT_CHECK (27, LABEL_64_69);
  (Rsp [5]) = Rvl;
  (Wrd6.Obj) = (* (Rsp++));
  (Rsp [5]) = (Wrd6.Obj);
  Rsp = (& (Rsp [3]));
  goto lambda_29;

DEFLABEL (lambda_83)
DEFLABEL (lambda_56)
  INTERRUPT_CHECK (26, LABEL_64_13);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_19]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_20]));

DEFLABEL (continuation_53)
  INTERRUPT_CHECK (27, LABEL_64_19);
  (* (--Rsp)) = Rvl;
  Rsp = (& (Rsp [1]));
  (Wrd13.Obj) = (MAKE_OBJECT (0, 1));
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd9.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd9.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (lambda_84)
  CLOSURE_HEADER (LABEL_64_16);

DEFLABEL (lambda_24)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_23]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_12]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_64_23);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_29]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_10]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_64_29);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_103;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_64_43);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_64_42])));
  Rhp += 1;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  ((Wrd9.pObj) [2]) = Rvl;
  (Rsp [0]) = (Wrd8.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_44]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_6]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_64_44);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_64_53);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_64_52])));
  Rhp += 4;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd16 = Wrd7;
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [2]);
  ((Wrd16.pObj) [2]) = (Wrd19.Obj);
  (Wrd15.Obj) = ((Wrd18.pObj) [3]);
  ((Wrd16.pObj) [3]) = (Wrd15.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd16.pObj) [4]) = (Wrd11.Obj);
  ((Wrd16.pObj) [5]) = Rvl;
  (Rsp [0]) = (Wrd6.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_54]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_64_0]);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_22]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_64_54);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_101;
  (Wrd13.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd13.Obj);
  Rsp = (& (Rsp [2]));
  goto lambda_16;

DEFLABEL (label_101)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_63]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_64]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_64_63);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_102;
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd8.Obj);
  (Rsp [2]) = Rvl;
  (Rsp [3]) = (Wrd7.Obj);
  Rsp = (& (Rsp [1]));
  goto lambda_8;

DEFLABEL (label_102)
  (Wrd11.Obj) = (Rsp [1]);
  (Rsp [3]) = (Wrd11.Obj);
  Rsp = (& (Rsp [3]));
  goto lambda_16;

DEFLABEL (label_103)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_41]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [3]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd26.Obj) = ((Wrd22.pObj) [2]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_12]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_64_41);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (lambda_85)
DEFLABEL (lambda_29)
  INTERRUPT_CHECK (26, LABEL_64_24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_30]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_31]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_20]));

DEFLABEL (continuation_26)
  INTERRUPT_CHECK (27, LABEL_64_31);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_45]));

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_64_30);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_104;
  Rvl = Rvl;
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_104)
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (lambda_87)
DEFLABEL (lambda_64)
  INTERRUPT_CHECK (26, LABEL_64_39);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_40]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_12]));

DEFLABEL (continuation_58)
  INTERRUPT_CHECK (27, LABEL_64_40);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_49]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_28]));

DEFLABEL (continuation_59)
  INTERRUPT_CHECK (27, LABEL_64_49);
  (Rsp [0]) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_105;
  (Wrd12.Obj) = (Rsp [2]);
  (Rsp [3]) = (Wrd12.Obj);
  Rsp = (& (Rsp [3]));
  goto lambda_51;

DEFLABEL (label_105)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_60]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_38]));

DEFLABEL (continuation_60)
  INTERRUPT_CHECK (27, LABEL_64_60);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_106;
  (Wrd13.Obj) = (Rsp [3]);
  (Rsp [4]) = (Wrd13.Obj);
  Rsp = (& (Rsp [4]));
  goto lambda_51;

DEFLABEL (label_106)
  (Wrd7.Obj) = (Rsp [2]);
  (Rsp [3]) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_66]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_20]));

DEFLABEL (continuation_61)
  INTERRUPT_CHECK (27, LABEL_64_66);
  (Rsp [4]) = Rvl;
  Rsp = (& (Rsp [3]));
  goto lambda_56;

DEFLABEL (lambda_86)
  CLOSURE_HEADER (LABEL_64_32);

DEFLABEL (lambda_38)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_46]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_12]));

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_64_46);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_55]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_64_2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_22]));

DEFLABEL (continuation_32)
  INTERRUPT_CHECK (27, LABEL_64_55);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_107;
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd13.Obj) = ((Wrd15.pObj) [3]);
  (Rsp [0]) = (Wrd13.Obj);
  goto lambda_24;

DEFLABEL (label_107)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_65]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_48]));

DEFLABEL (continuation_33)
  INTERRUPT_CHECK (27, LABEL_64_65);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_108;
  (Wrd14.Obj) = (Rsp [1]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd13.Obj) = ((Wrd15.pObj) [3]);
  (Rsp [1]) = (Wrd13.Obj);
  Rsp = (& (Rsp [1]));
  goto lambda_24;

DEFLABEL (label_108)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_68]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_58]));

DEFLABEL (continuation_34)
  INTERRUPT_CHECK (27, LABEL_64_68);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_109;
  (Wrd13.Obj) = (Rsp [2]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd12.Obj) = ((Wrd14.pObj) [3]);
  (Rsp [2]) = (Wrd12.Obj);
  Rsp = (& (Rsp [2]));
  goto lambda_24;

DEFLABEL (label_109)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_73]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_20]));

DEFLABEL (continuation_35)
  INTERRUPT_CHECK (27, LABEL_64_73);
  (Rsp [1]) = Rvl;
  (Wrd7.Obj) = (Rsp [2]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [4]);
  (Rsp [0]) = (Wrd6.Obj);
  (Wrd9.Obj) = ((Wrd8.pObj) [3]);
  (Rsp [2]) = (Wrd9.Obj);
  goto lambda_29;

DEFLABEL (lambda_88)
DEFLABEL (lambda_8)
  INTERRUPT_CHECK (26, LABEL_64_42);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_50]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_51]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_20]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_64_51);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_61]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_64_50);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_110;
  Rvl = Rvl;
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_110)
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (lambda_89)
  CLOSURE_HEADER (LABEL_64_52);

DEFLABEL (lambda_16)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_62]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_12]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_64_62);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_67]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_64]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_64_67);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_111;
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd12.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_64_72);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_64_71])));
  Rhp += 2;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd12.pObj)));
  Wrd17 = Wrd12;
  (Wrd20.Obj) = ((Wrd8.pObj) [2]);
  ((Wrd17.pObj) [2]) = (Wrd20.Obj);
  (Wrd16.Obj) = ((Wrd8.pObj) [3]);
  ((Wrd17.pObj) [3]) = (Wrd16.Obj);
  (Rsp [2]) = (Wrd11.Obj);
  goto lambda_8;

DEFLABEL (label_111)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_70]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [2]);
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [3]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd29.Obj) = ((Wrd25.pObj) [2]);
  (* (--Rsp)) = (Wrd29.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_12]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_64_70);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (lambda_90)
  CLOSURE_HEADER (LABEL_64_71);

DEFLABEL (lambda_14)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_74]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_12]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_64_74);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_65_4 3
#define LABEL_65_5 5
#define LABEL_65_6 7
#define LABEL_65_7 9
#define LABEL_65_8 11
#define LABEL_65_11 13
#define LABEL_65_12 15
#define LABEL_65_13 17
#define LABEL_65_14 19
#define LABEL_65_9 21
#define LABEL_65_15 23
#define LABEL_65_16 25
#define LABEL_65_17 27
#define LABEL_65_18 29
#define LABEL_65_19 31
#define LABEL_65_20 33
#define LABEL_65_21 35
#define LABEL_65_22 37
#define LABEL_65_24 39
#define ENVIRONMENT_LABEL_65_3 57
#define DEBUGGING_LABEL_65_2 56
#define OBJECT_65_8 55
#define OBJECT_65_7 54
#define OBJECT_65_6 53
#define OBJECT_65_5 52
#define OBJECT_65_4 51
#define OBJECT_65_3 50
#define OBJECT_65_2 49
#define OBJECT_65_1 48
#define OBJECT_65_0 47
#define EXECUTE_CACHE_65_25 41
#define EXECUTE_CACHE_65_23 43
#define EXECUTE_CACHE_65_10 45
#define FREE_REFERENCES_LABEL_65_0 40
#define NUMBER_OF_LINKER_SECTIONS_65_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_65 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd89;
  machine_word Wrd88;
  machine_word Wrd85;
  machine_word Wrd81;
  machine_word Wrd80;
  machine_word Wrd69;
  machine_word Wrd70;
  machine_word Wrd57;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd24;
  machine_word Wrd25;
  machine_word Wrd82;
  machine_word Wrd86;
  machine_word Wrd74;
  machine_word Wrd76;
  machine_word Wrd79;
  machine_word Wrd73;
  machine_word Wrd72;
  machine_word Wrd71;
  machine_word Wrd68;
  machine_word Wrd67;
  machine_word Wrd56;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd51;
  machine_word Wrd42;
  machine_word Wrd50;
  machine_word Wrd39;
  machine_word Wrd35;
  machine_word Wrd26;
  machine_word Wrd34;
  machine_word Wrd21;
  machine_word Wrd5;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd58;
  machine_word Wrd55;
  machine_word Wrd52;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd37;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd23;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_65_4);
      goto week_date__month_date_23;

    case 1:
      current_block = (Rpc - LABEL_65_5);
      goto label_25;

    case 2:
      current_block = (Rpc - LABEL_65_6);
      goto label_26;

    case 3:
      current_block = (Rpc - LABEL_65_7);
      goto label_27;

    case 4:
      current_block = (Rpc - LABEL_65_8);
      goto continuation_4;

    case 5:
      current_block = (Rpc - LABEL_65_11);
      goto label_28;

    case 6:
      current_block = (Rpc - LABEL_65_12);
      goto label_29;

    case 7:
      current_block = (Rpc - LABEL_65_13);
      goto label_30;

    case 8:
      current_block = (Rpc - LABEL_65_14);
      goto label_31;

    case 9:
      current_block = (Rpc - LABEL_65_9);
      goto continuation_3;

    case 10:
      current_block = (Rpc - LABEL_65_15);
      goto label_32;

    case 11:
      current_block = (Rpc - LABEL_65_16);
      goto label_33;

    case 12:
      current_block = (Rpc - LABEL_65_17);
      goto label_34;

    case 13:
      current_block = (Rpc - LABEL_65_18);
      goto label_35;

    case 14:
      current_block = (Rpc - LABEL_65_19);
      goto label_36;

    case 15:
      current_block = (Rpc - LABEL_65_20);
      goto label_37;

    case 16:
      current_block = (Rpc - LABEL_65_21);
      goto label_38;

    case 17:
      current_block = (Rpc - LABEL_65_22);
      goto continuation_5;

    case 18:
      current_block = (Rpc - LABEL_65_24);
      goto label_39;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (week_date__month_date_41)
DEFLABEL (week_date__month_date_23)
  INTERRUPT_CHECK (26, LABEL_65_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_63;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd13.Lng))))
    goto label_63;
  (Wrd7.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_62)
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_61;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd29.Lng))))
    goto label_61;
  (Wrd23.Obj) = ((Wrd27.pObj) [1]);
  (* (--Rsp)) = (Wrd23.Obj);

DEFLABEL (label_60)
  (Wrd46.Obj) = (Rsp [2]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if (! ((Wrd47.uLng) == 10))
    goto label_59;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [0]);
  (Wrd45.Lng) = (FIXNUM_TO_LONG (Wrd44.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd45.Lng))))
    goto label_59;
  (Wrd37.Obj) = ((Wrd43.pObj) [3]);

DEFLABEL (label_58)
  (Rsp [2]) = (Wrd37.Obj);
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_8]))));
  (* (--Rsp)) = (Wrd55.Obj);
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_9]))));
  (* (--Rsp)) = (Wrd58.Obj);
  (Wrd59.Obj) = (current_block [OBJECT_65_2]);
  (* (--Rsp)) = (Wrd59.Obj);
  (Wrd60.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd60.Obj);
  (Wrd61.Obj) = (current_block [OBJECT_65_0]);
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd59.Obj);
  (* (--Rsp)) = (Wrd59.Obj);
  (* (--Rsp)) = (Wrd59.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_65_10]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_65_9);
  (* (--Rsp)) = Rvl;
  (Wrd15.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd15.uLng) == 10))
    goto label_57;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd13.Lng))))
    goto label_57;
  (Wrd5.Obj) = ((Wrd11.pObj) [8]);

DEFLABEL (label_56)
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd26.uLng) == 26))
    goto label_55;
  (Wrd28.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  (Wrd27.Lng) = ((Wrd28.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd27.Lng)))
    goto label_55;
  (Wrd25.Obj) = (LONG_TO_FIXNUM (Wrd27.Lng));

DEFLABEL (label_54)
  (Wrd34.Obj) = (Rsp [4]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 26))
    goto label_53;
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd36.uLng) == 26))
    goto label_53;
  (Wrd39.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  (Wrd40.Lng) = (FIXNUM_TO_LONG (Wrd25.Obj));
  (Wrd37.Lng) = ((Wrd39.Lng) - (Wrd40.Lng));
  if (! (LONG_TO_FIXNUM_P (Wrd37.Lng)))
    goto label_53;
  (Wrd41.Obj) = (LONG_TO_FIXNUM (Wrd37.Lng));
  (* (--Rsp)) = (Wrd41.Obj);

DEFLABEL (label_52)
  (Wrd47.Obj) = (Rsp [4]);
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd47.Obj));
  if (! ((Wrd48.uLng) == 26))
    goto label_51;
  (Wrd51.Lng) = (FIXNUM_TO_LONG (Wrd47.Obj));
  (Wrd49.Lng) = ((Wrd51.Lng) - 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd49.Lng)))
    goto label_51;
  (Wrd46.Obj) = (LONG_TO_FIXNUM (Wrd49.Lng));

DEFLABEL (label_50)
  (Wrd58.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if (! ((Wrd58.uLng) == 26))
    goto label_49;
  (Wrd62.Lng) = (FIXNUM_TO_LONG (Wrd46.Obj));
  if (multiply_with_overflow ((Wrd62.Lng), 7, (& (Wrd59.Lng))))
    goto label_49;
  (Wrd57.Obj) = (LONG_TO_FIXNUM (Wrd59.Lng));

DEFLABEL (label_48)
  (Wrd63.Obj) = (* (Rsp++));
  (Wrd70.uLng) = (OBJECT_TYPE (Wrd57.Obj));
  if (! ((Wrd70.uLng) == 26))
    goto label_47;
  (Wrd71.uLng) = (OBJECT_TYPE (Wrd63.Obj));
  if (! ((Wrd71.uLng) == 26))
    goto label_47;
  (Wrd73.Lng) = (FIXNUM_TO_LONG (Wrd57.Obj));
  (Wrd74.Lng) = (FIXNUM_TO_LONG (Wrd63.Obj));
  (Wrd72.Lng) = ((Wrd73.Lng) + (Wrd74.Lng));
  if (! (LONG_TO_FIXNUM_P (Wrd72.Lng)))
    goto label_47;
  (Wrd69.Obj) = (LONG_TO_FIXNUM (Wrd72.Lng));

DEFLABEL (label_46)
  (Wrd80.uLng) = (OBJECT_TYPE (Wrd69.Obj));
  if (! ((Wrd80.uLng) == 26))
    goto label_45;
  (Wrd82.Lng) = (FIXNUM_TO_LONG (Wrd69.Obj));
  if (multiply_with_overflow ((Wrd82.Lng), 86400, (& (Wrd81.Lng))))
    goto label_45;
  (Wrd85.Obj) = (LONG_TO_FIXNUM (Wrd81.Lng));
  (* (--Rsp)) = (Wrd85.Obj);

DEFLABEL (label_44)
  (Wrd88.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_22]))));
  (* (--Rsp)) = (Wrd88.Obj);
  (Wrd89.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd89.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_65_23]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_65_22);
  (Wrd6.Obj) = Rvl;
  (Wrd5.Obj) = (* (Rsp++));
  (Wrd13.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd13.uLng) == 26))
    goto label_43;
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd14.uLng) == 26))
    goto label_43;
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Rvl));
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  (Wrd15.Lng) = ((Wrd16.Lng) + (Wrd17.Lng));
  if (! (LONG_TO_FIXNUM_P (Wrd15.Lng)))
    goto label_43;
  (Wrd12.Obj) = (LONG_TO_FIXNUM (Wrd15.Lng));

DEFLABEL (label_42)
  (Rsp [0]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_65_25]));

DEFLABEL (label_43)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_24]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_INTERFACE_0 (43);

DEFLABEL (label_39)
  (Wrd12.Obj) = Rvl;
  goto label_42;

DEFLABEL (label_45)
  (Wrd76.Obj) = (current_block [OBJECT_65_8]);
  (Wrd79.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_21]))));
  (* (--Rsp)) = (Wrd79.Obj);
  (* (--Rsp)) = (Wrd76.Obj);
  (* (--Rsp)) = (Wrd69.Obj);
  INVOKE_INTERFACE_0 (41);

DEFLABEL (label_38)
  (* (--Rsp)) = Rvl;
  goto label_44;

DEFLABEL (label_47)
  (Wrd68.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_20]))));
  (* (--Rsp)) = (Wrd68.Obj);
  (* (--Rsp)) = (Wrd63.Obj);
  (* (--Rsp)) = (Wrd57.Obj);
  INVOKE_INTERFACE_0 (43);

DEFLABEL (label_37)
  (Wrd69.Obj) = Rvl;
  goto label_46;

DEFLABEL (label_49)
  (Wrd52.Obj) = (current_block [OBJECT_65_7]);
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_19]))));
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd46.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  INVOKE_INTERFACE_0 (41);

DEFLABEL (label_36)
  (Wrd57.Obj) = Rvl;
  goto label_48;

DEFLABEL (label_51)
  (Wrd42.Obj) = (Rsp [4]);
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_18]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  INVOKE_INTERFACE_0 (34);

DEFLABEL (label_35)
  (Wrd46.Obj) = Rvl;
  goto label_50;

DEFLABEL (label_53)
  (Wrd29.Obj) = (Rsp [4]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_17]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_INTERFACE_0 (40);

DEFLABEL (label_34)
  (* (--Rsp)) = Rvl;
  goto label_52;

DEFLABEL (label_55)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_16]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_33)
  (Wrd25.Obj) = Rvl;
  goto label_54;

DEFLABEL (label_57)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_65_7]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_15]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_65_1]), 2);

DEFLABEL (label_32)
  (Wrd5.Obj) = Rvl;
  goto label_56;

DEFLABEL (label_59)
  (Wrd48.Obj) = (Rsp [2]);
  (Wrd49.Obj) = (current_block [OBJECT_65_3]);
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_7]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_65_1]), 2);

DEFLABEL (label_27)
  (Wrd37.Obj) = Rvl;
  goto label_58;

DEFLABEL (label_61)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.Obj) = (current_block [OBJECT_65_2]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_6]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_65_1]), 2);

DEFLABEL (label_26)
  (* (--Rsp)) = Rvl;
  goto label_60;

DEFLABEL (label_63)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_65_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_65_1]), 2);

DEFLABEL (label_25)
  (* (--Rsp)) = Rvl;
  goto label_62;

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_65_8);
  (* (--Rsp)) = Rvl;
  (Wrd15.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd15.uLng) == 10))
    goto label_73;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd13.Lng))))
    goto label_73;
  (Wrd5.Obj) = ((Wrd11.pObj) [7]);

DEFLABEL (label_72)
  (Wrd21.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == (Wrd21.Obj))
    goto label_65;
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_64)
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_65)
  (Wrd33.Obj) = (Rsp [0]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 10))
    goto label_71;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd32.Lng))))
    goto label_71;
  (Wrd26.Obj) = ((Wrd30.pObj) [6]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_70)
  (Wrd49.Obj) = (Rsp [1]);
  (Wrd50.uLng) = (OBJECT_TYPE (Wrd49.Obj));
  if (! ((Wrd50.uLng) == 10))
    goto label_69;
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd49.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [0]);
  (Wrd48.Lng) = (FIXNUM_TO_LONG (Wrd47.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd48.Lng))))
    goto label_69;
  (Wrd42.Obj) = ((Wrd46.pObj) [5]);
  (* (--Rsp)) = (Wrd42.Obj);

DEFLABEL (label_68)
  (Wrd65.Obj) = (Rsp [2]);
  (Wrd66.uLng) = (OBJECT_TYPE (Wrd65.Obj));
  if (! ((Wrd66.uLng) == 10))
    goto label_67;
  (Wrd62.pObj) = (OBJECT_ADDRESS (Wrd65.Obj));
  (Wrd63.Obj) = ((Wrd62.pObj) [0]);
  (Wrd64.Lng) = (FIXNUM_TO_LONG (Wrd63.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd64.Lng))))
    goto label_67;
  (Wrd56.Obj) = ((Wrd62.pObj) [7]);

DEFLABEL (label_66)
  (Wrd72.Obj) = (* (Rsp++));
  (Wrd73.Obj) = (* (Rsp++));
  (Wrd79.Obj) = (MAKE_OBJECT (0, 3));
  (* (Rhp++)) = (Wrd79.Obj);
  (* (Rhp++)) = (Wrd56.Obj);
  (* (Rhp++)) = (Wrd73.Obj);
  (* (Rhp++)) = (Wrd72.Obj);
  (Wrd76.pObj) = (& (Rhp [-4]));
  (Wrd74.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd76.pObj)));
  (Wrd86.Obj) = (MAKE_OBJECT (0, 1));
  (* (Rhp++)) = (Wrd86.Obj);
  (* (Rhp++)) = (Wrd74.Obj);
  (Wrd82.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd82.pObj)));
  goto label_64;

DEFLABEL (label_67)
  (Wrd67.Obj) = (Rsp [2]);
  (Wrd68.Obj) = (current_block [OBJECT_65_4]);
  (Wrd71.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_14]))));
  (* (--Rsp)) = (Wrd71.Obj);
  (* (--Rsp)) = (Wrd68.Obj);
  (* (--Rsp)) = (Wrd67.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_65_1]), 2);

DEFLABEL (label_31)
  (Wrd56.Obj) = Rvl;
  goto label_66;

DEFLABEL (label_69)
  (Wrd51.Obj) = (Rsp [1]);
  (Wrd52.Obj) = (current_block [OBJECT_65_6]);
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_13]))));
  (* (--Rsp)) = (Wrd55.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_65_1]), 2);

DEFLABEL (label_30)
  (* (--Rsp)) = Rvl;
  goto label_68;

DEFLABEL (label_71)
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.Obj) = (current_block [OBJECT_65_5]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_12]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_65_1]), 2);

DEFLABEL (label_29)
  (* (--Rsp)) = Rvl;
  goto label_70;

DEFLABEL (label_73)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_65_4]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_11]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_65_1]), 2);

DEFLABEL (label_28)
  (Wrd5.Obj) = Rvl;
  goto label_72;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_66_4 3
#define LABEL_66_5 5
#define LABEL_66_6 7
#define LABEL_66_7 9
#define LABEL_66_10 11
#define LABEL_66_11 13
#define LABEL_66_12 15
#define LABEL_66_13 17
#define LABEL_66_8 19
#define LABEL_66_14 21
#define LABEL_66_15 23
#define LABEL_66_16 25
#define LABEL_66_18 27
#define ENVIRONMENT_LABEL_66_3 43
#define DEBUGGING_LABEL_66_2 42
#define OBJECT_66_6 41
#define OBJECT_66_5 40
#define OBJECT_66_4 39
#define OBJECT_66_3 38
#define OBJECT_66_2 37
#define OBJECT_66_1 36
#define OBJECT_66_0 35
#define EXECUTE_CACHE_66_19 29
#define EXECUTE_CACHE_66_17 31
#define EXECUTE_CACHE_66_9 33
#define FREE_REFERENCES_LABEL_66_0 28
#define NUMBER_OF_LINKER_SECTIONS_66_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_66 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd19;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd10;
  machine_word Wrd82;
  machine_word Wrd86;
  machine_word Wrd74;
  machine_word Wrd76;
  machine_word Wrd79;
  machine_word Wrd73;
  machine_word Wrd72;
  machine_word Wrd71;
  machine_word Wrd68;
  machine_word Wrd67;
  machine_word Wrd56;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd55;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd35;
  machine_word Wrd26;
  machine_word Wrd34;
  machine_word Wrd5;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd21;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_66_4);
      goto ordinal_date__month_date_17;

    case 1:
      current_block = (Rpc - LABEL_66_5);
      goto label_19;

    case 2:
      current_block = (Rpc - LABEL_66_6);
      goto label_20;

    case 3:
      current_block = (Rpc - LABEL_66_7);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_66_10);
      goto label_21;

    case 5:
      current_block = (Rpc - LABEL_66_11);
      goto label_22;

    case 6:
      current_block = (Rpc - LABEL_66_12);
      goto label_23;

    case 7:
      current_block = (Rpc - LABEL_66_13);
      goto label_24;

    case 8:
      current_block = (Rpc - LABEL_66_8);
      goto continuation_2;

    case 9:
      current_block = (Rpc - LABEL_66_14);
      goto label_25;

    case 10:
      current_block = (Rpc - LABEL_66_15);
      goto label_26;

    case 11:
      current_block = (Rpc - LABEL_66_16);
      goto continuation_4;

    case 12:
      current_block = (Rpc - LABEL_66_18);
      goto label_27;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (ordinal_date__month_date_29)
DEFLABEL (ordinal_date__month_date_17)
  INTERRUPT_CHECK (26, LABEL_66_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_39;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd13.Lng))))
    goto label_39;
  (Wrd7.Obj) = ((Wrd11.pObj) [1]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_38)
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_37;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd29.Lng))))
    goto label_37;
  (Wrd21.Obj) = ((Wrd27.pObj) [2]);

DEFLABEL (label_36)
  (Rsp [1]) = (Wrd21.Obj);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66_7]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66_8]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (Wrd43.Obj) = (current_block [OBJECT_66_0]);
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd44.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd45.Obj) = (current_block [OBJECT_66_2]);
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_66_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_66_8);
  (* (--Rsp)) = Rvl;
  (Wrd10.Obj) = (Rsp [3]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 26))
    goto label_35;
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd10.Obj));
  (Wrd12.Lng) = ((Wrd14.Lng) - 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd12.Lng)))
    goto label_35;
  (Wrd9.Obj) = (LONG_TO_FIXNUM (Wrd12.Lng));

DEFLABEL (label_34)
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd20.uLng) == 26))
    goto label_33;
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd9.Obj));
  if (multiply_with_overflow ((Wrd22.Lng), 86400, (& (Wrd21.Lng))))
    goto label_33;
  (Wrd25.Obj) = (LONG_TO_FIXNUM (Wrd21.Lng));
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_32)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66_16]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd29.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd29.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_66_17]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_66_16);
  (Wrd6.Obj) = Rvl;
  (Wrd5.Obj) = (* (Rsp++));
  (Wrd13.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd13.uLng) == 26))
    goto label_31;
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd14.uLng) == 26))
    goto label_31;
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Rvl));
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  (Wrd15.Lng) = ((Wrd16.Lng) + (Wrd17.Lng));
  if (! (LONG_TO_FIXNUM_P (Wrd15.Lng)))
    goto label_31;
  (Wrd12.Obj) = (LONG_TO_FIXNUM (Wrd15.Lng));

DEFLABEL (label_30)
  (Rsp [0]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_66_19]));

DEFLABEL (label_31)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66_18]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_INTERFACE_0 (43);

DEFLABEL (label_27)
  (Wrd12.Obj) = Rvl;
  goto label_30;

DEFLABEL (label_33)
  (Wrd16.Obj) = (current_block [OBJECT_66_6]);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66_15]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_INTERFACE_0 (41);

DEFLABEL (label_26)
  (* (--Rsp)) = Rvl;
  goto label_32;

DEFLABEL (label_35)
  (Wrd5.Obj) = (Rsp [3]);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66_14]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_INTERFACE_0 (34);

DEFLABEL (label_25)
  (Wrd9.Obj) = Rvl;
  goto label_34;

DEFLABEL (label_37)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.Obj) = (current_block [OBJECT_66_2]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66_6]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_66_1]), 2);

DEFLABEL (label_20)
  (Wrd21.Obj) = Rvl;
  goto label_36;

DEFLABEL (label_39)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_66_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_66_1]), 2);

DEFLABEL (label_19)
  (* (--Rsp)) = Rvl;
  goto label_38;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_66_7);
  (* (--Rsp)) = Rvl;
  (Wrd15.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd15.uLng) == 10))
    goto label_49;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd13.Lng))))
    goto label_49;
  (Wrd5.Obj) = ((Wrd11.pObj) [7]);

DEFLABEL (label_48)
  (Wrd21.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == (Wrd21.Obj))
    goto label_41;
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_40)
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_41)
  (Wrd33.Obj) = (Rsp [0]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 10))
    goto label_47;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd32.Lng))))
    goto label_47;
  (Wrd26.Obj) = ((Wrd30.pObj) [6]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_46)
  (Wrd49.Obj) = (Rsp [1]);
  (Wrd50.uLng) = (OBJECT_TYPE (Wrd49.Obj));
  if (! ((Wrd50.uLng) == 10))
    goto label_45;
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd49.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [0]);
  (Wrd48.Lng) = (FIXNUM_TO_LONG (Wrd47.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd48.Lng))))
    goto label_45;
  (Wrd42.Obj) = ((Wrd46.pObj) [5]);
  (* (--Rsp)) = (Wrd42.Obj);

DEFLABEL (label_44)
  (Wrd65.Obj) = (Rsp [2]);
  (Wrd66.uLng) = (OBJECT_TYPE (Wrd65.Obj));
  if (! ((Wrd66.uLng) == 10))
    goto label_43;
  (Wrd62.pObj) = (OBJECT_ADDRESS (Wrd65.Obj));
  (Wrd63.Obj) = ((Wrd62.pObj) [0]);
  (Wrd64.Lng) = (FIXNUM_TO_LONG (Wrd63.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd64.Lng))))
    goto label_43;
  (Wrd56.Obj) = ((Wrd62.pObj) [7]);

DEFLABEL (label_42)
  (Wrd72.Obj) = (* (Rsp++));
  (Wrd73.Obj) = (* (Rsp++));
  (Wrd79.Obj) = (MAKE_OBJECT (0, 3));
  (* (Rhp++)) = (Wrd79.Obj);
  (* (Rhp++)) = (Wrd56.Obj);
  (* (Rhp++)) = (Wrd73.Obj);
  (* (Rhp++)) = (Wrd72.Obj);
  (Wrd76.pObj) = (& (Rhp [-4]));
  (Wrd74.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd76.pObj)));
  (Wrd86.Obj) = (MAKE_OBJECT (0, 1));
  (* (Rhp++)) = (Wrd86.Obj);
  (* (Rhp++)) = (Wrd74.Obj);
  (Wrd82.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd82.pObj)));
  goto label_40;

DEFLABEL (label_43)
  (Wrd67.Obj) = (Rsp [2]);
  (Wrd68.Obj) = (current_block [OBJECT_66_3]);
  (Wrd71.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66_13]))));
  (* (--Rsp)) = (Wrd71.Obj);
  (* (--Rsp)) = (Wrd68.Obj);
  (* (--Rsp)) = (Wrd67.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_66_1]), 2);

DEFLABEL (label_24)
  (Wrd56.Obj) = Rvl;
  goto label_42;

DEFLABEL (label_45)
  (Wrd51.Obj) = (Rsp [1]);
  (Wrd52.Obj) = (current_block [OBJECT_66_5]);
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66_12]))));
  (* (--Rsp)) = (Wrd55.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_66_1]), 2);

DEFLABEL (label_23)
  (* (--Rsp)) = Rvl;
  goto label_44;

DEFLABEL (label_47)
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.Obj) = (current_block [OBJECT_66_4]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66_11]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_66_1]), 2);

DEFLABEL (label_22)
  (* (--Rsp)) = Rvl;
  goto label_46;

DEFLABEL (label_49)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_66_3]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66_10]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_66_1]), 2);

DEFLABEL (label_21)
  (Wrd5.Obj) = Rvl;
  goto label_48;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_67_4 3
#define LABEL_67_5 5
#define LABEL_67_7 7
#define LABEL_67_8 9
#define LABEL_67_10 11
#define LABEL_67_12 13
#define LABEL_67_15 15
#define LABEL_67_13 17
#define LABEL_67_16 19
#define LABEL_67_19 21
#define LABEL_67_18 23
#define LABEL_67_22 25
#define TAG_67_23 11
#define LABEL_67_24 27
#define LABEL_67_21 29
#define LABEL_67_25 31
#define LABEL_67_27 33
#define LABEL_67_28 35
#define LABEL_67_30 37
#define LABEL_67_29 39
#define LABEL_67_31 41
#define LABEL_67_33 43
#define LABEL_67_34 45
#define LABEL_67_36 47
#define ENVIRONMENT_LABEL_67_3 72
#define DEBUGGING_LABEL_67_2 71
#define OBJECT_67_3 70
#define OBJECT_67_2 69
#define OBJECT_67_1 68
#define OBJECT_67_0 67
#define EXECUTE_CACHE_67_32 49
#define EXECUTE_CACHE_67_35 51
#define EXECUTE_CACHE_67_26 53
#define EXECUTE_CACHE_67_20 55
#define EXECUTE_CACHE_67_17 57
#define EXECUTE_CACHE_67_14 59
#define EXECUTE_CACHE_67_11 61
#define EXECUTE_CACHE_67_9 63
#define EXECUTE_CACHE_67_6 65
#define FREE_REFERENCES_LABEL_67_0 48
#define NUMBER_OF_LINKER_SECTIONS_67_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_67 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd17;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd15;
  machine_word Wrd5;
  machine_word Wrd14;
  machine_word Wrd16;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_67_4);
      goto parse_8601_zone_43;

    case 1:
      current_block = (Rpc - LABEL_67_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_67_7);
      goto continuation_4;

    case 3:
      current_block = (Rpc - LABEL_67_8);
      goto continuation_32;

    case 4:
      current_block = (Rpc - LABEL_67_10);
      goto continuation_33;

    case 5:
      current_block = (Rpc - LABEL_67_12);
      goto lambda_31;

    case 6:
      current_block = (Rpc - LABEL_67_15);
      goto lambda_3;

    case 7:
      current_block = (Rpc - LABEL_67_13);
      goto continuation_5;

    case 8:
      current_block = (Rpc - LABEL_67_16);
      goto continuation_6;

    case 9:
      current_block = (Rpc - LABEL_67_19);
      goto continuation_8;

    case 10:
      current_block = (Rpc - LABEL_67_18);
      goto continuation_7;

    case 11:
      current_block = (Rpc - LABEL_67_22);
      goto lambda_11;

    case 12:
      current_block = (Rpc - LABEL_67_24);
      goto continuation_12;

    case 13:
      current_block = (Rpc - LABEL_67_21);
      goto continuation_9;

    case 14:
      current_block = (Rpc - LABEL_67_25);
      goto continuation_10;

    case 15:
      current_block = (Rpc - LABEL_67_27);
      goto continuation_23;

    case 16:
      current_block = (Rpc - LABEL_67_28);
      goto lambda_22;

    case 17:
      current_block = (Rpc - LABEL_67_30);
      goto lambda_16;

    case 18:
      current_block = (Rpc - LABEL_67_29);
      goto continuation_17;

    case 19:
      current_block = (Rpc - LABEL_67_31);
      goto continuation_13;

    case 20:
      current_block = (Rpc - LABEL_67_33);
      goto lambda_21;

    case 21:
      current_block = (Rpc - LABEL_67_34);
      goto continuation_14;

    case 22:
      current_block = (Rpc - LABEL_67_36);
      goto continuation_19;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (parse_8601_zone_46)
DEFLABEL (parse_8601_zone_43)
  INTERRUPT_CHECK (26, LABEL_67_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_67_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_6]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_67_7);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_67_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_9]));

DEFLABEL (continuation_32)
  INTERRUPT_CHECK (27, LABEL_67_8);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_53;
  goto lambda_31;

DEFLABEL (label_53)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_10]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_11]));

DEFLABEL (continuation_33)
  INTERRUPT_CHECK (27, LABEL_67_10);
  (Wrd11.Obj) = (MAKE_OBJECT (0, 1));
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd19.Obj) = (MAKE_OBJECT (0, 3));
  (Wrd20.Obj) = (current_block [OBJECT_67_1]);
  (Wrd21.Obj) = (current_block [OBJECT_67_2]);
  (* (Rhp++)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd20.Obj);
  (* (Rhp++)) = (Wrd21.Obj);
  (* (Rhp++)) = (Wrd21.Obj);
  (Wrd16.pObj) = (& (Rhp [-4]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd16.pObj)));
  Rsp = (& (Rsp [1]));
  (Rsp [0]) = (Wrd14.Obj);
  if ((Wrd14.Obj) == ((SCHEME_OBJECT) 0))
    goto label_54;
  (Rsp [3]) = (Wrd14.Obj);
  Rsp = (& (Rsp [3]));
  goto lambda_3;

DEFLABEL (label_54)
  Rsp = (& (Rsp [1]));
  goto lambda_31;

DEFLABEL (lambda_47)
DEFLABEL (lambda_31)
  INTERRUPT_CHECK (26, LABEL_67_12);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_14]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_67_13);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_17]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_67_16);
  (Rsp [0]) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_57;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_19]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_20]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_67_19);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_56;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_67_23);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_67_22])));
  Rhp += 2;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd12 = Wrd9;
  (Wrd13.Obj) = (Rsp [1]);
  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
  ((Wrd12.pObj) [3]) = Rvl;
  (Rsp [2]) = (Wrd8.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_24]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_6]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_67_24);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_27]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_67_3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_9]));

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_67_27);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_55;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_28]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (Wrd10.pObj) = (& (Rhp [-1]));
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd10.pObj)));
  (* (--Rsp)) = (Wrd11.Obj);
  goto lambda_16;

DEFLABEL (label_55)
  goto lambda_22;

DEFLABEL (label_56)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_21]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_14]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_67_21);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_57)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_18]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_14]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_67_18);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (lambda_48)
DEFLABEL (lambda_3)
  INTERRUPT_CHECK (26, LABEL_67_15);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd14.Obj) = (MAKE_OBJECT (0, 1));
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd10.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd10.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_49)
DEFLABEL (lambda_11)
  INTERRUPT_CHECK (26, LABEL_67_22);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_25]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_26]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_67_25);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  goto lambda_3;

DEFLABEL (lambda_50)
DEFLABEL (lambda_22)
  INTERRUPT_CHECK (26, LABEL_67_28);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_29]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_14]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_67_29);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_33]))));
  (* (--Rsp)) = (Wrd6.Obj);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (Wrd8.pObj) = (& (Rhp [-1]));
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd8.pObj)));
  (* (--Rsp)) = (Wrd9.Obj);
  goto lambda_16;

DEFLABEL (lambda_51)
DEFLABEL (lambda_16)
  INTERRUPT_CHECK (26, LABEL_67_30);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_31]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_32]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_67_31);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_58;
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_58)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_34]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_35]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_67_34);
  (Rsp [5]) = Rvl;
  Rsp = (& (Rsp [4]));
  goto lambda_11;

DEFLABEL (lambda_52)
DEFLABEL (lambda_21)
  INTERRUPT_CHECK (26, LABEL_67_33);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_36]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_14]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_67_36);
  (Wrd10.Obj) = (MAKE_OBJECT (0, 1));
  (Wrd11.Obj) = (current_block [OBJECT_67_2]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd7.pObj)));
  (Rsp [2]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  goto lambda_11;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_68_4 3
#define LABEL_68_5 5
#define LABEL_68_7 7
#define LABEL_68_11 9
#define TAG_68_12 3
#define LABEL_68_13 11
#define LABEL_68_9 13
#define LABEL_68_14 15
#define LABEL_68_20 17
#define LABEL_68_21 19
#define LABEL_68_22 21
#define LABEL_68_16 23
#define TAG_68_17 10
#define LABEL_68_18 25
#define LABEL_68_23 27
#define LABEL_68_24 29
#define LABEL_68_26 31
#define LABEL_68_27 33
#define TAG_68_28 15
#define LABEL_68_29 35
#define LABEL_68_31 37
#define TAG_68_32 17
#define LABEL_68_33 39
#define LABEL_68_30 41
#define LABEL_68_34 43
#define LABEL_68_35 45
#define TAG_68_36 21
#define LABEL_68_37 47
#define LABEL_68_38 49
#define LABEL_68_39 51
#define TAG_68_40 24
#define LABEL_68_41 53
#define LABEL_68_43 55
#define LABEL_68_44 57
#define LABEL_68_45 59
#define LABEL_68_46 61
#define TAG_68_47 29
#define LABEL_68_48 63
#define ENVIRONMENT_LABEL_68_3 86
#define DEBUGGING_LABEL_68_2 85
#define OBJECT_68_5 84
#define OBJECT_68_4 83
#define OBJECT_68_3 82
#define OBJECT_68_2 81
#define OBJECT_68_1 80
#define OBJECT_68_0 79
#define EXECUTE_CACHE_68_42 65
#define EXECUTE_CACHE_68_25 67
#define EXECUTE_CACHE_68_19 69
#define EXECUTE_CACHE_68_15 71
#define EXECUTE_CACHE_68_10 73
#define EXECUTE_CACHE_68_8 75
#define EXECUTE_CACHE_68_6 77
#define FREE_REFERENCES_LABEL_68_0 64
#define NUMBER_OF_LINKER_SECTIONS_68_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_68 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd30;
  machine_word Wrd81;
  machine_word Wrd83;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd86;
  machine_word Wrd71;
  machine_word Wrd73;
  machine_word Wrd76;
  machine_word Wrd70;
  machine_word Wrd69;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd54;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd50;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd35;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd12;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd9;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_68_4);
      goto parse_8601_time_54;

    case 1:
      current_block = (Rpc - LABEL_68_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_68_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_68_11);
      goto lambda_14;

    case 4:
      current_block = (Rpc - LABEL_68_13);
      goto continuation_15;

    case 5:
      current_block = (Rpc - LABEL_68_9);
      goto continuation_2;

    case 6:
      current_block = (Rpc - LABEL_68_14);
      goto continuation_3;

    case 7:
      current_block = (Rpc - LABEL_68_20);
      goto label_56;

    case 8:
      current_block = (Rpc - LABEL_68_21);
      goto label_57;

    case 9:
      current_block = (Rpc - LABEL_68_22);
      goto label_58;

    case 10:
      current_block = (Rpc - LABEL_68_16);
      goto lambda_62;

    case 11:
      current_block = (Rpc - LABEL_68_18);
      goto continuation_34;

    case 12:
      current_block = (Rpc - LABEL_68_23);
      goto continuation_16;

    case 13:
      current_block = (Rpc - LABEL_68_24);
      goto continuation_35;

    case 14:
      current_block = (Rpc - LABEL_68_26);
      goto continuation_17;

    case 15:
      current_block = (Rpc - LABEL_68_27);
      goto lambda_37;

    case 16:
      current_block = (Rpc - LABEL_68_29);
      goto continuation_38;

    case 17:
      current_block = (Rpc - LABEL_68_31);
      goto lambda_20;

    case 18:
      current_block = (Rpc - LABEL_68_33);
      goto continuation_21;

    case 19:
      current_block = (Rpc - LABEL_68_30);
      goto continuation_18;

    case 20:
      current_block = (Rpc - LABEL_68_34);
      goto continuation_36;

    case 21:
      current_block = (Rpc - LABEL_68_35);
      goto lambda_65;

    case 22:
      current_block = (Rpc - LABEL_68_37);
      goto continuation_42;

    case 23:
      current_block = (Rpc - LABEL_68_38);
      goto continuation_19;

    case 24:
      current_block = (Rpc - LABEL_68_39);
      goto lambda_66;

    case 25:
      current_block = (Rpc - LABEL_68_41);
      goto continuation_27;

    case 26:
      current_block = (Rpc - LABEL_68_43);
      goto continuation_39;

    case 27:
      current_block = (Rpc - LABEL_68_44);
      goto continuation_43;

    case 28:
      current_block = (Rpc - LABEL_68_45);
      goto continuation_22;

    case 29:
      current_block = (Rpc - LABEL_68_46);
      goto lambda_67;

    case 30:
      current_block = (Rpc - LABEL_68_48);
      goto continuation_24;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (parse_8601_time_60)
DEFLABEL (parse_8601_time_54)
  INTERRUPT_CHECK (26, LABEL_68_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_68_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_68_7);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_72;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_68_12);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_68_11])));
  Rhp += 1;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  ((Wrd9.pObj) [2]) = Rvl;
  (Rsp [0]) = (Wrd8.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_13]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_6]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_68_13);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_68_17);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_68_16])));
  Rhp += 4;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [3]);
  ((Wrd14.pObj) [2]) = (Wrd15.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd14.pObj) [4]) = (Wrd11.Obj);
  ((Wrd14.pObj) [5]) = Rvl;
  (Rsp [0]) = (Wrd6.Obj);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_18]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (current_block [OBJECT_68_0]);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_19]));

DEFLABEL (continuation_34)
  INTERRUPT_CHECK (27, LABEL_68_18);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_68;
  (Wrd11.Obj) = (Rsp [0]);
  (Rsp [3]) = (Wrd11.Obj);
  Rsp = (& (Rsp [3]));
  goto lambda_33;

DEFLABEL (label_68)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_24]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_25]));

DEFLABEL (continuation_35)
  INTERRUPT_CHECK (27, LABEL_68_24);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_69;
  (Wrd18.Obj) = (Rsp [1]);
  (Rsp [4]) = (Wrd18.Obj);
  Rsp = (& (Rsp [4]));
  goto lambda_33;

DEFLABEL (label_69)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_68_28);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_68_27])));
  Rhp += 2;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd12 = Wrd9;
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
  ((Wrd12.pObj) [3]) = Rvl;
  (Rsp [0]) = (Wrd8.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_29]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_6]));

DEFLABEL (continuation_38)
  INTERRUPT_CHECK (27, LABEL_68_29);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_68_36);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_68_35])));
  Rhp += 4;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [5]);
  ((Wrd14.pObj) [2]) = (Wrd15.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd14.pObj) [4]) = (Wrd11.Obj);
  ((Wrd14.pObj) [5]) = Rvl;
  (Rsp [0]) = (Wrd6.Obj);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_37]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (current_block [OBJECT_68_0]);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_19]));

DEFLABEL (continuation_42)
  INTERRUPT_CHECK (27, LABEL_68_37);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_70;
  (Wrd11.Obj) = (Rsp [0]);
  (Rsp [5]) = (Wrd11.Obj);
  Rsp = (& (Rsp [5]));
  goto lambda_41;

DEFLABEL (label_70)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_44]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_42]));

DEFLABEL (continuation_43)
  INTERRUPT_CHECK (27, LABEL_68_44);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_71;
  (Wrd7.Obj) = (Rsp [2]);
  (Rsp [4]) = (Wrd7.Obj);
  (Rsp [5]) = Rvl;
  (Wrd9.Obj) = (Rsp [1]);
  (Rsp [6]) = (Wrd9.Obj);
  Rsp = (& (Rsp [4]));
  goto lambda_37;

DEFLABEL (label_71)
  (Wrd11.Obj) = (Rsp [1]);
  (Rsp [6]) = (Wrd11.Obj);
  Rsp = (& (Rsp [6]));
  goto lambda_41;

DEFLABEL (label_72)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_9]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_68_9);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (lambda_61)
DEFLABEL (lambda_14)
  INTERRUPT_CHECK (26, LABEL_68_11);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_15]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_68_14);
  (* (--Rsp)) = Rvl;
  (Wrd15.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd15.uLng) == 10))
    goto label_84;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd13.Lng))))
    goto label_84;
  (Wrd5.Obj) = ((Wrd11.pObj) [1]);

DEFLABEL (label_83)
  if ((Wrd5.Obj) == (current_block [OBJECT_68_3]))
    goto label_76;
  (Wrd28.Obj) = (MAKE_OBJECT (0, 1));
  (Wrd29.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd28.Obj);
  (* (Rhp++)) = (Wrd29.Obj);

DEFLABEL (label_75)
  (Wrd83.pObj) = (& (Rhp [-2]));
  (Wrd81.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd83.pObj)));
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd81.Obj);

DEFLABEL (label_74)
  (Wrd30.Obj) = (Rsp [0]);
  if ((Wrd30.Obj) == ((SCHEME_OBJECT) 0))
    goto label_73;
  Rvl = (Wrd30.Obj);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_73)
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_76)
  (Wrd44.Obj) = (Rsp [0]);
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if (! ((Wrd45.uLng) == 10))
    goto label_82;
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd42.Obj) = ((Wrd41.pObj) [0]);
  (Wrd43.Lng) = (FIXNUM_TO_LONG (Wrd42.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd43.Lng))))
    goto label_82;
  (Wrd35.Obj) = ((Wrd41.pObj) [2]);

DEFLABEL (label_81)
  if ((Wrd35.Obj) == (current_block [OBJECT_68_1]))
    goto label_78;

DEFLABEL (label_77)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  goto label_74;

DEFLABEL (label_78)
  (Wrd63.Obj) = (Rsp [0]);
  (Wrd64.uLng) = (OBJECT_TYPE (Wrd63.Obj));
  if (! ((Wrd64.uLng) == 10))
    goto label_80;
  (Wrd60.pObj) = (OBJECT_ADDRESS (Wrd63.Obj));
  (Wrd61.Obj) = ((Wrd60.pObj) [0]);
  (Wrd62.Lng) = (FIXNUM_TO_LONG (Wrd61.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd62.Lng))))
    goto label_80;
  (Wrd54.Obj) = ((Wrd60.pObj) [3]);

DEFLABEL (label_79)
  (Wrd70.Obj) = (current_block [OBJECT_68_1]);
  if (! ((Wrd54.Obj) == (Wrd70.Obj)))
    goto label_77;
  (Wrd76.Obj) = (MAKE_OBJECT (0, 3));
  (* (Rhp++)) = (Wrd76.Obj);
  (* (Rhp++)) = (Wrd70.Obj);
  (* (Rhp++)) = (Wrd70.Obj);
  (* (Rhp++)) = (Wrd70.Obj);
  (Wrd73.pObj) = (& (Rhp [-4]));
  (Wrd71.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd73.pObj)));
  (Wrd86.Obj) = (MAKE_OBJECT (0, 1));
  (* (Rhp++)) = (Wrd86.Obj);
  (* (Rhp++)) = (Wrd71.Obj);
  goto label_75;

DEFLABEL (label_80)
  (Wrd65.Obj) = (Rsp [0]);
  (Wrd66.Obj) = (current_block [OBJECT_68_5]);
  (Wrd69.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_22]))));
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd66.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_68_2]), 2);

DEFLABEL (label_58)
  (Wrd54.Obj) = Rvl;
  goto label_79;

DEFLABEL (label_82)
  (Wrd46.Obj) = (Rsp [0]);
  (Wrd47.Obj) = (current_block [OBJECT_68_4]);
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_21]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd46.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_68_2]), 2);

DEFLABEL (label_57)
  (Wrd35.Obj) = Rvl;
  goto label_81;

DEFLABEL (label_84)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_68_1]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_20]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_68_2]), 2);

DEFLABEL (label_56)
  (Wrd5.Obj) = Rvl;
  goto label_83;

DEFLABEL (lambda_62)
  CLOSURE_HEADER (LABEL_68_16);

DEFLABEL (lambda_33)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_23]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_10]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_68_23);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_26]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_25]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_68_26);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_86;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_68_32);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_68_31])));
  Rhp += 2;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd12 = Wrd9;
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [4]);
  ((Wrd12.pObj) [2]) = (Wrd15.Obj);
  ((Wrd12.pObj) [3]) = Rvl;
  (Rsp [0]) = (Wrd8.Obj);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_33]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd21.Obj) = ((Wrd14.pObj) [2]);
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_6]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_68_33);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_68_40);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_68_39])));
  Rhp += 4;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd16 = Wrd7;
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [2]);
  ((Wrd16.pObj) [2]) = (Wrd19.Obj);
  (Wrd15.Obj) = ((Wrd18.pObj) [3]);
  ((Wrd16.pObj) [3]) = (Wrd15.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd16.pObj) [4]) = (Wrd11.Obj);
  ((Wrd16.pObj) [5]) = Rvl;
  (Rsp [0]) = (Wrd6.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_41]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_42]));

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_68_41);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_85;
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd8.Obj);
  (Rsp [2]) = Rvl;
  (Rsp [3]) = (Wrd7.Obj);
  Rsp = (& (Rsp [1]));
  goto lambda_20;

DEFLABEL (label_85)
  (Wrd11.Obj) = (Rsp [1]);
  (Rsp [3]) = (Wrd11.Obj);
  Rsp = (& (Rsp [3]));
  goto lambda_26;

DEFLABEL (label_86)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_30]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [2]);
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [3]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd30.Obj) = ((Wrd26.pObj) [2]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_10]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_68_30);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (lambda_63)
DEFLABEL (lambda_37)
  INTERRUPT_CHECK (26, LABEL_68_27);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_34]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_15]));

DEFLABEL (continuation_36)
  INTERRUPT_CHECK (27, LABEL_68_34);
  (Rsp [1]) = Rvl;
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [0]) = (Wrd6.Obj);
  goto lambda_14;

DEFLABEL (lambda_64)
DEFLABEL (lambda_20)
  INTERRUPT_CHECK (26, LABEL_68_31);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_38]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_15]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_68_38);
  (Rsp [1]) = Rvl;
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [0]) = (Wrd6.Obj);
  goto lambda_14;

DEFLABEL (lambda_65)
  CLOSURE_HEADER (LABEL_68_35);

DEFLABEL (lambda_41)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_43]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_10]));

DEFLABEL (continuation_39)
  INTERRUPT_CHECK (27, LABEL_68_43);
  (Wrd10.Obj) = (MAKE_OBJECT (0, 1));
  (Wrd11.Obj) = (current_block [OBJECT_68_1]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd6.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [4]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = ((Wrd13.pObj) [3]);
  (Rsp [2]) = (Wrd15.Obj);
  goto lambda_37;

DEFLABEL (lambda_66)
  CLOSURE_HEADER (LABEL_68_39);

DEFLABEL (lambda_26)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_45]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_10]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_68_45);
  (Wrd10.Obj) = (MAKE_OBJECT (0, 1));
  (Wrd11.Obj) = (current_block [OBJECT_68_1]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd6.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [4]);
  (* (--Rsp)) = (Wrd14.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd17.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_68_47);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_68_46])));
  Rhp += 2;
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd17.pObj)));
  Wrd22 = Wrd17;
  (Wrd25.Obj) = ((Wrd13.pObj) [2]);
  ((Wrd22.pObj) [2]) = (Wrd25.Obj);
  (Wrd21.Obj) = ((Wrd13.pObj) [3]);
  ((Wrd22.pObj) [3]) = (Wrd21.Obj);
  (Rsp [2]) = (Wrd16.Obj);
  goto lambda_20;

DEFLABEL (lambda_67)
  CLOSURE_HEADER (LABEL_68_46);

DEFLABEL (lambda_25)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_48]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_10]));

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_68_48);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_69_5 3
#define LABEL_69_4 5
#define LABEL_69_9 7
#define LABEL_69_10 9
#define TAG_69_11 3
#define LABEL_69_8 11
#define LABEL_69_7 13
#define LABEL_69_6 15
#define LABEL_69_13 17
#define LABEL_69_20 19
#define LABEL_69_22 21
#define LABEL_69_23 23
#define LABEL_69_24 25
#define LABEL_69_25 27
#define LABEL_69_15 29
#define LABEL_69_27 31
#define LABEL_69_16 33
#define LABEL_69_30 35
#define LABEL_69_17 37
#define LABEL_69_32 39
#define LABEL_69_18 41
#define LABEL_69_34 43
#define LABEL_69_35 45
#define LABEL_69_38 47
#define LABEL_69_39 49
#define LABEL_69_40 51
#define LABEL_69_41 53
#define LABEL_69_19 55
#define LABEL_69_43 57
#define LABEL_69_26 59
#define LABEL_69_44 61
#define LABEL_69_46 63
#define LABEL_69_47 65
#define LABEL_69_29 67
#define LABEL_69_48 69
#define LABEL_69_49 71
#define LABEL_69_31 73
#define LABEL_69_51 75
#define LABEL_69_33 77
#define LABEL_69_52 79
#define LABEL_69_53 81
#define LABEL_69_50 83
#define LABEL_69_55 85
#define LABEL_69_45 87
#define LABEL_69_56 89
#define LABEL_69_36 91
#define LABEL_69_57 93
#define ENVIRONMENT_LABEL_69_3 120
#define DEBUGGING_LABEL_69_2 119
#define OBJECT_69_6 118
#define OBJECT_69_5 117
#define OBJECT_69_4 116
#define OBJECT_69_3 115
#define OBJECT_69_2 114
#define OBJECT_69_1 113
#define OBJECT_69_0 112
#define EXECUTE_CACHE_69_54 95
#define EXECUTE_CACHE_69_42 97
#define EXECUTE_CACHE_69_37 99
#define EXECUTE_CACHE_69_28 101
#define EXECUTE_CACHE_69_21 103
#define EXECUTE_CACHE_69_14 105
#define EXECUTE_CACHE_69_12 107
#define FREE_REFERENCE_69_1 110
#define FREE_REFERENCE_69_0 111
#define FREE_REFERENCES_LABEL_69_0 94
#define NUMBER_OF_LINKER_SECTIONS_69_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_69 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd17;
  machine_word Wrd6;
  machine_word Wrd33;
  machine_word Wrd45;
  machine_word Wrd32;
  machine_word Wrd26;
  machine_word Wrd39;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd40;
  machine_word Wrd38;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd30;
  machine_word Wrd24;
  machine_word Wrd15;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd5;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd16;
  machine_word Wrd25;
  machine_word Wrd27;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd22;
  machine_word Wrd23;
  machine_word Wrd19;
  machine_word Wrd31;
  machine_word Wrd34;
  machine_word Wrd37;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_69_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_69_4);
      goto Z_8601_number_parser_50;

    case 2:
      current_block = (Rpc - LABEL_69_9);
      goto lambda_15;

    case 3:
      current_block = (Rpc - LABEL_69_10);
      goto lambda_69;

    case 4:
      current_block = (Rpc - LABEL_69_8);
      goto lambda_25;

    case 5:
      current_block = (Rpc - LABEL_69_7);
      goto lambda_34;

    case 6:
      current_block = (Rpc - LABEL_69_6);
      goto lambda_42;

    case 7:
      current_block = (Rpc - LABEL_69_13);
      goto continuation_5;

    case 8:
      current_block = (Rpc - LABEL_69_20);
      goto label_52;

    case 9:
      current_block = (Rpc - LABEL_69_22);
      goto continuation_37;

    case 10:
      current_block = (Rpc - LABEL_69_23);
      goto continuation_29;

    case 11:
      current_block = (Rpc - LABEL_69_24);
      goto continuation_20;

    case 12:
      current_block = (Rpc - LABEL_69_25);
      goto continuation_10;

    case 13:
      current_block = (Rpc - LABEL_69_15);
      goto continuation_44;

    case 14:
      current_block = (Rpc - LABEL_69_27);
      goto label_53;

    case 15:
      current_block = (Rpc - LABEL_69_16);
      goto continuation_16;

    case 16:
      current_block = (Rpc - LABEL_69_30);
      goto label_54;

    case 17:
      current_block = (Rpc - LABEL_69_17);
      goto continuation_26;

    case 18:
      current_block = (Rpc - LABEL_69_32);
      goto label_55;

    case 19:
      current_block = (Rpc - LABEL_69_18);
      goto continuation_35;

    case 20:
      current_block = (Rpc - LABEL_69_34);
      goto label_56;

    case 21:
      current_block = (Rpc - LABEL_69_35);
      goto continuation_9;

    case 22:
      current_block = (Rpc - LABEL_69_38);
      goto continuation_8;

    case 23:
      current_block = (Rpc - LABEL_69_39);
      goto label_63;

    case 24:
      current_block = (Rpc - LABEL_69_40);
      goto continuation_7;

    case 25:
      current_block = (Rpc - LABEL_69_41);
      goto label_60;

    case 26:
      current_block = (Rpc - LABEL_69_19);
      goto continuation_6;

    case 27:
      current_block = (Rpc - LABEL_69_43);
      goto label_57;

    case 28:
      current_block = (Rpc - LABEL_69_26);
      goto continuation_46;

    case 29:
      current_block = (Rpc - LABEL_69_44);
      goto continuation_19;

    case 30:
      current_block = (Rpc - LABEL_69_46);
      goto continuation_18;

    case 31:
      current_block = (Rpc - LABEL_69_47);
      goto label_61;

    case 32:
      current_block = (Rpc - LABEL_69_29);
      goto continuation_17;

    case 33:
      current_block = (Rpc - LABEL_69_48);
      goto label_58;

    case 34:
      current_block = (Rpc - LABEL_69_49);
      goto continuation_28;

    case 35:
      current_block = (Rpc - LABEL_69_31);
      goto continuation_27;

    case 36:
      current_block = (Rpc - LABEL_69_51);
      goto label_59;

    case 37:
      current_block = (Rpc - LABEL_69_33);
      goto continuation_36;

    case 38:
      current_block = (Rpc - LABEL_69_52);
      goto continuation_38;

    case 39:
      current_block = (Rpc - LABEL_69_53);
      goto label_62;

    case 40:
      current_block = (Rpc - LABEL_69_50);
      goto continuation_30;

    case 41:
      current_block = (Rpc - LABEL_69_55);
      goto label_64;

    case 42:
      current_block = (Rpc - LABEL_69_45);
      goto continuation_21;

    case 43:
      current_block = (Rpc - LABEL_69_56);
      goto label_65;

    case 44:
      current_block = (Rpc - LABEL_69_36);
      goto continuation_11;

    case 45:
      current_block = (Rpc - LABEL_69_57);
      goto label_66;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z_8601_number_parser_68)
DEFLABEL (Z_8601_number_parser_50)
  INTERRUPT_CHECK (26, LABEL_69_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  if ((Wrd8.Obj) == (current_block [OBJECT_69_0]))
    goto label_78;
  if ((Wrd8.Obj) == (current_block [OBJECT_69_1]))
    goto label_77;
  if ((Wrd8.Obj) == (current_block [OBJECT_69_2]))
    goto label_76;
  if ((Wrd8.Obj) == (current_block [OBJECT_69_3]))
    goto label_74;
  (Wrd16.Obj) = (current_block [OBJECT_69_4]);
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_12]));

DEFLABEL (label_74)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_9]))));
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd19.Obj);

DEFLABEL (label_75)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd23.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_69_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_69_10])));
  Rhp += 3;
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd23.pObj)));
  Wrd28 = Wrd23;
  (Wrd29.Obj) = (Rsp [3]);
  ((Wrd28.pObj) [2]) = (Wrd29.Obj);
  (Wrd27.Obj) = (Rsp [2]);
  ((Wrd28.pObj) [3]) = (Wrd27.Obj);
  (Wrd25.Obj) = (Rsp [0]);
  ((Wrd28.pObj) [4]) = (Wrd25.Obj);
  Rvl = (Wrd22.Obj);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_76)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_8]))));
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd31.Obj);
  goto label_75;

DEFLABEL (label_77)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_7]))));
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd34.Obj);
  goto label_75;

DEFLABEL (label_78)
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_6]))));
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd37.Obj);
  goto label_75;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_69_5);
  (* (--Rsp)) = Rvl;
  goto label_75;

DEFLABEL (lambda_70)
DEFLABEL (lambda_15)
  INTERRUPT_CHECK (26, LABEL_69_9);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_14]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_69_13);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_19]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_69_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_93;
  Wrd8 = Wrd12;

DEFLABEL (label_92)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_21]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_69_19);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_88;

DEFLABEL (label_87)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_25]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_42]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_69_25);

DEFLABEL (label_86)
  Rsp = (& (Rsp [3]));
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_85)
  (Wrd5.Obj) = (Rsp [0]);
  if (! ((Wrd5.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_79;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_79)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_26]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd23.uLng) == 10))
    goto label_84;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd21.Lng))))
    goto label_84;
  (Wrd15.Obj) = ((Wrd19.pObj) [1]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_83)
  (Wrd29.Obj) = (Rsp [4]);
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [3]);
  (* (--Rsp)) = (Wrd31.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_28]));

DEFLABEL (continuation_46)
  INTERRUPT_CHECK (27, LABEL_69_26);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_81;
  Rvl = (Rsp [0]);
  goto label_80;

DEFLABEL (label_81)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_80)
DEFLABEL (label_82)
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_84)
  (Wrd24.Obj) = (Rsp [2]);
  (Wrd25.Obj) = (current_block [OBJECT_69_5]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_27]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_69_6]), 2);

DEFLABEL (label_53)
  (* (--Rsp)) = Rvl;
  goto label_83;

DEFLABEL (label_88)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_40]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_69_0]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_91;
  Wrd10 = Wrd14;

DEFLABEL (label_90)
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_89)
  (Wrd45.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd45.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_21]));

DEFLABEL (label_91)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_69_43])), (Wrd11.pObj));

DEFLABEL (label_57)
  (Wrd10.Obj) = Rvl;
  goto label_90;

DEFLABEL (label_93)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_69_20])), (Wrd9.pObj));

DEFLABEL (label_52)
  (Wrd8.Obj) = Rvl;
  goto label_92;

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_69_40);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_87;
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_38]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd28.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_69_0]));
  (Wrd31.Obj) = ((Wrd28.pObj) [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd32.uLng) == 50)
    goto label_95;
  Wrd27 = Wrd31;

DEFLABEL (label_94)
  (* (--Rsp)) = (Wrd27.Obj);
  goto label_89;

DEFLABEL (label_95)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_69_41])), (Wrd28.pObj));

DEFLABEL (label_60)
  (Wrd27.Obj) = Rvl;
  goto label_94;

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_69_38);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_87;
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_35]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd40.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_69_0]));
  (Wrd43.Obj) = ((Wrd40.pObj) [0]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if ((Wrd44.uLng) == 50)
    goto label_97;
  Wrd39 = Wrd43;

DEFLABEL (label_96)
  (* (--Rsp)) = (Wrd39.Obj);
  goto label_89;

DEFLABEL (label_97)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_69_39])), (Wrd40.pObj));

DEFLABEL (label_63)
  (Wrd39.Obj) = Rvl;
  goto label_96;

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_69_35);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_87;
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_36]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (Wrd51.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd51.Obj);
  (Wrd52.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd52.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_37]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_69_36);
  (Wrd11.Obj) = (MAKE_OBJECT (0, 1));
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd8.pObj)));
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_69_1]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_99;
  Wrd12 = Wrd16;

DEFLABEL (label_98)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_54]));

DEFLABEL (label_99)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_69_57])), (Wrd13.pObj));

DEFLABEL (label_66)
  (Wrd12.Obj) = Rvl;
  goto label_98;

DEFLABEL (lambda_69)
  CLOSURE_HEADER (LABEL_69_10);

DEFLABEL (lambda_48)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_15]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_44)
  INTERRUPT_CHECK (27, LABEL_69_15);
  (* (--Rsp)) = Rvl;
  goto label_85;

DEFLABEL (lambda_71)
DEFLABEL (lambda_25)
  INTERRUPT_CHECK (26, LABEL_69_8);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_14]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_69_16);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_29]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_69_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_106;
  Wrd8 = Wrd12;

DEFLABEL (label_105)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_21]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_69_29);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_101;

DEFLABEL (label_100)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_24]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_42]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_69_24);
  goto label_86;

DEFLABEL (label_101)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_46]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_69_0]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_104;
  Wrd10 = Wrd14;

DEFLABEL (label_103)
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_102)
  (Wrd33.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd33.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_21]));

DEFLABEL (label_104)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_69_48])), (Wrd11.pObj));

DEFLABEL (label_58)
  (Wrd10.Obj) = Rvl;
  goto label_103;

DEFLABEL (label_106)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_69_30])), (Wrd9.pObj));

DEFLABEL (label_54)
  (Wrd8.Obj) = Rvl;
  goto label_105;

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_69_46);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_100;
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_44]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd28.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_69_0]));
  (Wrd31.Obj) = ((Wrd28.pObj) [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd32.uLng) == 50)
    goto label_108;
  Wrd27 = Wrd31;

DEFLABEL (label_107)
  (* (--Rsp)) = (Wrd27.Obj);
  goto label_102;

DEFLABEL (label_108)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_69_47])), (Wrd28.pObj));

DEFLABEL (label_61)
  (Wrd27.Obj) = Rvl;
  goto label_107;

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_69_44);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_100;
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_45]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd39.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd40.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd40.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_37]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_69_45);
  (Wrd11.Obj) = (MAKE_OBJECT (0, 1));
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd8.pObj)));
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_69_1]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_110;
  Wrd12 = Wrd16;

DEFLABEL (label_109)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_54]));

DEFLABEL (label_110)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_69_56])), (Wrd13.pObj));

DEFLABEL (label_65)
  (Wrd12.Obj) = Rvl;
  goto label_109;

DEFLABEL (lambda_72)
DEFLABEL (lambda_34)
  INTERRUPT_CHECK (26, LABEL_69_7);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_14]));

DEFLABEL (continuation_26)
  INTERRUPT_CHECK (27, LABEL_69_17);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_31]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_69_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_118;
  Wrd8 = Wrd12;

DEFLABEL (label_117)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_21]));

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_69_31);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_112;

DEFLABEL (label_111)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_23]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_42]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_69_23);
  goto label_86;

DEFLABEL (label_112)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_49]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_69_0]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_116;
  Wrd10 = Wrd14;

DEFLABEL (label_115)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd16.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_21]));

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_69_49);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_111;
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_50]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd28.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_37]));

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_69_50);
  (Wrd11.Obj) = (MAKE_OBJECT (0, 1));
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd8.pObj)));
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_69_1]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_114;
  Wrd12 = Wrd16;

DEFLABEL (label_113)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_54]));

DEFLABEL (label_114)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_69_55])), (Wrd13.pObj));

DEFLABEL (label_64)
  (Wrd12.Obj) = Rvl;
  goto label_113;

DEFLABEL (label_116)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_69_51])), (Wrd11.pObj));

DEFLABEL (label_59)
  (Wrd10.Obj) = Rvl;
  goto label_115;

DEFLABEL (label_118)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_69_32])), (Wrd9.pObj));

DEFLABEL (label_55)
  (Wrd8.Obj) = Rvl;
  goto label_117;

DEFLABEL (lambda_73)
DEFLABEL (lambda_42)
  INTERRUPT_CHECK (26, LABEL_69_6);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_18]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_14]));

DEFLABEL (continuation_35)
  INTERRUPT_CHECK (27, LABEL_69_18);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_33]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_69_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_123;
  Wrd8 = Wrd12;

DEFLABEL (label_122)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_21]));

DEFLABEL (continuation_36)
  INTERRUPT_CHECK (27, LABEL_69_33);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_121;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_52]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_37]));

DEFLABEL (continuation_38)
  INTERRUPT_CHECK (27, LABEL_69_52);
  (Wrd11.Obj) = (MAKE_OBJECT (0, 1));
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd8.pObj)));
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_69_1]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_120;
  Wrd12 = Wrd16;

DEFLABEL (label_119)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_54]));

DEFLABEL (label_120)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_69_53])), (Wrd13.pObj));

DEFLABEL (label_62)
  (Wrd12.Obj) = Rvl;
  goto label_119;

DEFLABEL (label_121)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_22]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_42]));

DEFLABEL (continuation_37)
  INTERRUPT_CHECK (27, LABEL_69_22);
  goto label_86;

DEFLABEL (label_123)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_69_34])), (Wrd9.pObj));

DEFLABEL (label_56)
  (Wrd8.Obj) = Rvl;
  goto label_122;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_70_4 3
#define LABEL_70_5 5
#define LABEL_70_10 7
#define LABEL_70_7 9
#define TAG_70_8 3
#define LABEL_70_14 11
#define LABEL_70_9 13
#define LABEL_70_18 15
#define LABEL_70_12 17
#define LABEL_70_20 19
#define LABEL_70_16 21
#define LABEL_70_22 23
#define LABEL_70_19 25
#define LABEL_70_23 27
#define LABEL_70_24 29
#define LABEL_70_15 31
#define LABEL_70_25 33
#define LABEL_70_27 35
#define TAG_70_28 16
#define LABEL_70_29 37
#define LABEL_70_32 39
#define LABEL_70_33 41
#define TAG_70_34 19
#define LABEL_70_35 43
#define TAG_70_36 20
#define LABEL_70_37 45
#define LABEL_70_42 47
#define LABEL_70_38 49
#define LABEL_70_39 51
#define TAG_70_40 24
#define LABEL_70_41 53
#define LABEL_70_43 55
#define ENVIRONMENT_LABEL_70_3 82
#define DEBUGGING_LABEL_70_2 81
#define OBJECT_70_5 80
#define OBJECT_70_4 79
#define OBJECT_70_3 78
#define OBJECT_70_2 77
#define OBJECT_70_1 76
#define OBJECT_70_0 75
#define EXECUTE_CACHE_70_31 57
#define EXECUTE_CACHE_70_30 59
#define EXECUTE_CACHE_70_26 61
#define EXECUTE_CACHE_70_21 63
#define EXECUTE_CACHE_70_17 65
#define EXECUTE_CACHE_70_13 67
#define EXECUTE_CACHE_70_11 69
#define EXECUTE_CACHE_70_6 71
#define FREE_REFERENCE_70_0 74
#define FREE_REFERENCES_LABEL_70_0 56
#define NUMBER_OF_LINKER_SECTIONS_70_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_70 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd17;
  machine_word Wrd32;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd40;
  machine_word Wrd44;
  machine_word Wrd47;
  machine_word Wrd31;
  machine_word Wrd28;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd11;
  machine_word Wrd21;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_70_4);
      goto parse_8601_second_37;

    case 1:
      current_block = (Rpc - LABEL_70_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_70_10);
      goto label_39;

    case 3:
      current_block = (Rpc - LABEL_70_7);
      goto lambda_14;

    case 4:
      current_block = (Rpc - LABEL_70_14);
      goto continuation_16;

    case 5:
      current_block = (Rpc - LABEL_70_9);
      goto continuation_15;

    case 6:
      current_block = (Rpc - LABEL_70_18);
      goto label_40;

    case 7:
      current_block = (Rpc - LABEL_70_12);
      goto continuation_1;

    case 8:
      current_block = (Rpc - LABEL_70_20);
      goto label_41;

    case 9:
      current_block = (Rpc - LABEL_70_16);
      goto continuation_17;

    case 10:
      current_block = (Rpc - LABEL_70_22);
      goto continuation_9;

    case 11:
      current_block = (Rpc - LABEL_70_19);
      goto continuation_5;

    case 12:
      current_block = (Rpc - LABEL_70_23);
      goto label_42;

    case 13:
      current_block = (Rpc - LABEL_70_24);
      goto label_43;

    case 14:
      current_block = (Rpc - LABEL_70_15);
      goto continuation_18;

    case 15:
      current_block = (Rpc - LABEL_70_25);
      goto continuation_8;

    case 16:
      current_block = (Rpc - LABEL_70_27);
      goto lambda_48;

    case 17:
      current_block = (Rpc - LABEL_70_29);
      goto continuation_23;

    case 18:
      current_block = (Rpc - LABEL_70_32);
      goto continuation_19;

    case 19:
      current_block = (Rpc - LABEL_70_33);
      goto Z___ks4__31;

    case 20:
      current_block = (Rpc - LABEL_70_35);
      goto lambda_50;

    case 21:
      current_block = (Rpc - LABEL_70_37);
      goto continuation_25;

    case 22:
      current_block = (Rpc - LABEL_70_42);
      goto label_44;

    case 23:
      current_block = (Rpc - LABEL_70_38);
      goto continuation_20;

    case 24:
      current_block = (Rpc - LABEL_70_39);
      goto lambda_51;

    case 25:
      current_block = (Rpc - LABEL_70_41);
      goto continuation_28;

    case 26:
      current_block = (Rpc - LABEL_70_43);
      goto continuation_26;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (parse_8601_second_46)
DEFLABEL (parse_8601_second_37)
  INTERRUPT_CHECK (26, LABEL_70_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_70_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_70_5);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_70_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_70_7])));
  Rhp += 2;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd9 = Wrd6;
  (Wrd10.Obj) = (Rsp [1]);
  ((Wrd9.pObj) [2]) = (Wrd10.Obj);
  ((Wrd9.pObj) [3]) = Rvl;
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70_9]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_70_0]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_58;
  Wrd14 = Wrd18;

DEFLABEL (label_57)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd20.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_70_11]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_70_9);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_53;

DEFLABEL (label_52)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70_16]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_70_17]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_70_16);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_53)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70_14]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_70_0]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_56;
  Wrd10 = Wrd14;

DEFLABEL (label_55)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd16.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_70_11]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_70_14);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_52;
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70_15]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd27.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_70_6]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_70_15);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_70_28);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_70_27])));
  Rhp += 4;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [3]);
  ((Wrd14.pObj) [2]) = (Wrd15.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd14.pObj) [4]) = (Wrd11.Obj);
  ((Wrd14.pObj) [5]) = Rvl;
  (Rsp [0]) = (Wrd6.Obj);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70_29]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (current_block [OBJECT_70_4]);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_70_30]));

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_70_29);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_54;
  (Wrd7.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd18.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_70_34);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_70_33])));
  Rhp += 2;
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd18.pObj)));
  (* (--Rsp)) = (Wrd19.Obj);
  Wrd16 = Wrd18;
  (Wrd17.Obj) = (Rsp [5]);
  ((Wrd16.pObj) [2]) = (Wrd17.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  ((Wrd16.pObj) [3]) = (Wrd14.Obj);
  Rsp = (& (Rsp [1]));
  (Rsp [3]) = (Wrd19.Obj);
  (Wrd10.Obj) = (* (Rsp++));
  (Rsp [3]) = (Wrd10.Obj);
  Rsp = (& (Rsp [2]));
  goto Z___ks4__31;

DEFLABEL (label_54)
  (Wrd20.Obj) = (Rsp [0]);
  (Rsp [3]) = (Wrd20.Obj);
  Rsp = (& (Rsp [3]));
  goto lambda_22;

DEFLABEL (label_56)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_70_18])), (Wrd11.pObj));

DEFLABEL (label_40)
  (Wrd10.Obj) = Rvl;
  goto label_55;

DEFLABEL (label_58)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_70_10])), (Wrd15.pObj));

DEFLABEL (label_39)
  (Wrd14.Obj) = Rvl;
  goto label_57;

DEFLABEL (lambda_47)
DEFLABEL (lambda_14)
  INTERRUPT_CHECK (26, LABEL_70_7);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_70_13]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_70_12);
  (Wrd11.Obj) = (MAKE_OBJECT (0, 1));
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70_19]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd26.Obj) = ((SCHEME_OBJECT) 10);
  if (! ((Wrd26.uLng) == 10))
    goto label_67;
  Wrd22 = Wrd7;
  (Wrd23.Obj) = ((Wrd22.pObj) [0]);
  (Wrd24.Lng) = (FIXNUM_TO_LONG (Wrd23.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd24.Lng))))
    goto label_67;
  (Wrd18.Obj) = ((Wrd22.pObj) [1]);
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_66)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_70_21]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_70_19);
  (Rsp [0]) = Rvl;
  (Wrd7.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd7.uLng) == 26))
    goto label_65;
  (Wrd40.Lng) = (FIXNUM_TO_LONG (Rvl));
  if ((Wrd40.Lng) < 0)
    goto label_62;

DEFLABEL (label_64)
  (Wrd13.Obj) = (Rsp [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 26))
    goto label_63;
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! ((Wrd16.Lng) < 60L))
    goto label_62;

DEFLABEL (label_61)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70_22]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70_25]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd32.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd32.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_70_26]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_70_25);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_70_5]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_70_31]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_70_22);
  (Wrd47.Obj) = (MAKE_OBJECT (0, 1));
  (* (Rhp++)) = (Wrd47.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd44.pObj) = (& (Rhp [-2]));
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd44.pObj)));

DEFLABEL (label_60)
  Rsp = (& (Rsp [1]));
  (Rsp [0]) = (Wrd20.Obj);
  if ((Wrd20.Obj) == ((SCHEME_OBJECT) 0))
    goto label_59;
  Rvl = (Wrd20.Obj);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_59)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_62)
  (Wrd20.Obj) = (current_block [OBJECT_70_3]);
  goto label_60;

DEFLABEL (label_63)
  (Wrd34.Obj) = (current_block [OBJECT_70_2]);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70_24]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_43)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_62;
  goto label_61;

DEFLABEL (label_65)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70_23]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_INTERFACE_0 (42);

DEFLABEL (label_42)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_64;
  goto label_62;

DEFLABEL (label_67)
  (Wrd27.Obj) = (Rsp [1]);
  (Wrd28.Obj) = (current_block [OBJECT_70_0]);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70_20]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_70_1]), 2);

DEFLABEL (label_41)
  (* (--Rsp)) = Rvl;
  goto label_66;

DEFLABEL (lambda_48)
  CLOSURE_HEADER (LABEL_70_27);

DEFLABEL (lambda_22)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70_32]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_70_17]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_70_32);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd10.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_70_36);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_70_35])));
  Rhp += 2;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd10.pObj)));
  Wrd15 = Wrd10;
  (Wrd18.Obj) = ((Wrd6.pObj) [2]);
  ((Wrd15.pObj) [2]) = (Wrd18.Obj);
  (Wrd14.Obj) = ((Wrd6.pObj) [3]);
  ((Wrd15.pObj) [3]) = (Wrd14.Obj);
  (Rsp [1]) = (Wrd9.Obj);
  goto lambda_14;

DEFLABEL (Z___ks4__49)
DEFLABEL (Z___ks4__31)
  INTERRUPT_CHECK (26, LABEL_70_33);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70_37]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_70_6]));

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_70_37);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_70_40);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_70_39])));
  Rhp += 4;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd16 = Wrd7;
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [2]);
  ((Wrd16.pObj) [2]) = (Wrd19.Obj);
  (Wrd15.Obj) = ((Wrd18.pObj) [3]);
  ((Wrd16.pObj) [3]) = (Wrd15.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  ((Wrd16.pObj) [4]) = (Wrd11.Obj);
  ((Wrd16.pObj) [5]) = Rvl;
  (Rsp [0]) = (Wrd6.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70_41]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_70_0]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_70;
  Wrd23 = Wrd27;

DEFLABEL (label_69)
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd29.Obj) = (Rsp [3]);
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [2]);
  (* (--Rsp)) = (Wrd31.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_70_11]));

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_70_41);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_68;
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Rsp [1]) = (Wrd8.Obj);
  Rsp = (& (Rsp [1]));
  goto Z___ks4__31;

DEFLABEL (label_68)
  (Wrd10.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd10.Obj);
  Rsp = (& (Rsp [2]));
  goto lambda_27;

DEFLABEL (label_70)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_70_42])), (Wrd24.pObj));

DEFLABEL (label_44)
  (Wrd23.Obj) = Rvl;
  goto label_69;

DEFLABEL (lambda_50)
  CLOSURE_HEADER (LABEL_70_35);

DEFLABEL (lambda_21)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70_38]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_70_17]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_70_38);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_51)
  CLOSURE_HEADER (LABEL_70_39);

DEFLABEL (lambda_27)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70_43]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_70_17]));

DEFLABEL (continuation_26)
  INTERRUPT_CHECK (27, LABEL_70_43);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = ((Wrd6.pObj) [4]);
  (Rsp [1]) = (Wrd8.Obj);
  goto lambda_14;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_71_4 3
#define LABEL_71_5 5
#define LABEL_71_7 7
#define LABEL_71_11 9
#define LABEL_71_9 11
#define LABEL_71_13 13
#define LABEL_71_15 15
#define LABEL_71_17 17
#define LABEL_71_16 19
#define LABEL_71_18 21
#define ENVIRONMENT_LABEL_71_3 38
#define DEBUGGING_LABEL_71_2 37
#define OBJECT_71_3 36
#define OBJECT_71_2 35
#define OBJECT_71_1 34
#define OBJECT_71_0 33
#define EXECUTE_CACHE_71_14 23
#define EXECUTE_CACHE_71_12 25
#define EXECUTE_CACHE_71_10 27
#define EXECUTE_CACHE_71_8 29
#define EXECUTE_CACHE_71_6 31
#define FREE_REFERENCES_LABEL_71_0 22
#define NUMBER_OF_LINKER_SECTIONS_71_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_71 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_71_4);
      goto parse_8601_sign_14;

    case 1:
      current_block = (Rpc - LABEL_71_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_71_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_71_11);
      goto continuation_9;

    case 4:
      current_block = (Rpc - LABEL_71_9);
      goto continuation_2;

    case 5:
      current_block = (Rpc - LABEL_71_13);
      goto lambda_11;

    case 6:
      current_block = (Rpc - LABEL_71_15);
      goto continuation_3;

    case 7:
      current_block = (Rpc - LABEL_71_17);
      goto continuation_5;

    case 8:
      current_block = (Rpc - LABEL_71_16);
      goto continuation_4;

    case 9:
      current_block = (Rpc - LABEL_71_18);
      goto lambda_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (parse_8601_sign_17)
DEFLABEL (parse_8601_sign_14)
  INTERRUPT_CHECK (26, LABEL_71_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_71_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_71_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_71_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_20;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_11]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_12]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_71_11);
  (Wrd11.Obj) = (MAKE_OBJECT (0, 1));
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd8.pObj)));
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_13]))));
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_14]));

DEFLABEL (label_20)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_9]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_71_9);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_15]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_71_1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_8]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_71_15);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_21;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_17]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_12]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_71_17);
  (Wrd11.Obj) = (MAKE_OBJECT (0, 1));
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd8.pObj)));
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_18]))));
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_14]));

DEFLABEL (label_21)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_16]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_10]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_71_16);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (lambda_18)
DEFLABEL (lambda_11)
  INTERRUPT_CHECK (26, LABEL_71_13);
  Rvl = (current_block [OBJECT_71_2]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_19)
DEFLABEL (lambda_7)
  INTERRUPT_CHECK (26, LABEL_71_18);
  Rvl = (current_block [OBJECT_71_3]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_72_4 3
#define LABEL_72_5 5
#define LABEL_72_7 7
#define ENVIRONMENT_LABEL_72_3 15
#define DEBUGGING_LABEL_72_2 14
#define OBJECT_72_2 13
#define OBJECT_72_1 12
#define OBJECT_72_0 11
#define EXECUTE_CACHE_72_6 9
#define FREE_REFERENCES_LABEL_72_0 8
#define NUMBER_OF_LINKER_SECTIONS_72_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_72 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd24;
  machine_word Wrd6;
  machine_word Wrd10;
  machine_word Wrd13;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_72_4);
      goto month_max_days_2;

    case 1:
      current_block = (Rpc - LABEL_72_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_72_7);
      goto label_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (month_max_days_6)
DEFLABEL (month_max_days_2)
  INTERRUPT_CHECK (26, LABEL_72_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_72_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_72_5);
  (Wrd5.Obj) = (current_block [OBJECT_72_1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 26))
    goto label_10;
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd11.Obj));
  (Wrd13.Lng) = ((Wrd15.Lng) - 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd13.Lng)))
    goto label_10;
  (Wrd10.Obj) = (LONG_TO_FIXNUM (Wrd13.Lng));

DEFLABEL (label_9)
  (Rsp [1]) = (Wrd10.Obj);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd24.uLng) == 26)
    goto label_8;

DEFLABEL (label_7)
  INVOKE_PRIMITIVE ((current_block [OBJECT_72_2]), 2);

DEFLABEL (label_8)
  (Wrd26.Lng) = (FIXNUM_TO_LONG (Wrd10.Obj));
  (Wrd27.Obj) = (current_block [OBJECT_72_1]);
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [0]);
  (Wrd30.Lng) = (FIXNUM_TO_LONG (Wrd29.Obj));
  if (! (((unsigned long) (Wrd26.Lng)) < ((unsigned long) (Wrd30.Lng))))
    goto label_7;
  (Wrd18.uLng) = (OBJECT_DATUM (Wrd10.Obj));
  (Wrd21.pObj) = (& ((Wrd28.pObj) [(Wrd18.Lng)]));
  Rvl = ((Wrd21.pObj) [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_10)
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_INTERFACE_0 (34);

DEFLABEL (label_4)
  (Wrd10.Obj) = Rvl;
  goto label_9;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_73_4 3
#define LABEL_73_5 5
#define LABEL_73_7 7
#define LABEL_73_8 9
#define ENVIRONMENT_LABEL_73_3 18
#define DEBUGGING_LABEL_73_2 17
#define OBJECT_73_1 16
#define OBJECT_73_0 15
#define EXECUTE_CACHE_73_6 11
#define FREE_REFERENCE_73_0 14
#define FREE_REFERENCES_LABEL_73_0 10
#define NUMBER_OF_LINKER_SECTIONS_73_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_73 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd31;
  machine_word Wrd29;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_73_4);
      goto month_short_string_2;

    case 1:
      current_block = (Rpc - LABEL_73_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_73_7);
      goto label_4;

    case 3:
      current_block = (Rpc - LABEL_73_8);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (month_short_string_7)
DEFLABEL (month_short_string_2)
  INTERRUPT_CHECK (26, LABEL_73_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_73_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_73_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_73_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_73_5);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_73_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_13;
  Wrd5 = Wrd9;

DEFLABEL (label_12)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 26))
    goto label_11;
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  (Wrd18.Lng) = ((Wrd20.Lng) - 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd18.Lng)))
    goto label_11;
  (Wrd15.Obj) = (LONG_TO_FIXNUM (Wrd18.Lng));

DEFLABEL (label_10)
  (Rsp [1]) = (Wrd15.Obj);
  (Wrd36.Obj) = (Rsp [0]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if ((Wrd37.uLng) == 10)
    goto label_9;

DEFLABEL (label_8)
  INVOKE_PRIMITIVE ((current_block [OBJECT_73_1]), 2);

DEFLABEL (label_9)
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd29.uLng) == 26))
    goto label_8;
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  if (! (((unsigned long) (Wrd31.Lng)) < ((unsigned long) (Wrd35.Lng))))
    goto label_8;
  (Wrd23.uLng) = (OBJECT_DATUM (Wrd15.Obj));
  (Wrd26.pObj) = (& ((Wrd33.pObj) [(Wrd23.Lng)]));
  Rvl = ((Wrd26.pObj) [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_11)
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_73_8]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_INTERFACE_0 (34);

DEFLABEL (label_5)
  (Wrd15.Obj) = Rvl;
  goto label_10;

DEFLABEL (label_13)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_73_7])), (Wrd6.pObj));

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_12;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_74_4 3
#define LABEL_74_5 5
#define LABEL_74_7 7
#define LABEL_74_8 9
#define ENVIRONMENT_LABEL_74_3 18
#define DEBUGGING_LABEL_74_2 17
#define OBJECT_74_1 16
#define OBJECT_74_0 15
#define EXECUTE_CACHE_74_6 11
#define FREE_REFERENCE_74_0 14
#define FREE_REFERENCES_LABEL_74_0 10
#define NUMBER_OF_LINKER_SECTIONS_74_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_74 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd31;
  machine_word Wrd29;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_74_4);
      goto month_long_string_2;

    case 1:
      current_block = (Rpc - LABEL_74_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_74_7);
      goto label_4;

    case 3:
      current_block = (Rpc - LABEL_74_8);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (month_long_string_7)
DEFLABEL (month_long_string_2)
  INTERRUPT_CHECK (26, LABEL_74_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_74_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_74_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_74_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_74_5);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_74_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_13;
  Wrd5 = Wrd9;

DEFLABEL (label_12)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 26))
    goto label_11;
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  (Wrd18.Lng) = ((Wrd20.Lng) - 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd18.Lng)))
    goto label_11;
  (Wrd15.Obj) = (LONG_TO_FIXNUM (Wrd18.Lng));

DEFLABEL (label_10)
  (Rsp [1]) = (Wrd15.Obj);
  (Wrd36.Obj) = (Rsp [0]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if ((Wrd37.uLng) == 10)
    goto label_9;

DEFLABEL (label_8)
  INVOKE_PRIMITIVE ((current_block [OBJECT_74_1]), 2);

DEFLABEL (label_9)
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd29.uLng) == 26))
    goto label_8;
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  if (! (((unsigned long) (Wrd31.Lng)) < ((unsigned long) (Wrd35.Lng))))
    goto label_8;
  (Wrd23.uLng) = (OBJECT_DATUM (Wrd15.Obj));
  (Wrd26.pObj) = (& ((Wrd33.pObj) [(Wrd23.Lng)]));
  Rvl = ((Wrd26.pObj) [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_11)
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_74_8]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_INTERFACE_0 (34);

DEFLABEL (label_5)
  (Wrd15.Obj) = Rvl;
  goto label_10;

DEFLABEL (label_13)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_74_7])), (Wrd6.pObj));

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_12;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_75_5 3
#define LABEL_75_6 5
#define LABEL_75_4 7
#define LABEL_75_7 9
#define LABEL_75_9 11
#define ENVIRONMENT_LABEL_75_3 29
#define DEBUGGING_LABEL_75_2 28
#define OBJECT_75_8 27
#define OBJECT_75_7 26
#define OBJECT_75_6 25
#define OBJECT_75_5 24
#define OBJECT_75_4 23
#define OBJECT_75_3 22
#define OBJECT_75_2 21
#define OBJECT_75_1 20
#define OBJECT_75_0 19
#define EXECUTE_CACHE_75_11 13
#define EXECUTE_CACHE_75_10 15
#define EXECUTE_CACHE_75_8 17
#define FREE_REFERENCES_LABEL_75_0 12
#define NUMBER_OF_LINKER_SECTIONS_75_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_75 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd23;
  machine_word Wrd13;
  machine_word Wrd46;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd41;
  machine_word Wrd38;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_75_5);
      goto continuation_3;

    case 1:
      current_block = (Rpc - LABEL_75_6);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_75_4);
      goto guarantee_month_5;

    case 3:
      current_block = (Rpc - LABEL_75_7);
      goto label_7;

    case 4:
      current_block = (Rpc - LABEL_75_9);
      goto continuation_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_month_9)
DEFLABEL (guarantee_month_5)
  INTERRUPT_CHECK (26, LABEL_75_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_75_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd38.Obj) = (current_block [OBJECT_75_0]);
  (Wrd41.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 26L) < ((unsigned long) (Wrd41.Lng))))
    goto label_19;
  (Wrd10.uLng) = (OBJECT_DATUM (Wrd38.Obj));
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd10.Obj) == (Wrd12.Obj))
    goto label_18;

DEFLABEL (label_17)
  (Wrd13.Obj) = (current_block [OBJECT_75_2]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd23.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 14L) < ((unsigned long) (Wrd23.Lng)))
    goto label_10;
  INVOKE_PRIMITIVE ((current_block [OBJECT_75_1]), 2);

DEFLABEL (label_10)
  (Wrd17.uLng) = (OBJECT_DATUM (Wrd13.Obj));
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd17.Obj) == (Wrd19.Obj))
    goto label_12;
  (Wrd15.Obj) = (current_block [OBJECT_75_4]);
  goto label_11;

DEFLABEL (label_12)
  (Wrd15.Obj) = (current_block [OBJECT_75_3]);

DEFLABEL (label_11)
DEFLABEL (label_16)
  Rsp = (& (Rsp [3]));
  if ((Wrd15.Obj) == ((SCHEME_OBJECT) 0))
    goto label_15;

DEFLABEL (label_14)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_75_9]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (current_block [OBJECT_75_6]);
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd35.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd36.Obj) = (current_block [OBJECT_75_7]);
  (* (--Rsp)) = (Wrd36.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_75_10]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_75_9);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_13;
  Rvl = (current_block [OBJECT_75_8]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_13)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_75_11]));

DEFLABEL (label_15)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_75_5]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd28.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd29.Obj) = (current_block [OBJECT_75_5]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_75_8]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_75_5);
  goto label_14;

DEFLABEL (label_18)
  Rsp = (& (Rsp [2]));
  goto label_14;

DEFLABEL (label_19)
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_75_7]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_75_1]), 2);

DEFLABEL (label_7)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_17;
  goto label_18;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_75_6);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_15;
  goto label_14;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_76_4 3
#define LABEL_76_7 5
#define LABEL_76_9 7
#define LABEL_76_6 9
#define LABEL_76_11 11
#define LABEL_76_5 13
#define ENVIRONMENT_LABEL_76_3 24
#define DEBUGGING_LABEL_76_2 23
#define OBJECT_76_0 22
#define EXECUTE_CACHE_76_10 15
#define EXECUTE_CACHE_76_8 17
#define FREE_REFERENCE_76_1 20
#define FREE_REFERENCE_76_0 21
#define FREE_REFERENCES_LABEL_76_0 14
#define NUMBER_OF_LINKER_SECTIONS_76_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_76 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd5;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd12;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_76_4);
      goto string__month_5;

    case 1:
      current_block = (Rpc - LABEL_76_7);
      goto label_7;

    case 2:
      current_block = (Rpc - LABEL_76_9);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_76_6);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_76_11);
      goto label_8;

    case 5:
      current_block = (Rpc - LABEL_76_5);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (string__month_10)
DEFLABEL (string__month_5)
  INTERRUPT_CHECK (26, LABEL_76_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_76_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_76_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_76_0]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_17;
  Wrd12 = Wrd16;

DEFLABEL (label_16)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_76_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_76_6);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_13;

DEFLABEL (label_12)
  (Wrd5.Obj) = Rvl;
  Rsp = (& (Rsp [2]));

DEFLABEL (label_11)
  (Wrd7.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  (Wrd8.Lng) = ((Wrd7.Lng) + 1L);
  Rvl = (LONG_TO_FIXNUM (Wrd8.Lng));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_13)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_76_9]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_76_1]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_15;
  Wrd17 = Wrd21;

DEFLABEL (label_14)
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_76_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_76_9);
  (Rsp [0]) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_12;
  (Wrd27.Obj) = (current_block [OBJECT_76_0]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd28.Obj) = (Rsp [3]);
  (Rsp [1]) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_76_10]));

DEFLABEL (label_15)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_76_11])), (Wrd18.pObj));

DEFLABEL (label_8)
  (Wrd17.Obj) = Rvl;
  goto label_14;

DEFLABEL (label_17)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_76_7])), (Wrd13.pObj));

DEFLABEL (label_7)
  (Wrd12.Obj) = Rvl;
  goto label_16;

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_76_5);
  (Wrd5.Obj) = Rvl;
  goto label_11;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_77_4 3
#define LABEL_77_5 5
#define LABEL_77_7 7
#define ENVIRONMENT_LABEL_77_3 16
#define DEBUGGING_LABEL_77_2 15
#define OBJECT_77_1 14
#define OBJECT_77_0 13
#define EXECUTE_CACHE_77_6 9
#define FREE_REFERENCE_77_0 12
#define FREE_REFERENCES_LABEL_77_0 8
#define NUMBER_OF_LINKER_SECTIONS_77_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_77 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd27;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_77_4);
      goto day_of_week_short_string_1;

    case 1:
      current_block = (Rpc - LABEL_77_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_77_7);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (day_of_week_short_string_5)
DEFLABEL (day_of_week_short_string_1)
  INTERRUPT_CHECK (26, LABEL_77_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_77_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_77_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_77_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_77_5);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_77_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_9;
  Wrd5 = Wrd9;

DEFLABEL (label_8)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd27.uLng) == 10)
    goto label_7;

DEFLABEL (label_6)
  INVOKE_PRIMITIVE ((current_block [OBJECT_77_1]), 2);

DEFLABEL (label_7)
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 26))
    goto label_6;
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [0]);
  (Wrd25.Lng) = (FIXNUM_TO_LONG (Wrd24.Obj));
  if (! (((unsigned long) (Wrd21.Lng)) < ((unsigned long) (Wrd25.Lng))))
    goto label_6;
  (Wrd13.uLng) = (OBJECT_DATUM (Wrd18.Obj));
  (Wrd16.pObj) = (& ((Wrd23.pObj) [(Wrd13.Lng)]));
  Rvl = ((Wrd16.pObj) [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_9)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_77_7])), (Wrd6.pObj));

DEFLABEL (label_3)
  (Wrd5.Obj) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_78_4 3
#define LABEL_78_5 5
#define LABEL_78_7 7
#define ENVIRONMENT_LABEL_78_3 16
#define DEBUGGING_LABEL_78_2 15
#define OBJECT_78_1 14
#define OBJECT_78_0 13
#define EXECUTE_CACHE_78_6 9
#define FREE_REFERENCE_78_0 12
#define FREE_REFERENCES_LABEL_78_0 8
#define NUMBER_OF_LINKER_SECTIONS_78_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_78 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd27;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_78_4);
      goto day_of_week_long_string_1;

    case 1:
      current_block = (Rpc - LABEL_78_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_78_7);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (day_of_week_long_string_5)
DEFLABEL (day_of_week_long_string_1)
  INTERRUPT_CHECK (26, LABEL_78_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_78_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_78_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_78_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_78_5);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_78_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_9;
  Wrd5 = Wrd9;

DEFLABEL (label_8)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd27.uLng) == 10)
    goto label_7;

DEFLABEL (label_6)
  INVOKE_PRIMITIVE ((current_block [OBJECT_78_1]), 2);

DEFLABEL (label_7)
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 26))
    goto label_6;
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [0]);
  (Wrd25.Lng) = (FIXNUM_TO_LONG (Wrd24.Obj));
  if (! (((unsigned long) (Wrd21.Lng)) < ((unsigned long) (Wrd25.Lng))))
    goto label_6;
  (Wrd13.uLng) = (OBJECT_DATUM (Wrd18.Obj));
  (Wrd16.pObj) = (& ((Wrd23.pObj) [(Wrd13.Lng)]));
  Rvl = ((Wrd16.pObj) [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_9)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_78_7])), (Wrd6.pObj));

DEFLABEL (label_3)
  (Wrd5.Obj) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_79_5 3
#define LABEL_79_6 5
#define LABEL_79_4 7
#define LABEL_79_7 9
#define LABEL_79_9 11
#define ENVIRONMENT_LABEL_79_3 29
#define DEBUGGING_LABEL_79_2 28
#define OBJECT_79_8 27
#define OBJECT_79_7 26
#define OBJECT_79_6 25
#define OBJECT_79_5 24
#define OBJECT_79_4 23
#define OBJECT_79_3 22
#define OBJECT_79_2 21
#define OBJECT_79_1 20
#define OBJECT_79_0 19
#define EXECUTE_CACHE_79_11 13
#define EXECUTE_CACHE_79_10 15
#define EXECUTE_CACHE_79_8 17
#define FREE_REFERENCES_LABEL_79_0 12
#define NUMBER_OF_LINKER_SECTIONS_79_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_79 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd23;
  machine_word Wrd13;
  machine_word Wrd46;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd41;
  machine_word Wrd38;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_79_5);
      goto continuation_3;

    case 1:
      current_block = (Rpc - LABEL_79_6);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_79_4);
      goto guarantee_day_of_week_5;

    case 3:
      current_block = (Rpc - LABEL_79_7);
      goto label_7;

    case 4:
      current_block = (Rpc - LABEL_79_9);
      goto continuation_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_day_of_week_9)
DEFLABEL (guarantee_day_of_week_5)
  INTERRUPT_CHECK (26, LABEL_79_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_79_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd38.Obj) = (current_block [OBJECT_79_0]);
  (Wrd41.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 26L) < ((unsigned long) (Wrd41.Lng))))
    goto label_19;
  (Wrd10.uLng) = (OBJECT_DATUM (Wrd38.Obj));
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd10.Obj) == (Wrd12.Obj))
    goto label_18;

DEFLABEL (label_17)
  (Wrd13.Obj) = (current_block [OBJECT_79_2]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd23.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 14L) < ((unsigned long) (Wrd23.Lng)))
    goto label_10;
  INVOKE_PRIMITIVE ((current_block [OBJECT_79_1]), 2);

DEFLABEL (label_10)
  (Wrd17.uLng) = (OBJECT_DATUM (Wrd13.Obj));
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd17.Obj) == (Wrd19.Obj))
    goto label_12;
  (Wrd15.Obj) = (current_block [OBJECT_79_4]);
  goto label_11;

DEFLABEL (label_12)
  (Wrd15.Obj) = (current_block [OBJECT_79_3]);

DEFLABEL (label_11)
DEFLABEL (label_16)
  Rsp = (& (Rsp [3]));
  if ((Wrd15.Obj) == ((SCHEME_OBJECT) 0))
    goto label_15;

DEFLABEL (label_14)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_79_9]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (current_block [OBJECT_79_6]);
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd35.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd36.Obj) = (current_block [OBJECT_79_7]);
  (* (--Rsp)) = (Wrd36.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_79_10]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_79_9);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_13;
  Rvl = (current_block [OBJECT_79_8]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_13)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_79_11]));

DEFLABEL (label_15)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_79_5]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd28.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd29.Obj) = (current_block [OBJECT_79_5]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_79_8]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_79_5);
  goto label_14;

DEFLABEL (label_18)
  Rsp = (& (Rsp [2]));
  goto label_14;

DEFLABEL (label_19)
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_79_7]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_79_1]), 2);

DEFLABEL (label_7)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_17;
  goto label_18;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_79_6);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_15;
  goto label_14;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_80_4 3
#define LABEL_80_6 5
#define LABEL_80_5 7
#define LABEL_80_9 9
#define LABEL_80_8 11
#define ENVIRONMENT_LABEL_80_3 22
#define DEBUGGING_LABEL_80_2 21
#define OBJECT_80_0 20
#define EXECUTE_CACHE_80_10 13
#define EXECUTE_CACHE_80_7 15
#define FREE_REFERENCE_80_1 18
#define FREE_REFERENCE_80_0 19
#define FREE_REFERENCES_LABEL_80_0 12
#define NUMBER_OF_LINKER_SECTIONS_80_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_80 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_80_4);
      goto string__day_of_week_4;

    case 1:
      current_block = (Rpc - LABEL_80_6);
      goto label_6;

    case 2:
      current_block = (Rpc - LABEL_80_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_80_9);
      goto label_7;

    case 4:
      current_block = (Rpc - LABEL_80_8);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (string__day_of_week_9)
DEFLABEL (string__day_of_week_4)
  INTERRUPT_CHECK (26, LABEL_80_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_80_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_80_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_15;
  Wrd9 = Wrd13;

DEFLABEL (label_14)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_80_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_80_5);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_10;
  Rvl = Rvl;
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_10)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_80_8]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd14.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_80_1]));
  (Wrd17.Obj) = ((Wrd14.pObj) [0]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd18.uLng) == 50)
    goto label_13;
  Wrd13 = Wrd17;

DEFLABEL (label_12)
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_80_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_80_8);
  (Rsp [0]) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_11;
  Rvl = Rvl;
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_11)
  (Wrd10.Obj) = (current_block [OBJECT_80_0]);
  (Rsp [0]) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_80_10]));

DEFLABEL (label_13)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_80_9])), (Wrd14.pObj));

DEFLABEL (label_7)
  (Wrd13.Obj) = Rvl;
  goto label_12;

DEFLABEL (label_15)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_80_6])), (Wrd10.pObj));

DEFLABEL (label_6)
  (Wrd9.Obj) = Rvl;
  goto label_14;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_81_4 3
#define LABEL_81_5 5
#define LABEL_81_6 7
#define LABEL_81_8 9
#define LABEL_81_7 11
#define ENVIRONMENT_LABEL_81_3 19
#define DEBUGGING_LABEL_81_2 18
#define OBJECT_81_2 17
#define OBJECT_81_1 16
#define OBJECT_81_0 15
#define EXECUTE_CACHE_81_9 13
#define FREE_REFERENCES_LABEL_81_0 12
#define NUMBER_OF_LINKER_SECTIONS_81_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_81 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd14;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd17;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd11;
  machine_word Wrd10;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_81_4);
      goto string_ci__index_9;

    case 1:
      current_block = (Rpc - LABEL_81_5);
      goto label_11;

    case 2:
      current_block = (Rpc - LABEL_81_6);
      goto loop_6;

    case 3:
      current_block = (Rpc - LABEL_81_8);
      goto label_12;

    case 4:
      current_block = (Rpc - LABEL_81_7);
      goto continuation_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (string_ci__index_14)
DEFLABEL (string_ci__index_9)
  INTERRUPT_CHECK (26, LABEL_81_4);
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 10))
    goto label_17;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [0]);
  (Wrd9.Obj) = (MAKE_OBJECT (26, (Wrd8.uLng)));
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_16)
  (Wrd16.Obj) = (current_block [OBJECT_81_1]);
  (* (--Rsp)) = (Wrd16.Obj);
  goto loop_6;

DEFLABEL (label_17)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_5]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_81_0]), 1);

DEFLABEL (label_11)
  (* (--Rsp)) = Rvl;
  goto label_16;

DEFLABEL (loop_15)
DEFLABEL (loop_6)
  INTERRUPT_CHECK (26, LABEL_81_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (Rsp [1]);
  if (! ((Wrd5.Obj) == (Wrd6.Obj)))
    goto label_18;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_18)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd24.Obj) = (Rsp [3]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd25.uLng) == 10))
    goto label_21;
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd17.uLng) == 26))
    goto label_21;
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [0]);
  (Wrd23.Lng) = (FIXNUM_TO_LONG (Wrd22.Obj));
  if (! (((unsigned long) (Wrd19.Lng)) < ((unsigned long) (Wrd23.Lng))))
    goto label_21;
  (Wrd11.uLng) = (OBJECT_DATUM (Wrd5.Obj));
  (Wrd14.pObj) = (& ((Wrd21.pObj) [(Wrd11.Lng)]));
  (Wrd15.Obj) = ((Wrd14.pObj) [1]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_20)
  (Wrd31.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd31.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_81_9]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_81_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_19;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_19)
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.Lng) = (FIXNUM_TO_LONG (Wrd10.Obj));
  (Wrd12.Lng) = ((Wrd11.Lng) + 1L);
  (Wrd9.Obj) = (LONG_TO_FIXNUM (Wrd12.Lng));
  (Rsp [0]) = (Wrd9.Obj);
  goto loop_6;

DEFLABEL (label_21)
  (Wrd26.Obj) = (Rsp [3]);
  (Wrd27.Obj) = (Rsp [1]);
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_8]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_81_2]), 2);

DEFLABEL (label_12)
  (* (--Rsp)) = Rvl;
  goto label_20;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_82_4 3
#define LABEL_82_5 5
#define LABEL_82_9 7
#define LABEL_82_7 9
#define LABEL_82_11 11
#define LABEL_82_12 13
#define ENVIRONMENT_LABEL_82_3 27
#define DEBUGGING_LABEL_82_2 26
#define OBJECT_82_4 25
#define OBJECT_82_3 24
#define OBJECT_82_2 23
#define OBJECT_82_1 22
#define OBJECT_82_0 21
#define EXECUTE_CACHE_82_10 15
#define EXECUTE_CACHE_82_8 17
#define EXECUTE_CACHE_82_6 19
#define FREE_REFERENCES_LABEL_82_0 14
#define NUMBER_OF_LINKER_SECTIONS_82_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_82 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd43;
  machine_word Wrd47;
  machine_word Wrd42;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd26;
  machine_word Wrd30;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd53;
  machine_word Wrd50;
  machine_word Wrd10;
  machine_word Wrd59;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_82_4);
      goto string__year_6;

    case 1:
      current_block = (Rpc - LABEL_82_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_82_9);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_82_7);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_82_11);
      goto label_9;

    case 5:
      current_block = (Rpc - LABEL_82_12);
      goto label_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (string__year_11)
DEFLABEL (string__year_6)
  INTERRUPT_CHECK (26, LABEL_82_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_82_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_82_7);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_21;
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_9]))));
  (* (--Rsp)) = (Wrd57.Obj);
  (Wrd58.Obj) = (current_block [OBJECT_82_0]);
  (* (--Rsp)) = (Wrd58.Obj);
  (Wrd59.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd59.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_82_9);

DEFLABEL (label_21)
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd8.uLng) == 26))
    goto label_20;
  (Wrd10.Lng) = (FIXNUM_TO_LONG (Wrd7.Obj));
  if ((Wrd10.Lng) < 70L)
    goto label_19;

DEFLABEL (label_18)
  (Wrd13.Obj) = (Rsp [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 26))
    goto label_17;
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if ((Wrd16.Lng) < 100L)
    goto label_14;

DEFLABEL (label_13)
  Rvl = (Rsp [0]);

DEFLABEL (label_12)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_14)
  (Wrd21.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd21.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_82_3]);
  (Rsp [0]) = (Wrd22.Obj);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd25.uLng) == 26)
    goto label_16;

DEFLABEL (label_15)
  INVOKE_INTERFACE_0 (43);

DEFLABEL (label_16)
  (Wrd30.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  (Wrd26.Lng) = ((Wrd30.Lng) + 1900L);
  if (! (LONG_TO_FIXNUM_P (Wrd26.Lng)))
    goto label_15;
  Rvl = (LONG_TO_FIXNUM (Wrd26.Lng));
  goto label_12;

DEFLABEL (label_17)
  (Wrd33.Obj) = (current_block [OBJECT_82_2]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_12]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_8)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_13;
  goto label_14;

DEFLABEL (label_19)
  (Wrd38.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd38.Obj);
  (Wrd39.Obj) = (current_block [OBJECT_82_4]);
  (Rsp [0]) = (Wrd39.Obj);
  (Wrd42.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if (! ((Wrd42.uLng) == 26))
    goto label_15;
  (Wrd47.Lng) = (FIXNUM_TO_LONG (Wrd38.Obj));
  (Wrd43.Lng) = ((Wrd47.Lng) + 2000L);
  if (! (LONG_TO_FIXNUM_P (Wrd43.Lng)))
    goto label_15;
  Rvl = (LONG_TO_FIXNUM (Wrd43.Lng));
  goto label_12;

DEFLABEL (label_20)
  (Wrd50.Obj) = (current_block [OBJECT_82_1]);
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_11]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_9)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_18;
  goto label_19;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_83_4 3
#define LABEL_83_5 5
#define ENVIRONMENT_LABEL_83_3 14
#define DEBUGGING_LABEL_83_2 13
#define OBJECT_83_1 12
#define OBJECT_83_0 11
#define EXECUTE_CACHE_83_7 7
#define EXECUTE_CACHE_83_6 9
#define FREE_REFERENCES_LABEL_83_0 6
#define NUMBER_OF_LINKER_SECTIONS_83_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
datime_so_code_83 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_83_4);
      goto d2_1;

    case 1:
      current_block = (Rpc - LABEL_83_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (d2_4)
DEFLABEL (d2_1)
  INTERRUPT_CHECK (26, LABEL_83_4);
  (Wrd5.Obj) = (current_block [OBJECT_83_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_5]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_83_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_83_1]);
  (Rsp [2]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4 3
#define LABEL_7 5
#define LABEL_5 7
#define LABEL_11 9
#define LABEL_12 11
#define LABEL_6 13
#define LABEL_8 15
#define LABEL_10 17
#define LABEL_15 19
#define LABEL_16 21
#define LABEL_17 23
#define LABEL_19 25
#define LABEL_20 27
#define LABEL_22 29
#define LABEL_23 31
#define LABEL_24 33
#define LABEL_25 35
#define LABEL_26 37
#define LABEL_27 39
#define LABEL_28 41
#define LABEL_29 43
#define LABEL_30 45
#define LABEL_31 47
#define LABEL_32 49
#define LABEL_33 51
#define LABEL_34 53
#define LABEL_35 55
#define LABEL_36 57
#define LABEL_37 59
#define LABEL_38 61
#define LABEL_40 63
#define LABEL_39 65
#define LABEL_42 67
#define LABEL_41 69
#define LABEL_44 71
#define LABEL_43 73
#define LABEL_46 75
#define LABEL_45 77
#define LABEL_47 79
#define LABEL_48 81
#define LABEL_49 83
#define LABEL_50 85
#define ENVIRONMENT_LABEL_3 162
#define DEBUGGING_LABEL_2 161
#define PURIFICATION_ROOT 160
#define OBJECT_53 159
#define OBJECT_52 158
#define OBJECT_51 157
#define OBJECT_50 156
#define OBJECT_49 155
#define OBJECT_48 154
#define OBJECT_47 153
#define OBJECT_46 152
#define OBJECT_45 151
#define OBJECT_44 150
#define OBJECT_43 149
#define OBJECT_42 148
#define OBJECT_41 147
#define OBJECT_40 146
#define OBJECT_39 145
#define OBJECT_38 144
#define OBJECT_37 143
#define OBJECT_36 142
#define OBJECT_35 141
#define OBJECT_34 140
#define OBJECT_33 139
#define OBJECT_32 138
#define OBJECT_31 137
#define OBJECT_30 136
#define OBJECT_29 135
#define OBJECT_28 134
#define OBJECT_27 133
#define OBJECT_26 132
#define OBJECT_25 131
#define OBJECT_24 130
#define OBJECT_23 129
#define OBJECT_22 128
#define OBJECT_21 127
#define OBJECT_20 126
#define OBJECT_19 125
#define OBJECT_18 124
#define OBJECT_17 123
#define OBJECT_16 122
#define OBJECT_15 121
#define OBJECT_14 120
#define OBJECT_13 119
#define OBJECT_12 118
#define OBJECT_11 117
#define OBJECT_10 116
#define OBJECT_9 115
#define OBJECT_8 114
#define OBJECT_7 113
#define OBJECT_6 112
#define OBJECT_5 111
#define OBJECT_4 110
#define OBJECT_3 109
#define OBJECT_2 108
#define OBJECT_1 107
#define OBJECT_0 106
#define EXECUTE_CACHE_21 87
#define FREE_REFERENCE_6 90
#define FREE_REFERENCE_5 91
#define FREE_REFERENCE_4 92
#define FREE_REFERENCE_3 93
#define FREE_REFERENCE_2 94
#define FREE_REFERENCE_1 95
#define FREE_REFERENCE_0 96
#define GLOBAL_EXECUTE_CACHE_18 98
#define GLOBAL_EXECUTE_CACHE_14 100
#define GLOBAL_EXECUTE_CACHE_13 102
#define GLOBAL_EXECUTE_CACHE_9 104
#define FREE_REFERENCES_LABEL_0 86
#define NUMBER_OF_LINKER_SECTIONS_1 3

#ifndef WANT_ONLY_DATA

SCHEME_OBJECT *
datime_so_1efa395e919a8dd3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd23;
  machine_word Wrd21;
  machine_word Wrd6;
  machine_word Wrd14;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd22;
  machine_word Wrd20;
  machine_word Wrd12;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_7);
      goto label_34;

    case 2:
      current_block = (Rpc - LABEL_5);
      goto continuation_4;

    case 3:
      current_block = (Rpc - LABEL_11);
      goto label_35;

    case 4:
      current_block = (Rpc - LABEL_12);
      goto label_36;

    case 5:
      current_block = (Rpc - LABEL_6);
      goto continuation_3;

    case 6:
      current_block = (Rpc - LABEL_8);
      goto continuation_2;

    case 7:
      current_block = (Rpc - LABEL_10);
      goto continuation_5;

    case 8:
      current_block = (Rpc - LABEL_15);
      goto continuation_7;

    case 9:
      current_block = (Rpc - LABEL_16);
      goto continuation_6;

    case 10:
      current_block = (Rpc - LABEL_17);
      goto continuation_8;

    case 11:
      current_block = (Rpc - LABEL_19);
      goto continuation_10;

    case 12:
      current_block = (Rpc - LABEL_20);
      goto continuation_9;

    case 13:
      current_block = (Rpc - LABEL_22);
      goto continuation_12;

    case 14:
      current_block = (Rpc - LABEL_23);
      goto continuation_11;

    case 15:
      current_block = (Rpc - LABEL_24);
      goto continuation_14;

    case 16:
      current_block = (Rpc - LABEL_25);
      goto continuation_13;

    case 17:
      current_block = (Rpc - LABEL_26);
      goto continuation_16;

    case 18:
      current_block = (Rpc - LABEL_27);
      goto continuation_15;

    case 19:
      current_block = (Rpc - LABEL_28);
      goto continuation_18;

    case 20:
      current_block = (Rpc - LABEL_29);
      goto continuation_17;

    case 21:
      current_block = (Rpc - LABEL_30);
      goto continuation_20;

    case 22:
      current_block = (Rpc - LABEL_31);
      goto continuation_19;

    case 23:
      current_block = (Rpc - LABEL_32);
      goto continuation_22;

    case 24:
      current_block = (Rpc - LABEL_33);
      goto continuation_21;

    case 25:
      current_block = (Rpc - LABEL_34);
      goto continuation_24;

    case 26:
      current_block = (Rpc - LABEL_35);
      goto continuation_23;

    case 27:
      current_block = (Rpc - LABEL_36);
      goto continuation_26;

    case 28:
      current_block = (Rpc - LABEL_37);
      goto continuation_25;

    case 29:
      current_block = (Rpc - LABEL_38);
      goto continuation_27;

    case 30:
      current_block = (Rpc - LABEL_40);
      goto label_37;

    case 31:
      current_block = (Rpc - LABEL_39);
      goto continuation_28;

    case 32:
      current_block = (Rpc - LABEL_42);
      goto label_38;

    case 33:
      current_block = (Rpc - LABEL_41);
      goto continuation_29;

    case 34:
      current_block = (Rpc - LABEL_44);
      goto label_39;

    case 35:
      current_block = (Rpc - LABEL_43);
      goto continuation_30;

    case 36:
      current_block = (Rpc - LABEL_46);
      goto label_40;

    case 37:
      current_block = (Rpc - LABEL_45);
      goto continuation_31;

    case 38:
      current_block = (Rpc - LABEL_47);
      goto label_41;

    case 39:
      current_block = (Rpc - LABEL_48);
      goto label_44;

    case 40:
      current_block = (Rpc - LABEL_49);
      goto label_45;

    case 41:
      current_block = (Rpc - LABEL_50);
      goto expression_33;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_33)
  (current_block [ENVIRONMENT_LABEL_3]) = (Rrb [REGBLOCK_ENV]);
  INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_49])), current_block, (& (current_block [FREE_REFERENCES_LABEL_0])), NUMBER_OF_LINKER_SECTIONS_1);

DEFLABEL (label_45)
  (* (--Rsp)) = (ULONG_TO_FIXNUM (1UL));

DEFLABEL (label_44)
  {
    static const short sections [] =
      {
	0,
	1,
	1,
	1,
	2,
	1,
	2,
	2,
	2,
	1,
	2,
	2,
	1,
	1,
	2,
	2,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	2,
	1,
	1,
	1,
	2,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	0,
	1,
	1,
	1,
	1,
	2,
	2,
	2,
	1,
	1,
	1,
	1,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	2,
	1,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0
      };
    unsigned long counter = (OBJECT_DATUM (* Rsp));
    SCHEME_OBJECT blocks;
    SCHEME_OBJECT * sub_block;
    short section;
    if (counter > 83)
      goto label_43;
    blocks = (current_block [OBJECT_53]);
    sub_block = (OBJECT_ADDRESS (MEMORY_REF (blocks, counter)));
    (sub_block [(OBJECT_DATUM (sub_block [0]))]) = (Rrb [REGBLOCK_ENV]);
    section = (sections [counter]);
    (* Rsp) = (ULONG_TO_FIXNUM (counter + 1));
    INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_48])), sub_block, (sub_block + (2 + (OBJECT_DATUM (sub_block [1])))), section);
  }

DEFLABEL (label_43)
  Rsp += 1;
  (Wrd5.Obj) = (Rrb [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_1]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_3]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_61;
  Wrd12 = Wrd16;

DEFLABEL (label_60)
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd22.Obj) = (current_block [OBJECT_4]);
  (* (--Rsp)) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_8);
  (* (--Rsp)) = Rvl;
  (Wrd16.Obj) = (MAKE_OBJECT (0, 9));
  (Wrd17.Obj) = (current_block [OBJECT_6]);
  (Wrd18.Obj) = (current_block [OBJECT_7]);
  (Wrd19.Obj) = (current_block [OBJECT_8]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_9]);
  (Wrd11.Obj) = (current_block [OBJECT_10]);
  (Wrd12.Obj) = (current_block [OBJECT_11]);
  (Wrd13.Obj) = (current_block [OBJECT_12]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_13]);
  (Wrd9.Obj) = (current_block [OBJECT_14]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd6.pObj) = (& (Rhp [-10]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_15]);
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (current_block [OBJECT_16]);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_0]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_17]);
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_14]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_6);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_5]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_59;
  Wrd8 = Wrd12;

DEFLABEL (label_58)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_57;
  Wrd14 = Wrd18;

DEFLABEL (label_56)
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_13]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_10);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_18]);
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19]), 2);

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_16);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_22]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_15);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_20]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_21]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_18]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_17);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_23]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_24]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_25]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_20);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_29]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_19);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_26]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_27]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_28]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_23);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_31]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_22);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_30]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_27]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_28]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_25);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_33]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_32]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_27]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_28]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_27);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_35]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_26);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_34]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_27]);
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_29);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_38]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_28);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_36]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_27]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_37]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_31);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_41]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_30);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_39]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_40]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_28]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_33);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_42]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_32);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_26]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_40]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_28]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21]));

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_35);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_44]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_34);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_43]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_40]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_28]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21]));

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_37);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_47]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_26)
  INTERRUPT_CHECK (27, LABEL_36);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_45]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_46]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_18]));

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_38);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_55;
  Wrd8 = Wrd12;

DEFLABEL (label_54)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_48]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_39);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_53;
  Wrd8 = Wrd12;

DEFLABEL (label_52)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_49]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_41);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_51;
  Wrd8 = Wrd12;

DEFLABEL (label_50)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_50]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_43);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_5]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_49;
  Wrd8 = Wrd12;

DEFLABEL (label_48)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_51]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_45);
  (Wrd5.Obj) = (current_block [OBJECT_52]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_47;
  Wrd8 = Wrd12;

DEFLABEL (label_46)
  (Rsp [2]) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (label_47)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_47])), (Wrd9.pObj));

DEFLABEL (label_41)
  (Wrd8.Obj) = Rvl;
  goto label_46;

DEFLABEL (label_49)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_46])), (Wrd9.pObj));

DEFLABEL (label_40)
  (Wrd8.Obj) = Rvl;
  goto label_48;

DEFLABEL (label_51)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_44])), (Wrd9.pObj));

DEFLABEL (label_39)
  (Wrd8.Obj) = Rvl;
  goto label_50;

DEFLABEL (label_53)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_42])), (Wrd9.pObj));

DEFLABEL (label_38)
  (Wrd8.Obj) = Rvl;
  goto label_52;

DEFLABEL (label_55)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_40])), (Wrd9.pObj));

DEFLABEL (label_37)
  (Wrd8.Obj) = Rvl;
  goto label_54;

DEFLABEL (label_57)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_12])), (Wrd15.pObj));

DEFLABEL (label_36)
  (Wrd14.Obj) = Rvl;
  goto label_56;

DEFLABEL (label_59)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_11])), (Wrd9.pObj));

DEFLABEL (label_35)
  (Wrd8.Obj) = Rvl;
  goto label_58;

DEFLABEL (label_61)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_7])), (Wrd13.pObj));

DEFLABEL (label_34)
  (Wrd12.Obj) = Rvl;
  goto label_60;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

static const struct liarc_code_S arr_decl_datime_so_1efa395e919a8dd3 [83] =
  {
    { "datime_so_code_1", 1, datime_so_code_1 },
    { "datime_so_code_2", 1, datime_so_code_2 },
    { "datime_so_code_3", 1, datime_so_code_3 },
    { "datime_so_code_4", 1, datime_so_code_4 },
    { "datime_so_code_5", 1, datime_so_code_5 },
    { "datime_so_code_6", 1, datime_so_code_6 },
    { "datime_so_code_7", 1, datime_so_code_7 },
    { "datime_so_code_8", 1, datime_so_code_8 },
    { "datime_so_code_9", 1, datime_so_code_9 },
    { "datime_so_code_10", 2, datime_so_code_10 },
    { "datime_so_code_11", 20, datime_so_code_11 },
    { "datime_so_code_12", 1, datime_so_code_12 },
    { "datime_so_code_13", 1, datime_so_code_13 },
    { "datime_so_code_14", 1, datime_so_code_14 },
    { "datime_so_code_15", 1, datime_so_code_15 },
    { "datime_so_code_16", 1, datime_so_code_16 },
    { "datime_so_code_17", 1, datime_so_code_17 },
    { "datime_so_code_18", 1, datime_so_code_18 },
    { "datime_so_code_19", 1, datime_so_code_19 },
    { "datime_so_code_20", 1, datime_so_code_20 },
    { "datime_so_code_21", 1, datime_so_code_21 },
    { "datime_so_code_22", 1, datime_so_code_22 },
    { "datime_so_code_23", 5, datime_so_code_23 },
    { "datime_so_code_24", 15, datime_so_code_24 },
    { "datime_so_code_25", 12, datime_so_code_25 },
    { "datime_so_code_26", 27, datime_so_code_26 },
    { "datime_so_code_27", 9, datime_so_code_27 },
    { "datime_so_code_28", 9, datime_so_code_28 },
    { "datime_so_code_29", 8, datime_so_code_29 },
    { "datime_so_code_30", 3, datime_so_code_30 },
    { "datime_so_code_31", 2, datime_so_code_31 },
    { "datime_so_code_32", 2, datime_so_code_32 },
    { "datime_so_code_33", 9, datime_so_code_33 },
    { "datime_so_code_34", 2, datime_so_code_34 },
    { "datime_so_code_35", 10, datime_so_code_35 },
    { "datime_so_code_36", 14, datime_so_code_36 },
    { "datime_so_code_37", 2, datime_so_code_37 },
    { "datime_so_code_38", 2, datime_so_code_38 },
    { "datime_so_code_39", 2, datime_so_code_39 },
    { "datime_so_code_40", 2, datime_so_code_40 },
    { "datime_so_code_41", 22, datime_so_code_41 },
    { "datime_so_code_42", 50, datime_so_code_42 },
    { "datime_so_code_43", 2, datime_so_code_43 },
    { "datime_so_code_44", 2, datime_so_code_44 },
    { "datime_so_code_45", 13, datime_so_code_45 },
    { "datime_so_code_46", 20, datime_so_code_46 },
    { "datime_so_code_47", 19, datime_so_code_47 },
    { "datime_so_code_48", 36, datime_so_code_48 },
    { "datime_so_code_49", 2, datime_so_code_49 },
    { "datime_so_code_50", 2, datime_so_code_50 },
    { "datime_so_code_51", 2, datime_so_code_51 },
    { "datime_so_code_52", 2, datime_so_code_52 },
    { "datime_so_code_53", 2, datime_so_code_53 },
    { "datime_so_code_54", 2, datime_so_code_54 },
    { "datime_so_code_55", 4, datime_so_code_55 },
    { "datime_so_code_56", 18, datime_so_code_56 },
    { "datime_so_code_57", 2, datime_so_code_57 },
    { "datime_so_code_58", 2, datime_so_code_58 },
    { "datime_so_code_59", 2, datime_so_code_59 },
    { "datime_so_code_60", 2, datime_so_code_60 },
    { "datime_so_code_61", 2, datime_so_code_61 },
    { "datime_so_code_62", 2, datime_so_code_62 },
    { "datime_so_code_63", 39, datime_so_code_63 },
    { "datime_so_code_64", 50, datime_so_code_64 },
    { "datime_so_code_65", 19, datime_so_code_65 },
    { "datime_so_code_66", 13, datime_so_code_66 },
    { "datime_so_code_67", 23, datime_so_code_67 },
    { "datime_so_code_68", 31, datime_so_code_68 },
    { "datime_so_code_69", 46, datime_so_code_69 },
    { "datime_so_code_70", 27, datime_so_code_70 },
    { "datime_so_code_71", 10, datime_so_code_71 },
    { "datime_so_code_72", 3, datime_so_code_72 },
    { "datime_so_code_73", 4, datime_so_code_73 },
    { "datime_so_code_74", 4, datime_so_code_74 },
    { "datime_so_code_75", 5, datime_so_code_75 },
    { "datime_so_code_76", 6, datime_so_code_76 },
    { "datime_so_code_77", 3, datime_so_code_77 },
    { "datime_so_code_78", 3, datime_so_code_78 },
    { "datime_so_code_79", 5, datime_so_code_79 },
    { "datime_so_code_80", 5, datime_so_code_80 },
    { "datime_so_code_81", 5, datime_so_code_81 },
    { "datime_so_code_82", 6, datime_so_code_82 },
    { "datime_so_code_83", 2, datime_so_code_83 }
  };

int
decl_datime_so_1efa395e919a8dd3 (void)
{
  DECLARE_SUBCODE_MULTIPLE (arr_decl_datime_so_1efa395e919a8dd3);
  return (0);
}

DECLARE_COMPILED_CODE ("datime.so", 42, decl_datime_so_1efa395e919a8dd3, datime_so_1efa395e919a8dd3)

#endif /* !WANT_ONLY_DATA */

#ifndef WANT_ONLY_CODE

static const unsigned char prog_datime_so_data_1efa395e919a8dd3 [13305] =
  "\xc8\x01\x9e\x01\x9b\x1c\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x22\x29"
  "\x21\x9c\x2b\xb9\x1d\xb0\x82\x88\x22\x29\x21\x9c\x2b\xba\x1d\xb0"
  "\x83\x88\x22\x29\x21\x9c\x2b\xbb\x1d\xb0\x84\x88\x22\x29\x21\x9c"
  "\x2b\xbc\x1d\xb0\x85\x88\x22\x29\x21\x9c\x2b\xbd\x1d\xb0\x86\x88"
  "\x22\x29\x21\x9c\x2b\xbe\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\xbf"
  "\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x22\x29"
  "\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x24\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d"
  "\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x28\x0d\x26\x0d\x1c\x1b\x24"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\xc2\x1c\x81\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x82\x22"
  "\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x83\x22\x29\x21\x9e\x2b"
  "\x1c\x1d\xb0\x02\x88\x1b\x84\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02"
  "\x88\x1b\x85\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x86\x22"
  "\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x02\x22\x29\x21\x9e\x2b"
  "\x1c\x1d\xb0\x02\x88\x1b\x02\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02"
  "\x88\x1b\x02\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\xc3\x1c\x1d"
  "\x02\x22\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88\x1b\x1d\x02\x22\x29"
  "\x21\x9f\x2b\x1c\x1d\xb0\x02\x88\x07\x1b\x80\xc1\x1c\x1b\x24\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x02\xc2\x1c\xc1\x1c\x02\x1b\x02\x1b\x80\x87\x1d\x0c\x0d\x1c"
  "\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28"
  "\x0d\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x02\x80\x02\x1d\x0c\x81"
  "\x02\x28\x0d\x1c\x28\x0d\x1c\x28\x1b\x28\x0d\x1c\x28\x0d\x1c\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x02\x81\x02\x02\x85\x84\x02\x02\x82\x02\x87\x28\x0d\x28\x0d\x28"
  "\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x02\x1b\x1b\x02\x1b\x0d\x1c\x24\x28\x0d\x1c\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x02\x1b\x1b\x02\xc2\x1b\x24\x28\x1b\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x02\x1b\x02\x1b"
  "\x24\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xc0\x1b\x24"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x0d"
  "\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x02\x03\x02\x06\x07\x02\x86\x02\x02\xc2\x1c\x02\x28"
  "\x0d\x28\x1b\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x07\x1b\x02\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x86"
  "\x0c\x02\x85\x0c\x1b\x84\x0c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c"
  "\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x0c\x0c\x0c\x02\x02\x0c\x0c\x02\x83\x81\x1b\x82\x28\x1b"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x1b\x23\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x0d\x1c\x28\x1b\x23"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x0d\x1c\x28"
  "\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x02"
  "\x0c\x02\x84\x85\x86\x0c\x83\x82\x0c\x1b\x81\x28\x0d\x1c\x28\x1b"
  "\x28\x0d\x1c\x28\x1b\x28\x1b\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x81\x0c\x82\x83\x08\x89\x0f\x80\x0f\xc2\xc1"
  "\x86\x85\x83\x0f\x84\x08\xc1\x1c\xc1\x1c\x82\x07\x0d\x0d\x1c\x24"
  "\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x28\x0d\x1c\x28\x0d\x1c\x28\x0d"
  "\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x1b\x28\x0d"
  "\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x0d"
  "\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x1b\x1b\x0c\x0c\x02\x80\x0c\x1b\x28\x1b\x28\x1b\x28"
  "\x0d\x28\x0d\x1c\x28\x1b\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x02\x80"
  "\x02\x03\x02\x0c\x06\x07\x02\x1b\x02\x02\x1b\x1b\x0d\x1c\x24\x28"
  "\x0d\x28\x1b\x28\x0d\x1c\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x86"
  "\x02\x85\x84\x83\x0c\x1b\x81\x82\x0f\x0c\x28\x1b\x28\x0d\x1c\x28"
  "\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x81\x84\x80\x82\x1b\x1b\x0c\x83\x0f\x85"
  "\x0f\x07\x1d\x0c\x0d\x1c\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b"
  "\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x0d\x1c"
  "\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28"
  "\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\x28"
  "\x1b\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x1d\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x1b\x80\x0d\x1c\x28\x0d\x28\x1b\x28\x0d\x1c\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x0c\x02\x86\x85\x0c\x84\x0c\x83\x82\x0c\x1b\x81\x28\x1b\x28\x1b"
  "\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x1b\x23\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x1b\x23\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x1b\x23\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x02\x82\x80\x1b\x81\x0f"
  "\x0f\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c"
  "\x28\x0d\x28\x0d\x1c\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x0f\x0c\x0f\x28\x1b\x28\x0d\x1c\x28\x1b\x28\x1b\x28\x1b\x28"
  "\x0d\x1c\x28\x0d\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c"
  "\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x02\x02\x84\x85\x86\x82\x80\x1b\x81\x28\x1b\x28\x1b"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x02\x84\x85\x86\x81\x1b\x80\x28\x1b\x28\x1b\x28\x1b\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x0f\x80\x81\x0f\x28\x1b\x28\x1b\x28\x0d\x1c\x28\x1b\x28\x0d"
  "\x1c\x28\x0d\x1c\x28\x1b\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x82\x81\x02\x1b\x80\x0f\x28\x1b\x28\x0d\x1c\x28\x1b\x28"
  "\x1b\x28\x1b\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b"
  "\x80\x0d\x1c\x84\x83\x82\x81\x0d\x1c\x1b\x24\x28\x1b\x28\x1b\x28"
  "\x0d\x1c\x28\x1b\x28\x1b\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x02\x0f\x06\x02\x1b\x80\x1b\x24\x28\x1b\x28\x1b\x28\x1b\x28\x1b"
  "\x28\x1b\x28\x0d\x28\x1b\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x87\x81\x0f\x0f\x28\x1b\x28\x1b\x28"
  "\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x1b\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x02\x17"
  "\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x1b\x1b\x0d\x1c\x24\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x0d\x1c\x24"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x1d\x81\x02\x0c\x06\x07\x02\x1b\x02\x28\x1b\x28\x1b"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x0c\x1b\x1b\x24\x28\x1b\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x1b\x1b\x1b\x24\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x0d\x1c\x24\x28\x1b\x23"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\x80"
  "\x86\x0c\x06\x07\x02\x1b\x02\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x0c\x1b\x1b\x24\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x80\x1b\x28\x1b"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x02\x02\x02\x02\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x0f\x82\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x17\x1c\x88\x1b\x0d\x0d\x0d\x0d\x0d\x1b\x1b\x1b\x1b\x1b"
  "\x1b\x0d\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x17\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x0c\x0c\x0c\x0c\x0c\x0c\x0c\x9e\x0c\x0c\x0c"
  "\x0c\x0c\x0c\x0c\x9e\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x0c\x0c\x0c"
  "\x0c\x0c\x0c\x0c\x0c\x0c\x0c\x0c\x0c\x17\x0c\x0c\x0c\x0c\x0c\x0c"
  "\x0c\x0c\x0c\x0c\x0c\x0c\x17\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x17\x1b\x02\x1b\x1b\x80\x02\x1b\x83\x02\x1b"
  "\x02\x1b\x02\x1b\x02\x1b\x82\x81\x02\x84\x02\x02\x1b\x1b\x1b\x1b"
  "\x1b\x1b\x1b\x1b\x0d\x0d\x0d\x0d\x0d\x0d\x1b\x1b\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x1b\x1b\x1b\x1b\x1b\x0d\x0d\x1b\x1b\x0d\x0d\x1c\x0d\x0d"
  "\x1c\x0d\x0d\x1b\x1b\x0d\x0d\x1c\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x1b\x1b\x17\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x0c\x80\x08"
  "\x89\x0c\x80\x08\x89\x0c\x85\x08\x89\x0c\x84\x08\x89\x0c\x86\x08"
  "\x89\x0c\x85\x08\x89\x0c\x02\x08\x89\x0c\x86\x08\x89\x0c\x02\x08"
  "\x89\x0c\x02\x08\x89\x0c\x81\x08\x89\x0c\x82\x08\x89\x0c\x83\x08"
  "\x89\x0c\x84\x08\x89\x0c\x85\x08\x89\x0c\x86\x08\x89\x0c\x02\x08"
  "\x89\x0c\x02\x08\x89\x0c\x02\x08\x89\x0c\x02\x08\x89\x0c\x02\x08"
  "\x89\x0c\x02\x08\x89\x0c\x87\x08\x89\x0c\x03\x08\x89\x0c\x03\x08"
  "\x89\x0c\x03\x08\x89\x0c\x03\x08\x89\x0c\x03\x08\x89\x0c\x03\x08"
  "\x89\x0c\x03\x08\x89\x0c\x03\x08\x89\x0c\x03\x08\x89\x0c\x03\x08"
  "\x89\x0c\x03\x08\x89\x0c\x80\x08\x89\x08\x14\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x04\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x17\xc2\x0d\x0d\x1b\x1b\x1b\x1b\x1b\x1b"
  "\x1b\x1b\x1b\x17\x02\x02\x02\x86\x85\x84\x83\x82\x81\x17\x1b\x2a"
  "\x1b\x2a\xb7\x2a\xb6\x2a\xb5\x2a\xb4\x2a\xb3\x2a\xb2\x2a\xb1\x2a"
  "\x1b\x0d\x02\xc3\x1b\x0c\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x26\x1b"
  "\x1b\x1b\x1b\x1b\x1b\x1b\x24\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x02\x78\x2f\x61\x66\x73\x2f\x63\x73\x61\x69\x6c\x2e\x6d\x69\x74"
  "\x2e\x65\x64\x75\x2f\x67\x72\x6f\x75\x70\x2f\x6d\x61\x63\x2f\x70"
  "\x72\x6f\x6a\x65\x63\x74\x73\x2f\x73\x63\x68\x65\x6d\x65\x2f\x76"
  "\x37\x2f\x64\x69\x73\x74\x2f\x73\x6e\x61\x70\x73\x68\x6f\x74\x2e"
  "\x70\x6b\x67\x2f\x32\x30\x30\x37\x30\x39\x30\x39\x2f\x6d\x69\x74"
  "\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x32\x30\x30\x37\x30\x39"
  "\x30\x39\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f\x64"
  "\x61\x74\x69\x6d\x65\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69"
  "\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x2b"
  "\x04\x82\x02\x03\x02\x2c\x04\x82\x02\x03\x02\x2d\x04\x82\x02\x03"
  "\x02\x2e\x04\x82\x02\x03\x02\x2f\x04\x82\x02\x03\x02\x30\x04\x82"
  "\x02\x03\x02\x08\x31\x04\x82\x02\x03\x02\x09\x32\x04\x82\x02\x03"
  "\x09\x02\x0a\x33\x04\x82\x02\x03\x0a\x02\x0b\x1b\x64\x65\x63\x6f"
  "\x64\x65\x64\x2d\x74\x69\x6d\x65\x2d\x73\x74\x72\x75\x63\x74\x75"
  "\x72\x65\x2d\x74\x61\x67\x0b\x02\x35\x06\x81\x93\x02\x34\x04\x8b"
  "\x14\x05\x0a\x0c\x02\x0c\x05\x7a\x6f\x6e\x65\x0d\x16\x64\x61\x79"
  "\x6c\x69\x67\x68\x74\x2d\x73\x61\x76\x69\x6e\x67\x73\x2d\x74\x69"
  "\x6d\x65\x0e\x0c\x64\x61\x79\x2d\x6f\x66\x2d\x77\x65\x65\x6b\x0f"
  "\x05\x79\x65\x61\x72\x10\x06\x6d\x6f\x6e\x74\x68\x11\x04\x64\x61"
  "\x79\x12\x05\x68\x6f\x75\x72\x13\x07\x6d\x69\x6e\x75\x74\x65\x14"
  "\x07\x73\x65\x63\x6f\x6e\x64\x15\x04\x1f\x64\x65\x66\x69\x6e\x65"
  "\x2d\x73\x74\x72\x75\x63\x74\x75\x72\x65\x2f\x64\x65\x66\x61\x75"
  "\x6c\x74\x2d\x76\x61\x6c\x75\x65\x02\x11\x72\x74\x64\x3a\x64\x65"
  "\x63\x6f\x64\x65\x64\x2d\x74\x69\x6d\x65\x16\x0b\x03\x49\x2a\x81"
  "\x93\x02\x48\x28\x81\x91\x02\x47\x26\x81\x95\x02\x46\x24\x81\x8f"
  "\x02\x45\x22\x81\x93\x02\x44\x20\x81\x8d\x02\x43\x1e\x81\x91\x02"
  "\x42\x1c\x81\x8b\x02\x41\x1a\x81\x8f\x02\x40\x18\x81\x89\x02\x3f"
  "\x16\x81\x8d\x02\x3e\x14\x81\x87\x02\x3d\x12\x81\x8b\x02\x3c\x10"
  "\x81\x85\x02\x3b\x0e\x81\x89\x02\x3a\x0c\x81\x83\x02\x39\x0a\x81"
  "\x87\x02\x38\x08\x81\x81\x02\x37\x06\x81\x85\x02\x36\x04\x82\x02"
  "\x29\x3b\x17\x02\x0d\x0b\x76\x65\x63\x74\x6f\x72\x2d\x72\x65\x66"
  "\x18\x4a\x04\x83\x04\x03\x19\x02\x0e\x18\x4b\x04\x83\x04\x03\x1a"
  "\x02\x0f\x18\x4c\x04\x83\x04\x03\x1b\x02\x10\x18\x4d\x04\x83\x04"
  "\x03\x1c\x02\x11\x18\x4e\x04\x83\x04\x03\x1d\x02\x12\x18\x4f\x04"
  "\x83\x04\x03\x1e\x02\x13\x18\x08\x50\x04\x83\x04\x03\x1f\x02\x14"
  "\x18\x09\x51\x04\x83\x04\x03\x20\x02\x15\x18\x0a\x52\x04\x83\x04"
  "\x03\x21\x02\x16\x0c\x76\x65\x63\x74\x6f\x72\x2d\x73\x65\x74\x21"
  "\x22\x02\x08\x53\x04\x84\x06\x03\x23\x02\x17\x22\x02\x0a\x54\x04"
  "\x84\x06\x03\x24\x02\x18\x18\x0e\x76\x65\x63\x74\x6f\x72\x2d\x6c"
  "\x65\x6e\x67\x74\x68\x25\x0b\x02\x59\x0c\x81\x85\x02\x58\x0a\x81"
  "\x83\x02\x57\x08\x81\x83\x02\x56\x06\x81\x83\x02\x55\x04\x83\x04"
  "\x0b\x14\x26\x02\x19\x08\x0c\x64\x65\x63\x6f\x64\x65\x2d\x74\x69"
  "\x6d\x65\x27\x0c\x65\x6e\x63\x6f\x64\x65\x2d\x74\x69\x6d\x65\x28"
  "\x91\x1c\x18\x0a\x22\x08\x0a\x74\x69\x6d\x65\x20\x7a\x6f\x6e\x65"
  "\x12\x6d\x61\x6b\x65\x2d\x64\x65\x63\x6f\x64\x65\x64\x2d\x74\x69"
  "\x6d\x65\x29\x09\x18\x63\x68\x65\x63\x6b\x2d\x64\x65\x63\x6f\x64"
  "\x65\x64\x2d\x74\x69\x6d\x65\x2d\x61\x72\x67\x73\x2a\x05\x1a\x65"
  "\x72\x72\x6f\x72\x3a\x77\x72\x6f\x6e\x67\x2d\x74\x79\x70\x65\x2d"
  "\x61\x72\x67\x75\x6d\x65\x6e\x74\x2b\x0b\x13\x25\x6d\x61\x6b\x65"
  "\x2d\x64\x65\x63\x6f\x64\x65\x64\x2d\x74\x69\x6d\x65\x2c\x05\x14"
  "\x63\x6f\x6d\x70\x75\x74\x65\x2d\x64\x61\x79\x2d\x6f\x66\x2d\x77"
  "\x65\x65\x6b\x2d\x03\x0b\x74\x69\x6d\x65\x2d\x7a\x6f\x6e\x65\x3f"
  "\x2e\x03\x0e\x69\x67\x6e\x6f\x72\x65\x2d\x65\x72\x72\x6f\x72\x73"
  "\x03\x0b\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x3f\x08\x68\x20\x81"
  "\x83\x02\x67\x1e\x81\x83\x02\x66\x1c\x81\x93\x02\x65\x1a\x81\x95"
  "\x02\x64\x18\x81\x91\x02\x63\x16\x81\x91\x02\x62\x14\x81\x91\x02"
  "\x61\x12\x81\x91\x02\x60\x10\x81\x87\x02\x5f\x0e\x81\x91\x02\x5e"
  "\x0c\x81\x93\x02\x5d\x0a\x81\x8f\x02\x5c\x08\x81\x91\x02\x5b\x06"
  "\x81\x91\x02\x5a\x04\x89\x0e\x1f\x3d\x2f\x02\x1a\x3c\x18\x02\x1b"
  "\x65\x78\x61\x63\x74\x20\x6e\x6f\x6e\x2d\x6e\x65\x67\x61\x74\x69"
  "\x76\x65\x20\x69\x6e\x74\x65\x67\x65\x72\x0d\x03\x1b\x65\x78\x61"
  "\x63\x74\x2d\x6e\x6f\x6e\x6e\x65\x67\x61\x74\x69\x76\x65\x2d\x69"
  "\x6e\x74\x65\x67\x65\x72\x3f\x30\x03\x0f\x6d\x6f\x6e\x74\x68\x2f"
  "\x6d\x61\x78\x2d\x64\x61\x79\x73\x31\x05\x2b\x05\x03\x3c\x3d\x32"
  "\x04\x19\x65\x72\x72\x6f\x72\x3a\x62\x61\x64\x2d\x72\x61\x6e\x67"
  "\x65\x2d\x61\x72\x67\x75\x6d\x65\x6e\x74\x33\x06\x74\x1a\x81\x8f"
  "\x02\x73\x18\xfd\xff\x03\x72\x16\x81\x8f\x02\x71\x14\xfd\xff\x03"
  "\x70\x12\x81\x93\x02\x6f\x10\x81\x8f\x02\x6e\x0e\x81\x85\x02\x6d"
  "\x0c\xff\xff\x03\x6c\x0a\x81\x8f\x02\x6b\x08\x81\x85\x02\x6a\x06"
  "\x81\x8f\x02\x69\x04\x89\x10\x19\x2e\x34\x02\x1b\x0c\x91\x03\x0e"
  "\x65\x08\x0d\x04\x07\x6d\x6f\x64\x75\x6c\x6f\x03\x06\x66\x6c\x6f"
  "\x6f\x72\x07\x02\x2b\x04\x8f\x01\x38\x81\x89\x02\x8e\x01\x36\x81"
  "\x87\x02\x8d\x01\x34\x81\x8f\x02\x8c\x01\x32\x81\x85\x02\x8b\x01"
  "\x30\x81\x85\x02\x8a\x01\x2e\x81\x85\x02\x89\x01\x2c\x81\x85\x02"
  "\x88\x01\x2a\x81\x85\x02\x87\x01\x28\x81\x85\x02\x86\x01\x26\x81"
  "\x85\x02\x85\x01\x24\x81\x85\x02\x84\x01\x22\x81\x83\x02\x83\x01"
  "\x20\x81\x85\x02\x82\x01\x1e\x81\x91\x02\x81\x01\x1c\x81\x8d\x02"
  "\x80\x01\x1a\x81\x85\x02\x7f\x18\x81\x83\x02\x7e\x16\x81\x89\x02"
  "\x7d\x14\x81\x89\x02\x7c\x12\x81\x8d\x02\x7b\x10\x81\x8f\x02\x7a"
  "\x0e\x81\x8b\x02\x79\x0c\x81\x85\x02\x78\x0a\x81\x87\x02\x77\x08"
  "\x81\x87\x02\x76\x06\x81\x91\x02\x75\x04\x85\x08\x37\x4c\x35\x02"
  "\x1c\x91\x1c\x18\x22\x0a\x27\x06\x65\x70\x6f\x63\x68\x27\x02\x02"
  "\x16\x61\x6c\x6c\x6f\x63\x61\x74\x65\x2d\x64\x65\x63\x6f\x64\x65"
  "\x64\x2d\x74\x69\x6d\x65\x36\x02\x98\x01\x14\x81\x89\x02\x97\x01"
  "\x12\x81\x85\x02\x96\x01\x10\x81\x85\x02\x95\x01\x0e\x81\x85\x02"
  "\x94\x01\x0c\x81\x85\x02\x93\x01\x0a\x81\x87\x02\x92\x01\x08\x81"
  "\x87\x02\x91\x01\x06\x81\x83\x02\x90\x01\x04\x83\x04\x13\x20\x37"
  "\x02\x1d\x91\x1c\x18\x22\x0a\x0b\x64\x65\x63\x6f\x64\x65\x2d\x75"
  "\x74\x63\x27\x02\x02\x36\x02\xa1\x01\x14\x81\x89\x02\xa0\x01\x12"
  "\x81\x85\x02\x9f\x01\x10\x81\x85\x02\x9e\x01\x0e\x81\x85\x02\x9d"
  "\x01\x0c\x81\x85\x02\x9c\x01\x0a\x81\x87\x02\x9b\x01\x08\x81\x87"
  "\x02\x9a\x01\x06\x81\x83\x02\x99\x01\x04\x83\x04\x13\x20\x38\x02"
  "\x1e\x28\x22\x91\x1c\x18\x0a\x27\x02\x03\x12\x63\x6f\x70\x79\x2d"
  "\x64\x65\x63\x6f\x64\x65\x64\x2d\x74\x69\x6d\x65\x28\x02\xa9\x01"
  "\x12\x81\x85\x02\xa8\x01\x10\x81\x83\x02\xa7\x01\x0e\x81\x85\x02"
  "\xa6\x01\x0c\x83\x04\xa5\x01\x0a\x81\x87\x02\xa4\x01\x08\x81\x87"
  "\x02\xa3\x01\x06\x81\x87\x02\xa2\x01\x04\x81\x85\x02\x11\x1e\x22"
  "\x02\x1f\x0d\x65\x6e\x63\x6f\x64\x65\x64\x2d\x74\x69\x6d\x65\x27"
  "\x02\xac\x01\x08\x81\x83\x02\xab\x01\x06\x81\x81\x02\xaa\x01\x04"
  "\x82\x02\x07\x0d\x39\x02\x20\x02\x13\x67\x65\x74\x2d\x75\x6e\x69"
  "\x76\x65\x72\x73\x61\x6c\x2d\x74\x69\x6d\x65\x3a\x03\x23\x75\x6e"
  "\x69\x76\x65\x72\x73\x61\x6c\x2d\x74\x69\x6d\x65\x2d\x3e\x6c\x6f"
  "\x63\x61\x6c\x2d\x64\x65\x63\x6f\x64\x65\x64\x2d\x74\x69\x6d\x65"
  "\x3b\x03\xae\x01\x06\x81\x81\x02\xad\x01\x04\x82\x02\x05\x0d\x3c"
  "\x02\x21\x02\x3a\x03\x24\x75\x6e\x69\x76\x65\x72\x73\x61\x6c\x2d"
  "\x74\x69\x6d\x65\x2d\x3e\x67\x6c\x6f\x62\x61\x6c\x2d\x64\x65\x63"
  "\x6f\x64\x65\x64\x2d\x74\x69\x6d\x65\x3d\x03\xb0\x01\x06\x81\x81"
  "\x02\xaf\x01\x04\x82\x02\x05\x0d\x3e\x02\x22\x91\x1c\x19\x19\x3d"
  "\x3b\x0f\x0d\x6f\x62\x6a\x65\x63\x74\x2d\x74\x79\x70\x65\x3f\x3f"
  "\x1b\x03\x07\x65\x78\x61\x63\x74\x3f\x05\x32\x03\x09\x69\x6e\x74"
  "\x65\x67\x65\x72\x3f\x04\xb9\x01\x14\x81\x83\x02\xb8\x01\x12\x81"
  "\x83\x02\xb7\x01\x10\x81\x83\x02\xb6\x01\x0e\x81\x83\x02\xb5\x01"
  "\x0c\x81\x83\x02\xb4\x01\x0a\x81\x83\x02\xb3\x01\x08\x81\x83\x02"
  "\xb2\x01\x06\x83\x04\xb1\x01\x04\x81\x83\x02\x13\x28\x40\x02\x23"
  "\x18\x09\xbb\x01\x06\x81\x83\x02\xba\x01\x04\x83\x04\x05\x0b\x41"
  "\x02\x24\x01\x08\x02\x20\x18\x03\x2c\x20\x03\x0f\x6e\x75\x6d\x62"
  "\x65\x72\x2d\x3e\x73\x74\x72\x69\x6e\x67\x42\x03\x12\x6d\x6f\x6e"
  "\x74\x68\x2f\x6c\x6f\x6e\x67\x2d\x73\x74\x72\x69\x6e\x67\x43\x03"
  "\x18\x64\x61\x79\x2d\x6f\x66\x2d\x77\x65\x65\x6b\x2f\x6c\x6f\x6e"
  "\x67\x2d\x73\x74\x72\x69\x6e\x67\x44\x04\x0e\x73\x74\x72\x69\x6e"
  "\x67\x2d\x61\x70\x70\x65\x6e\x64\x45\x08\x45\x06\xc5\x01\x16\x81"
  "\x8d\x02\xc4\x01\x14\x81\x83\x02\xc3\x01\x12\x81\x8f\x02\xc2\x01"
  "\x10\x81\x8d\x02\xc1\x01\x0e\x81\x89\x02\xc0\x01\x0c\x81\x8b\x02"
  "\xbf\x01\x0a\x81\x8b\x02\xbe\x01\x08\x81\x85\x02\xbd\x01\x06\x81"
  "\x87\x02\xbc\x01\x04\x83\x04\x15\x2b\x46\x02\x25\x03\x41\x4d\x03"
  "\x50\x4d\x02\x20\x0d\x0e\x03\x3a\x30\x02\x3a\x0b\x18\x03\x42\x09"
  "\x45\x03\xd3\x01\x1e\x81\x8f\x02\xd2\x01\x1c\x81\x8f\x02\xd1\x01"
  "\x1a\x81\x8d\x02\xd0\x01\x18\x81\x91\x02\xcf\x01\x16\x81\x91\x02"
  "\xce\x01\x14\x81\x91\x02\xcd\x01\x12\x81\x8b\x02\xcc\x01\x10\x81"
  "\x89\x02\xcb\x01\x0e\x81\x8f\x02\xca\x01\x0c\x81\x87\x02\xc9\x01"
  "\x0a\x81\x87\x02\xc8\x01\x08\x81\x85\x02\xc7\x01\x06\x81\x83\x02"
  "\xc6\x01\x04\x83\x04\x1d\x31\x47\x02\x26\x03\x3b\x03\x15\x64\x65"
  "\x63\x6f\x64\x65\x64\x2d\x74\x69\x6d\x65\x2d\x3e\x73\x74\x72\x69"
  "\x6e\x67\x48\x03\xd5\x01\x06\x81\x83\x02\xd4\x01\x04\x83\x04\x05"
  "\x0d\x49\x02\x27\x03\x3d\x03\x48\x03\xd7\x01\x06\x81\x83\x02\xd6"
  "\x01\x04\x83\x04\x05\x0d\x4a\x02\x28\x03\x1e\x66\x69\x6c\x65\x2d"
  "\x74\x69\x6d\x65\x2d\x3e\x6c\x6f\x63\x61\x6c\x2d\x64\x65\x63\x6f"
  "\x64\x65\x64\x2d\x74\x69\x6d\x65\x4b\x03\x48\x03\xd9\x01\x06\x81"
  "\x83\x02\xd8\x01\x04\x83\x04\x05\x0d\x4c\x02\x29\x03\x1f\x66\x69"
  "\x6c\x65\x2d\x74\x69\x6d\x65\x2d\x3e\x67\x6c\x6f\x62\x61\x6c\x2d"
  "\x64\x65\x63\x6f\x64\x65\x64\x2d\x74\x69\x6d\x65\x4d\x03\x48\x03"
  "\xdb\x01\x06\x81\x83\x02\xda\x01\x04\x83\x04\x05\x0d\x4e\x02\x2a"
  "\x03\x2c\x20\x0a\x01\x08\x02\x20\x02\x3a\x18\x03\x03\x64\x32\x4f"
  "\x03\x42\x03\x13\x6d\x6f\x6e\x74\x68\x2f\x73\x68\x6f\x72\x74\x2d"
  "\x73\x74\x72\x69\x6e\x67\x50\x0f\x45\x04\x45\x03\x24\x64\x65\x63"
  "\x6f\x64\x65\x64\x2d\x74\x69\x6d\x65\x2f\x64\x61\x79\x6c\x69\x67"
  "\x68\x74\x2d\x73\x61\x76\x69\x6e\x67\x73\x2d\x74\x69\x6d\x65\x3f"
  "\x51\x03\x19\x64\x61\x79\x2d\x6f\x66\x2d\x77\x65\x65\x6b\x2f\x73"
  "\x68\x6f\x72\x74\x2d\x73\x74\x72\x69\x6e\x67\x52\x03\x12\x74\x69"
  "\x6d\x65\x2d\x7a\x6f\x6e\x65\x2d\x3e\x73\x74\x72\x69\x6e\x67\x53"
  "\x09\xf1\x01\x2e\x81\x87\x02\xf0\x01\x2c\x81\x89\x02\xef\x01\x2a"
  "\x81\x89\x02\xee\x01\x28\x81\x85\x02\xed\x01\x26\x81\x83\x02\xec"
  "\x01\x24\x81\x9d\x02\xeb\x01\x22\x81\x9b\x02\xea\x01\x20\x81\x97"
  "\x02\xe9\x01\x1e\x81\x99\x02\xe8\x01\x1c\x81\x9b\x02\xe7\x01\x1a"
  "\x81\x99\x02\xe6\x01\x18\x81\x93\x02\xe5\x01\x16\x81\x95\x02\xe4"
  "\x01\x14\x81\x8f\x02\xe3\x01\x12\x81\x91\x02\xe2\x01\x10\x81\x8b"
  "\x02\xe1\x01\x0e\x81\x8d\x02\xe0\x01\x0c\x81\x87\x02\xdf\x01\x0a"
  "\x81\x89\x02\xde\x01\x08\x81\x83\x02\xdd\x01\x06\x81\x85\x02\xdc"
  "\x01\x04\x83\x04\x2d\x4e\x54\x02\x2b\x20\x49\x6c\x6c\x2d\x66\x6f"
  "\x72\x6d\x65\x64\x20\x52\x46\x43\x2d\x38\x32\x32\x20\x74\x69\x6d"
  "\x65\x20\x73\x74\x72\x69\x6e\x67\x3a\x01\x3b\x01\x2d\x0b\x73\x74"
  "\x72\x69\x6e\x67\x2d\x72\x65\x66\x0e\x73\x74\x72\x69\x6e\x67\x2d"
  "\x6c\x65\x6e\x67\x74\x68\x01\x2e\x04\x63\x61\x72\x55\x04\x63\x64"
  "\x72\x56\x14\x63\x68\x61\x72\x2d\x73\x65\x74\x3a\x77\x68\x69\x74"
  "\x65\x73\x70\x61\x63\x65\x1b\x64\x61\x79\x73\x2d\x6f\x66\x2d\x77"
  "\x65\x65\x6b\x2f\x73\x68\x6f\x72\x74\x2d\x73\x74\x72\x69\x6e\x67"
  "\x73\x57\x03\x05\x0d\x62\x75\x72\x73\x74\x2d\x73\x74\x72\x69\x6e"
  "\x67\x58\x04\x09\x6c\x69\x73\x74\x2d\x72\x65\x66\x59\x05\x0a\x73"
  "\x75\x62\x73\x74\x72\x69\x6e\x67\x03\x07\x6c\x65\x6e\x67\x74\x68"
  "\x5a\x04\x06\x65\x72\x72\x6f\x72\x5b\x04\x05\x6d\x65\x6d\x76\x04"
  "\x11\x73\x74\x72\x69\x6e\x67\x2d\x63\x69\x2d\x3e\x69\x6e\x64\x65"
  "\x78\x5c\x03\x0f\x73\x74\x72\x69\x6e\x67\x2d\x3e\x6e\x75\x6d\x62"
  "\x65\x72\x5d\x03\x0e\x73\x74\x72\x69\x6e\x67\x2d\x3e\x6d\x6f\x6e"
  "\x74\x68\x5e\x03\x12\x73\x74\x72\x69\x6e\x67\x2d\x3e\x74\x69\x6d"
  "\x65\x2d\x7a\x6f\x6e\x65\x5f\x09\x29\x03\x0d\x73\x74\x72\x69\x6e"
  "\x67\x2d\x3e\x79\x65\x61\x72\x60\x0d\xa3\x02\x66\x81\x91\x02\xa2"
  "\x02\x64\x81\x8f\x02\xa1\x02\x62\x81\x91\x02\xa0\x02\x60\x81\x8f"
  "\x02\x9f\x02\x5e\x81\x91\x02\x9e\x02\x5c\x81\x8f\x02\x9d\x02\x5a"
  "\x81\x8f\x02\x9c\x02\x58\x81\x8f\x02\x9b\x02\x56\x81\x8f\x02\x9a"
  "\x02\x54\x81\x8f\x02\x99\x02\x52\x81\x8f\x02\x98\x02\x50\x81\x8b"
  "\x02\x97\x02\x4e\x81\x8d\x02\x96\x02\x4c\x81\x8d\x02\x95\x02\x4a"
  "\x81\x8d\x02\x94\x02\x48\x81\x89\x02\x93\x02\x46\x81\x89\x02\x92"
  "\x02\x44\x81\x8b\x02\x91\x02\x42\x81\x87\x02\x90\x02\x40\x81\x8b"
  "\x02\x8f\x02\x3e\x81\x85\x02\x8e\x02\x3c\x81\x89\x02\x8d\x02\x3a"
  "\x81\x87\x02\x8c\x02\x38\x81\x81\x02\x8b\x02\x36\x81\x8b\x02\x8a"
  "\x02\x34\x81\x87\x02\x89\x02\x32\x81\x87\x02\x88\x02\x30\x81\x8b"
  "\x02\x87\x02\x2e\x81\x85\x02\x86\x02\x2c\x81\x85\x02\x85\x02\x2a"
  "\x81\x83\x02\x84\x02\x28\x81\x8d\x02\x83\x02\x26\x81\x85\x02\x82"
  "\x02\x24\x81\x85\x02\x81\x02\x22\x81\x85\x02\x80\x02\x20\x81\x85"
  "\x02\xff\x01\x1e\x81\x83\x02\xfe\x01\x1c\x81\x85\x02\xfd\x01\x1a"
  "\x81\x87\x02\xfc\x01\x18\x81\x87\x02\xfb\x01\x16\x81\x87\x02\xfa"
  "\x01\x14\x81\x87\x02\xf9\x01\x12\x81\x87\x02\xf8\x01\x10\x81\x87"
  "\x02\xf7\x01\x0e\x81\x87\x02\xf6\x01\x0c\x81\x85\x02\xf5\x01\x0a"
  "\x81\x85\x02\xf4\x01\x08\x81\x85\x02\xf3\x01\x06\x81\x89\x02\xf2"
  "\x01\x04\x83\x04\x65\x96\x01\x61\x02\x2c\x03\x15\x73\x74\x72\x69"
  "\x6e\x67\x2d\x3e\x64\x65\x63\x6f\x64\x65\x64\x2d\x74\x69\x6d\x65"
  "\x62\x03\x1d\x64\x65\x63\x6f\x64\x65\x64\x2d\x74\x69\x6d\x65\x2d"
  "\x3e\x75\x6e\x69\x76\x65\x72\x73\x61\x6c\x2d\x74\x69\x6d\x65\x63"
  "\x03\xa5\x02\x06\x81\x83\x02\xa4\x02\x04\x83\x04\x05\x0d\x64\x02"
  "\x2d\x03\x62\x03\x18\x64\x65\x63\x6f\x64\x65\x64\x2d\x74\x69\x6d"
  "\x65\x2d\x3e\x66\x69\x6c\x65\x2d\x74\x69\x6d\x65\x65\x03\xa7\x02"
  "\x06\x81\x83\x02\xa6\x02\x04\x83\x04\x05\x0d\x66\x02\x2e\x55\x56"
  "\x02\x2d\x02\x2b\x3d\x0a\x74\x69\x6d\x65\x20\x7a\x6f\x6e\x65\x53"
  "\x03\x2e\x05\x2b\x03\x06\x72\x6f\x75\x6e\x64\x03\x04\x61\x62\x73"
  "\x67\x03\x4f\x04\x0f\x69\x6e\x74\x65\x67\x65\x72\x2d\x64\x69\x76"
  "\x69\x64\x65\x68\x05\x45\x08\xb4\x02\x1c\x81\x87\x02\xb3\x02\x1a"
  "\x81\x89\x02\xb2\x02\x18\x81\x87\x02\xb1\x02\x16\x81\x87\x02\xb0"
  "\x02\x14\x81\x89\x02\xaf\x02\x12\x81\x85\x02\xae\x02\x10\x81\x83"
  "\x02\xad\x02\x0e\x81\x83\x02\xac\x02\x0c\x81\x85\x02\xab\x02\x0a"
  "\x81\x85\x02\xaa\x02\x08\x81\x83\x02\xa9\x02\x06\x81\x83\x02\xa8"
  "\x02\x04\x83\x04\x1b\x35\x69\x02\x2f\x3d\x3c\xe1\x12\xe1\x12\x15"
  "\x4d\x61\x6c\x66\x6f\x72\x6d\x65\x64\x20\x74\x69\x6d\x65\x20\x7a"
  "\x6f\x6e\x65\x3a\x0f\x3f\x1b\x65\x55\x56\x11\x6e\x61\x6d\x65\x64"
  "\x2d\x74\x69\x6d\x65\x2d\x7a\x6f\x6e\x65\x73\x6a\x02\x04\x15\x6c"
  "\x69\x73\x74\x2d\x73\x65\x61\x72\x63\x68\x2d\x70\x6f\x73\x69\x74"
  "\x69\x76\x65\x03\x5d\x04\x0c\x73\x74\x72\x69\x6e\x67\x2d\x63\x69"
  "\x3d\x3f\x6b\x03\x67\x04\x5b\x05\x32\x04\x68\x08\xc8\x02\x2a\x81"
  "\x87\x02\xc7\x02\x28\x81\x89\x02\xc6\x02\x26\x81\x89\x02\xc5\x02"
  "\x24\x81\x89\x02\xc4\x02\x22\x81\x89\x02\xc3\x02\x20\x81\x89\x02"
  "\xc2\x02\x1e\x81\x89\x02\xc1\x02\x1c\x81\x87\x02\xc0\x02\x1a\x81"
  "\x85\x02\xbf\x02\x18\x81\x83\x02\xbe\x02\x16\x81\x85\x02\xbd\x02"
  "\x14\x81\x85\x02\xbc\x02\x12\x81\x85\x02\xbb\x02\x10\x81\x85\x02"
  "\xba\x02\x0e\x81\x85\x02\xb9\x02\x0c\x81\x85\x02\xb8\x02\x0a\x81"
  "\x85\x02\xb7\x02\x08\x81\x83\x02\xb6\x02\x06\x81\x87\x02\xb5\x02"
  "\x04\x83\x04\x29\x4b\x68\x02\x30\x08\x02\x3a\x18\x01\x31\x02\x20"
  "\x03\x42\x05\x10\x73\x74\x72\x69\x6e\x67\x2d\x70\x61\x64\x2d\x6c"
  "\x65\x66\x74\x67\x04\x67\x03\x50\x03\x52\x0f\x45\x07\xdb\x02\x28"
  "\x81\x9b\x02\xda\x02\x26\x81\x9d\x02\xd9\x02\x24\x81\x99\x02\xd8"
  "\x02\x22\x81\x9b\x02\xd7\x02\x20\x81\x95\x02\xd6\x02\x1e\x81\x95"
  "\x02\xd5\x02\x1c\x81\x97\x02\xd4\x02\x1a\x81\x91\x02\xd3\x02\x18"
  "\x81\x93\x02\xd2\x02\x16\x81\x97\x02\xd1\x02\x14\x81\x8d\x02\xd0"
  "\x02\x12\x81\x8f\x02\xcf\x02\x10\x81\x95\x02\xce\x02\x0e\x81\x89"
  "\x02\xcd\x02\x0c\x81\x8b\x02\xcc\x02\x0a\x81\x91\x02\xcb\x02\x08"
  "\x81\x85\x02\xca\x02\x06\x81\x8d\x02\xc9\x02\x04\x83\x04\x27\x42"
  "\x6c\x02\x31\x55\x56\x1b\x49\x6c\x6c\x2d\x66\x6f\x72\x6d\x65\x64"
  "\x20\x63\x74\x69\x6d\x65\x28\x29\x20\x73\x74\x72\x69\x6e\x67\x3a"
  "\x01\x3b\x01\x21\x08\x0a\x74\x69\x6d\x65\x20\x7a\x6f\x6e\x65\x1b"
  "\x63\x74\x69\x6d\x65\x2d\x73\x74\x72\x69\x6e\x67\x2d\x3e\x64\x65"
  "\x63\x6f\x64\x65\x64\x2d\x74\x69\x6d\x65\x56\x05\x2b\x05\x58\x03"
  "\x2e\x03\x5a\x04\x59\x04\x5b\x03\x5d\x03\x60\x09\x29\x03\x5e\x0b"
  "\xff\x02\x4a\x81\x93\x02\xfe\x02\x48\x81\x91\x02\xfd\x02\x46\x81"
  "\x91\x02\xfc\x02\x44\x81\x93\x02\xfb\x02\x42\x81\x91\x02\xfa\x02"
  "\x40\x81\x91\x02\xf9\x02\x3e\x81\x93\x02\xf8\x02\x3c\x81\x8f\x02"
  "\xf7\x02\x3a\x81\x91\x02\xf6\x02\x38\x81\x91\x02\xf5\x02\x36\x81"
  "\x8f\x02\xf4\x02\x34\x81\x91\x02\xf3\x02\x32\x81\x93\x02\xf2\x02"
  "\x30\x81\x8f\x02\xf1\x02\x2e\x81\x8f\x02\xf0\x02\x2c\x81\x91\x02"
  "\xef\x02\x2a\x81\x8f\x02\xee\x02\x28\x81\x91\x02\xed\x02\x26\x81"
  "\x91\x02\xec\x02\x24\x81\x8d\x02\xeb\x02\x22\x81\x8f\x02\xea\x02"
  "\x20\x81\x91\x02\xe9\x02\x1e\x81\x91\x02\xe8\x02\x1c\x81\x8f\x02"
  "\xe7\x02\x1a\x81\x8f\x02\xe6\x02\x18\x81\x8f\x02\xe5\x02\x16\x81"
  "\x8b\x02\xe4\x02\x14\x81\x8f\x02\xe3\x02\x12\x81\x89\x02\xe2\x02"
  "\x10\xff\xff\x03\xe1\x02\x0e\x81\x89\x02\xe0\x02\x0c\x81\x89\x02"
  "\xdf\x02\x0a\x81\x87\x02\xde\x02\x08\x84\x04\xdd\x02\x06\x81\x87"
  "\x02\xdc\x02\x04\x81\x87\x02\x49\x70\x5a\x02\x32\x03\x3b\x03\x1b"
  "\x64\x65\x63\x6f\x64\x65\x64\x2d\x74\x69\x6d\x65\x2d\x3e\x63\x74"
  "\x69\x6d\x65\x2d\x73\x74\x72\x69\x6e\x67\x59\x03\x81\x03\x06\x81"
  "\x83\x02\x80\x03\x04\x83\x04\x05\x0d\x58\x02\x33\x03\x3d\x03\x59"
  "\x03\x83\x03\x06\x81\x83\x02\x82\x03\x04\x83\x04\x05\x0d\x55\x02"
  "\x34\x08\x04\x56\x03\x63\x03\x85\x03\x06\x81\x85\x02\x84\x03\x04"
  "\x84\x04\x05\x0e\x6d\x02\x35\x03\x4b\x03\x59\x03\x87\x03\x06\x81"
  "\x83\x02\x86\x03\x04\x83\x04\x05\x0d\x6e\x02\x36\x03\x4d\x03\x59"
  "\x03\x89\x03\x06\x81\x83\x02\x88\x03\x04\x83\x04\x05\x0d\x6f\x02"
  "\x37\x08\x04\x56\x03\x65\x03\x8b\x03\x06\x81\x85\x02\x8a\x03\x04"
  "\x84\x04\x05\x0e\x70\x02\x38\x18\x1d\x69\x73\x6f\x38\x36\x30\x31"
  "\x2d\x73\x74\x72\x69\x6e\x67\x2d\x3e\x64\x65\x63\x6f\x64\x65\x64"
  "\x2d\x74\x69\x6d\x65\x71\x03\x16\x73\x74\x72\x69\x6e\x67\x2d\x3e"
  "\x70\x61\x72\x73\x65\x72\x2d\x62\x75\x66\x66\x65\x72\x04\x33\x03"
  "\x15\x70\x61\x72\x73\x65\x2d\x38\x36\x30\x31\x2d\x64\x61\x74\x65"
  "\x2f\x74\x69\x6d\x65\x72\x04\x8f\x03\x0a\x81\x85\x02\x8e\x03\x08"
  "\x81\x83\x02\x8d\x03\x06\x81\x85\x02\x8c\x03\x04\x83\x04\x09\x16"
  "\x73\x02\x39\x01\x0a\x02\x2d\x02\x54\x02\x3a\x18\x03\x4f\x03\x42"
  "\x0e\x45\x03\x51\x03\x53\x06\xa1\x03\x26\x81\x83\x02\xa0\x03\x24"
  "\x81\x85\x02\x9f\x03\x22\x81\x85\x02\x9e\x03\x20\x81\x9b\x02\x9d"
  "\x03\x1e\x81\x97\x02\x9c\x03\x1c\x81\x99\x02\x9b\x03\x1a\x81\x99"
  "\x02\x9a\x03\x18\x81\x93\x02\x99\x03\x16\x81\x95\x02\x98\x03\x14"
  "\x81\x8f\x02\x97\x03\x12\x81\x91\x02\x96\x03\x10\x81\x8b\x02\x95"
  "\x03\x0e\x81\x8d\x02\x94\x03\x0c\x81\x87\x02\x93\x03\x0a\x81\x89"
  "\x02\x92\x03\x08\x81\x83\x02\x91\x03\x06\x81\x85\x02\x90\x03\x04"
  "\x83\x04\x25\x3f\x45\x02\x3a\x03\x3b\x03\x1d\x64\x65\x63\x6f\x64"
  "\x65\x64\x2d\x74\x69\x6d\x65\x2d\x3e\x69\x73\x6f\x38\x36\x30\x31"
  "\x2d\x73\x74\x72\x69\x6e\x67\x74\x03\xa3\x03\x06\x81\x83\x02\xa2"
  "\x03\x04\x83\x04\x05\x0d\x75\x02\x3b\x03\x3d\x03\x74\x03\xa5\x03"
  "\x06\x81\x83\x02\xa4\x03\x04\x83\x04\x05\x0d\x76\x02\x3c\x03\x71"
  "\x03\x63\x03\xa7\x03\x06\x81\x83\x02\xa6\x03\x04\x83\x04\x05\x0d"
  "\x77\x02\x3d\x03\x4b\x03\x74\x03\xa9\x03\x06\x81\x83\x02\xa8\x03"
  "\x04\x83\x04\x05\x0d\x4b\x02\x3e\x03\x4d\x03\x74\x03\xab\x03\x06"
  "\x81\x83\x02\xaa\x03\x04\x83\x04\x05\x0d\x4d\x02\x3f\x03\x71\x03"
  "\x65\x03\xad\x03\x06\x81\x83\x02\xac\x03\x04\x83\x04\x05\x0d\x65"
  "\x02\x40\x3d\x18\x01\x21\x01\x55\x03\x1a\x67\x65\x74\x2d\x70\x61"
  "\x72\x73\x65\x72\x2d\x62\x75\x66\x66\x65\x72\x2d\x70\x6f\x69\x6e"
  "\x74\x65\x72\x78\x03\x10\x70\x61\x72\x73\x65\x2d\x38\x36\x30\x31"
  "\x2d\x64\x61\x74\x65\x79\x04\x1b\x73\x65\x74\x2d\x70\x61\x72\x73"
  "\x65\x72\x2d\x62\x75\x66\x66\x65\x72\x2d\x70\x6f\x69\x6e\x74\x65"
  "\x72\x21\x7a\x03\x10\x70\x61\x72\x73\x65\x2d\x38\x36\x30\x31\x2d"
  "\x74\x69\x6d\x65\x7b\x04\x19\x6d\x61\x74\x63\x68\x2d\x70\x61\x72"
  "\x73\x65\x72\x2d\x62\x75\x66\x66\x65\x72\x2d\x63\x68\x61\x72\x7c"
  "\x03\x18\x70\x65\x65\x6b\x2d\x70\x61\x72\x73\x65\x72\x2d\x62\x75"
  "\x66\x66\x65\x72\x2d\x63\x68\x61\x72\x03\x10\x70\x61\x72\x73\x65"
  "\x2d\x38\x36\x30\x31\x2d\x7a\x6f\x6e\x65\x7d\x06\x0e\x76\x65\x63"
  "\x74\x6f\x72\x2d\x61\x70\x70\x65\x6e\x64\x7e\x09\x29\x0a\xd4\x03"
  "\x50\x81\x83\x02\xd3\x03\x4e\x81\x83\x02\xd2\x03\x4c\x81\x83\x02"
  "\xd1\x03\x4a\x81\x83\x02\xd0\x03\x48\x81\x95\x02\xcf\x03\x46\x81"
  "\x8f\x02\xce\x03\x44\x81\x8f\x02\xcd\x03\x42\x81\x8d\x02\xcc\x03"
  "\x40\x81\x8b\x02\xcb\x03\x3e\x81\x89\x02\xca\x03\x3c\x81\x87\x02"
  "\xc9\x03\x3a\x81\x87\x02\xc8\x03\x38\x81\x85\x02\xc7\x03\x36\x81"
  "\x83\x02\xc6\x03\x34\x81\x89\x02\xc5\x03\x32\x81\x8f\x02\xc4\x03"
  "\x30\x81\x91\x02\xc3\x03\x2e\x81\x93\x02\xc2\x03\x2c\x81\x95\x02"
  "\xc1\x03\x2a\x81\x95\x02\xc0\x03\x28\x81\x93\x02\xbf\x03\x26\x81"
  "\x91\x02\xbe\x03\x24\x81\x87\x02\xbd\x03\x22\x81\x83\x02\xbc\x03"
  "\x20\x81\x8b\x02\xbb\x03\x1e\x81\x83\x02\xba\x03\x1c\x81\x87\x02"
  "\xb9\x03\x1a\x81\x83\x02\xb8\x03\x18\x81\x89\x02\xb7\x03\x16\x81"
  "\x87\x02\xb6\x03\x14\x81\x89\x02\xb5\x03\x12\x81\x83\x02\xb4\x03"
  "\x10\x81\x87\x02\xb3\x03\x0e\x81\x87\x02\xb2\x03\x0c\x81\x87\x02"
  "\xb1\x03\x0a\x81\x87\x02\xb0\x03\x08\x81\x85\x02\xaf\x03\x06\x81"
  "\x83\x02\xae\x03\x04\x83\x04\x4f\x6c\x7f\x02\x41\x01\x58\x03\x2d"
  "\x57\x01\x2e\x03\x78\x03\x10\x70\x61\x72\x73\x65\x2d\x38\x36\x30"
  "\x31\x2d\x79\x65\x61\x72\x80\x01\x04\x7a\x04\x7e\x04\x7c\x03\x11"
  "\x70\x61\x72\x73\x65\x2d\x38\x36\x30\x31\x2d\x6d\x6f\x6e\x74\x68"
  "\x81\x01\x04\x1b\x6d\x61\x74\x63\x68\x2d\x70\x61\x72\x73\x65\x72"
  "\x2d\x62\x75\x66\x66\x65\x72\x2d\x73\x74\x72\x69\x6e\x67\x03\x0f"
  "\x70\x61\x72\x73\x65\x2d\x38\x36\x30\x31\x2d\x64\x61\x79\x82\x01"
  "\x03\x16\x77\x65\x65\x6b\x2d\x64\x61\x74\x65\x2d\x3e\x6d\x6f\x6e"
  "\x74\x68\x2d\x64\x61\x74\x65\x83\x01\x03\x10\x70\x61\x72\x73\x65"
  "\x2d\x38\x36\x30\x31\x2d\x77\x65\x65\x6b\x84\x01\x03\x14\x70\x61"
  "\x72\x73\x65\x2d\x38\x36\x30\x31\x2d\x77\x65\x65\x6b\x2d\x64\x61"
  "\x79\x85\x01\x03\x19\x6f\x72\x64\x69\x6e\x61\x6c\x2d\x64\x61\x74"
  "\x65\x2d\x3e\x6d\x6f\x6e\x74\x68\x2d\x64\x61\x74\x65\x86\x01\x03"
  "\x17\x70\x61\x72\x73\x65\x2d\x38\x36\x30\x31\x2d\x6f\x72\x64\x69"
  "\x6e\x61\x6c\x2d\x64\x61\x79\x87\x01\x0e\x86\x04\x66\x81\x83\x02"
  "\x85\x04\x64\x81\x87\x02\x84\x04\x62\x81\x85\x02\x83\x04\x60\x81"
  "\x83\x02\x82\x04\x5e\x81\x8f\x02\x81\x04\x5c\x81\x85\x02\x80\x04"
  "\x5a\x81\x83\x02\xff\x03\x58\x81\x8b\x02\xfe\x03\x56\x81\x8b\x02"
  "\xfd\x03\x54\x81\x83\x02\xfc\x03\x52\x81\x87\x02\xfb\x03\x50\x81"
  "\x83\x02\xfa\x03\x4e\x81\x89\x02\xf9\x03\x4c\x81\x8d\x02\xf8\x03"
  "\x4a\x81\x83\x02\xf7\x03\x48\x81\x87\x02\xf6\x03\x46\x81\x83\x02"
  "\xf5\x03\x44\x81\x89\x02\xf4\x03\x42\x81\x87\x02\xf3\x03\x40\x81"
  "\x89\x02\xf2\x03\x3e\x81\x8b\x02\xf1\x03\x3c\x81\x89\x02\xf0\x03"
  "\x3a\x81\x8b\x02\xef\x03\x38\x81\x83\x02\xee\x03\x36\x81\x85\x02"
  "\xed\x03\x34\x81\x85\x02\xec\x03\x32\x81\x87\x02\xeb\x03\x30\x81"
  "\x89\x02\xea\x03\x2e\x81\x89\x02\xe9\x03\x2c\x81\x83\x02\xe8\x03"
  "\x2a\x81\x89\x02\xe7\x03\x28\x81\x87\x02\xe6\x03\x26\x81\x83\x02"
  "\xe5\x03\x24\x81\x89\x02\xe4\x03\x22\x81\x89\x02\xe3\x03\x20\x81"
  "\x8b\x02\xe2\x03\x1e\x81\x87\x02\xe1\x03\x1c\x81\x87\x02\xe0\x03"
  "\x1a\x81\x83\x02\xdf\x03\x18\x81\x89\x02\xde\x03\x16\x81\x85\x02"
  "\xdd\x03\x14\x81\x85\x02\xdc\x03\x12\x81\x83\x02\xdb\x03\x10\x81"
  "\x87\x02\xda\x03\x0e\x81\x85\x02\xd9\x03\x0c\x81\x83\x02\xd8\x03"
  "\x0a\x81\x85\x02\xd7\x03\x08\x81\x83\x02\xd6\x03\x06\x81\x83\x02"
  "\xd5\x03\x04\x83\x04\x65\x86\x01\x88\x01\x02\x42\x81\xa3\x05\x08"
  "\x18\x09\x29\x03\x63\x03\x3d\x04\x99\x04\x28\x81\x83\x02\x98\x04"
  "\x26\x81\x85\x02\x97\x04\x24\x81\x83\x02\x96\x04\x22\x81\x83\x02"
  "\x95\x04\x20\x81\x85\x02\x94\x04\x1e\x81\x85\x02\x93\x04\x1c\x81"
  "\x83\x02\x92\x04\x1a\x81\x83\x02\x91\x04\x18\x81\x83\x02\x90\x04"
  "\x16\x81\x89\x02\x8f\x04\x14\x81\x8d\x02\x8e\x04\x12\x81\x8b\x02"
  "\x8d\x04\x10\x81\x89\x02\x8c\x04\x0e\x81\x89\x02\x8b\x04\x0c\x81"
  "\x87\x02\x8a\x04\x0a\x81\x87\x02\x89\x04\x08\x81\x85\x02\x88\x04"
  "\x06\x81\x83\x02\x87\x04\x04\x83\x04\x27\x3a\x89\x01\x02\x43\x81"
  "\xa3\x05\x18\x09\x29\x03\x63\x03\x3d\x04\xa6\x04\x1c\x81\x83\x02"
  "\xa5\x04\x1a\x81\x85\x02\xa4\x04\x18\x81\x83\x02\xa3\x04\x16\x81"
  "\x83\x02\xa2\x04\x14\x81\x87\x02\xa1\x04\x12\x81\x8b\x02\xa0\x04"
  "\x10\x81\x89\x02\x9f\x04\x0e\x81\x87\x02\x9e\x04\x0c\x81\x87\x02"
  "\x9d\x04\x0a\x81\x85\x02\x9c\x04\x08\x81\x85\x02\x9b\x04\x06\x81"
  "\x83\x02\x9a\x04\x04\x83\x04\x1b\x2c\x8a\x01\x02\x44\x01\x3b\x01"
  "\x5b\x03\x78\x04\x7c\x04\x17\x67\x65\x74\x2d\x70\x61\x72\x73\x65"
  "\x72\x2d\x62\x75\x66\x66\x65\x72\x2d\x74\x61\x69\x6c\x8b\x01\x04"
  "\x7a\x03\x10\x70\x61\x72\x73\x65\x2d\x38\x36\x30\x31\x2d\x73\x69"
  "\x67\x6e\x8c\x01\x03\x15\x70\x61\x72\x73\x65\x2d\x38\x36\x30\x31"
  "\x2d\x7a\x6f\x6e\x65\x2d\x68\x6f\x75\x72\x8d\x01\x05\x7e\x04\x7e"
  "\x03\x12\x70\x61\x72\x73\x65\x2d\x38\x36\x30\x31\x2d\x6d\x69\x6e"
  "\x75\x74\x65\x8e\x01\x0a\xbd\x04\x30\x81\x87\x02\xbc\x04\x2e\x81"
  "\x8d\x02\xbb\x04\x2c\x81\x87\x02\xba\x04\x2a\x81\x8b\x02\xb9\x04"
  "\x28\x81\x87\x02\xb8\x04\x26\x81\x8b\x02\xb7\x04\x24\x81\x87\x02"
  "\xb6\x04\x22\x81\x87\x02\xb5\x04\x20\x81\x85\x02\xb4\x04\x1e\x81"
  "\x89\x02\xb3\x04\x1c\x81\x85\x02\xb2\x04\x1a\x81\x85\x02\xb1\x04"
  "\x18\x81\x87\x02\xb0\x04\x16\x81\x87\x02\xaf\x04\x14\x81\x87\x02"
  "\xae\x04\x12\x81\x87\x02\xad\x04\x10\x81\x83\x02\xac\x04\x0e\x81"
  "\x87\x02\xab\x04\x0c\x81\x87\x02\xaa\x04\x0a\x81\x87\x02\xa9\x04"
  "\x08\x81\x85\x02\xa8\x04\x06\x81\x83\x02\xa7\x04\x04\x83\x04\x2f"
  "\x49\x8f\x01\x02\x45\x19\x18\x01\x3b\x03\x78\x03\x10\x70\x61\x72"
  "\x73\x65\x2d\x38\x36\x30\x31\x2d\x68\x6f\x75\x72\x90\x01\x04\x7a"
  "\x04\x7e\x04\x7c\x03\x8e\x01\x03\x12\x70\x61\x72\x73\x65\x2d\x38"
  "\x36\x30\x31\x2d\x73\x65\x63\x6f\x6e\x64\x7e\x08\xdc\x04\x40\x81"
  "\x83\x02\xdb\x04\x3e\x81\x83\x02\xda\x04\x3c\x81\x83\x02\xd9\x04"
  "\x3a\x81\x8d\x02\xd8\x04\x38\x81\x83\x02\xd7\x04\x36\x81\x87\x02"
  "\xd6\x04\x34\x81\x83\x02\xd5\x04\x32\x81\x87\x02\xd4\x04\x30\x81"
  "\x8d\x02\xd3\x04\x2e\x81\x83\x02\xd2\x04\x2c\x81\x87\x02\xd1\x04"
  "\x2a\x81\x85\x02\xd0\x04\x28\x81\x85\x02\xcf\x04\x26\x81\x87\x02"
  "\xce\x04\x24\x81\x8b\x02\xcd\x04\x22\x81\x87\x02\xcc\x04\x20\x81"
  "\x83\x02\xcb\x04\x1e\x81\x89\x02\xca\x04\x1c\x81\x83\x02\xc9\x04"
  "\x1a\x81\x89\x02\xc8\x04\x18\x81\x83\x02\xc7\x04\x16\x81\x89\x02"
  "\xc6\x04\x14\x81\x89\x02\xc5\x04\x12\x81\x89\x02\xc4\x04\x10\x81"
  "\x87\x02\xc3\x04\x0e\x81\x87\x02\xc2\x04\x0c\x81\x87\x02\xc1\x04"
  "\x0a\x81\x87\x02\xc0\x04\x08\x81\x85\x02\xbf\x04\x06\x81\x83\x02"
  "\xbe\x04\x04\x83\x04\x3f\x57\x91\x01\x02\x46\x18\x13\x38\x36\x30"
  "\x31\x2d\x6e\x75\x6d\x62\x65\x72\x2d\x70\x61\x72\x73\x65\x72\x92"
  "\x01\x11\x63\x68\x61\x72\x2d\x73\x65\x74\x3a\x6e\x75\x6d\x65\x72"
  "\x69\x63\x93\x01\x5d\x03\x04\x33\x03\x78\x04\x20\x6d\x61\x74\x63"
  "\x68\x2d\x70\x61\x72\x73\x65\x72\x2d\x62\x75\x66\x66\x65\x72\x2d"
  "\x63\x68\x61\x72\x2d\x69\x6e\x2d\x73\x65\x74\x94\x01\x05\x32\x04"
  "\x8b\x01\x04\x7a\x04\x0b\x76\x65\x63\x74\x6f\x72\x2d\x6d\x61\x70"
  "\x95\x01\x08\x8a\x05\x5e\x81\x83\x02\x89\x05\x5c\x81\x85\x02\x88"
  "\x05\x5a\x81\x83\x02\x87\x05\x58\x81\x85\x02\x86\x05\x56\x81\x83"
  "\x02\x85\x05\x54\x81\x85\x02\x84\x05\x52\x81\x83\x02\x83\x05\x50"
  "\x81\x85\x02\x82\x05\x4e\x81\x85\x02\x81\x05\x4c\x81\x87\x02\x80"
  "\x05\x4a\x81\x85\x02\xff\x04\x48\x81\x85\x02\xfe\x04\x46\x81\x87"
  "\x02\xfd\x04\x44\x81\x85\x02\xfc\x04\x42\x81\x87\x02\xfb\x04\x40"
  "\x81\x85\x02\xfa\x04\x3e\x81\x85\x02\xf9\x04\x3c\x81\x87\x02\xf8"
  "\x04\x3a\x81\x87\x02\xf7\x04\x38\x81\x85\x02\xf6\x04\x36\x81\x87"
  "\x02\xf5\x04\x34\x81\x85\x02\xf4\x04\x32\x81\x87\x02\xf3\x04\x30"
  "\x81\x85\x02\xf2\x04\x2e\x81\x85\x02\xf1\x04\x2c\x81\x87\x02\xf0"
  "\x04\x2a\x81\x83\x02\xef\x04\x28\x81\x87\x02\xee\x04\x26\x81\x83"
  "\x02\xed\x04\x24\x81\x87\x02\xec\x04\x22\x81\x83\x02\xeb\x04\x20"
  "\x81\x8b\x02\xea\x04\x1e\x81\x85\x02\xe9\x04\x1c\x81\x85\x02\xe8"
  "\x04\x1a\x81\x85\x02\xe7\x04\x18\x81\x85\x02\xe6\x04\x16\x81\x85"
  "\x02\xe5\x04\x14\x81\x87\x02\xe4\x04\x12\x81\x83\x02\xe3\x04\x10"
  "\x83\x04\xe2\x04\x0e\x83\x04\xe1\x04\x0c\x83\x04\xe0\x04\x0a\x81"
  "\x85\x02\xdf\x04\x08\x83\x04\xde\x04\x06\x85\x08\xdd\x04\x04\x81"
  "\x87\x02\x5d\x79\x96\x01\x02\x47\x3c\x01\x2f\x3d\x18\x93\x01\x02"
  "\x03\x78\x04\x94\x01\x04\x8b\x01\x04\x7a\x03\x5d\x03\x0d\x72\x6f"
  "\x75\x6e\x64\x2d\x3e\x65\x78\x61\x63\x74\x04\x7c\x04\x04\x6d\x69"
  "\x6e\x09\xa5\x05\x38\x81\x83\x02\xa4\x05\x36\x81\x87\x02\xa3\x05"
  "\x34\x81\x83\x02\xa2\x05\x32\x81\x83\x02\xa1\x05\x30\x81\x89\x02"
  "\xa0\x05\x2e\x81\x85\x02\x9f\x05\x2c\x81\x83\x02\x9e\x05\x2a\x81"
  "\x85\x02\x9d\x05\x28\x81\x83\x02\x9c\x05\x26\x81\x89\x02\x9b\x05"
  "\x24\x81\x83\x02\x9a\x05\x22\x81\x8b\x02\x99\x05\x20\x81\x87\x02"
  "\x98\x05\x1e\x81\x89\x02\x97\x05\x1c\x81\x89\x02\x96\x05\x1a\x81"
  "\x89\x02\x95\x05\x18\x81\x89\x02\x94\x05\x16\x81\x87\x02\x93\x05"
  "\x14\x81\x8b\x02\x92\x05\x12\x81\x85\x02\x91\x05\x10\x81\x89\x02"
  "\x90\x05\x0e\x81\x87\x02\x8f\x05\x0c\x81\x87\x02\x8e\x05\x0a\x81"
  "\x85\x02\x8d\x05\x08\x81\x89\x02\x8c\x05\x06\x81\x83\x02\x8b\x05"
  "\x04\x83\x04\x37\x53\x94\x01\x02\x48\x01\x2e\x01\x2c\x03\x78\x04"
  "\x7c\x04\x7a\x04\x8b\x01\x04\x95\x01\x06\xaf\x05\x16\x83\x04\xae"
  "\x05\x14\x81\x85\x02\xad\x05\x12\x81\x85\x02\xac\x05\x10\x81\x85"
  "\x02\xab\x05\x0e\x83\x04\xaa\x05\x0c\x81\x85\x02\xa9\x05\x0a\x81"
  "\x85\x02\xa8\x05\x08\x81\x85\x02\xa7\x05\x06\x81\x83\x02\xa6\x05"
  "\x04\x83\x04\x15\x27\x95\x01\x02\x49\x18\x20\x1f\x20\x1f\x20\x20"
  "\x1f\x20\x1f\x20\x1e\x20\x0d\x31\x04\x10\x67\x75\x61\x72\x61\x6e"
  "\x74\x65\x65\x2d\x6d\x6f\x6e\x74\x68\x93\x01\x02\xb2\x05\x08\x81"
  "\x85\x02\xb1\x05\x06\x81\x83\x02\xb0\x05\x04\x83\x04\x07\x10\x8b"
  "\x01\x02\x4a\x18\x50\x14\x6d\x6f\x6e\x74\x68\x2f\x73\x68\x6f\x72"
  "\x74\x2d\x73\x74\x72\x69\x6e\x67\x73\x7c\x02\x04\x93\x01\x02\xb6"
  "\x05\x0a\x81\x85\x02\xb5\x05\x08\x81\x83\x02\xb4\x05\x06\x81\x83"
  "\x02\xb3\x05\x04\x83\x04\x09\x13\x7a\x02\x4b\x18\x43\x13\x6d\x6f"
  "\x6e\x74\x68\x2f\x6c\x6f\x6e\x67\x2d\x73\x74\x72\x69\x6e\x67\x73"
  "\x78\x02\x04\x93\x01\x02\xba\x05\x0a\x81\x85\x02\xb9\x05\x08\x81"
  "\x83\x02\xb8\x05\x06\x81\x83\x02\xb7\x05\x04\x83\x04\x09\x13\x97"
  "\x01\x02\x4c\x02\x0d\x0e\x6d\x6f\x6e\x74\x68\x20\x69\x6e\x74\x65"
  "\x67\x65\x72\x0f\x3f\x1b\x05\x2b\x05\x32\x04\x33\x04\xbf\x05\x0c"
  "\x81\x85\x02\xbe\x05\x0a\x81\x83\x02\xbd\x05\x08\x84\x06\xbc\x05"
  "\x06\x81\x85\x02\xbb\x05\x04\x81\x85\x02\x0b\x1e\x98\x01\x02\x4d"
  "\x1b\x55\x6e\x6b\x6e\x6f\x77\x6e\x20\x6d\x6f\x6e\x74\x68\x20\x64"
  "\x65\x73\x69\x67\x6e\x61\x74\x69\x6f\x6e\x3a\x7c\x78\x03\x04\x5c"
  "\x04\x5b\x03\xc5\x05\x0e\x81\x83\x02\xc4\x05\x0c\x81\x87\x02\xc3"
  "\x05\x0a\x81\x85\x02\xc2\x05\x08\x81\x83\x02\xc1\x05\x06\x81\x89"
  "\x02\xc0\x05\x04\x83\x04\x0d\x19\x99\x01\x02\x4e\x18\x52\x57\x02"
  "\x04\x16\x67\x75\x61\x72\x61\x6e\x74\x65\x65\x2d\x64\x61\x79\x2d"
  "\x6f\x66\x2d\x77\x65\x65\x6b\x9a\x01\x02\xc8\x05\x08\x81\x83\x02"
  "\xc7\x05\x06\x81\x83\x02\xc6\x05\x04\x83\x04\x07\x11\x9b\x01\x02"
  "\x4f\x18\x44\x1a\x64\x61\x79\x73\x2d\x6f\x66\x2d\x77\x65\x65\x6b"
  "\x2f\x6c\x6f\x6e\x67\x2d\x73\x74\x72\x69\x6e\x67\x73\x9c\x01\x02"
  "\x04\x9a\x01\x02\xcb\x05\x08\x81\x83\x02\xca\x05\x06\x81\x83\x02"
  "\xc9\x05\x04\x83\x04\x07\x11\x9d\x01\x02\x50\x02\x14\x64\x61\x79"
  "\x2d\x6f\x66\x2d\x77\x65\x65\x6b\x20\x69\x6e\x74\x65\x67\x65\x72"
  "\x0f\x3f\x1b\x05\x2b\x05\x32\x04\x33\x04\xd0\x05\x0c\x81\x85\x02"
  "\xcf\x05\x0a\x81\x83\x02\xce\x05\x08\x84\x06\xcd\x05\x06\x81\x85"
  "\x02\xcc\x05\x04\x81\x85\x02\x0b\x1e\x3f\x02\x51\x21\x55\x6e\x6b"
  "\x6e\x6f\x77\x6e\x20\x64\x61\x79\x2d\x6f\x66\x2d\x77\x65\x65\x6b"
  "\x20\x64\x65\x73\x69\x67\x6e\x61\x74\x69\x6f\x6e\x3a\x57\x9c\x01"
  "\x03\x04\x5c\x04\x5b\x03\xd5\x05\x0c\x81\x85\x02\xd4\x05\x0a\x81"
  "\x89\x02\xd3\x05\x08\x81\x83\x02\xd2\x05\x06\x81\x87\x02\xd1\x05"
  "\x04\x83\x04\x0b\x17\x5b\x02\x52\x18\x25\x04\x6b\x02\xda\x05\x0c"
  "\x81\x89\x02\xd9\x05\x0a\x81\x8b\x02\xd8\x05\x08\x81\x89\x02\xd7"
  "\x05\x06\x81\x85\x02\xd6\x05\x04\x84\x06\x0b\x14\x6b\x02\x53\xd1"
  "\x0f\xed\x0e\x65\x47\x60\x03\x5d\x03\x30\x04\x33\x04\xe0\x05\x0e"
  "\x81\x85\x02\xdf\x05\x0c\x81\x85\x02\xde\x05\x0a\x81\x85\x02\xdd"
  "\x05\x08\x81\x85\x02\xdc\x05\x06\x81\x83\x02\xdb\x05\x04\x83\x04"
  "\x0d\x1c\x5d\x02\x54\x01\x31\x03\x42\x05\x67\x03\xe2\x05\x06\x81"
  "\x85\x02\xe1\x05\x04\x83\x04\x05\x0f\x67\x54\x42\x42\x12\x66\x69"
  "\x6c\x65\x2d\x74\x69\x6d\x65\x2d\x3e\x73\x74\x72\x69\x6e\x67\x17"
  "\x75\x6e\x69\x76\x65\x72\x73\x61\x6c\x2d\x74\x69\x6d\x65\x2d\x3e"
  "\x73\x74\x72\x69\x6e\x67\x11\x67\x65\x74\x2d\x64\x65\x63\x6f\x64"
  "\x65\x64\x2d\x74\x69\x6d\x65\x16\x65\x6e\x63\x6f\x64\x65\x2d\x75"
  "\x6e\x69\x76\x65\x72\x73\x61\x6c\x2d\x74\x69\x6d\x65\x16\x64\x65"
  "\x63\x6f\x64\x65\x2d\x75\x6e\x69\x76\x65\x72\x73\x61\x6c\x2d\x74"
  "\x69\x6d\x65\x8e\x01\x4f\x60\x5c\x9c\x01\x57\x14\x73\x74\x72\x69"
  "\x6e\x67\x2d\x3e\x64\x61\x79\x2d\x6f\x66\x2d\x77\x65\x65\x6b\x9a"
  "\x01\x44\x52\x78\x7c\x5e\x93\x01\x43\x50\x31\x8c\x01\x7e\x13\x67"
  "\x04\x5d\x04\x6b\x04\x07\x53\x75\x6e\x64\x61\x79\x09\x53\x61\x74"
  "\x75\x72\x64\x61\x79\x07\x46\x72\x69\x64\x61\x79\x09\x54\x68\x75"
  "\x72\x73\x64\x61\x79\x0a\x57\x65\x64\x6e\x65\x73\x64\x61\x79\x08"
  "\x54\x75\x65\x73\x64\x61\x79\x07\x4d\x6f\x6e\x64\x61\x79\x04\x53"
  "\x75\x6e\x04\x53\x61\x74\x04\x46\x72\x69\x04\x54\x68\x75\x04\x57"
  "\x65\x64\x04\x54\x75\x65\x04\x4d\x6f\x6e\x5b\x04\x3f\x08\x9d\x01"
  "\x04\x9b\x01\x04\x09\x44\x65\x63\x65\x6d\x62\x65\x72\x09\x4e\x6f"
  "\x76\x65\x6d\x62\x65\x72\x08\x4f\x63\x74\x6f\x62\x65\x72\x0a\x53"
  "\x65\x70\x74\x65\x6d\x62\x65\x72\x07\x41\x75\x67\x75\x73\x74\x05"
  "\x4a\x75\x6c\x79\x05\x4a\x75\x6e\x65\x04\x4d\x61\x79\x06\x41\x70"
  "\x72\x69\x6c\x06\x4d\x61\x72\x63\x68\x09\x46\x65\x62\x72\x75\x61"
  "\x72\x79\x08\x4a\x61\x6e\x75\x61\x72\x79\x0d\x04\x44\x65\x63\x04"
  "\x4e\x6f\x76\x04\x4f\x63\x74\x04\x53\x65\x70\x04\x41\x75\x67\x04"
  "\x4a\x75\x6c\x04\x4a\x75\x6e\x04\x4d\x61\x79\x04\x41\x70\x72\x04"
  "\x4d\x61\x72\x04\x46\x65\x62\x04\x4a\x61\x6e\x0d\x99\x01\x04\x98"
  "\x01\x08\x97\x01\x04\x7a\x04\x8b\x01\x04\x95\x01\x04\x94\x01\x04"
  "\x13\x8d\x01\x3c\x90\x01\x87\x01\x19\x85\x01\xef\x02\x82\x01\x08"
  "\x84\x01\x20\x81\x01\x36\x80\x01\x0d\xaf\x0c\x90\x4e\x28\x92\x01"
  "\x7b\x7d\x86\x01\x83\x01\x79\x72\x1a\x69\x73\x6f\x38\x36\x30\x31"
  "\x2d\x73\x74\x72\x69\x6e\x67\x2d\x3e\x66\x69\x6c\x65\x2d\x74\x69"
  "\x6d\x65\x21\x66\x69\x6c\x65\x2d\x74\x69\x6d\x65\x2d\x3e\x67\x6c"
  "\x6f\x62\x61\x6c\x2d\x69\x73\x6f\x38\x36\x30\x31\x2d\x73\x74\x72"
  "\x69\x6e\x67\x20\x66\x69\x6c\x65\x2d\x74\x69\x6d\x65\x2d\x3e\x6c"
  "\x6f\x63\x61\x6c\x2d\x69\x73\x6f\x38\x36\x30\x31\x2d\x73\x74\x72"
  "\x69\x6e\x67\x1f\x69\x73\x6f\x38\x36\x30\x31\x2d\x73\x74\x72\x69"
  "\x6e\x67\x2d\x3e\x75\x6e\x69\x76\x65\x72\x73\x61\x6c\x2d\x74\x69"
  "\x6d\x65\x26\x75\x6e\x69\x76\x65\x72\x73\x61\x6c\x2d\x74\x69\x6d"
  "\x65\x2d\x3e\x67\x6c\x6f\x62\x61\x6c\x2d\x69\x73\x6f\x38\x36\x30"
  "\x31\x2d\x73\x74\x72\x69\x6e\x67\x25\x75\x6e\x69\x76\x65\x72\x73"
  "\x61\x6c\x2d\x74\x69\x6d\x65\x2d\x3e\x6c\x6f\x63\x61\x6c\x2d\x69"
  "\x73\x6f\x38\x36\x30\x31\x2d\x73\x74\x72\x69\x6e\x67\x74\x71\x18"
  "\x63\x74\x69\x6d\x65\x2d\x73\x74\x72\x69\x6e\x67\x2d\x3e\x66\x69"
  "\x6c\x65\x2d\x74\x69\x6d\x65\x1f\x66\x69\x6c\x65\x2d\x74\x69\x6d"
  "\x65\x2d\x3e\x67\x6c\x6f\x62\x61\x6c\x2d\x63\x74\x69\x6d\x65\x2d"
  "\x73\x74\x72\x69\x6e\x67\x1e\x66\x69\x6c\x65\x2d\x74\x69\x6d\x65"
  "\x2d\x3e\x6c\x6f\x63\x61\x6c\x2d\x63\x74\x69\x6d\x65\x2d\x73\x74"
  "\x72\x69\x6e\x67\x1d\x63\x74\x69\x6d\x65\x2d\x73\x74\x72\x69\x6e"
  "\x67\x2d\x3e\x75\x6e\x69\x76\x65\x72\x73\x61\x6c\x2d\x74\x69\x6d"
  "\x65\x24\x75\x6e\x69\x76\x65\x72\x73\x61\x6c\x2d\x74\x69\x6d\x65"
  "\x2d\x3e\x67\x6c\x6f\x62\x61\x6c\x2d\x63\x74\x69\x6d\x65\x2d\x73"
  "\x74\x72\x69\x6e\x67\x23\x75\x6e\x69\x76\x65\x72\x73\x61\x6c\x2d"
  "\x74\x69\x6d\x65\x2d\x3e\x6c\x6f\x63\x61\x6c\x2d\x63\x74\x69\x6d"
  "\x65\x2d\x73\x74\x72\x69\x6e\x67\x56\x59\x6a\x5f\x53\x12\x73\x74"
  "\x72\x69\x6e\x67\x2d\x3e\x66\x69\x6c\x65\x2d\x74\x69\x6d\x65\x17"
  "\x73\x74\x72\x69\x6e\x67\x2d\x3e\x75\x6e\x69\x76\x65\x72\x73\x61"
  "\x6c\x2d\x74\x69\x6d\x65\x62\x48\x1e\x66\x69\x6c\x65\x2d\x74\x69"
  "\x6d\x65\x2d\x3e\x67\x6c\x6f\x62\x61\x6c\x2d\x74\x69\x6d\x65\x2d"
  "\x73\x74\x72\x69\x6e\x67\x1d\x66\x69\x6c\x65\x2d\x74\x69\x6d\x65"
  "\x2d\x3e\x6c\x6f\x63\x61\x6c\x2d\x74\x69\x6d\x65\x2d\x73\x74\x72"
  "\x69\x6e\x67\x9d\x01\x23\x75\x6e\x69\x76\x65\x72\x73\x61\x6c\x2d"
  "\x74\x69\x6d\x65\x2d\x3e\x67\x6c\x6f\x62\x61\x6c\x2d\x74\x69\x6d"
  "\x65\x2d\x73\x74\x72\x69\x6e\x67\x22\x75\x6e\x69\x76\x65\x72\x73"
  "\x61\x6c\x2d\x74\x69\x6d\x65\x2d\x3e\x6c\x6f\x63\x61\x6c\x2d\x74"
  "\x69\x6d\x65\x2d\x73\x74\x72\x69\x6e\x67\x9c\x01\x19\x64\x65\x63"
  "\x6f\x64\x65\x64\x2d\x74\x69\x6d\x65\x2f\x74\x69\x6d\x65\x2d\x73"
  "\x74\x72\x69\x6e\x67\x19\x64\x65\x63\x6f\x64\x65\x64\x2d\x74\x69"
  "\x6d\x65\x2f\x64\x61\x74\x65\x2d\x73\x74\x72\x69\x6e\x67\x51\x2e"
  "\x14\x67\x6c\x6f\x62\x61\x6c\x2d\x64\x65\x63\x6f\x64\x65\x64\x2d"
  "\x74\x69\x6d\x65\x13\x6c\x6f\x63\x61\x6c\x2d\x64\x65\x63\x6f\x64"
  "\x65\x64\x2d\x74\x69\x6d\x65\x9b\x01\x27\x3a\x63\x3d\x3b\x2d\x2a"
  "\x29\x0e\x64\x65\x63\x6f\x64\x65\x64\x2d\x74\x69\x6d\x65\x3f\x17"
  "\x73\x65\x74\x2d\x64\x65\x63\x6f\x64\x65\x64\x2d\x74\x69\x6d\x65"
  "\x2f\x7a\x6f\x6e\x65\x21\x1e\x73\x65\x74\x2d\x64\x65\x63\x6f\x64"
  "\x65\x64\x2d\x74\x69\x6d\x65\x2f\x64\x61\x79\x2d\x6f\x66\x2d\x77"
  "\x65\x65\x6b\x21\x12\x64\x65\x63\x6f\x64\x65\x64\x2d\x74\x69\x6d"
  "\x65\x2f\x7a\x6f\x6e\x65\x23\x64\x65\x63\x6f\x64\x65\x64\x2d\x74"
  "\x69\x6d\x65\x2f\x64\x61\x79\x6c\x69\x67\x68\x74\x2d\x73\x61\x76"
  "\x69\x6e\x67\x73\x2d\x74\x69\x6d\x65\x19\x64\x65\x63\x6f\x64\x65"
  "\x64\x2d\x74\x69\x6d\x65\x2f\x64\x61\x79\x2d\x6f\x66\x2d\x77\x65"
  "\x65\x6b\x12\x64\x65\x63\x6f\x64\x65\x64\x2d\x74\x69\x6d\x65\x2f"
  "\x79\x65\x61\x72\x13\x64\x65\x63\x6f\x64\x65\x64\x2d\x74\x69\x6d"
  "\x65\x2f\x6d\x6f\x6e\x74\x68\x11\x64\x65\x63\x6f\x64\x65\x64\x2d"
  "\x74\x69\x6d\x65\x2f\x64\x61\x79\x12\x64\x65\x63\x6f\x64\x65\x64"
  "\x2d\x74\x69\x6d\x65\x2f\x68\x6f\x75\x72\x14\x64\x65\x63\x6f\x64"
  "\x65\x64\x2d\x74\x69\x6d\x65\x2f\x6d\x69\x6e\x75\x74\x65\x14\x64"
  "\x65\x63\x6f\x64\x65\x64\x2d\x74\x69\x6d\x65\x2f\x73\x65\x63\x6f"
  "\x6e\x64\x36\x2c\x3f\x96\x01\x06\x91\x01\x04\x8f\x01\x04\x8a\x01"
  "\x04\x89\x01\x04\x88\x01\x04\x7f\x04\x65\x04\x4d\x04\x4b\x04\x77"
  "\x04\x76\x04\x75\x04\x45\x04\x73\x04\x70\x04\x6f\x04\x6e\x04\x6d"
  "\x04\x55\x04\x58\x04\x5a\x08\x6c\x04\x03\x55\x54\x04\x47\x4d\x54"
  "\x04\x45\x53\x54\x04\x45\x44\x54\x04\x43\x53\x54\x04\x43\x44\x54"
  "\x04\x4d\x53\x54\x08\x04\x4d\x44\x54\x04\x50\x53\x54\x09\x04\x50"
  "\x44\x54\x08\x02\x41\x02\x42\x02\x43\x02\x44\x02\x45\x02\x46\x02"
  "\x47\x08\x02\x48\x09\x02\x49\x0a\x02\x4b\x0b\x02\x4c\x0c\x02\x4d"
  "\x0d\x02\x4e\x02\x4f\x03\x02\x50\x04\x02\x51\x05\x02\x52\x06\x02"
  "\x53\x07\x02\x54\x08\x02\x55\x09\x02\x56\x0a\x02\x57\x0b\x02\x58"
  "\x0c\x02\x59\x0d\x02\x5a\x23\x68\x04\x69\x04\x66\x04\x64\x04\x61"
  "\x04\x54\x04\x4e\x04\x4c\x04\x4a\x04\x49\x04\x47\x04\x46\x04\x41"
  "\x04\x40\x06\x3e\x04\x3c\x04\x09\x38\x33\x61\x61\x37\x65\x38\x30"
  "\x39\x04\x22\x0c\x38\x04\x37\x04\x35\x04\x34\x04\x2f\x04\x26\x04"
  "\x24\x04\x23\x04\x21\x04\x20\x04\x1f\x04\x1e\x04\x1d\x04\x1c\x04"
  "\x1b\x04\x1a\x04\x19\x04\x17\x04\x0c\x04\x3f\x12\x6c\x65\x78\x69"
  "\x63\x61\x6c\x2d\x72\x65\x66\x65\x72\x65\x6e\x63\x65\x0c\x76\x65"
  "\x63\x74\x6f\x72\x2d\x63\x6f\x70\x79\x07\x76\x65\x63\x74\x6f\x72"
  "\x0d\x0e\x0f\x10\x11\x12\x13\x14\x15\x0a\x0a\x09\x08\x0a\x0a\x04"
  "\x09\x04\x04\x04\x04\x04\x04\x04\x04\x16\x0d\x64\x65\x63\x6f\x64"
  "\x65\x64\x2d\x74\x69\x6d\x65\x0b\x11\x6c\x6f\x63\x61\x6c\x2d\x61"
  "\x73\x73\x69\x67\x6e\x6d\x65\x6e\x74\x0b\x0d\x64\x65\x63\x6f\x64"
  "\x65\x64\x2d\x74\x69\x6d\x65\x04\x19\x73\x74\x61\x6e\x64\x61\x72"
  "\x64\x2d\x75\x6e\x70\x61\x72\x73\x65\x72\x2d\x6d\x65\x74\x68\x6f"
  "\x64\x04\x25\x6e\x61\x6d\x65\x64\x2d\x73\x74\x72\x75\x63\x74\x75"
  "\x72\x65\x2f\x73\x65\x74\x2d\x74\x61\x67\x2d\x64\x65\x73\x63\x72"
  "\x69\x70\x74\x69\x6f\x6e\x21\x0a\x1b\x6d\x61\x6b\x65\x2d\x64\x65"
  "\x66\x69\x6e\x65\x2d\x73\x74\x72\x75\x63\x74\x75\x72\x65\x2d\x74"
  "\x79\x70\x65\x05\x10\x64\x65\x66\x69\x6e\x65\x2d\x6d\x75\x6c\x74"
  "\x69\x70\x6c\x65\x05\x0b\x16\x3b\x63\x9b\x01\x9c\x01\x9d\x01\x08"
  "\x05\x92\x01\x02\x2a\x56\x80\x80\x04\x29\x54\x81\x81\x02\x28\x52"
  "\x81\x81\x02\x27\x50\x81\x87\x02\x26\x4e\x81\x83\x02\x25\x4c\x81"
  "\x85\x02\x24\x4a\x81\x83\x02\x23\x48\x81\x85\x02\x22\x46\x81\x83"
  "\x02\x21\x44\x81\x85\x02\x20\x42\x81\x83\x02\x1f\x40\x81\x85\x02"
  "\x1e\x3e\x81\x83\x02\x1d\x3c\x81\x85\x02\x1c\x3a\x81\x83\x02\x1b"
  "\x38\x81\x85\x02\x1a\x36\x81\x83\x02\x19\x34\x81\x85\x02\x18\x32"
  "\x81\x83\x02\x17\x30\x81\x85\x02\x16\x2e\x81\x83\x02\x15\x2c\x81"
  "\x85\x02\x14\x2a\x81\x83\x02\x13\x28\x81\x85\x02\x12\x26\x81\x83"
  "\x02\x11\x24\x81\x85\x02\x10\x22\x81\x83\x02\x0f\x20\x81\x85\x02"
  "\x0e\x1e\x81\x83\x02\x0d\x1c\x81\x85\x02\x0c\x1a\x81\x83\x02\x0b"
  "\x18\x81\x83\x02\x0a\x16\x81\x85\x02\x09\x14\x81\x83\x02\x08\x12"
  "\x81\x83\x02\x07\x10\x81\x8b\x02\x06\x0e\x81\x85\x02\x05\x0c\x81"
  "\x87\x02\x04\x0a\x81\x85\x02\x03\x08\x81\x83\x02\x02\x06\x81\x89"
  "\x02\x01\x04\x81\x83\x02\x55\xa3\x01";

SCHEME_OBJECT *
datime_so_data_1efa395e919a8dd3 (entry_count_t dispatch_base)
{
  SCHEME_OBJECT ccb;
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES_FOR_DATA ();

  ccb = (unstackify (((unsigned char *) (& (prog_datime_so_data_1efa395e919a8dd3 [0]))), (sizeof (prog_datime_so_data_1efa395e919a8dd3)), dispatch_base));
  current_block = (OBJECT_ADDRESS (ccb));
  return (& (current_block [LABEL_50]));
}

DECLARE_COMPILED_DATA_NS ("datime.so", datime_so_data_1efa395e919a8dd3)

#endif /* !WANT_ONLY_CODE */

DECLARE_DYNAMIC_INITIALIZATION ("datime.so", "439306c66f4f31a5")
