/* Emacs: this is -*- C -*- code, */
/* generated 2007-09-09T13:47:27-0400 by Liar version UNKNOWN. */

#include "liarc.h"

#define LABEL_1_4 3
#define ENVIRONMENT_LABEL_1_3 9
#define DEBUGGING_LABEL_1_2 8
#define OBJECT_1_0 7
#define EXECUTE_CACHE_1_5 5
#define FREE_REFERENCES_LABEL_1_0 4
#define NUMBER_OF_LINKER_SECTIONS_1_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd7;
  machine_word Wrd9;
  machine_word Wrd8;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_1_4);
      goto syntax_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (syntax_4)
DEFLABEL (syntax_1)
  INTERRUPT_CHECK (26, LABEL_1_4);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.Obj) = (current_block [OBJECT_1_0]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_2_4 3
#define LABEL_2_7 5
#define LABEL_2_5 7
#define LABEL_2_9 9
#define LABEL_2_11 11
#define LABEL_2_13 13
#define TAG_2_14 5
#define LABEL_2_15 15
#define TAG_2_16 6
#define LABEL_2_23 17
#define LABEL_2_24 19
#define LABEL_2_17 21
#define TAG_2_18 9
#define LABEL_2_25 23
#define LABEL_2_26 25
#define LABEL_2_20 27
#define LABEL_2_21 29
#define LABEL_2_31 31
#define LABEL_2_34 33
#define LABEL_2_28 35
#define LABEL_2_29 37
#define LABEL_2_33 39
#define LABEL_2_35 41
#define ENVIRONMENT_LABEL_2_3 78
#define DEBUGGING_LABEL_2_2 77
#define OBJECT_2_2 76
#define OBJECT_2_1 75
#define OBJECT_2_0 74
#define EXECUTE_CACHE_2_39 43
#define EXECUTE_CACHE_2_38 45
#define EXECUTE_CACHE_2_37 47
#define EXECUTE_CACHE_2_36 49
#define EXECUTE_CACHE_2_32 51
#define EXECUTE_CACHE_2_30 53
#define EXECUTE_CACHE_2_27 55
#define EXECUTE_CACHE_2_22 57
#define EXECUTE_CACHE_2_19 59
#define EXECUTE_CACHE_2_12 61
#define EXECUTE_CACHE_2_10 63
#define EXECUTE_CACHE_2_8 65
#define EXECUTE_CACHE_2_6 67
#define FREE_REFERENCE_2_1 70
#define FREE_REFERENCE_2_0 71
#define FREE_ASSIGNMENT_2_0 73
#define FREE_REFERENCES_LABEL_2_0 42
#define NUMBER_OF_LINKER_SECTIONS_2_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd19;
  machine_word Wrd23;
  machine_word Wrd5;
  machine_word Wrd12;
  machine_word Wrd24;
  machine_word Wrd20;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_2_4);
      goto syntax__28;

    case 1:
      current_block = (Rpc - LABEL_2_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_2_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_2_9);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_2_11);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_2_13);
      goto lambda_37;

    case 6:
      current_block = (Rpc - LABEL_2_15);
      goto lambda_38;

    case 7:
      current_block = (Rpc - LABEL_2_23);
      goto label_30;

    case 8:
      current_block = (Rpc - LABEL_2_24);
      goto label_31;

    case 9:
      current_block = (Rpc - LABEL_2_17);
      goto lambda_39;

    case 10:
      current_block = (Rpc - LABEL_2_25);
      goto label_32;

    case 11:
      current_block = (Rpc - LABEL_2_26);
      goto label_33;

    case 12:
      current_block = (Rpc - LABEL_2_20);
      goto continuation_12;

    case 13:
      current_block = (Rpc - LABEL_2_21);
      goto continuation_11;

    case 14:
      current_block = (Rpc - LABEL_2_31);
      goto continuation_15;

    case 15:
      current_block = (Rpc - LABEL_2_34);
      goto label_34;

    case 16:
      current_block = (Rpc - LABEL_2_28);
      goto continuation_14;

    case 17:
      current_block = (Rpc - LABEL_2_29);
      goto continuation_13;

    case 18:
      current_block = (Rpc - LABEL_2_33);
      goto continuation_17;

    case 19:
      current_block = (Rpc - LABEL_2_35);
      goto continuation_16;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (syntax__36)
DEFLABEL (syntax__28)
  INTERRUPT_CHECK (26, LABEL_2_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_2_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_41;

DEFLABEL (label_40)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_2_0]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_2_9);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_11]))));
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_12]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_2_11);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = Rvl;
  (Wrd28.pObj) = (& (Rhp [-1]));
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd28.pObj)));
  (Rsp [0]) = (Wrd29.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_2_14);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_2_13])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [3]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd14.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_2_16);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_2_15])));
  Rhp += 2;
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd14.pObj)));
  Wrd17 = Wrd14;
  (Wrd18.Obj) = (Rsp [1]);
  ((Wrd17.pObj) [2]) = (Wrd18.Obj);
  ((Wrd17.pObj) [3]) = (Wrd29.Obj);
  (Rsp [3]) = (Wrd13.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd21.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_2_18);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_2_17])));
  Rhp += 2;
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd21.pObj)));
  Wrd24 = Wrd21;
  ((Wrd24.pObj) [2]) = (Wrd18.Obj);
  ((Wrd24.pObj) [3]) = (Wrd29.Obj);
  (Rsp [1]) = (Wrd20.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_19]));

DEFLABEL (label_41)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_7]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (current_block [OBJECT_2_0]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (current_block [OBJECT_2_1]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_2_7);
  goto label_40;

DEFLABEL (lambda_37)
  CLOSURE_HEADER (LABEL_2_13);

DEFLABEL (lambda_19)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_20]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_21]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_22]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_2_21);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_44;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_31]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_32]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_2_31);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_33]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_1]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_43;
  Wrd8 = Wrd12;

DEFLABEL (label_42)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_35]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [6]);
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [3]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_30]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_2_35);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.Obj) = (Rsp [7]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_39]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_2_33);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_38]));

DEFLABEL (label_43)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_34])), (Wrd9.pObj));

DEFLABEL (label_34)
  (Wrd8.Obj) = Rvl;
  goto label_42;

DEFLABEL (label_44)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_28]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_29]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (Rsp [3]);
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [2]);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd24.Obj) = ((Wrd20.pObj) [3]);
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_30]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_2_29);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [3]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_37]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_2_28);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_36]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_2_20);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_27]));

DEFLABEL (lambda_38)
  CLOSURE_HEADER (LABEL_2_15);

DEFLABEL (lambda_26)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_50;

DEFLABEL (label_49)
  Wrd19 = Wrd23;

DEFLABEL (label_48)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_2_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_47;

DEFLABEL (label_46)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_45)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_2_2]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_47)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_46;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_2_24])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_31)
  goto label_45;

DEFLABEL (label_50)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_49;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_2_23])), (Wrd20.pObj));

DEFLABEL (label_30)
  (Wrd19.Obj) = Rvl;
  goto label_48;

DEFLABEL (lambda_39)
  CLOSURE_HEADER (LABEL_2_17);

DEFLABEL (lambda_10)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_56;

DEFLABEL (label_55)
  Wrd19 = Wrd23;

DEFLABEL (label_54)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_2_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_53;

DEFLABEL (label_52)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_51)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [2]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  Rvl = (current_block [OBJECT_2_2]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_53)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_52;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_2_26])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_33)
  goto label_51;

DEFLABEL (label_56)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_55;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_2_25])), (Wrd20.pObj));

DEFLABEL (label_32)
  (Wrd19.Obj) = Rvl;
  goto label_54;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_3_4 3
#define LABEL_3_5 5
#define LABEL_3_8 7
#define LABEL_3_10 9
#define LABEL_3_12 11
#define LABEL_3_15 13
#define LABEL_3_16 15
#define LABEL_3_14 17
#define ENVIRONMENT_LABEL_3_3 36
#define DEBUGGING_LABEL_3_2 35
#define EXECUTE_CACHE_3_19 19
#define EXECUTE_CACHE_3_18 21
#define EXECUTE_CACHE_3_17 23
#define EXECUTE_CACHE_3_13 25
#define EXECUTE_CACHE_3_11 27
#define EXECUTE_CACHE_3_9 29
#define EXECUTE_CACHE_3_7 31
#define EXECUTE_CACHE_3_6 33
#define FREE_REFERENCES_LABEL_3_0 18
#define NUMBER_OF_LINKER_SECTIONS_3_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_3_4);
      goto compile_item_top_level_8;

    case 1:
      current_block = (Rpc - LABEL_3_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_3_8);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_3_10);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_3_12);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_3_15);
      goto continuation_6;

    case 6:
      current_block = (Rpc - LABEL_3_16);
      goto continuation_5;

    case 7:
      current_block = (Rpc - LABEL_3_14);
      goto continuation_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (compile_item_top_level_11)
DEFLABEL (compile_item_top_level_8)
  INTERRUPT_CHECK (26, LABEL_3_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_3_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_12;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_7]));

DEFLABEL (label_12)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_8]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_3_8);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_3_10);
  (Rsp [1]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_12]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_13]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_3_12);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_13;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_15]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_16]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_17]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_3_16);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_7]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_3_15);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_18]));

DEFLABEL (label_13)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_14]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_7]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_3_14);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_19]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4_4 3
#define LABEL_4_5 5
#define LABEL_4_7 7
#define LABEL_4_9 9
#define LABEL_4_8 11
#define LABEL_4_12 13
#define LABEL_4_11 15
#define ENVIRONMENT_LABEL_4_3 27
#define DEBUGGING_LABEL_4_2 26
#define EXECUTE_CACHE_4_13 17
#define EXECUTE_CACHE_4_10 19
#define EXECUTE_CACHE_4_6 21
#define FREE_REFERENCE_4_1 24
#define FREE_REFERENCE_4_0 25
#define FREE_REFERENCES_LABEL_4_0 16
#define NUMBER_OF_LINKER_SECTIONS_4_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4_4);
      goto compile_body_items_top_level_4;

    case 1:
      current_block = (Rpc - LABEL_4_5);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_4_7);
      goto lambda_2;

    case 3:
      current_block = (Rpc - LABEL_4_9);
      goto label_6;

    case 4:
      current_block = (Rpc - LABEL_4_8);
      goto continuation_0;

    case 5:
      current_block = (Rpc - LABEL_4_12);
      goto label_7;

    case 6:
      current_block = (Rpc - LABEL_4_11);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (compile_body_items_top_level_9)
DEFLABEL (compile_body_items_top_level_4)
  INTERRUPT_CHECK (26, LABEL_4_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_6]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_4_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_7]))));
  (Rsp [1]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (lambda_10)
DEFLABEL (lambda_2)
  INTERRUPT_CHECK (26, LABEL_4_7);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_14;
  Wrd9 = Wrd13;

DEFLABEL (label_13)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_10]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_4_8);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_11]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_1]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_12;
  Wrd10 = Wrd14;

DEFLABEL (label_11)
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_10]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_4_11);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_13]));

DEFLABEL (label_12)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_12])), (Wrd11.pObj));

DEFLABEL (label_7)
  (Wrd10.Obj) = Rvl;
  goto label_11;

DEFLABEL (label_14)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_9])), (Wrd10.pObj));

DEFLABEL (label_6)
  (Wrd9.Obj) = Rvl;
  goto label_13;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_5_4 3
#define LABEL_5_7 5
#define LABEL_5_5 7
#define LABEL_5_11 9
#define LABEL_5_9 11
#define ENVIRONMENT_LABEL_5_3 24
#define DEBUGGING_LABEL_5_2 23
#define OBJECT_5_1 22
#define OBJECT_5_0 21
#define EXECUTE_CACHE_5_12 13
#define EXECUTE_CACHE_5_10 15
#define EXECUTE_CACHE_5_8 17
#define EXECUTE_CACHE_5_6 19
#define FREE_REFERENCES_LABEL_5_0 12
#define NUMBER_OF_LINKER_SECTIONS_5_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_5_4);
      goto compile_item_expression_5;

    case 1:
      current_block = (Rpc - LABEL_5_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_5_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_5_11);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_5_9);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (compile_item_expression_8)
DEFLABEL (compile_item_expression_5)
  INTERRUPT_CHECK (26, LABEL_5_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_5_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_12;

DEFLABEL (label_11)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_5_9);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_10;

DEFLABEL (label_9)
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_10)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_11]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_5_0]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_12]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_5_11);
  goto label_9;

DEFLABEL (label_12)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_7]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_5_0]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (current_block [OBJECT_5_1]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_5_7);
  goto label_11;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_6_4 3
#define LABEL_6_6 5
#define LABEL_6_5 7
#define LABEL_6_7 9
#define LABEL_6_8 11
#define ENVIRONMENT_LABEL_6_3 23
#define DEBUGGING_LABEL_6_2 22
#define OBJECT_6_0 21
#define EXECUTE_CACHE_6_11 13
#define EXECUTE_CACHE_6_10 15
#define EXECUTE_CACHE_6_9 17
#define FREE_REFERENCE_6_0 20
#define FREE_REFERENCES_LABEL_6_0 12
#define NUMBER_OF_LINKER_SECTIONS_6_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_6_4);
      goto get_item_compiler_4;

    case 1:
      current_block = (Rpc - LABEL_6_6);
      goto label_6;

    case 2:
      current_block = (Rpc - LABEL_6_5);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_6_7);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_6_8);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (get_item_compiler_8)
DEFLABEL (get_item_compiler_4)
  INTERRUPT_CHECK (26, LABEL_6_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_13;
  Wrd8 = Wrd12;

DEFLABEL (label_12)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_7]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_8]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_9]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_6_8);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_11]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_6_7);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_6_5);
  (Rsp [0]) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_11;
  (Wrd13.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd13.uLng) == 1)
    goto label_9;
  INVOKE_PRIMITIVE ((current_block [OBJECT_6_0]), 1);

DEFLABEL (label_9)
  (Wrd10.pObj) = (OBJECT_ADDRESS (Rvl));
  Rvl = ((Wrd10.pObj) [1]);

DEFLABEL (label_10)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_11)
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_10;

DEFLABEL (label_13)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_6_6])), (Wrd9.pObj));

DEFLABEL (label_6)
  (Wrd8.Obj) = Rvl;
  goto label_12;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_7_4 3
#define LABEL_7_6 5
#define LABEL_7_5 7
#define LABEL_7_8 9
#define LABEL_7_9 11
#define ENVIRONMENT_LABEL_7_3 22
#define DEBUGGING_LABEL_7_2 21
#define OBJECT_7_1 20
#define OBJECT_7_0 19
#define EXECUTE_CACHE_7_7 13
#define FREE_REFERENCE_7_0 16
#define FREE_ASSIGNMENT_7_0 18
#define FREE_REFERENCES_LABEL_7_0 12
#define NUMBER_OF_LINKER_SECTIONS_7_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_7 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd31;
  machine_word Wrd28;
  machine_word Wrd30;
  machine_word Wrd23;
  machine_word Wrd25;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd17;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd14;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_7_4);
      goto define_item_compiler_4;

    case 1:
      current_block = (Rpc - LABEL_7_6);
      goto label_6;

    case 2:
      current_block = (Rpc - LABEL_7_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_7_8);
      goto label_7;

    case 4:
      current_block = (Rpc - LABEL_7_9);
      goto label_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (define_item_compiler_10)
DEFLABEL (define_item_compiler_4)
  INTERRUPT_CHECK (26, LABEL_7_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_19;
  Wrd8 = Wrd12;

DEFLABEL (label_18)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_7_5);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_12;
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  (Wrd13.Obj) = (Rsp [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_11;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [1]) = (Wrd11.Obj);
  Rvl = (current_block [OBJECT_7_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_11)
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_1]), 2);

DEFLABEL (label_12)
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7_0]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_17;
  Wrd17 = Wrd21;

DEFLABEL (label_16)
  (Wrd26.Obj) = (Rsp [1]);
  (Wrd27.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd26.Obj);
  (* (Rhp++)) = (Wrd27.Obj);
  (Wrd25.pObj) = (& (Rhp [-2]));
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd25.pObj)));
  (* (Rhp++)) = (Wrd23.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (Wrd30.pObj) = (& (Rhp [-2]));
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd30.pObj)));
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_7_0]));
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_15;

DEFLABEL (label_14)
  ((Wrd31.pObj) [0]) = (Wrd28.Obj);

DEFLABEL (label_13)
  Rvl = (current_block [OBJECT_7_0]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_15)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_14;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_7_9])), (Wrd31.pObj), (Wrd28.Obj));

DEFLABEL (label_8)
  goto label_13;

DEFLABEL (label_17)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_7_8])), (Wrd18.pObj));

DEFLABEL (label_7)
  (Wrd17.Obj) = Rvl;
  goto label_16;

DEFLABEL (label_19)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_7_6])), (Wrd9.pObj));

DEFLABEL (label_6)
  (Wrd8.Obj) = Rvl;
  goto label_18;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_8_4 3
#define LABEL_8_5 5
#define ENVIRONMENT_LABEL_8_3 12
#define DEBUGGING_LABEL_8_2 11
#define EXECUTE_CACHE_8_7 7
#define EXECUTE_CACHE_8_6 9
#define FREE_REFERENCES_LABEL_8_0 6
#define NUMBER_OF_LINKER_SECTIONS_8_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_8_4);
      goto compile_expression_1;

    case 1:
      current_block = (Rpc - LABEL_8_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (compile_expression_4)
DEFLABEL (compile_expression_1)
  INTERRUPT_CHECK (26, LABEL_8_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_8_5);
  (Rsp [2]) = Rvl;
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_9_4 3
#define LABEL_9_5 5
#define ENVIRONMENT_LABEL_9_3 12
#define DEBUGGING_LABEL_9_2 11
#define EXECUTE_CACHE_9_6 7
#define FREE_REFERENCE_9_0 10
#define FREE_REFERENCES_LABEL_9_0 6
#define NUMBER_OF_LINKER_SECTIONS_9_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_9_4);
      goto compile_expressions_0;

    case 1:
      current_block = (Rpc - LABEL_9_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (compile_expressions_4)
DEFLABEL (compile_expressions_0)
  INTERRUPT_CHECK (26, LABEL_9_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [3]);
  (Rsp [2]) = (Wrd7.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_6;
  Wrd9 = Wrd13;

DEFLABEL (label_5)
  (Rsp [3]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_9_5])), (Wrd10.pObj));

DEFLABEL (label_2)
  (Wrd9.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_10_4 3
#define LABEL_10_5 5
#define ENVIRONMENT_LABEL_10_3 12
#define DEBUGGING_LABEL_10_2 11
#define EXECUTE_CACHE_10_7 7
#define EXECUTE_CACHE_10_6 9
#define FREE_REFERENCES_LABEL_10_0 6
#define NUMBER_OF_LINKER_SECTIONS_10_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_10 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_10_4);
      goto compile_subexpression_1;

    case 1:
      current_block = (Rpc - LABEL_10_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (compile_subexpression_4)
DEFLABEL (compile_subexpression_1)
  INTERRUPT_CHECK (26, LABEL_10_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_10_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_10_5);
  (Rsp [3]) = Rvl;
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_10_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_11_4 3
#define LABEL_11_5 5
#define TAG_11_6 1
#define ENVIRONMENT_LABEL_11_3 12
#define DEBUGGING_LABEL_11_2 11
#define EXECUTE_CACHE_11_8 7
#define EXECUTE_CACHE_11_7 9
#define FREE_REFERENCES_LABEL_11_0 6
#define NUMBER_OF_LINKER_SECTIONS_11_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_11 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd5;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_11_4);
      goto compile_subexpressions_1;

    case 1:
      current_block = (Rpc - LABEL_11_5);
      goto lambda_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (compile_subexpressions_4)
DEFLABEL (compile_subexpressions_1)
  INTERRUPT_CHECK (26, LABEL_11_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_11_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_11_5])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [2]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd12.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd12.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_7]));

DEFLABEL (lambda_5)
  CLOSURE_HEADER (LABEL_11_5);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd9.Obj) = ((Wrd8.pObj) [3]);
  (Rsp [1]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_8]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_12_4 3
#define LABEL_12_5 5
#define LABEL_12_9 7
#define LABEL_12_10 9
#define LABEL_12_7 11
#define LABEL_12_17 13
#define LABEL_12_18 15
#define LABEL_12_12 17
#define LABEL_12_23 19
#define LABEL_12_24 21
#define LABEL_12_20 23
#define TAG_12_21 10
#define LABEL_12_15 25
#define LABEL_12_16 27
#define LABEL_12_26 29
#define LABEL_12_28 31
#define LABEL_12_30 33
#define LABEL_12_33 35
#define LABEL_12_36 37
#define LABEL_12_41 39
#define LABEL_12_39 41
#define LABEL_12_44 43
#define LABEL_12_48 45
#define LABEL_12_51 47
#define LABEL_12_47 49
#define LABEL_12_54 51
#define LABEL_12_55 53
#define LABEL_12_53 55
#define LABEL_12_57 57
#define TAG_12_58 27
#define LABEL_12_59 59
#define LABEL_12_62 61
#define LABEL_12_61 63
#define ENVIRONMENT_LABEL_12_3 129
#define DEBUGGING_LABEL_12_2 128
#define OBJECT_12_2 127
#define OBJECT_12_1 126
#define OBJECT_12_0 125
#define EXECUTE_CACHE_12_64 65
#define EXECUTE_CACHE_12_63 67
#define EXECUTE_CACHE_12_60 69
#define EXECUTE_CACHE_12_56 71
#define EXECUTE_CACHE_12_52 73
#define EXECUTE_CACHE_12_50 75
#define EXECUTE_CACHE_12_49 77
#define EXECUTE_CACHE_12_46 79
#define EXECUTE_CACHE_12_45 81
#define EXECUTE_CACHE_12_43 83
#define EXECUTE_CACHE_12_42 85
#define EXECUTE_CACHE_12_40 87
#define EXECUTE_CACHE_12_38 89
#define EXECUTE_CACHE_12_37 91
#define EXECUTE_CACHE_12_35 93
#define EXECUTE_CACHE_12_34 95
#define EXECUTE_CACHE_12_32 97
#define EXECUTE_CACHE_12_31 99
#define EXECUTE_CACHE_12_29 101
#define EXECUTE_CACHE_12_27 103
#define EXECUTE_CACHE_12_25 105
#define EXECUTE_CACHE_12_22 107
#define EXECUTE_CACHE_12_19 109
#define EXECUTE_CACHE_12_14 111
#define EXECUTE_CACHE_12_13 113
#define EXECUTE_CACHE_12_11 115
#define EXECUTE_CACHE_12_8 117
#define EXECUTE_CACHE_12_6 119
#define FREE_REFERENCE_12_2 122
#define FREE_REFERENCE_12_1 123
#define FREE_REFERENCE_12_0 124
#define FREE_REFERENCES_LABEL_12_0 64
#define NUMBER_OF_LINKER_SECTIONS_12_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_12 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd26;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd17;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd12;
  machine_word Wrd16;
  machine_word Wrd45;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd29;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_12_4);
      goto classify_form_32;

    case 1:
      current_block = (Rpc - LABEL_12_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_12_9);
      goto continuation_28;

    case 3:
      current_block = (Rpc - LABEL_12_10);
      goto continuation_27;

    case 4:
      current_block = (Rpc - LABEL_12_7);
      goto continuation_1;

    case 5:
      current_block = (Rpc - LABEL_12_17);
      goto label_34;

    case 6:
      current_block = (Rpc - LABEL_12_18);
      goto label_35;

    case 7:
      current_block = (Rpc - LABEL_12_12);
      goto continuation_29;

    case 8:
      current_block = (Rpc - LABEL_12_23);
      goto continuation_24;

    case 9:
      current_block = (Rpc - LABEL_12_24);
      goto continuation_23;

    case 10:
      current_block = (Rpc - LABEL_12_20);
      goto lambda_42;

    case 11:
      current_block = (Rpc - LABEL_12_15);
      goto continuation_6;

    case 12:
      current_block = (Rpc - LABEL_12_16);
      goto continuation_5;

    case 13:
      current_block = (Rpc - LABEL_12_26);
      goto continuation_30;

    case 14:
      current_block = (Rpc - LABEL_12_28);
      goto continuation_21;

    case 15:
      current_block = (Rpc - LABEL_12_30);
      goto continuation_22;

    case 16:
      current_block = (Rpc - LABEL_12_33);
      goto continuation_7;

    case 17:
      current_block = (Rpc - LABEL_12_36);
      goto continuation_25;

    case 18:
      current_block = (Rpc - LABEL_12_41);
      goto continuation_19;

    case 19:
      current_block = (Rpc - LABEL_12_39);
      goto continuation_8;

    case 20:
      current_block = (Rpc - LABEL_12_44);
      goto continuation_9;

    case 21:
      current_block = (Rpc - LABEL_12_48);
      goto label_36;

    case 22:
      current_block = (Rpc - LABEL_12_51);
      goto continuation_12;

    case 23:
      current_block = (Rpc - LABEL_12_47);
      goto continuation_11;

    case 24:
      current_block = (Rpc - LABEL_12_54);
      goto label_37;

    case 25:
      current_block = (Rpc - LABEL_12_55);
      goto label_38;

    case 26:
      current_block = (Rpc - LABEL_12_53);
      goto continuation_14;

    case 27:
      current_block = (Rpc - LABEL_12_57);
      goto lambda_43;

    case 28:
      current_block = (Rpc - LABEL_12_59);
      goto continuation_15;

    case 29:
      current_block = (Rpc - LABEL_12_62);
      goto label_39;

    case 30:
      current_block = (Rpc - LABEL_12_61);
      goto continuation_16;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (classify_form_41)
DEFLABEL (classify_form_32)
  INTERRUPT_CHECK (26, LABEL_12_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_12_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_45;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_10]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_11]));

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_12_10);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_14]));

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_12_9);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_13]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_12_12);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_44;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_44)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_26]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_27]));

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_12_26);
  (Rsp [2]) = Rvl;
  (Wrd6.Obj) = (Rsp [1]);
  (Rsp [3]) = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_35]));

DEFLABEL (label_45)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_7]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd19.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_12_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_46;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_23]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_24]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_25]));

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_12_24);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_30]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_31]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_12_30);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_38]));

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_12_23);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_28]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_29]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_12_28);
  (* (--Rsp)) = Rvl;
  (Rsp [2]) = Rvl;
  (Wrd6.Obj) = (Rsp [1]);
  (Rsp [3]) = (Wrd6.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_36]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd6.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_37]));

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_12_36);
  (Rsp [5]) = Rvl;
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_43]));

DEFLABEL (label_46)
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 1)
    goto label_47;
  (Wrd16.Obj) = (Rsp [3]);
  (Rsp [2]) = (Wrd16.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd19.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_12_21);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_12_20])));
  Rhp += 1;
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd19.pObj)));
  ((Wrd19.pObj) [2]) = (Wrd14.Obj);
  (Rsp [3]) = (Wrd18.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_22]));

DEFLABEL (label_47)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_15]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_16]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd30.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_12_0]));
  (Wrd33.Obj) = ((Wrd30.pObj) [0]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if ((Wrd34.uLng) == 50)
    goto label_61;
  Wrd29 = Wrd33;

DEFLABEL (label_60)
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd35.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd36.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd40.Obj) = (Rsp [5]);
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if (! ((Wrd41.uLng) == 1))
    goto label_59;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [0]);
  (* (--Rsp)) = (Wrd39.Obj);

DEFLABEL (label_58)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_19]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_12_16);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_27]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_12_15);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_33]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_34]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_12_33);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_48;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_41]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_42]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_12_41);
  (Rsp [0]) = Rvl;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 5);
  }

DEFLABEL (label_48)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_39]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_40]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_12_39);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_49;
  (Wrd7.Obj) = (Rsp [2]);
  (Rsp [3]) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd9.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_46]));

DEFLABEL (label_49)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_44]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_45]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_12_44);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_50;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_50]));

DEFLABEL (label_50)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_47]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_57;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [1]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_56)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_49]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_12_47);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_55;
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_51]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd31.Obj) = (current_block [OBJECT_12_2]);
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd32.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd32.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_52]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_12_51);

DEFLABEL (label_55)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_53]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_12_1]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_54;
  Wrd10 = Wrd14;

DEFLABEL (label_53)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd16.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd21.Obj) = (Rsp [5]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_52;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [1]);
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_51)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_56]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_12_53);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [5]);
  (Rsp [4]) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_12_58);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_12_57])));
  Rhp += 2;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  Wrd11 = Wrd8;
  (Wrd12.Obj) = (Rsp [1]);
  ((Wrd11.pObj) [2]) = (Wrd12.Obj);
  ((Wrd11.pObj) [3]) = Rvl;
  (Rsp [5]) = (Wrd7.Obj);
  Rsp = (& (Rsp [4]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_22]));

DEFLABEL (label_52)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_55]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_1]), 1);

DEFLABEL (label_38)
  (* (--Rsp)) = Rvl;
  goto label_51;

DEFLABEL (label_54)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_12_54])), (Wrd11.pObj));

DEFLABEL (label_37)
  (Wrd10.Obj) = Rvl;
  goto label_53;

DEFLABEL (label_57)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_48]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_1]), 1);

DEFLABEL (label_36)
  (* (--Rsp)) = Rvl;
  goto label_56;

DEFLABEL (label_59)
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_18]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_0]), 1);

DEFLABEL (label_35)
  (* (--Rsp)) = Rvl;
  goto label_58;

DEFLABEL (label_61)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_12_17])), (Wrd30.pObj));

DEFLABEL (label_34)
  (Wrd29.Obj) = Rvl;
  goto label_60;

DEFLABEL (lambda_42)
  CLOSURE_HEADER (LABEL_12_20);

DEFLABEL (lambda_3)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_32]));

DEFLABEL (lambda_43)
  CLOSURE_HEADER (LABEL_12_57);

DEFLABEL (lambda_17)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_59]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_60]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_12_59);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_61]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_12_2]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_63;
  Wrd11 = Wrd15;

DEFLABEL (label_62)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_63]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_12_61);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_64]));

DEFLABEL (label_63)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_12_62])), (Wrd12.pObj));

DEFLABEL (label_39)
  (Wrd11.Obj) = Rvl;
  goto label_62;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_13_4 3
#define LABEL_13_5 5
#define TAG_13_6 1
#define LABEL_13_8 7
#define ENVIRONMENT_LABEL_13_3 14
#define DEBUGGING_LABEL_13_2 13
#define EXECUTE_CACHE_13_9 9
#define EXECUTE_CACHE_13_7 11
#define FREE_REFERENCES_LABEL_13_0 8
#define NUMBER_OF_LINKER_SECTIONS_13_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_13 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_13_4);
      goto classify_compiler_2;

    case 1:
      current_block = (Rpc - LABEL_13_5);
      goto lambda_6;

    case 2:
      current_block = (Rpc - LABEL_13_8);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (classify_compiler_5)
DEFLABEL (classify_compiler_2)
  INTERRUPT_CHECK (26, LABEL_13_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_13_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_13_5])));
  Rhp += 4;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [3]);
  ((Wrd14.pObj) [2]) = (Wrd15.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd14.pObj) [4]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd14.pObj) [5]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd15.Obj);
  (Rsp [3]) = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_7]));

DEFLABEL (lambda_6)
  CLOSURE_HEADER (LABEL_13_5);

DEFLABEL (lambda_1)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_8]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd16.Obj) = ((Wrd6.pObj) [5]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_9]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_13_8);
  (* (--Rsp)) = Rvl;
  (Wrd6.Obj) = (Rsp [3]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [3]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_14_4 3
#define LABEL_14_5 5
#define LABEL_14_6 7
#define LABEL_14_8 9
#define LABEL_14_10 11
#define ENVIRONMENT_LABEL_14_3 22
#define DEBUGGING_LABEL_14_2 21
#define EXECUTE_CACHE_14_12 13
#define EXECUTE_CACHE_14_11 15
#define EXECUTE_CACHE_14_9 17
#define EXECUTE_CACHE_14_7 19
#define FREE_REFERENCES_LABEL_14_0 12
#define NUMBER_OF_LINKER_SECTIONS_14_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_14 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_14_4);
      goto classify_expander_5;

    case 1:
      current_block = (Rpc - LABEL_14_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_14_6);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_14_8);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_14_10);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (classify_expander_8)
DEFLABEL (classify_expander_5)
  INTERRUPT_CHECK (26, LABEL_14_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_14_6);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_10]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_14_10);
  (* (--Rsp)) = Rvl;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_14_5);
  (* (--Rsp)) = Rvl;
  (Rsp [2]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_8]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_9]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_14_8);
  (Rsp [5]) = Rvl;
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_12]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_15_4 3
#define LABEL_15_5 5
#define ENVIRONMENT_LABEL_15_3 12
#define DEBUGGING_LABEL_15_2 11
#define EXECUTE_CACHE_15_7 7
#define EXECUTE_CACHE_15_6 9
#define FREE_REFERENCES_LABEL_15_0 6
#define NUMBER_OF_LINKER_SECTIONS_15_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_15 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_15_4);
      goto classify_subform_1;

    case 1:
      current_block = (Rpc - LABEL_15_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (classify_subform_4)
DEFLABEL (classify_subform_1)
  INTERRUPT_CHECK (26, LABEL_15_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_15_5);
  (Rsp [4]) = Rvl;
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (Rsp [3]) = (Wrd8.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_16_4 3
#define LABEL_16_5 5
#define TAG_16_6 1
#define ENVIRONMENT_LABEL_16_3 12
#define DEBUGGING_LABEL_16_2 11
#define EXECUTE_CACHE_16_8 7
#define EXECUTE_CACHE_16_7 9
#define FREE_REFERENCES_LABEL_16_0 6
#define NUMBER_OF_LINKER_SECTIONS_16_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_16 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd5;
  machine_word Wrd14;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_16_4);
      goto classify_subforms_1;

    case 1:
      current_block = (Rpc - LABEL_16_5);
      goto lambda_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (classify_subforms_4)
DEFLABEL (classify_subforms_1)
  INTERRUPT_CHECK (26, LABEL_16_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_16_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_16_5])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd12 = Wrd7;
  (Wrd13.Obj) = (Rsp [3]);
  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd12.pObj) [4]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd14.Obj) = (Rsp [0]);
  (Rsp [3]) = (Wrd14.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_7]));

DEFLABEL (lambda_5)
  CLOSURE_HEADER (LABEL_16_5);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = ((Wrd6.pObj) [2]);
  (Rsp [3]) = (Wrd9.Obj);
  (Wrd12.Obj) = ((Wrd6.pObj) [3]);
  (Rsp [2]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_8]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_17_4 3
#define LABEL_17_5 5
#define ENVIRONMENT_LABEL_17_3 12
#define DEBUGGING_LABEL_17_2 11
#define EXECUTE_CACHE_17_6 7
#define FREE_REFERENCE_17_0 10
#define FREE_REFERENCES_LABEL_17_0 6
#define NUMBER_OF_LINKER_SECTIONS_17_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_17 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_17_4);
      goto classify_expression_0;

    case 1:
      current_block = (Rpc - LABEL_17_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (classify_expression_4)
DEFLABEL (classify_expression_0)
  INTERRUPT_CHECK (26, LABEL_17_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_17_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_6;
  Wrd8 = Wrd12;

DEFLABEL (label_5)
  (Rsp [2]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_17_5])), (Wrd9.pObj));

DEFLABEL (label_2)
  (Wrd8.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_18_4 3
#define LABEL_18_5 5
#define ENVIRONMENT_LABEL_18_3 12
#define DEBUGGING_LABEL_18_2 11
#define EXECUTE_CACHE_18_6 7
#define FREE_REFERENCE_18_0 10
#define FREE_REFERENCES_LABEL_18_0 6
#define NUMBER_OF_LINKER_SECTIONS_18_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_18 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_18_4);
      goto classify_subexpression_0;

    case 1:
      current_block = (Rpc - LABEL_18_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (classify_subexpression_4)
DEFLABEL (classify_subexpression_0)
  INTERRUPT_CHECK (26, LABEL_18_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_18_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_6;
  Wrd8 = Wrd12;

DEFLABEL (label_5)
  (Rsp [2]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_18_5])), (Wrd9.pObj));

DEFLABEL (label_2)
  (Wrd8.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_19_4 3
#define LABEL_19_5 5
#define ENVIRONMENT_LABEL_19_3 12
#define DEBUGGING_LABEL_19_2 11
#define EXECUTE_CACHE_19_6 7
#define FREE_REFERENCE_19_0 10
#define FREE_REFERENCES_LABEL_19_0 6
#define NUMBER_OF_LINKER_SECTIONS_19_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_19 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_19_4);
      goto classify_subexpressions_0;

    case 1:
      current_block = (Rpc - LABEL_19_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (classify_subexpressions_4)
DEFLABEL (classify_subexpressions_0)
  INTERRUPT_CHECK (26, LABEL_19_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_19_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_6;
  Wrd8 = Wrd12;

DEFLABEL (label_5)
  (Rsp [2]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_19_5])), (Wrd9.pObj));

DEFLABEL (label_2)
  (Wrd8.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_20_4 3
#define LABEL_20_5 5
#define ENVIRONMENT_LABEL_20_3 12
#define DEBUGGING_LABEL_20_2 11
#define EXECUTE_CACHE_20_7 7
#define EXECUTE_CACHE_20_6 9
#define FREE_REFERENCES_LABEL_20_0 6
#define NUMBER_OF_LINKER_SECTIONS_20_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_20 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_20_4);
      goto classify_body_1;

    case 1:
      current_block = (Rpc - LABEL_20_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (classify_body_4)
DEFLABEL (classify_body_1)
  INTERRUPT_CHECK (26, LABEL_20_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_20_5);
  (Rsp [4]) = Rvl;
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_21_4 3
#define LABEL_21_5 5
#define LABEL_21_6 7
#define LABEL_21_7 9
#define LABEL_21_8 11
#define LABEL_21_12 13
#define LABEL_21_14 15
#define LABEL_21_16 17
#define LABEL_21_18 19
#define LABEL_21_19 21
#define LABEL_21_15 23
#define LABEL_21_21 25
#define LABEL_21_22 27
#define ENVIRONMENT_LABEL_21_3 45
#define DEBUGGING_LABEL_21_2 44
#define OBJECT_21_2 43
#define OBJECT_21_1 42
#define OBJECT_21_0 41
#define EXECUTE_CACHE_21_20 29
#define EXECUTE_CACHE_21_17 31
#define EXECUTE_CACHE_21_13 33
#define EXECUTE_CACHE_21_11 35
#define EXECUTE_CACHE_21_10 37
#define EXECUTE_CACHE_21_9 39
#define FREE_REFERENCES_LABEL_21_0 28
#define NUMBER_OF_LINKER_SECTIONS_21_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_21 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd27;
  machine_word Wrd28;
  machine_word Wrd17;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd31;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd11;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_21_4);
      goto classify_body_forms_19;

    case 1:
      current_block = (Rpc - LABEL_21_5);
      goto forms_loop_17;

    case 2:
      current_block = (Rpc - LABEL_21_6);
      goto continuation_5;

    case 3:
      current_block = (Rpc - LABEL_21_7);
      goto continuation_4;

    case 4:
      current_block = (Rpc - LABEL_21_8);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_21_12);
      goto label_21;

    case 6:
      current_block = (Rpc - LABEL_21_14);
      goto items_loop_15;

    case 7:
      current_block = (Rpc - LABEL_21_16);
      goto label_23;

    case 8:
      current_block = (Rpc - LABEL_21_18);
      goto label_22;

    case 9:
      current_block = (Rpc - LABEL_21_19);
      goto continuation_9;

    case 10:
      current_block = (Rpc - LABEL_21_15);
      goto continuation_12;

    case 11:
      current_block = (Rpc - LABEL_21_21);
      goto label_25;

    case 12:
      current_block = (Rpc - LABEL_21_22);
      goto label_24;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (classify_body_forms_27)
DEFLABEL (classify_body_forms_19)
  INTERRUPT_CHECK (26, LABEL_21_4);
  (Wrd5.Obj) = (current_block [OBJECT_21_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  goto forms_loop_17;

DEFLABEL (forms_loop_28)
DEFLABEL (forms_loop_17)
  INTERRUPT_CHECK (26, LABEL_21_5);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_30;
  (Wrd7.Obj) = (Rsp [2]);
  (Rsp [7]) = (Wrd7.Obj);
  Rsp = (& (Rsp [7]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_10]));

DEFLABEL (label_30)
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_6]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_7]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_8]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd19.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_9]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_21_8);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [7]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_32;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [0]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_31)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_13]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_21_7);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_11]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_21_6);
  (* (--Rsp)) = Rvl;
  goto items_loop_15;

DEFLABEL (label_32)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_12]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_1]), 1);

DEFLABEL (label_21)
  (* (--Rsp)) = Rvl;
  goto label_31;

DEFLABEL (items_loop_29)
DEFLABEL (items_loop_15)
  INTERRUPT_CHECK (26, LABEL_21_14);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_35;
  (Wrd10.Obj) = (Rsp [2]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_34;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_33)
  (Rsp [2]) = (Wrd7.Obj);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_19]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd19.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_20]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_21_19);
  (Rsp [3]) = Rvl;
  (Wrd6.Obj) = (Rsp [1]);
  (Rsp [4]) = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  goto forms_loop_17;

DEFLABEL (label_34)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_18]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_2]), 1);

DEFLABEL (label_22)
  (Wrd7.Obj) = Rvl;
  goto label_33;

DEFLABEL (label_35)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_15]))));
  (* (--Rsp)) = (Wrd22.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_43;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [0]);
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_42)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_17]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_21_15);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_39;
  (Wrd7.Obj) = (Rsp [1]);

DEFLABEL (label_38)
  (Rsp [1]) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_37;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd8.Obj) = ((Wrd10.pObj) [1]);

DEFLABEL (label_36)
  (Rsp [0]) = (Wrd8.Obj);
  goto items_loop_15;

DEFLABEL (label_37)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_22]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_2]), 1);

DEFLABEL (label_24)
  (Wrd8.Obj) = Rvl;
  goto label_36;

DEFLABEL (label_39)
  (Wrd20.Obj) = (Rsp [0]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 1))
    goto label_41;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [0]);

DEFLABEL (label_40)
  (Wrd28.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd28.Obj);
  (Wrd27.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd27.pObj)));
  goto label_38;

DEFLABEL (label_41)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_21]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_1]), 1);

DEFLABEL (label_25)
  (Wrd17.Obj) = Rvl;
  goto label_40;

DEFLABEL (label_43)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_16]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_21_1]), 1);

DEFLABEL (label_23)
  (* (--Rsp)) = Rvl;
  goto label_42;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_22_4 3
#define LABEL_22_5 5
#define LABEL_22_7 7
#define LABEL_22_9 9
#define LABEL_22_6 11
#define LABEL_22_12 13
#define LABEL_22_13 15
#define LABEL_22_14 17
#define LABEL_22_15 19
#define LABEL_22_11 21
#define LABEL_22_16 23
#define TAG_22_17 10
#define ENVIRONMENT_LABEL_22_3 33
#define DEBUGGING_LABEL_22_2 32
#define OBJECT_22_2 31
#define OBJECT_22_1 30
#define OBJECT_22_0 29
#define EXECUTE_CACHE_22_10 25
#define EXECUTE_CACHE_22_8 27
#define FREE_REFERENCES_LABEL_22_0 24
#define NUMBER_OF_LINKER_SECTIONS_22_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_22 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd18;
  machine_word Wrd19;
  machine_word Wrd7;
  machine_word Wrd11;
  machine_word Wrd50;
  machine_word Wrd42;
  machine_word Wrd44;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd38;
  machine_word Wrd40;
  machine_word Wrd41;
  machine_word Wrd37;
  machine_word Wrd29;
  machine_word Wrd31;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd8;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_22_4);
      goto extract_declarations_from_body_16;

    case 1:
      current_block = (Rpc - LABEL_22_5);
      goto loop_14;

    case 2:
      current_block = (Rpc - LABEL_22_7);
      goto label_18;

    case 3:
      current_block = (Rpc - LABEL_22_9);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_22_6);
      goto continuation_7;

    case 5:
      current_block = (Rpc - LABEL_22_12);
      goto label_21;

    case 6:
      current_block = (Rpc - LABEL_22_13);
      goto label_22;

    case 7:
      current_block = (Rpc - LABEL_22_14);
      goto label_19;

    case 8:
      current_block = (Rpc - LABEL_22_15);
      goto label_20;

    case 9:
      current_block = (Rpc - LABEL_22_11);
      goto continuation_3;

    case 10:
      current_block = (Rpc - LABEL_22_16);
      goto lambda_26;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (extract_declarations_from_body_24)
DEFLABEL (extract_declarations_from_body_16)
  INTERRUPT_CHECK (26, LABEL_22_4);
  (Wrd5.Obj) = (current_block [OBJECT_22_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Rsp [2]) = (Wrd5.Obj);
  goto loop_14;

DEFLABEL (loop_25)
DEFLABEL (loop_14)
  INTERRUPT_CHECK (26, LABEL_22_5);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_27;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_22_9);
  (Rsp [1]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_11]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_10]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_22_11);
  (Rsp [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_22_17);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_22_16])));
  Rhp += 2;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  Wrd11 = Wrd8;
  (Wrd12.Obj) = (Rsp [1]);
  ((Wrd11.pObj) [2]) = (Wrd12.Obj);
  (Wrd10.Obj) = (Rsp [0]);
  ((Wrd11.pObj) [3]) = (Wrd10.Obj);
  Rvl = (Wrd7.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_27)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_6]))));
  (* (--Rsp)) = (Wrd13.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_38;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_37)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_8]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_22_6);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_32;
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_31;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [0]);

DEFLABEL (label_30)
  (Wrd19.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (Wrd18.pObj) = (& (Rhp [-2]));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd18.pObj)));
  (Rsp [1]) = (Wrd16.Obj);
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 1))
    goto label_29;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [1]);

DEFLABEL (label_28)
  (Rsp [0]) = (Wrd20.Obj);
  goto loop_14;

DEFLABEL (label_29)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_15]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22_2]), 1);

DEFLABEL (label_20)
  (Wrd20.Obj) = Rvl;
  goto label_28;

DEFLABEL (label_31)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_14]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22_1]), 1);

DEFLABEL (label_19)
  (Wrd7.Obj) = Rvl;
  goto label_30;

DEFLABEL (label_32)
  (Wrd32.Obj) = (Rsp [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 1))
    goto label_36;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd29.Obj) = ((Wrd31.pObj) [0]);

DEFLABEL (label_35)
  (Wrd41.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd29.Obj);
  (* (Rhp++)) = (Wrd41.Obj);
  (Wrd40.pObj) = (& (Rhp [-2]));
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd40.pObj)));
  (Rsp [2]) = (Wrd38.Obj);
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd45.Obj));
  if (! ((Wrd46.uLng) == 1))
    goto label_34;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd42.Obj) = ((Wrd44.pObj) [1]);

DEFLABEL (label_33)
  (Rsp [0]) = (Wrd42.Obj);
  goto loop_14;

DEFLABEL (label_34)
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_13]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22_2]), 1);

DEFLABEL (label_22)
  (Wrd42.Obj) = Rvl;
  goto label_33;

DEFLABEL (label_36)
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_12]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22_1]), 1);

DEFLABEL (label_21)
  (Wrd29.Obj) = Rvl;
  goto label_35;

DEFLABEL (label_38)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_7]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22_1]), 1);

DEFLABEL (label_18)
  (* (--Rsp)) = Rvl;
  goto label_37;

DEFLABEL (lambda_26)
  CLOSURE_HEADER (LABEL_22_16);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd9.Obj) = ((Wrd8.pObj) [3]);
  (Rsp [1]) = (Wrd9.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_23_4 3
#define LABEL_23_5 5
#define ENVIRONMENT_LABEL_23_3 12
#define DEBUGGING_LABEL_23_2 11
#define EXECUTE_CACHE_23_7 7
#define EXECUTE_CACHE_23_6 9
#define FREE_REFERENCES_LABEL_23_0 6
#define NUMBER_OF_LINKER_SECTIONS_23_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_23 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_23_4);
      goto strip_keyword_value_item_1;

    case 1:
      current_block = (Rpc - LABEL_23_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (strip_keyword_value_item_4)
DEFLABEL (strip_keyword_value_item_1)
  INTERRUPT_CHECK (26, LABEL_23_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_23_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_5;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_7]));

DEFLABEL (label_5)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_24_4 3
#define LABEL_24_5 5
#define LABEL_24_8 7
#define LABEL_24_7 9
#define LABEL_24_12 11
#define LABEL_24_13 13
#define LABEL_24_14 15
#define LABEL_24_15 17
#define LABEL_24_17 19
#define LABEL_24_20 21
#define LABEL_24_10 23
#define LABEL_24_18 25
#define ENVIRONMENT_LABEL_24_3 54
#define DEBUGGING_LABEL_24_2 53
#define OBJECT_24_7 52
#define OBJECT_24_6 51
#define OBJECT_24_5 50
#define OBJECT_24_4 49
#define OBJECT_24_3 48
#define OBJECT_24_2 47
#define OBJECT_24_1 46
#define OBJECT_24_0 45
#define EXECUTE_CACHE_24_23 27
#define EXECUTE_CACHE_24_22 29
#define EXECUTE_CACHE_24_21 31
#define EXECUTE_CACHE_24_19 33
#define EXECUTE_CACHE_24_16 35
#define EXECUTE_CACHE_24_11 37
#define EXECUTE_CACHE_24_9 39
#define EXECUTE_CACHE_24_6 41
#define FREE_REFERENCE_24_0 44
#define FREE_REFERENCES_LABEL_24_0 26
#define NUMBER_OF_LINKER_SECTIONS_24_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_24 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd22;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd21;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd27;
  machine_word Wrd46;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd54;
  machine_word Wrd44;
  machine_word Wrd65;
  machine_word Wrd41;
  machine_word Wrd60;
  machine_word Wrd57;
  machine_word Wrd38;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_24_4);
      goto make_syntactic_closure_13;

    case 1:
      current_block = (Rpc - LABEL_24_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_24_8);
      goto label_15;

    case 3:
      current_block = (Rpc - LABEL_24_7);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_24_12);
      goto continuation_10;

    case 5:
      current_block = (Rpc - LABEL_24_13);
      goto continuation_7;

    case 6:
      current_block = (Rpc - LABEL_24_14);
      goto continuation_8;

    case 7:
      current_block = (Rpc - LABEL_24_15);
      goto label_16;

    case 8:
      current_block = (Rpc - LABEL_24_17);
      goto continuation_4;

    case 9:
      current_block = (Rpc - LABEL_24_20);
      goto continuation_3;

    case 10:
      current_block = (Rpc - LABEL_24_10);
      goto continuation_2;

    case 11:
      current_block = (Rpc - LABEL_24_18);
      goto continuation_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_syntactic_closure_18)
DEFLABEL (make_syntactic_closure_13)
  INTERRUPT_CHECK (26, LABEL_24_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_24_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_24_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_24_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_24_1]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_24_0]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_23;
  Wrd10 = Wrd14;

DEFLABEL (label_22)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd16.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_24_7);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_24_10);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_20;

DEFLABEL (label_19)
  Rvl = (Rsp [2]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_20)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_20]))));
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_21)
  (Wrd22.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_22]));

DEFLABEL (label_23)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_24_8])), (Wrd11.pObj));

DEFLABEL (label_15)
  (Wrd10.Obj) = Rvl;
  goto label_22;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_24_20);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_24;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_17]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_21]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_24_17);
  if (! (Rvl == (current_block [OBJECT_24_7])))
    goto label_24;
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_13]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_18]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd31.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd31.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_19]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_24_18);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_23]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_24_13);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_19;

DEFLABEL (label_24)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_14]))));
  (* (--Rsp)) = (Wrd21.Obj);
  goto label_21;

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_24_14);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_26;

DEFLABEL (label_25)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_16]));

DEFLABEL (label_26)
  (Wrd34.Obj) = (Rsp [2]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if ((Wrd35.uLng) == 1)
    goto label_25;
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_12]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd57.Obj) = (current_block [OBJECT_24_2]);
  (Wrd60.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 29L) < ((unsigned long) (Wrd60.Lng))))
    goto label_33;
  (Wrd41.uLng) = (OBJECT_DATUM (Wrd57.Obj));
  if ((Wrd41.Obj) == (Wrd35.Obj))
    goto label_32;

DEFLABEL (label_31)
  (Wrd44.Obj) = (current_block [OBJECT_24_4]);
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd54.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 5L) < ((unsigned long) (Wrd54.Lng)))
    goto label_27;
  INVOKE_PRIMITIVE ((current_block [OBJECT_24_3]), 2);

DEFLABEL (label_27)
  (Wrd48.uLng) = (OBJECT_DATUM (Wrd44.Obj));
  (Wrd49.Obj) = (Rsp [1]);
  (Wrd50.uLng) = (OBJECT_TYPE (Wrd49.Obj));
  if ((Wrd48.Obj) == (Wrd50.Obj))
    goto label_29;
  (Wrd46.Obj) = (current_block [OBJECT_24_6]);
  goto label_28;

DEFLABEL (label_29)
  (Wrd46.Obj) = (current_block [OBJECT_24_5]);

DEFLABEL (label_28)
DEFLABEL (label_30)
  Rsp = (& (Rsp [3]));
  if ((Wrd46.Obj) == ((SCHEME_OBJECT) 0))
    goto label_19;
  goto label_25;

DEFLABEL (label_32)
  Rsp = (& (Rsp [2]));
  goto label_25;

DEFLABEL (label_33)
  (Wrd65.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_15]))));
  (* (--Rsp)) = (Wrd65.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd57.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_24_3]), 2);

DEFLABEL (label_16)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_31;
  goto label_32;

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_24_12);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_19;
  goto label_25;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_25_4 3
#define LABEL_25_5 5
#define LABEL_25_6 7
#define LABEL_25_8 9
#define LABEL_25_10 11
#define LABEL_25_12 13
#define LABEL_25_7 15
#define LABEL_25_14 17
#define LABEL_25_13 19
#define LABEL_25_11 21
#define LABEL_25_18 23
#define LABEL_25_15 25
#define LABEL_25_17 27
#define ENVIRONMENT_LABEL_25_3 36
#define DEBUGGING_LABEL_25_2 35
#define OBJECT_25_1 34
#define OBJECT_25_0 33
#define EXECUTE_CACHE_25_16 29
#define EXECUTE_CACHE_25_9 31
#define FREE_REFERENCES_LABEL_25_0 28
#define NUMBER_OF_LINKER_SECTIONS_25_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_25 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd10;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd13;
  machine_word Wrd18;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_25_4);
      goto strip_syntactic_closures_19;

    case 1:
      current_block = (Rpc - LABEL_25_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_25_6);
      goto loop_7;

    case 3:
      current_block = (Rpc - LABEL_25_8);
      goto label_21;

    case 4:
      current_block = (Rpc - LABEL_25_10);
      goto loop_17;

    case 5:
      current_block = (Rpc - LABEL_25_12);
      goto label_22;

    case 6:
      current_block = (Rpc - LABEL_25_7);
      goto continuation_4;

    case 7:
      current_block = (Rpc - LABEL_25_14);
      goto label_23;

    case 8:
      current_block = (Rpc - LABEL_25_13);
      goto continuation_11;

    case 9:
      current_block = (Rpc - LABEL_25_11);
      goto continuation_16;

    case 10:
      current_block = (Rpc - LABEL_25_18);
      goto label_24;

    case 11:
      current_block = (Rpc - LABEL_25_15);
      goto continuation_12;

    case 12:
      current_block = (Rpc - LABEL_25_17);
      goto continuation_14;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (strip_syntactic_closures_26)
DEFLABEL (strip_syntactic_closures_19)
  INTERRUPT_CHECK (26, LABEL_25_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  goto loop_7;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_25_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_29;
  goto loop_17;

DEFLABEL (label_29)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (loop_27)
DEFLABEL (loop_7)
  INTERRUPT_CHECK (26, LABEL_25_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_30;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_9]));

DEFLABEL (label_30)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_35;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_34)
  goto loop_7;

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_25_7);
  (* (--Rsp)) = Rvl;
  Rdl = (& (Rsp [2]));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_31;
  Rvl = Rvl;
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_31)
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_33;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [1]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_32)
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  goto loop_7;

DEFLABEL (label_33)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_14]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_25_1]), 1);

DEFLABEL (label_23)
  (Wrd13.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd13.Obj));
  (* (--Rsp)) = Rvl;
  goto label_32;

DEFLABEL (label_35)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_8]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_25_0]), 1);

DEFLABEL (label_21)
  (* (--Rsp)) = Rvl;
  goto label_34;

DEFLABEL (loop_28)
DEFLABEL (loop_17)
  INTERRUPT_CHECK (26, LABEL_25_10);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_37;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_13]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_9]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_25_13);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_36;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_36)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_15]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_16]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_25_15);
  (Rsp [0]) = Rvl;
  goto loop_17;

DEFLABEL (label_37)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_11]))));
  (* (--Rsp)) = (Wrd13.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_41;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [1]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_40)
  goto loop_17;

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_25_11);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_39;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [0]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_38)
  goto loop_17;

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_25_17);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_39)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_18]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_25_0]), 1);

DEFLABEL (label_24)
  (* (--Rsp)) = Rvl;
  goto label_38;

DEFLABEL (label_41)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_12]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_25_1]), 1);

DEFLABEL (label_22)
  (* (--Rsp)) = Rvl;
  goto label_40;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_26_4 3
#define ENVIRONMENT_LABEL_26_3 9
#define DEBUGGING_LABEL_26_2 8
#define OBJECT_26_0 7
#define EXECUTE_CACHE_26_5 5
#define FREE_REFERENCES_LABEL_26_0 4
#define NUMBER_OF_LINKER_SECTIONS_26_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_26 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_26_4);
      goto close_syntax_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (close_syntax_3)
DEFLABEL (close_syntax_0)
  INTERRUPT_CHECK (26, LABEL_26_4);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_26_0]);
  (Rsp [1]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_26_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_27_5 3
#define LABEL_27_4 5
#define LABEL_27_6 7
#define ENVIRONMENT_LABEL_27_3 17
#define DEBUGGING_LABEL_27_2 16
#define OBJECT_27_4 15
#define OBJECT_27_3 14
#define OBJECT_27_2 13
#define OBJECT_27_1 12
#define OBJECT_27_0 11
#define EXECUTE_CACHE_27_7 9
#define FREE_REFERENCES_LABEL_27_0 8
#define NUMBER_OF_LINKER_SECTIONS_27_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_27 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd24;
  machine_word Wrd30;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd23;
  machine_word Wrd13;
  machine_word Wrd39;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd34;
  machine_word Wrd31;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_27_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_27_4);
      goto identifierP_4;

    case 2:
      current_block = (Rpc - LABEL_27_6);
      goto label_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (identifierP_8)
DEFLABEL (identifierP_4)
  INTERRUPT_CHECK (26, LABEL_27_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd31.Obj) = (current_block [OBJECT_27_0]);
  (Wrd34.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 29L) < ((unsigned long) (Wrd34.Lng))))
    goto label_17;
  (Wrd10.uLng) = (OBJECT_DATUM (Wrd31.Obj));
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd10.Obj) == (Wrd12.Obj))
    goto label_16;

DEFLABEL (label_15)
  (Wrd13.Obj) = (current_block [OBJECT_27_2]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd23.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 5L) < ((unsigned long) (Wrd23.Lng)))
    goto label_9;
  INVOKE_PRIMITIVE ((current_block [OBJECT_27_1]), 2);

DEFLABEL (label_9)
  (Wrd17.uLng) = (OBJECT_DATUM (Wrd13.Obj));
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd17.Obj) == (Wrd19.Obj))
    goto label_11;
  (Wrd15.Obj) = (current_block [OBJECT_27_4]);
  goto label_10;

DEFLABEL (label_11)
  (Wrd15.Obj) = (current_block [OBJECT_27_3]);

DEFLABEL (label_10)
DEFLABEL (label_14)
  Rsp = (& (Rsp [3]));
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_13)
  (Wrd24.Obj) = (Rsp [0]);
  if ((Wrd24.Obj) == ((SCHEME_OBJECT) 0))
    goto label_12;
  Rvl = (Wrd24.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_12)
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_7]));

DEFLABEL (label_16)
  (Wrd30.Obj) = (current_block [OBJECT_27_3]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd30.Obj);
  goto label_13;

DEFLABEL (label_17)
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_6]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd31.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_27_1]), 2);

DEFLABEL (label_6)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_15;
  goto label_16;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_27_5);
  (* (--Rsp)) = Rvl;
  goto label_13;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_28_4 3
#define LABEL_28_5 5
#define LABEL_28_7 7
#define ENVIRONMENT_LABEL_28_3 16
#define DEBUGGING_LABEL_28_2 15
#define EXECUTE_CACHE_28_9 9
#define EXECUTE_CACHE_28_8 11
#define EXECUTE_CACHE_28_6 13
#define FREE_REFERENCES_LABEL_28_0 8
#define NUMBER_OF_LINKER_SECTIONS_28_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_28 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_28_4);
      goto synthetic_identifierP_2;

    case 1:
      current_block = (Rpc - LABEL_28_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_28_7);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (synthetic_identifierP_5)
DEFLABEL (synthetic_identifierP_2)
  INTERRUPT_CHECK (26, LABEL_28_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_28_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_28_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_6;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_6)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_28_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_28_7);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_28_9]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_29_4 3
#define LABEL_29_5 5
#define ENVIRONMENT_LABEL_29_3 12
#define DEBUGGING_LABEL_29_2 11
#define EXECUTE_CACHE_29_6 7
#define FREE_REFERENCE_29_0 10
#define FREE_REFERENCES_LABEL_29_0 6
#define NUMBER_OF_LINKER_SECTIONS_29_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_29 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_29_4);
      goto make_synthetic_identifier_0;

    case 1:
      current_block = (Rpc - LABEL_29_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_synthetic_identifier_4)
DEFLABEL (make_synthetic_identifier_0)
  INTERRUPT_CHECK (26, LABEL_29_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_29_0]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_6;
  Wrd7 = Wrd11;

DEFLABEL (label_5)
  (Rsp [1]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_29_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_29_5])), (Wrd8.pObj));

DEFLABEL (label_2)
  (Wrd7.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_30_4 3
#define LABEL_30_5 5
#define LABEL_30_8 7
#define LABEL_30_6 9
#define LABEL_30_9 11
#define LABEL_30_11 13
#define ENVIRONMENT_LABEL_30_3 29
#define DEBUGGING_LABEL_30_2 28
#define OBJECT_30_6 27
#define OBJECT_30_5 26
#define OBJECT_30_4 25
#define OBJECT_30_3 24
#define OBJECT_30_2 23
#define OBJECT_30_1 22
#define OBJECT_30_0 21
#define EXECUTE_CACHE_30_12 15
#define EXECUTE_CACHE_30_10 17
#define EXECUTE_CACHE_30_7 19
#define FREE_REFERENCES_LABEL_30_0 14
#define NUMBER_OF_LINKER_SECTIONS_30_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_30 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd33;
  machine_word Wrd41;
  machine_word Wrd21;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd29;
  machine_word Wrd19;
  machine_word Wrd51;
  machine_word Wrd18;
  machine_word Wrd16;
  machine_word Wrd46;
  machine_word Wrd43;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_30_4);
      goto identifier__symbol_10;

    case 1:
      current_block = (Rpc - LABEL_30_5);
      goto loop_7;

    case 2:
      current_block = (Rpc - LABEL_30_8);
      goto continuation_3;

    case 3:
      current_block = (Rpc - LABEL_30_6);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_30_9);
      goto label_12;

    case 5:
      current_block = (Rpc - LABEL_30_11);
      goto continuation_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (identifier__symbol_14)
DEFLABEL (identifier__symbol_10)
  INTERRUPT_CHECK (26, LABEL_30_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_7;

DEFLABEL (loop_15)
DEFLABEL (loop_7)
  INTERRUPT_CHECK (26, LABEL_30_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_7]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_30_6);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_16;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_11]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_12]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_30_11);
  (Rsp [0]) = Rvl;
  goto loop_7;

DEFLABEL (label_16)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_8]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd43.Obj) = (current_block [OBJECT_30_0]);
  (Wrd46.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 29L) < ((unsigned long) (Wrd46.Lng))))
    goto label_28;
  (Wrd16.uLng) = (OBJECT_DATUM (Wrd43.Obj));
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd16.Obj) == (Wrd18.Obj))
    goto label_27;

DEFLABEL (label_26)
  (Wrd19.Obj) = (current_block [OBJECT_30_2]);
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd29.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 5L) < ((unsigned long) (Wrd29.Lng)))
    goto label_17;
  INVOKE_PRIMITIVE ((current_block [OBJECT_30_1]), 2);

DEFLABEL (label_17)
  (Wrd23.uLng) = (OBJECT_DATUM (Wrd19.Obj));
  (Wrd24.Obj) = (Rsp [1]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd23.Obj) == (Wrd25.Obj))
    goto label_19;
  (Wrd21.Obj) = (current_block [OBJECT_30_4]);
  goto label_18;

DEFLABEL (label_19)
  (Wrd21.Obj) = (current_block [OBJECT_30_3]);

DEFLABEL (label_18)
DEFLABEL (label_25)
  Rsp = (& (Rsp [3]));
  if ((Wrd21.Obj) == ((SCHEME_OBJECT) 0))
    goto label_21;

DEFLABEL (label_22)
  (Wrd41.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd41.Obj);
  goto label_20;

DEFLABEL (label_21)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_20)
DEFLABEL (label_24)
  (Wrd33.Obj) = (Rsp [0]);
  if ((Wrd33.Obj) == ((SCHEME_OBJECT) 0))
    goto label_23;
  Rvl = (Wrd33.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_23)
  (Wrd37.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd38.Obj) = (current_block [OBJECT_30_5]);
  (Rsp [1]) = (Wrd38.Obj);
  (Wrd39.Obj) = (current_block [OBJECT_30_6]);
  (Rsp [2]) = (Wrd39.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_10]));

DEFLABEL (label_27)
  Rsp = (& (Rsp [2]));
  goto label_22;

DEFLABEL (label_28)
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_9]))));
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_30_1]), 2);

DEFLABEL (label_12)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_26;
  goto label_27;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_30_8);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_21;
  goto label_22;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_31_4 3
#define LABEL_31_5 5
#define LABEL_31_7 7
#define LABEL_31_8 9
#define LABEL_31_10 11
#define LABEL_31_12 13
#define LABEL_31_13 15
#define LABEL_31_15 17
#define ENVIRONMENT_LABEL_31_3 29
#define DEBUGGING_LABEL_31_2 28
#define OBJECT_31_0 27
#define EXECUTE_CACHE_31_14 19
#define EXECUTE_CACHE_31_11 21
#define EXECUTE_CACHE_31_9 23
#define EXECUTE_CACHE_31_6 25
#define FREE_REFERENCES_LABEL_31_0 18
#define NUMBER_OF_LINKER_SECTIONS_31_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_31 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_31_4);
      goto identifier_P_9;

    case 1:
      current_block = (Rpc - LABEL_31_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_31_7);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_31_8);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_31_10);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_31_12);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_31_13);
      goto continuation_6;

    case 7:
      current_block = (Rpc - LABEL_31_15);
      goto continuation_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (identifier_P_12)
DEFLABEL (identifier_P_9)
  INTERRUPT_CHECK (26, LABEL_31_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_6]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_31_5);
  (Rsp [3]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_7]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_31_7);
  (Rsp [2]) = Rvl;
  Rsp = (& (Rsp [2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_8]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_31_8);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_13;
  Rvl = Rvl;
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_13)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_10]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_31_10);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_14;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_14)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_12]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_11]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_31_12);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_15;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_15)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_13]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_14]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_31_13);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_15]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_14]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_31_15);
  (Wrd5.Obj) = (* (Rsp++));
  if (Rvl == (Wrd5.Obj))
    goto label_17;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_16;

DEFLABEL (label_17)
  Rvl = (current_block [OBJECT_31_0]);

DEFLABEL (label_16)
DEFLABEL (label_18)
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_32_4 3
#define LABEL_32_5 5
#define LABEL_32_7 7
#define LABEL_32_9 9
#define LABEL_32_11 11
#define ENVIRONMENT_LABEL_32_3 24
#define DEBUGGING_LABEL_32_2 23
#define EXECUTE_CACHE_32_13 13
#define EXECUTE_CACHE_32_12 15
#define EXECUTE_CACHE_32_10 17
#define EXECUTE_CACHE_32_8 19
#define EXECUTE_CACHE_32_6 21
#define FREE_REFERENCES_LABEL_32_0 12
#define NUMBER_OF_LINKER_SECTIONS_32_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_32 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_32_4);
      goto syntactic_environmentP_8;

    case 1:
      current_block = (Rpc - LABEL_32_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_32_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_32_9);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_32_11);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (syntactic_environmentP_11)
DEFLABEL (syntactic_environmentP_8)
  INTERRUPT_CHECK (26, LABEL_32_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_32_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_32_5);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_12;
  Rvl = Rvl;
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_12)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32_7]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_32_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_32_7);
  (Rsp [0]) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_13;
  Rvl = Rvl;
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_13)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32_9]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_32_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_32_9);
  (Rsp [0]) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_14;
  Rvl = Rvl;
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_14)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32_11]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_32_12]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_32_11);
  (Rsp [0]) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_15;
  Rvl = Rvl;
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_15)
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_32_13]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_33_4 3
#define LABEL_33_5 5
#define ENVIRONMENT_LABEL_33_3 14
#define DEBUGGING_LABEL_33_2 13
#define OBJECT_33_1 12
#define OBJECT_33_0 11
#define EXECUTE_CACHE_33_7 7
#define EXECUTE_CACHE_33_6 9
#define FREE_REFERENCES_LABEL_33_0 6
#define NUMBER_OF_LINKER_SECTIONS_33_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_33 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_33_4);
      goto guarantee_syntactic_environment_1;

    case 1:
      current_block = (Rpc - LABEL_33_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_syntactic_environment_4)
DEFLABEL (guarantee_syntactic_environment_1)
  INTERRUPT_CHECK (26, LABEL_33_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_33_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_5;
  Rvl = (current_block [OBJECT_33_1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_5)
  (Wrd9.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_33_0]);
  (Rsp [1]) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_34_4 3
#define LABEL_34_5 5
#define ENVIRONMENT_LABEL_34_3 12
#define DEBUGGING_LABEL_34_2 11
#define EXECUTE_CACHE_34_7 7
#define EXECUTE_CACHE_34_6 9
#define FREE_REFERENCES_LABEL_34_0 6
#define NUMBER_OF_LINKER_SECTIONS_34_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_34 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_34_4);
      goto syntactic_environment_top_levelP_2;

    case 1:
      current_block = (Rpc - LABEL_34_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (syntactic_environment_top_levelP_5)
DEFLABEL (syntactic_environment_top_levelP_2)
  INTERRUPT_CHECK (26, LABEL_34_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_34_5);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_6;
  Rvl = Rvl;
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_6)
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_35_4 3
#define LABEL_35_7 5
#define LABEL_35_5 7
#define LABEL_35_8 9
#define LABEL_35_12 11
#define LABEL_35_9 13
#define LABEL_35_14 15
#define LABEL_35_17 17
#define LABEL_35_20 19
#define ENVIRONMENT_LABEL_35_3 50
#define DEBUGGING_LABEL_35_2 49
#define OBJECT_35_7 48
#define OBJECT_35_6 47
#define OBJECT_35_5 46
#define OBJECT_35_4 45
#define OBJECT_35_3 44
#define OBJECT_35_2 43
#define OBJECT_35_1 42
#define OBJECT_35_0 41
#define EXECUTE_CACHE_35_22 21
#define EXECUTE_CACHE_35_21 23
#define EXECUTE_CACHE_35_19 25
#define EXECUTE_CACHE_35_18 27
#define EXECUTE_CACHE_35_16 29
#define EXECUTE_CACHE_35_15 31
#define EXECUTE_CACHE_35_13 33
#define EXECUTE_CACHE_35_11 35
#define EXECUTE_CACHE_35_10 37
#define EXECUTE_CACHE_35_6 39
#define FREE_REFERENCES_LABEL_35_0 20
#define NUMBER_OF_LINKER_SECTIONS_35_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_35 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd21;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd29;
  machine_word Wrd19;
  machine_word Wrd45;
  machine_word Wrd18;
  machine_word Wrd16;
  machine_word Wrd40;
  machine_word Wrd37;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_35_4);
      goto lookup_identifier_10;

    case 1:
      current_block = (Rpc - LABEL_35_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_35_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_35_8);
      goto label_12;

    case 4:
      current_block = (Rpc - LABEL_35_12);
      goto continuation_7;

    case 5:
      current_block = (Rpc - LABEL_35_9);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_35_14);
      goto continuation_8;

    case 7:
      current_block = (Rpc - LABEL_35_17);
      goto continuation_5;

    case 8:
      current_block = (Rpc - LABEL_35_20);
      goto continuation_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lookup_identifier_14)
DEFLABEL (lookup_identifier_10)
  INTERRUPT_CHECK (26, LABEL_35_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_35_5);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_16;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_12]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_13]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_35_12);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_15;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_15)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_14]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_15]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_35_14);
  (Rsp [0]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_35_7]);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_19]));

DEFLABEL (label_16)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_7]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd37.Obj) = (current_block [OBJECT_35_0]);
  (Wrd40.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 29L) < ((unsigned long) (Wrd40.Lng))))
    goto label_26;
  (Wrd16.uLng) = (OBJECT_DATUM (Wrd37.Obj));
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd16.Obj) == (Wrd18.Obj))
    goto label_25;

DEFLABEL (label_24)
  (Wrd19.Obj) = (current_block [OBJECT_35_2]);
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd29.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 5L) < ((unsigned long) (Wrd29.Lng)))
    goto label_17;
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_1]), 2);

DEFLABEL (label_17)
  (Wrd23.uLng) = (OBJECT_DATUM (Wrd19.Obj));
  (Wrd24.Obj) = (Rsp [1]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd23.Obj) == (Wrd25.Obj))
    goto label_19;
  (Wrd21.Obj) = (current_block [OBJECT_35_4]);
  goto label_18;

DEFLABEL (label_19)
  (Wrd21.Obj) = (current_block [OBJECT_35_3]);

DEFLABEL (label_18)
DEFLABEL (label_23)
  Rsp = (& (Rsp [3]));
  if ((Wrd21.Obj) == ((SCHEME_OBJECT) 0))
    goto label_21;

DEFLABEL (label_20)
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_11]));

DEFLABEL (label_21)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_9]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd34.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_10]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_35_9);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_22;
  (Wrd11.Obj) = (Rsp [2]);
  (Rsp [0]) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_35_5]);
  (Rsp [1]) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_35_6]);
  (Rsp [2]) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_16]));

DEFLABEL (label_22)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_17]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_18]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_35_17);
  (Rsp [1]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_20]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_21]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_35_20);
  (Rsp [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_22]));

DEFLABEL (label_25)
  Rsp = (& (Rsp [2]));
  goto label_20;

DEFLABEL (label_26)
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_8]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_1]), 2);

DEFLABEL (label_12)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_24;
  goto label_25;

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_35_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_21;
  goto label_20;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_36_4 3
#define LABEL_36_5 5
#define LABEL_36_7 7
#define LABEL_36_13 9
#define LABEL_36_10 11
#define LABEL_36_16 13
#define LABEL_36_14 15
#define LABEL_36_18 17
#define ENVIRONMENT_LABEL_36_3 49
#define DEBUGGING_LABEL_36_2 48
#define OBJECT_36_6 47
#define OBJECT_36_5 46
#define OBJECT_36_4 45
#define OBJECT_36_3 44
#define OBJECT_36_2 43
#define OBJECT_36_1 42
#define OBJECT_36_0 41
#define EXECUTE_CACHE_36_22 19
#define EXECUTE_CACHE_36_21 21
#define EXECUTE_CACHE_36_20 23
#define EXECUTE_CACHE_36_19 25
#define EXECUTE_CACHE_36_17 27
#define EXECUTE_CACHE_36_15 29
#define EXECUTE_CACHE_36_12 31
#define EXECUTE_CACHE_36_11 33
#define EXECUTE_CACHE_36_9 35
#define EXECUTE_CACHE_36_8 37
#define EXECUTE_CACHE_36_6 39
#define FREE_REFERENCES_LABEL_36_0 18
#define NUMBER_OF_LINKER_SECTIONS_36_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_36 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd17;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd25;
  machine_word Wrd15;
  machine_word Wrd38;
  machine_word Wrd14;
  machine_word Wrd12;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_36_4);
      goto syntactic_environment_lookup_8;

    case 1:
      current_block = (Rpc - LABEL_36_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_36_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_36_13);
      goto continuation_5;

    case 4:
      current_block = (Rpc - LABEL_36_10);
      goto continuation_2;

    case 5:
      current_block = (Rpc - LABEL_36_16);
      goto label_10;

    case 6:
      current_block = (Rpc - LABEL_36_14);
      goto continuation_3;

    case 7:
      current_block = (Rpc - LABEL_36_18);
      goto continuation_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (syntactic_environment_lookup_12)
DEFLABEL (syntactic_environment_lookup_8)
  INTERRUPT_CHECK (26, LABEL_36_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_36_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_13;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_9]));

DEFLABEL (label_13)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_36_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_14;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_12]));

DEFLABEL (label_14)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_10]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_36_10);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_17;
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_14]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (Wrd43.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd43.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_15]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_36_14);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_15;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_20]));

DEFLABEL (label_15)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_18]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_19]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_36_18);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_16;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_22]));

DEFLABEL (label_16)
  (Wrd7.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_36_5]);
  (Rsp [1]) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_36_6]);
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_21]));

DEFLABEL (label_17)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_13]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_36_0]);
  (Wrd33.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 29L) < ((unsigned long) (Wrd33.Lng))))
    goto label_26;
  (Wrd12.uLng) = (OBJECT_DATUM (Wrd30.Obj));
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd12.Obj) == (Wrd14.Obj))
    goto label_25;

DEFLABEL (label_24)
  (Wrd15.Obj) = (current_block [OBJECT_36_2]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd25.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 5L) < ((unsigned long) (Wrd25.Lng)))
    goto label_18;
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_1]), 2);

DEFLABEL (label_18)
  (Wrd19.uLng) = (OBJECT_DATUM (Wrd15.Obj));
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd19.Obj) == (Wrd21.Obj))
    goto label_20;
  (Wrd17.Obj) = (current_block [OBJECT_36_4]);
  goto label_19;

DEFLABEL (label_20)
  (Wrd17.Obj) = (current_block [OBJECT_36_3]);

DEFLABEL (label_19)
DEFLABEL (label_23)
  Rsp = (& (Rsp [3]));
  if ((Wrd17.Obj) == ((SCHEME_OBJECT) 0))
    goto label_22;

DEFLABEL (label_21)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_17]));

DEFLABEL (label_22)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_25)
  Rsp = (& (Rsp [2]));
  goto label_21;

DEFLABEL (label_26)
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_16]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_36_1]), 2);

DEFLABEL (label_10)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_24;
  goto label_25;

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_36_13);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_22;
  goto label_21;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_37_4 3
#define LABEL_37_5 5
#define LABEL_37_7 7
#define LABEL_37_10 9
#define LABEL_37_13 11
#define LABEL_37_16 13
#define ENVIRONMENT_LABEL_37_3 40
#define DEBUGGING_LABEL_37_2 39
#define OBJECT_37_1 38
#define OBJECT_37_0 37
#define EXECUTE_CACHE_37_20 15
#define EXECUTE_CACHE_37_19 17
#define EXECUTE_CACHE_37_18 19
#define EXECUTE_CACHE_37_17 21
#define EXECUTE_CACHE_37_15 23
#define EXECUTE_CACHE_37_14 25
#define EXECUTE_CACHE_37_12 27
#define EXECUTE_CACHE_37_11 29
#define EXECUTE_CACHE_37_9 31
#define EXECUTE_CACHE_37_8 33
#define EXECUTE_CACHE_37_6 35
#define FREE_REFERENCES_LABEL_37_0 14
#define NUMBER_OF_LINKER_SECTIONS_37_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_37 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_37_4);
      goto syntactic_environment_define_5;

    case 1:
      current_block = (Rpc - LABEL_37_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_37_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_37_10);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_37_13);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_37_16);
      goto continuation_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (syntactic_environment_define_8)
DEFLABEL (syntactic_environment_define_5)
  INTERRUPT_CHECK (26, LABEL_37_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_37_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_9;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_9]));

DEFLABEL (label_9)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_37_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_10;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_12]));

DEFLABEL (label_10)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_10]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_37_10);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_11;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_15]));

DEFLABEL (label_11)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_13]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_14]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_37_13);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_12;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_18]));

DEFLABEL (label_12)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_16]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_17]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_37_16);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_13;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_20]));

DEFLABEL (label_13)
  (Wrd7.Obj) = (current_block [OBJECT_37_0]);
  (Rsp [1]) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_37_1]);
  (Rsp [2]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_19]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_38_4 3
#define LABEL_38_5 5
#define LABEL_38_7 7
#define LABEL_38_10 9
#define LABEL_38_13 11
#define LABEL_38_16 13
#define ENVIRONMENT_LABEL_38_3 40
#define DEBUGGING_LABEL_38_2 39
#define OBJECT_38_1 38
#define OBJECT_38_0 37
#define EXECUTE_CACHE_38_20 15
#define EXECUTE_CACHE_38_19 17
#define EXECUTE_CACHE_38_18 19
#define EXECUTE_CACHE_38_17 21
#define EXECUTE_CACHE_38_15 23
#define EXECUTE_CACHE_38_14 25
#define EXECUTE_CACHE_38_12 27
#define EXECUTE_CACHE_38_11 29
#define EXECUTE_CACHE_38_9 31
#define EXECUTE_CACHE_38_8 33
#define EXECUTE_CACHE_38_6 35
#define FREE_REFERENCES_LABEL_38_0 14
#define NUMBER_OF_LINKER_SECTIONS_38_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_38 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_38_4);
      goto syntactic_environment_rename_5;

    case 1:
      current_block = (Rpc - LABEL_38_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_38_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_38_10);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_38_13);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_38_16);
      goto continuation_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (syntactic_environment_rename_8)
DEFLABEL (syntactic_environment_rename_5)
  INTERRUPT_CHECK (26, LABEL_38_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_38_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_9;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_9]));

DEFLABEL (label_9)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_38_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_10;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_12]));

DEFLABEL (label_10)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_10]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_38_10);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_11;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_15]));

DEFLABEL (label_11)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_13]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_14]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_38_13);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_12;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_18]));

DEFLABEL (label_12)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_16]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_17]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_38_16);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_13;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_20]));

DEFLABEL (label_13)
  (Wrd7.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_38_0]);
  (Rsp [1]) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_38_1]);
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_19]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_39_4 3
#define LABEL_39_5 5
#define LABEL_39_7 7
#define LABEL_39_10 9
#define LABEL_39_13 11
#define LABEL_39_15 13
#define ENVIRONMENT_LABEL_39_3 38
#define DEBUGGING_LABEL_39_2 37
#define OBJECT_39_1 36
#define OBJECT_39_0 35
#define EXECUTE_CACHE_39_19 15
#define EXECUTE_CACHE_39_18 17
#define EXECUTE_CACHE_39_17 19
#define EXECUTE_CACHE_39_16 21
#define EXECUTE_CACHE_39_14 23
#define EXECUTE_CACHE_39_12 25
#define EXECUTE_CACHE_39_11 27
#define EXECUTE_CACHE_39_9 29
#define EXECUTE_CACHE_39_8 31
#define EXECUTE_CACHE_39_6 33
#define FREE_REFERENCES_LABEL_39_0 14
#define NUMBER_OF_LINKER_SECTIONS_39_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_39 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_39_4);
      goto syntactic_environment__environment_5;

    case 1:
      current_block = (Rpc - LABEL_39_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_39_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_39_10);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_39_13);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_39_15);
      goto continuation_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (syntactic_environment__environment_8)
DEFLABEL (syntactic_environment__environment_5)
  INTERRUPT_CHECK (26, LABEL_39_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_39_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_9;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_9]));

DEFLABEL (label_9)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_39_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_10;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_12]));

DEFLABEL (label_10)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39_10]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_39_10);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_11;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_11)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39_13]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_14]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_39_13);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_12;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_17]));

DEFLABEL (label_12)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39_15]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_16]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_39_15);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_13;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_19]));

DEFLABEL (label_13)
  (Wrd7.Obj) = (current_block [OBJECT_39_0]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_39_1]);
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_18]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_40_4 3
#define ENVIRONMENT_LABEL_40_3 9
#define DEBUGGING_LABEL_40_2 8
#define OBJECT_40_0 7
#define EXECUTE_CACHE_40_5 5
#define FREE_REFERENCES_LABEL_40_0 4
#define NUMBER_OF_LINKER_SECTIONS_40_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_40 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_40_4);
      goto null_syntactic_environment_lookup_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (null_syntactic_environment_lookup_3)
DEFLABEL (null_syntactic_environment_lookup_0)
  INTERRUPT_CHECK (26, LABEL_40_4);
  (Wrd5.Obj) = (current_block [OBJECT_40_0]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_41_4 3
#define ENVIRONMENT_LABEL_41_3 9
#define DEBUGGING_LABEL_41_2 8
#define OBJECT_41_0 7
#define EXECUTE_CACHE_41_5 5
#define FREE_REFERENCES_LABEL_41_0 4
#define NUMBER_OF_LINKER_SECTIONS_41_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_41 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_41_4);
      goto null_syntactic_environment_define_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (null_syntactic_environment_define_3)
DEFLABEL (null_syntactic_environment_define_0)
  INTERRUPT_CHECK (26, LABEL_41_4);
  (Wrd5.Obj) = (current_block [OBJECT_41_0]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_42_4 3
#define ENVIRONMENT_LABEL_42_3 9
#define DEBUGGING_LABEL_42_2 8
#define OBJECT_42_0 7
#define EXECUTE_CACHE_42_5 5
#define FREE_REFERENCES_LABEL_42_0 4
#define NUMBER_OF_LINKER_SECTIONS_42_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_42 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_42_4);
      goto null_syntactic_environment_rename_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (null_syntactic_environment_rename_3)
DEFLABEL (null_syntactic_environment_rename_0)
  INTERRUPT_CHECK (26, LABEL_42_4);
  (Wrd5.Obj) = (current_block [OBJECT_42_0]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_43_4 3
#define ENVIRONMENT_LABEL_43_3 9
#define DEBUGGING_LABEL_43_2 8
#define OBJECT_43_0 7
#define EXECUTE_CACHE_43_5 5
#define FREE_REFERENCES_LABEL_43_0 4
#define NUMBER_OF_LINKER_SECTIONS_43_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_43 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_43_4);
      goto null_syntactic_environment__environment_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (null_syntactic_environment__environment_3)
DEFLABEL (null_syntactic_environment__environment_0)
  INTERRUPT_CHECK (26, LABEL_43_4);
  (Wrd5.Obj) = (current_block [OBJECT_43_0]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_44_4 3
#define LABEL_44_5 5
#define LABEL_44_7 7
#define LABEL_44_9 9
#define ENVIRONMENT_LABEL_44_3 23
#define DEBUGGING_LABEL_44_2 22
#define OBJECT_44_0 21
#define EXECUTE_CACHE_44_12 11
#define EXECUTE_CACHE_44_11 13
#define EXECUTE_CACHE_44_10 15
#define EXECUTE_CACHE_44_8 17
#define EXECUTE_CACHE_44_6 19
#define FREE_REFERENCES_LABEL_44_0 10
#define NUMBER_OF_LINKER_SECTIONS_44_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_44 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd13;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_44_4);
      goto environment_lookup_4;

    case 1:
      current_block = (Rpc - LABEL_44_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_44_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_44_9);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (environment_lookup_7)
DEFLABEL (environment_lookup_4)
  INTERRUPT_CHECK (26, LABEL_44_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_44_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_44_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_44_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_44_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_9;

DEFLABEL (label_8)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_9)
  (Wrd9.Obj) = (Rsp [0]);
  if ((Wrd9.Obj) == ((SCHEME_OBJECT) 0))
    goto label_8;
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_9]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_44_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_44_9);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_10;
  (Wrd7.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd8.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_44_12]));

DEFLABEL (label_10)
  (Wrd10.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_44_0]);
  (Rsp [2]) = (Wrd11.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_44_11]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_45_4 3
#define ENVIRONMENT_LABEL_45_3 8
#define DEBUGGING_LABEL_45_2 7
#define EXECUTE_CACHE_45_5 5
#define FREE_REFERENCES_LABEL_45_0 4
#define NUMBER_OF_LINKER_SECTIONS_45_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_45 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_45_4);
      goto environment_define_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (environment_define_3)
DEFLABEL (environment_define_0)
  INTERRUPT_CHECK (26, LABEL_45_4);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_46_4 3
#define ENVIRONMENT_LABEL_46_3 8
#define DEBUGGING_LABEL_46_2 7
#define EXECUTE_CACHE_46_5 5
#define FREE_REFERENCES_LABEL_46_0 4
#define NUMBER_OF_LINKER_SECTIONS_46_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_46 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_46_4);
      goto environment_rename_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (environment_rename_3)
DEFLABEL (environment_rename_0)
  INTERRUPT_CHECK (26, LABEL_46_4);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_47_4 3
#define LABEL_47_5 5
#define LABEL_47_9 7
#define LABEL_47_10 9
#define LABEL_47_7 11
#define ENVIRONMENT_LABEL_47_3 27
#define DEBUGGING_LABEL_47_2 26
#define OBJECT_47_2 25
#define OBJECT_47_1 24
#define OBJECT_47_0 23
#define EXECUTE_CACHE_47_13 13
#define EXECUTE_CACHE_47_12 15
#define EXECUTE_CACHE_47_11 17
#define EXECUTE_CACHE_47_8 19
#define EXECUTE_CACHE_47_6 21
#define FREE_REFERENCES_LABEL_47_0 12
#define NUMBER_OF_LINKER_SECTIONS_47_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_47 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_47_4);
      goto make_top_level_syntactic_environment_4;

    case 1:
      current_block = (Rpc - LABEL_47_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_47_9);
      goto continuation_3;

    case 3:
      current_block = (Rpc - LABEL_47_10);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_47_7);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_top_level_syntactic_environment_7)
DEFLABEL (make_top_level_syntactic_environment_4)
  INTERRUPT_CHECK (26, LABEL_47_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_47_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_47_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_47_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_9;

DEFLABEL (label_8)
  (Wrd7.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_47_2]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_13]));

DEFLABEL (label_9)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_10]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_12]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_47_10);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_8;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_9]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (current_block [OBJECT_47_0]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (current_block [OBJECT_47_1]);
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_47_9);
  goto label_8;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_48_4 3
#define LABEL_48_5 5
#define LABEL_48_6 7
#define LABEL_48_8 9
#define ENVIRONMENT_LABEL_48_3 21
#define DEBUGGING_LABEL_48_2 20
#define OBJECT_48_0 19
#define EXECUTE_CACHE_48_11 11
#define EXECUTE_CACHE_48_10 13
#define EXECUTE_CACHE_48_9 15
#define EXECUTE_CACHE_48_7 17
#define FREE_REFERENCES_LABEL_48_0 10
#define NUMBER_OF_LINKER_SECTIONS_48_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_48 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_48_4);
      goto top_level_syntactic_environment_lookup_4;

    case 1:
      current_block = (Rpc - LABEL_48_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_48_6);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_48_8);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (top_level_syntactic_environment_lookup_7)
DEFLABEL (top_level_syntactic_environment_lookup_4)
  INTERRUPT_CHECK (26, LABEL_48_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_48_6);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_10]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_48_5);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_8;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_8]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_48_8);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_11]));

DEFLABEL (label_8)
  (Rsp [2]) = Rvl;
  Rsp = (& (Rsp [2]));
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_9;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  Rvl = ((Wrd10.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_9)
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_49_4 3
#define LABEL_49_5 5
#define LABEL_49_7 7
#define ENVIRONMENT_LABEL_49_3 18
#define DEBUGGING_LABEL_49_2 17
#define OBJECT_49_1 16
#define OBJECT_49_0 15
#define EXECUTE_CACHE_49_9 9
#define EXECUTE_CACHE_49_8 11
#define EXECUTE_CACHE_49_6 13
#define FREE_REFERENCES_LABEL_49_0 8
#define NUMBER_OF_LINKER_SECTIONS_49_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_49 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd25;
  machine_word Wrd21;
  machine_word Wrd23;
  machine_word Wrd24;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_49_4);
      goto top_level_syntactic_environment_define_6;

    case 1:
      current_block = (Rpc - LABEL_49_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_49_7);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (top_level_syntactic_environment_define_9)
DEFLABEL (top_level_syntactic_environment_define_6)
  INTERRUPT_CHECK (26, LABEL_49_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_49_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_49_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_49_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_49_7);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_10;
  (Wrd19.Obj) = (Rsp [3]);
  (Wrd20.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd20.Obj);
  (Wrd18.pObj) = (& (Rhp [-2]));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd18.pObj)));
  (Wrd24.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd24.Obj);
  (Wrd23.pObj) = (& (Rhp [-2]));
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd23.pObj)));
  (Rsp [4]) = (Wrd21.Obj);
  (Wrd25.Obj) = (Rsp [2]);
  (Rsp [3]) = (Wrd25.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_49_9]));

DEFLABEL (label_10)
  (Rsp [3]) = Rvl;
  Rsp = (& (Rsp [3]));
  (Wrd13.Obj) = (Rsp [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_11;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [1]) = (Wrd11.Obj);
  Rvl = (current_block [OBJECT_49_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_11)
  INVOKE_PRIMITIVE ((current_block [OBJECT_49_1]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_50_4 3
#define ENVIRONMENT_LABEL_50_3 8
#define DEBUGGING_LABEL_50_2 7
#define EXECUTE_CACHE_50_5 5
#define FREE_REFERENCES_LABEL_50_0 4
#define NUMBER_OF_LINKER_SECTIONS_50_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_50 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_50_4);
      goto top_level_syntactic_environment_rename_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (top_level_syntactic_environment_rename_3)
DEFLABEL (top_level_syntactic_environment_rename_0)
  INTERRUPT_CHECK (26, LABEL_50_4);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_50_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_51_4 3
#define LABEL_51_5 5
#define ENVIRONMENT_LABEL_51_3 12
#define DEBUGGING_LABEL_51_2 11
#define EXECUTE_CACHE_51_7 7
#define EXECUTE_CACHE_51_6 9
#define FREE_REFERENCES_LABEL_51_0 6
#define NUMBER_OF_LINKER_SECTIONS_51_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_51 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_51_4);
      goto top_level_syntactic_environment__environment_1;

    case 1:
      current_block = (Rpc - LABEL_51_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (top_level_syntactic_environment__environment_4)
DEFLABEL (top_level_syntactic_environment__environment_1)
  INTERRUPT_CHECK (26, LABEL_51_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_51_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_51_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_51_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_52_4 3
#define LABEL_52_5 5
#define LABEL_52_7 7
#define ENVIRONMENT_LABEL_52_3 18
#define DEBUGGING_LABEL_52_2 17
#define OBJECT_52_1 16
#define OBJECT_52_0 15
#define EXECUTE_CACHE_52_9 9
#define EXECUTE_CACHE_52_8 11
#define EXECUTE_CACHE_52_6 13
#define FREE_REFERENCES_LABEL_52_0 8
#define NUMBER_OF_LINKER_SECTIONS_52_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_52 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_52_4);
      goto make_internal_syntactic_environment_2;

    case 1:
      current_block = (Rpc - LABEL_52_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_52_7);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_internal_syntactic_environment_5)
DEFLABEL (make_internal_syntactic_environment_2)
  INTERRUPT_CHECK (26, LABEL_52_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_52_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_52_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_52_5);
  (Wrd5.Obj) = (current_block [OBJECT_52_1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_7]))));
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_52_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_52_7);
  (Rsp [3]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_52_9]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_53_4 3
#define LABEL_53_6 5
#define LABEL_53_5 7
#define LABEL_53_7 9
#define LABEL_53_11 11
#define LABEL_53_12 13
#define LABEL_53_9 15
#define LABEL_53_15 17
#define LABEL_53_16 19
#define ENVIRONMENT_LABEL_53_3 35
#define DEBUGGING_LABEL_53_2 34
#define OBJECT_53_0 33
#define EXECUTE_CACHE_53_18 21
#define EXECUTE_CACHE_53_17 23
#define EXECUTE_CACHE_53_14 25
#define EXECUTE_CACHE_53_13 27
#define EXECUTE_CACHE_53_10 29
#define EXECUTE_CACHE_53_8 31
#define FREE_REFERENCES_LABEL_53_0 20
#define NUMBER_OF_LINKER_SECTIONS_53_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_53 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd12;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd5;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd27;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_53_4);
      goto internal_syntactic_environment_lookup_13;

    case 1:
      current_block = (Rpc - LABEL_53_6);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_53_5);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_53_7);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_53_11);
      goto continuation_6;

    case 5:
      current_block = (Rpc - LABEL_53_12);
      goto continuation_5;

    case 6:
      current_block = (Rpc - LABEL_53_9);
      goto continuation_3;

    case 7:
      current_block = (Rpc - LABEL_53_15);
      goto continuation_10;

    case 8:
      current_block = (Rpc - LABEL_53_16);
      goto continuation_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (internal_syntactic_environment_lookup_16)
DEFLABEL (internal_syntactic_environment_lookup_13)
  INTERRUPT_CHECK (26, LABEL_53_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_7]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_53_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_53_7);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_53_14]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_53_6);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_17;
  (Wrd27.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_9]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd31.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd31.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_53_10]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_53_9);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_53_14]));

DEFLABEL (label_17)
  Rsp = (& (Rsp [2]));

DEFLABEL (label_20)
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [0]);
  if (! ((Wrd5.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_18;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_11]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_12]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_53_13]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_53_12);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_53_17]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_53_11);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_15]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_16]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_53_10]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_53_16);
  (Wrd8.Obj) = (Rsp [3]);
  (Wrd9.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (Rhp++)) = (Wrd5.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_53_18]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_53_15);
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_18)
  (Rsp [2]) = (Wrd5.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_19;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  Rvl = ((Wrd10.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_19)
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_0]), 1);

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_53_5);
  goto label_20;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_54_4 3
#define LABEL_54_5 5
#define LABEL_54_6 7
#define LABEL_54_8 9
#define LABEL_54_9 11
#define LABEL_54_13 13
#define LABEL_54_12 15
#define LABEL_54_16 17
#define ENVIRONMENT_LABEL_54_3 40
#define DEBUGGING_LABEL_54_2 39
#define OBJECT_54_3 38
#define OBJECT_54_2 37
#define OBJECT_54_1 36
#define OBJECT_54_0 35
#define EXECUTE_CACHE_54_19 19
#define EXECUTE_CACHE_54_18 21
#define EXECUTE_CACHE_54_17 23
#define EXECUTE_CACHE_54_15 25
#define EXECUTE_CACHE_54_14 27
#define EXECUTE_CACHE_54_11 29
#define EXECUTE_CACHE_54_10 31
#define EXECUTE_CACHE_54_7 33
#define FREE_REFERENCES_LABEL_54_0 18
#define NUMBER_OF_LINKER_SECTIONS_54_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_54 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd8;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd5;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_54_4);
      goto internal_syntactic_environment_define_11;

    case 1:
      current_block = (Rpc - LABEL_54_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_54_6);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_54_8);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_54_9);
      goto continuation_2;

    case 5:
      current_block = (Rpc - LABEL_54_13);
      goto continuation_7;

    case 6:
      current_block = (Rpc - LABEL_54_12);
      goto continuation_5;

    case 7:
      current_block = (Rpc - LABEL_54_16);
      goto continuation_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (internal_syntactic_environment_define_14)
DEFLABEL (internal_syntactic_environment_define_11)
  INTERRUPT_CHECK (26, LABEL_54_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_54_6);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54_11]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_54_5);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_17;
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54_8]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54_9]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_54_9);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_54_8);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_16;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54_13]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54_14]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_54_13);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_15;
  (Wrd11.Obj) = (Rsp [2]);
  (Rsp [3]) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_54_2]);
  (Rsp [2]) = (Wrd12.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54_15]));

DEFLABEL (label_15)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54_16]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54_17]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_54_16);
  (Rsp [1]) = Rvl;
  (Wrd6.Obj) = (Rsp [2]);
  (Rsp [3]) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_54_3]);
  (Rsp [2]) = (Wrd7.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54_19]));

DEFLABEL (label_16)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54_12]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54_7]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_54_12);
  (Wrd8.Obj) = (Rsp [2]);
  (Wrd9.Obj) = (Rsp [3]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (Rhp++)) = (Wrd5.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd13.pObj) = (& (Rhp [-2]));
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd13.pObj)));
  (Rsp [3]) = (Wrd11.Obj);
  (Wrd14.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd14.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54_18]));

DEFLABEL (label_17)
  (Rsp [2]) = Rvl;
  Rsp = (& (Rsp [2]));
  (Wrd13.Obj) = (Rsp [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_18;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [1]) = (Wrd11.Obj);
  Rvl = (current_block [OBJECT_54_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_18)
  INVOKE_PRIMITIVE ((current_block [OBJECT_54_1]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_55_4 3
#define LABEL_55_5 5
#define ENVIRONMENT_LABEL_55_3 12
#define DEBUGGING_LABEL_55_2 11
#define EXECUTE_CACHE_55_7 7
#define EXECUTE_CACHE_55_6 9
#define FREE_REFERENCES_LABEL_55_0 6
#define NUMBER_OF_LINKER_SECTIONS_55_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_55 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_55_4);
      goto internal_syntactic_environment_rename_1;

    case 1:
      current_block = (Rpc - LABEL_55_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (internal_syntactic_environment_rename_4)
DEFLABEL (internal_syntactic_environment_rename_1)
  INTERRUPT_CHECK (26, LABEL_55_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_55_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_55_5);
  (Wrd5.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd5.Obj);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_55_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_56_4 3
#define LABEL_56_5 5
#define ENVIRONMENT_LABEL_56_3 12
#define DEBUGGING_LABEL_56_2 11
#define EXECUTE_CACHE_56_7 7
#define EXECUTE_CACHE_56_6 9
#define FREE_REFERENCES_LABEL_56_0 6
#define NUMBER_OF_LINKER_SECTIONS_56_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_56 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_56_4);
      goto internal_syntactic_environment__environment_1;

    case 1:
      current_block = (Rpc - LABEL_56_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (internal_syntactic_environment__environment_4)
DEFLABEL (internal_syntactic_environment__environment_1)
  INTERRUPT_CHECK (26, LABEL_56_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_56_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_56_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_56_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_57_4 3
#define ENVIRONMENT_LABEL_57_3 9
#define DEBUGGING_LABEL_57_2 8
#define OBJECT_57_0 7
#define EXECUTE_CACHE_57_5 5
#define FREE_REFERENCES_LABEL_57_0 4
#define NUMBER_OF_LINKER_SECTIONS_57_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_57 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_57_4);
      goto make_filtered_syntactic_environment_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_filtered_syntactic_environment_5)
DEFLABEL (make_filtered_syntactic_environment_2)
  INTERRUPT_CHECK (26, LABEL_57_4);
  (Wrd5.Obj) = (Rsp [0]);
  if (! ((Wrd5.Obj) == (current_block [OBJECT_57_0])))
    goto label_7;

DEFLABEL (label_6)
  Rvl = (Rsp [2]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_7)
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (Wrd8.Obj))
    goto label_6;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_57_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_58_4 3
#define LABEL_58_5 5
#define LABEL_58_6 7
#define LABEL_58_7 9
#define ENVIRONMENT_LABEL_58_3 22
#define DEBUGGING_LABEL_58_2 21
#define EXECUTE_CACHE_58_12 11
#define EXECUTE_CACHE_58_11 13
#define EXECUTE_CACHE_58_10 15
#define EXECUTE_CACHE_58_9 17
#define EXECUTE_CACHE_58_8 19
#define FREE_REFERENCES_LABEL_58_0 10
#define NUMBER_OF_LINKER_SECTIONS_58_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_58 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_58_4);
      goto filtered_syntactic_environment_lookup_3;

    case 1:
      current_block = (Rpc - LABEL_58_5);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_58_6);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_58_7);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (filtered_syntactic_environment_lookup_6)
DEFLABEL (filtered_syntactic_environment_lookup_3)
  INTERRUPT_CHECK (26, LABEL_58_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_7]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_58_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_58_7);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_58_12]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_58_6);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_7;
  (Wrd7.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_58_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_58_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_58_9]));

DEFLABEL (label_7)
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_58_10]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_59_4 3
#define ENVIRONMENT_LABEL_59_3 9
#define DEBUGGING_LABEL_59_2 8
#define OBJECT_59_0 7
#define EXECUTE_CACHE_59_5 5
#define FREE_REFERENCES_LABEL_59_0 4
#define NUMBER_OF_LINKER_SECTIONS_59_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_59 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_59_4);
      goto filtered_syntactic_environment_define_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (filtered_syntactic_environment_define_3)
DEFLABEL (filtered_syntactic_environment_define_0)
  INTERRUPT_CHECK (26, LABEL_59_4);
  (Wrd5.Obj) = (current_block [OBJECT_59_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_59_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_60_4 3
#define LABEL_60_5 5
#define LABEL_60_6 7
#define LABEL_60_7 9
#define ENVIRONMENT_LABEL_60_3 22
#define DEBUGGING_LABEL_60_2 21
#define EXECUTE_CACHE_60_12 11
#define EXECUTE_CACHE_60_11 13
#define EXECUTE_CACHE_60_10 15
#define EXECUTE_CACHE_60_9 17
#define EXECUTE_CACHE_60_8 19
#define FREE_REFERENCES_LABEL_60_0 10
#define NUMBER_OF_LINKER_SECTIONS_60_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_60 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_60_4);
      goto filtered_syntactic_environment_rename_3;

    case 1:
      current_block = (Rpc - LABEL_60_5);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_60_6);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_60_7);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (filtered_syntactic_environment_rename_6)
DEFLABEL (filtered_syntactic_environment_rename_3)
  INTERRUPT_CHECK (26, LABEL_60_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60_7]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_60_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_60_7);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_60_12]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_60_6);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_7;
  (Wrd7.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_60_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_60_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_60_9]));

DEFLABEL (label_7)
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_60_10]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_61_4 3
#define ENVIRONMENT_LABEL_61_3 9
#define DEBUGGING_LABEL_61_2 8
#define OBJECT_61_0 7
#define EXECUTE_CACHE_61_5 5
#define FREE_REFERENCES_LABEL_61_0 4
#define NUMBER_OF_LINKER_SECTIONS_61_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_61 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_61_4);
      goto filtered_syntactic_environment__environment_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (filtered_syntactic_environment__environment_3)
DEFLABEL (filtered_syntactic_environment__environment_0)
  INTERRUPT_CHECK (26, LABEL_61_4);
  (Wrd5.Obj) = (current_block [OBJECT_61_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_61_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_62_4 3
#define LABEL_62_5 5
#define ENVIRONMENT_LABEL_62_3 12
#define DEBUGGING_LABEL_62_2 11
#define EXECUTE_CACHE_62_7 7
#define EXECUTE_CACHE_62_6 9
#define FREE_REFERENCES_LABEL_62_0 6
#define NUMBER_OF_LINKER_SECTIONS_62_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_62 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_62_4);
      goto item_new_history_1;

    case 1:
      current_block = (Rpc - LABEL_62_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (item_new_history_4)
DEFLABEL (item_new_history_1)
  INTERRUPT_CHECK (26, LABEL_62_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_62_5);
  (Wrd5.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd5.Obj);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_63_4 3
#define LABEL_63_5 5
#define LABEL_63_7 7
#define ENVIRONMENT_LABEL_63_3 13
#define DEBUGGING_LABEL_63_2 12
#define OBJECT_63_0 11
#define EXECUTE_CACHE_63_6 9
#define FREE_REFERENCES_LABEL_63_0 8
#define NUMBER_OF_LINKER_SECTIONS_63_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_63 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_63_4);
      goto item_P_2;

    case 1:
      current_block = (Rpc - LABEL_63_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_63_7);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (item_P_5)
DEFLABEL (item_P_2)
  INTERRUPT_CHECK (26, LABEL_63_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_63_6]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_63_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_63_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_63_7);
  (Wrd5.Obj) = (* (Rsp++));
  if (Rvl == (Wrd5.Obj))
    goto label_7;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_6;

DEFLABEL (label_7)
  Rvl = (current_block [OBJECT_63_0]);

DEFLABEL (label_6)
DEFLABEL (label_8)
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_64_4 3
#define LABEL_64_5 5
#define LABEL_64_7 7
#define ENVIRONMENT_LABEL_64_3 14
#define DEBUGGING_LABEL_64_2 13
#define EXECUTE_CACHE_64_8 9
#define EXECUTE_CACHE_64_6 11
#define FREE_REFERENCES_LABEL_64_0 8
#define NUMBER_OF_LINKER_SECTIONS_64_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_64 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_64_4);
      goto make_item_type_3;

    case 1:
      current_block = (Rpc - LABEL_64_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_64_7);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_item_type_6)
DEFLABEL (make_item_type_3)
  INTERRUPT_CHECK (26, LABEL_64_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_64_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_64_7);
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_65_4 3
#define LABEL_65_5 5
#define LABEL_65_7 7
#define TAG_65_8 2
#define LABEL_65_9 9
#define ENVIRONMENT_LABEL_65_3 16
#define DEBUGGING_LABEL_65_2 15
#define EXECUTE_CACHE_65_10 11
#define EXECUTE_CACHE_65_6 13
#define FREE_REFERENCES_LABEL_65_0 10
#define NUMBER_OF_LINKER_SECTIONS_65_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_65 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_65_4);
      goto item_predicate_4;

    case 1:
      current_block = (Rpc - LABEL_65_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_65_7);
      goto lambda_8;

    case 3:
      current_block = (Rpc - LABEL_65_9);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (item_predicate_7)
DEFLABEL (item_predicate_4)
  INTERRUPT_CHECK (26, LABEL_65_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_65_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_65_5);
  (Rsp [0]) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_65_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_65_7])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rvl = (Wrd7.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_8)
  CLOSURE_HEADER (LABEL_65_7);

DEFLABEL (lambda_2)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_65_10]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_65_9);
  (Rsp [1]) = Rvl;
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [0]) = (Wrd6.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_66_4 3
#define LABEL_66_5 5
#define LABEL_66_7 7
#define TAG_66_8 2
#define LABEL_66_9 9
#define ENVIRONMENT_LABEL_66_3 16
#define DEBUGGING_LABEL_66_2 15
#define EXECUTE_CACHE_66_10 11
#define EXECUTE_CACHE_66_6 13
#define FREE_REFERENCES_LABEL_66_0 10
#define NUMBER_OF_LINKER_SECTIONS_66_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_66 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_66_4);
      goto item_accessor_4;

    case 1:
      current_block = (Rpc - LABEL_66_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_66_7);
      goto lambda_8;

    case 3:
      current_block = (Rpc - LABEL_66_9);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (item_accessor_7)
DEFLABEL (item_accessor_4)
  INTERRUPT_CHECK (26, LABEL_66_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_66_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_66_5);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_66_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_66_7])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  Wrd9 = Wrd8;
  (Wrd10.Obj) = (Rsp [0]);
  ((Wrd9.pObj) [2]) = (Wrd10.Obj);
  Rvl = (Wrd7.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_8)
  CLOSURE_HEADER (LABEL_66_7);

DEFLABEL (lambda_2)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_66_10]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_66_9);
  (Rsp [1]) = Rvl;
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [0]) = (Wrd6.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_67_4 3
#define LABEL_67_5 5
#define LABEL_67_7 7
#define LABEL_67_9 9
#define ENVIRONMENT_LABEL_67_3 21
#define DEBUGGING_LABEL_67_2 20
#define OBJECT_67_0 19
#define EXECUTE_CACHE_67_11 11
#define EXECUTE_CACHE_67_10 13
#define EXECUTE_CACHE_67_8 15
#define EXECUTE_CACHE_67_6 17
#define FREE_REFERENCES_LABEL_67_0 10
#define NUMBER_OF_LINKER_SECTIONS_67_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_67 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_67_4);
      goto illegal_expression_item_4;

    case 1:
      current_block = (Rpc - LABEL_67_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_67_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_67_9);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (illegal_expression_item_7)
DEFLABEL (illegal_expression_item_4)
  INTERRUPT_CHECK (26, LABEL_67_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_67_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_67_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_67_7);
  (Rsp [1]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_9]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_67_9);
  (Rsp [2]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_11]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_68_4 3
#define ENVIRONMENT_LABEL_68_3 9
#define DEBUGGING_LABEL_68_2 8
#define OBJECT_68_0 7
#define EXECUTE_CACHE_68_5 5
#define FREE_REFERENCES_LABEL_68_0 4
#define NUMBER_OF_LINKER_SECTIONS_68_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_68 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_68_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_68_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_68_0]);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_69_4 3
#define LABEL_69_5 5
#define LABEL_69_7 7
#define LABEL_69_9 9
#define ENVIRONMENT_LABEL_69_3 20
#define DEBUGGING_LABEL_69_2 19
#define EXECUTE_CACHE_69_11 11
#define EXECUTE_CACHE_69_10 13
#define EXECUTE_CACHE_69_8 15
#define EXECUTE_CACHE_69_6 17
#define FREE_REFERENCES_LABEL_69_0 10
#define NUMBER_OF_LINKER_SECTIONS_69_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_69 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_69_4);
      goto keyword_itemP_6;

    case 1:
      current_block = (Rpc - LABEL_69_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_69_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_69_9);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (keyword_itemP_9)
DEFLABEL (keyword_itemP_6)
  INTERRUPT_CHECK (26, LABEL_69_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_69_5);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_10;
  Rvl = Rvl;
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_10)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_7]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_69_7);
  (Rsp [0]) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_11;
  Rvl = Rvl;
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_11)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_9]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_69_9);
  (Rsp [0]) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_12;
  Rvl = Rvl;
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_12)
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_11]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_70_4 3
#define LABEL_70_5 5
#define ENVIRONMENT_LABEL_70_3 12
#define DEBUGGING_LABEL_70_2 11
#define EXECUTE_CACHE_70_6 7
#define FREE_REFERENCE_70_0 10
#define FREE_REFERENCES_LABEL_70_0 6
#define NUMBER_OF_LINKER_SECTIONS_70_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_70 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_70_4);
      goto make_keyword_type_0;

    case 1:
      current_block = (Rpc - LABEL_70_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_keyword_type_4)
DEFLABEL (make_keyword_type_0)
  INTERRUPT_CHECK (26, LABEL_70_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_70_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_6;
  Wrd8 = Wrd12;

DEFLABEL (label_5)
  (Rsp [2]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_70_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_70_5])), (Wrd9.pObj));

DEFLABEL (label_2)
  (Wrd8.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_71_4 3
#define ENVIRONMENT_LABEL_71_3 9
#define DEBUGGING_LABEL_71_2 8
#define OBJECT_71_0 7
#define EXECUTE_CACHE_71_5 5
#define FREE_REFERENCES_LABEL_71_0 4
#define NUMBER_OF_LINKER_SECTIONS_71_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_71 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_71_4);
      goto keyword_item_compiler_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (keyword_item_compiler_3)
DEFLABEL (keyword_item_compiler_0)
  INTERRUPT_CHECK (26, LABEL_71_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_71_0]);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_72_4 3
#define LABEL_72_5 5
#define LABEL_72_6 7
#define LABEL_72_9 9
#define TAG_72_10 3
#define LABEL_72_12 11
#define LABEL_72_14 13
#define ENVIRONMENT_LABEL_72_3 30
#define DEBUGGING_LABEL_72_2 29
#define OBJECT_72_1 28
#define OBJECT_72_0 27
#define EXECUTE_CACHE_72_16 15
#define EXECUTE_CACHE_72_15 17
#define EXECUTE_CACHE_72_13 19
#define EXECUTE_CACHE_72_11 21
#define EXECUTE_CACHE_72_8 23
#define EXECUTE_CACHE_72_7 25
#define FREE_REFERENCES_LABEL_72_0 14
#define NUMBER_OF_LINKER_SECTIONS_72_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_72 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_72_4);
      goto make_keyword_ref_item_9;

    case 1:
      current_block = (Rpc - LABEL_72_5);
      goto continuation_8;

    case 2:
      current_block = (Rpc - LABEL_72_6);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_72_9);
      goto lambda_13;

    case 4:
      current_block = (Rpc - LABEL_72_12);
      goto continuation_2;

    case 5:
      current_block = (Rpc - LABEL_72_14);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_keyword_ref_item_12)
DEFLABEL (make_keyword_ref_item_9)
  INTERRUPT_CHECK (26, LABEL_72_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_72_6);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_72_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_72_9])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_11]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_72_5);
  (Rsp [2]) = Rvl;
  (Wrd6.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_8]));

DEFLABEL (lambda_13)
  CLOSURE_HEADER (LABEL_72_9);

DEFLABEL (lambda_6)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd9.Obj) = (current_block [OBJECT_72_0]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_13]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_72_12);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_15]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_72_14);
  (Wrd9.Obj) = (current_block [OBJECT_72_1]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [2]);
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd6.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (Rsp [1]) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_16]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_73_4 3
#define LABEL_73_5 5
#define ENVIRONMENT_LABEL_73_3 12
#define DEBUGGING_LABEL_73_2 11
#define EXECUTE_CACHE_73_7 7
#define EXECUTE_CACHE_73_6 9
#define FREE_REFERENCES_LABEL_73_0 6
#define NUMBER_OF_LINKER_SECTIONS_73_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_73 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_73_4);
      goto lambda_1;

    case 1:
      current_block = (Rpc - LABEL_73_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_4)
DEFLABEL (lambda_1)
  INTERRUPT_CHECK (26, LABEL_73_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_73_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_73_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_73_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_73_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_74_4 3
#define LABEL_74_5 5
#define ENVIRONMENT_LABEL_74_3 10
#define DEBUGGING_LABEL_74_2 9
#define EXECUTE_CACHE_74_6 7
#define FREE_REFERENCES_LABEL_74_0 6
#define NUMBER_OF_LINKER_SECTIONS_74_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_74 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_74_4);
      goto lambda_1;

    case 1:
      current_block = (Rpc - LABEL_74_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_4)
DEFLABEL (lambda_1)
  INTERRUPT_CHECK (26, LABEL_74_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_74_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_74_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_74_5);
  (Rsp [0]) = Rvl;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_75_4 3
#define ENVIRONMENT_LABEL_75_3 8
#define DEBUGGING_LABEL_75_2 7
#define EXECUTE_CACHE_75_5 5
#define FREE_REFERENCES_LABEL_75_0 4
#define NUMBER_OF_LINKER_SECTIONS_75_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_75 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_75_4);
      goto make_expression_item_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_expression_item_3)
DEFLABEL (make_expression_item_0)
  INTERRUPT_CHECK (26, LABEL_75_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd6.Obj);
  (Rsp [2]) = ((SCHEME_OBJECT) 0);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_75_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_76_4 3
#define ENVIRONMENT_LABEL_76_3 8
#define DEBUGGING_LABEL_76_2 7
#define EXECUTE_CACHE_76_5 5
#define FREE_REFERENCES_LABEL_76_0 4
#define NUMBER_OF_LINKER_SECTIONS_76_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_76 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_76_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_76_4);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_76_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_77_4 3
#define ENVIRONMENT_LABEL_77_3 9
#define DEBUGGING_LABEL_77_2 8
#define OBJECT_77_0 7
#define EXECUTE_CACHE_77_5 5
#define FREE_REFERENCES_LABEL_77_0 4
#define NUMBER_OF_LINKER_SECTIONS_77_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_77 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_77_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_77_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_77_0]);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_77_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_78_4 3
#define LABEL_78_5 5
#define ENVIRONMENT_LABEL_78_3 12
#define DEBUGGING_LABEL_78_2 11
#define EXECUTE_CACHE_78_7 7
#define EXECUTE_CACHE_78_6 9
#define FREE_REFERENCES_LABEL_78_0 6
#define NUMBER_OF_LINKER_SECTIONS_78_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_78 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_78_4);
      goto lambda_1;

    case 1:
      current_block = (Rpc - LABEL_78_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_4)
DEFLABEL (lambda_1)
  INTERRUPT_CHECK (26, LABEL_78_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_78_5]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_78_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_78_5);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_78_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_79_4 3
#define LABEL_79_7 5
#define LABEL_79_5 7
#define LABEL_79_8 9
#define LABEL_79_9 11
#define LABEL_79_13 13
#define LABEL_79_16 15
#define LABEL_79_18 17
#define LABEL_79_20 19
#define LABEL_79_21 21
#define ENVIRONMENT_LABEL_79_3 46
#define DEBUGGING_LABEL_79_2 45
#define OBJECT_79_1 44
#define OBJECT_79_0 43
#define EXECUTE_CACHE_79_23 23
#define EXECUTE_CACHE_79_22 25
#define EXECUTE_CACHE_79_19 27
#define EXECUTE_CACHE_79_17 29
#define EXECUTE_CACHE_79_15 31
#define EXECUTE_CACHE_79_14 33
#define EXECUTE_CACHE_79_12 35
#define EXECUTE_CACHE_79_11 37
#define EXECUTE_CACHE_79_10 39
#define EXECUTE_CACHE_79_6 41
#define FREE_REFERENCES_LABEL_79_0 22
#define NUMBER_OF_LINKER_SECTIONS_79_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_79 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd17;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_79_4);
      goto compile_body_items_12;

    case 1:
      current_block = (Rpc - LABEL_79_7);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_79_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_79_8);
      goto continuation_10;

    case 4:
      current_block = (Rpc - LABEL_79_9);
      goto lambda_9;

    case 5:
      current_block = (Rpc - LABEL_79_13);
      goto continuation_3;

    case 6:
      current_block = (Rpc - LABEL_79_16);
      goto continuation_4;

    case 7:
      current_block = (Rpc - LABEL_79_18);
      goto continuation_5;

    case 8:
      current_block = (Rpc - LABEL_79_20);
      goto continuation_7;

    case 9:
      current_block = (Rpc - LABEL_79_21);
      goto continuation_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (compile_body_items_15)
DEFLABEL (compile_body_items_12)
  INTERRUPT_CHECK (26, LABEL_79_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_79_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_79_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_79_5);
  (* (--Rsp)) = Rvl;
  (Wrd6.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd6.uLng) == 1)
    goto label_17;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_79_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_79_0]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_79_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_79_7);

DEFLABEL (label_17)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_79_8]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_79_9]))));
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_79_10]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_79_8);
  (Rsp [2]) = Rvl;
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_79_12]));

DEFLABEL (lambda_16)
DEFLABEL (lambda_9)
  INTERRUPT_CHECK (26, LABEL_79_9);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_79_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_79_14]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_79_13);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_18;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_79_15]));

DEFLABEL (label_18)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_79_16]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_79_17]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_79_16);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_79_18]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_79_19]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_79_18);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_19;
  (Wrd7.Obj) = (current_block [OBJECT_79_1]);
  (Rsp [1]) = (Wrd7.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_79_12]));

DEFLABEL (label_19)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_79_20]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_79_15]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_79_20);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_79_21]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_79_22]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_79_21);
  (Rsp [1]) = Rvl;
  (Wrd6.Obj) = (* (Rsp++));
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_79_23]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_80_4 3
#define ENVIRONMENT_LABEL_80_3 9
#define DEBUGGING_LABEL_80_2 8
#define OBJECT_80_0 7
#define EXECUTE_CACHE_80_5 5
#define FREE_REFERENCES_LABEL_80_0 4
#define NUMBER_OF_LINKER_SECTIONS_80_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_80 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_80_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_80_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_80_0]);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_80_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_81_4 3
#define ENVIRONMENT_LABEL_81_3 9
#define DEBUGGING_LABEL_81_2 8
#define OBJECT_81_0 7
#define EXECUTE_CACHE_81_5 5
#define FREE_REFERENCES_LABEL_81_0 4
#define NUMBER_OF_LINKER_SECTIONS_81_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_81 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_81_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_81_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_81_0]);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_81_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_82_4 3
#define LABEL_82_5 5
#define LABEL_82_7 7
#define LABEL_82_8 9
#define ENVIRONMENT_LABEL_82_3 18
#define DEBUGGING_LABEL_82_2 17
#define EXECUTE_CACHE_82_10 11
#define EXECUTE_CACHE_82_9 13
#define EXECUTE_CACHE_82_6 15
#define FREE_REFERENCES_LABEL_82_0 10
#define NUMBER_OF_LINKER_SECTIONS_82_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_82 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_82_4);
      goto bind_variableB_4;

    case 1:
      current_block = (Rpc - LABEL_82_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_82_7);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_82_8);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (bind_variableB_7)
DEFLABEL (bind_variableB_4)
  INTERRUPT_CHECK (26, LABEL_82_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_82_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_8]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_82_8);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_82_7);
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_83_4 3
#define ENVIRONMENT_LABEL_83_3 6
#define DEBUGGING_LABEL_83_2 5
#define OBJECT_83_0 4
#define FREE_REFERENCES_LABEL_83_0 4
#define NUMBER_OF_LINKER_SECTIONS_83_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_83 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd12;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd7;
  machine_word Wrd9;
  machine_word Wrd8;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_83_4);
      goto make_top_level_history_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_top_level_history_5)
DEFLABEL (make_top_level_history_2)
  INTERRUPT_CHECK (26, LABEL_83_4);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Wrd13.Obj) = (current_block [OBJECT_83_0]);
  (* (Rhp++)) = (Wrd5.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_84_4 3
#define LABEL_84_5 5
#define LABEL_84_6 7
#define ENVIRONMENT_LABEL_84_3 11
#define DEBUGGING_LABEL_84_2 10
#define OBJECT_84_1 9
#define OBJECT_84_0 8
#define FREE_REFERENCES_LABEL_84_0 8
#define NUMBER_OF_LINKER_SECTIONS_84_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_84 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd25;
  machine_word Wrd27;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd24;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd15;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd11;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_84_4);
      goto history_add_reduction_4;

    case 1:
      current_block = (Rpc - LABEL_84_5);
      goto label_6;

    case 2:
      current_block = (Rpc - LABEL_84_6);
      goto label_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (history_add_reduction_9)
DEFLABEL (history_add_reduction_4)
  INTERRUPT_CHECK (26, LABEL_84_4);
  (Wrd5.Obj) = (Rsp [2]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_15;
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_14;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [1]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_13)
  (Wrd19.Obj) = (Rsp [3]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_12;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [0]);

DEFLABEL (label_11)
  (Wrd28.Obj) = (Rsp [1]);
  (Wrd29.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd28.Obj);
  (* (Rhp++)) = (Wrd29.Obj);
  (Wrd27.pObj) = (& (Rhp [-2]));
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd27.pObj)));
  (* (Rhp++)) = (Wrd25.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (Wrd32.pObj) = (& (Rhp [-2]));
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd32.pObj)));
  (Wrd33.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd30.Obj);
  (* (Rhp++)) = (Wrd33.Obj);
  (Wrd36.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd36.pObj)));

DEFLABEL (label_10)
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_12)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_6]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_84_1]), 1);

DEFLABEL (label_7)
  (Wrd16.Obj) = Rvl;
  goto label_11;

DEFLABEL (label_14)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_5]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_84_0]), 1);

DEFLABEL (label_6)
  (* (--Rsp)) = Rvl;
  goto label_13;

DEFLABEL (label_15)
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_85_4 3
#define LABEL_85_5 5
#define LABEL_85_6 7
#define LABEL_85_7 9
#define ENVIRONMENT_LABEL_85_3 13
#define DEBUGGING_LABEL_85_2 12
#define OBJECT_85_1 11
#define OBJECT_85_0 10
#define FREE_REFERENCES_LABEL_85_0 10
#define NUMBER_OF_LINKER_SECTIONS_85_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_85 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd43;
  machine_word Wrd40;
  machine_word Wrd37;
  machine_word Wrd39;
  machine_word Wrd32;
  machine_word Wrd34;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd31;
  machine_word Wrd25;
  machine_word Wrd26;
  machine_word Wrd27;
  machine_word Wrd24;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd15;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd11;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_85_4);
      goto history_replace_reduction_5;

    case 1:
      current_block = (Rpc - LABEL_85_5);
      goto label_7;

    case 2:
      current_block = (Rpc - LABEL_85_6);
      goto label_8;

    case 3:
      current_block = (Rpc - LABEL_85_7);
      goto label_9;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (history_replace_reduction_11)
DEFLABEL (history_replace_reduction_5)
  INTERRUPT_CHECK (26, LABEL_85_4);
  (Wrd5.Obj) = (Rsp [2]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_19;
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_18;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [1]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_17)
  (Wrd19.Obj) = (Rsp [3]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_16;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [0]);

DEFLABEL (label_15)
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd27.uLng) == 1))
    goto label_14;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd25.Obj) = ((Wrd26.pObj) [1]);

DEFLABEL (label_13)
  (Wrd35.Obj) = (Rsp [1]);
  (Wrd36.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd35.Obj);
  (* (Rhp++)) = (Wrd36.Obj);
  (Wrd34.pObj) = (& (Rhp [-2]));
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd34.pObj)));
  (* (Rhp++)) = (Wrd32.Obj);
  (* (Rhp++)) = (Wrd25.Obj);
  (Wrd39.pObj) = (& (Rhp [-2]));
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd39.pObj)));
  (Wrd40.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd37.Obj);
  (* (Rhp++)) = (Wrd40.Obj);
  (Wrd43.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd43.pObj)));

DEFLABEL (label_12)
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_14)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_7]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_85_0]), 1);

DEFLABEL (label_9)
  (Wrd25.Obj) = Rvl;
  goto label_13;

DEFLABEL (label_16)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_6]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_85_1]), 1);

DEFLABEL (label_8)
  (Wrd16.Obj) = Rvl;
  goto label_15;

DEFLABEL (label_18)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_5]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_85_0]), 1);

DEFLABEL (label_7)
  (* (--Rsp)) = Rvl;
  goto label_17;

DEFLABEL (label_19)
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_12;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_86_4 3
#define LABEL_86_5 5
#define LABEL_86_6 7
#define ENVIRONMENT_LABEL_86_3 12
#define DEBUGGING_LABEL_86_2 11
#define OBJECT_86_2 10
#define OBJECT_86_1 9
#define OBJECT_86_0 8
#define FREE_REFERENCES_LABEL_86_0 8
#define NUMBER_OF_LINKER_SECTIONS_86_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_86 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd44;
  machine_word Wrd38;
  machine_word Wrd40;
  machine_word Wrd41;
  machine_word Wrd33;
  machine_word Wrd35;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd29;
  machine_word Wrd25;
  machine_word Wrd27;
  machine_word Wrd28;
  machine_word Wrd24;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd15;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd11;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_86_4);
      goto history_add_subproblem_6;

    case 1:
      current_block = (Rpc - LABEL_86_5);
      goto label_8;

    case 2:
      current_block = (Rpc - LABEL_86_6);
      goto label_9;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (history_add_subproblem_11)
DEFLABEL (history_add_subproblem_6)
  INTERRUPT_CHECK (26, LABEL_86_4);
  (Wrd5.Obj) = (Rsp [2]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_17;
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_16;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [1]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_15)
  (Wrd19.Obj) = (Rsp [3]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_14;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [0]);

DEFLABEL (label_13)
  (Wrd28.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd28.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (Wrd27.pObj) = (& (Rhp [-2]));
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd27.pObj)));
  (Wrd29.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd25.Obj);
  (* (Rhp++)) = (Wrd29.Obj);
  (Wrd32.pObj) = (& (Rhp [-2]));
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd32.pObj)));
  (Wrd36.Obj) = (Rsp [0]);
  (Wrd37.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd36.Obj);
  (* (Rhp++)) = (Wrd37.Obj);
  (Wrd35.pObj) = (& (Rhp [-2]));
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd35.pObj)));
  (Wrd41.Obj) = (current_block [OBJECT_86_2]);
  (* (Rhp++)) = (Wrd33.Obj);
  (* (Rhp++)) = (Wrd41.Obj);
  (Wrd40.pObj) = (& (Rhp [-2]));
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd40.pObj)));
  (* (Rhp++)) = (Wrd38.Obj);
  (* (Rhp++)) = (Wrd30.Obj);
  (Wrd44.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd44.pObj)));

DEFLABEL (label_12)
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_14)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_86_6]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_86_1]), 1);

DEFLABEL (label_9)
  (Wrd16.Obj) = Rvl;
  goto label_13;

DEFLABEL (label_16)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_86_5]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_86_0]), 1);

DEFLABEL (label_8)
  (* (--Rsp)) = Rvl;
  goto label_15;

DEFLABEL (label_17)
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_12;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_87_4 3
#define LABEL_87_6 5
#define LABEL_87_5 7
#define LABEL_87_8 9
#define ENVIRONMENT_LABEL_87_3 15
#define DEBUGGING_LABEL_87_2 14
#define OBJECT_87_0 13
#define EXECUTE_CACHE_87_7 11
#define FREE_REFERENCES_LABEL_87_0 10
#define NUMBER_OF_LINKER_SECTIONS_87_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_87 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd6;
  machine_word Wrd7;
  machine_word Wrd8;
  machine_word Wrd18;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd14;
  machine_word Wrd9;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_87_4);
      goto history_original_form_3;

    case 1:
      current_block = (Rpc - LABEL_87_6);
      goto label_5;

    case 2:
      current_block = (Rpc - LABEL_87_5);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_87_8);
      goto label_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (history_original_form_8)
DEFLABEL (history_original_form_3)
  INTERRUPT_CHECK (26, LABEL_87_4);
  (Wrd5.Obj) = (Rsp [0]);
  if (! ((Wrd5.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_9;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_9)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_87_5]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_14;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_13)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_87_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_87_5);
  (Wrd8.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd8.uLng) == 1))
    goto label_12;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd6.Obj) = ((Wrd7.pObj) [0]);

DEFLABEL (label_11)
  (Rsp [0]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_10;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  Rvl = ((Wrd15.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_10)
  INVOKE_PRIMITIVE ((current_block [OBJECT_87_0]), 1);

DEFLABEL (label_12)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_87_8]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_87_0]), 1);

DEFLABEL (label_6)
  (Wrd6.Obj) = Rvl;
  goto label_11;

DEFLABEL (label_14)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_87_6]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_87_0]), 1);

DEFLABEL (label_5)
  (* (--Rsp)) = Rvl;
  goto label_13;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_88_4 3
#define LABEL_88_6 5
#define LABEL_88_7 7
#define LABEL_88_8 9
#define LABEL_88_10 11
#define LABEL_88_11 13
#define LABEL_88_5 15
#define LABEL_88_13 17
#define ENVIRONMENT_LABEL_88_3 29
#define DEBUGGING_LABEL_88_2 28
#define OBJECT_88_2 27
#define OBJECT_88_1 26
#define OBJECT_88_0 25
#define EXECUTE_CACHE_88_14 19
#define EXECUTE_CACHE_88_12 21
#define EXECUTE_CACHE_88_9 23
#define FREE_REFERENCES_LABEL_88_0 18
#define NUMBER_OF_LINKER_SECTIONS_88_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_88 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd57;
  machine_word Wrd50;
  machine_word Wrd46;
  machine_word Wrd56;
  machine_word Wrd52;
  machine_word Wrd55;
  machine_word Wrd51;
  machine_word Wrd45;
  machine_word Wrd37;
  machine_word Wrd39;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd25;
  machine_word Wrd58;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd12;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_88_4);
      goto selector_apply_8;

    case 1:
      current_block = (Rpc - LABEL_88_6);
      goto label_10;

    case 2:
      current_block = (Rpc - LABEL_88_7);
      goto label_11;

    case 3:
      current_block = (Rpc - LABEL_88_8);
      goto label_12;

    case 4:
      current_block = (Rpc - LABEL_88_10);
      goto label_13;

    case 5:
      current_block = (Rpc - LABEL_88_11);
      goto label_14;

    case 6:
      current_block = (Rpc - LABEL_88_5);
      goto continuation_4;

    case 7:
      current_block = (Rpc - LABEL_88_13);
      goto label_15;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (selector_apply_17)
DEFLABEL (selector_apply_8)
  INTERRUPT_CHECK (26, LABEL_88_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_18;
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_18)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_88_5]))));
  (* (--Rsp)) = (Wrd11.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_31;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd12.Obj) = ((Wrd14.pObj) [0]);

DEFLABEL (label_30)
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd21.uLng) == 26))
    goto label_29;
  (Wrd58.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if ((Wrd58.Lng) < 0)
    goto label_24;

DEFLABEL (label_23)
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 1))
    goto label_22;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [0]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_21)
  (Wrd36.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd36.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_88_9]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_88_5);
  (Rsp [1]) = Rvl;
  (Wrd9.Obj) = (Rsp [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd10.uLng) == 1))
    goto label_20;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [1]);

DEFLABEL (label_19)
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_88_14]));

DEFLABEL (label_20)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_88_13]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_88_2]), 1);

DEFLABEL (label_15)
  (Wrd6.Obj) = Rvl;
  goto label_19;

DEFLABEL (label_22)
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_88_8]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_88_0]), 1);

DEFLABEL (label_12)
  (* (--Rsp)) = Rvl;
  goto label_21;

DEFLABEL (label_24)
  (Wrd40.Obj) = (Rsp [1]);
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if (! ((Wrd41.uLng) == 1))
    goto label_28;
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  (Wrd37.Obj) = ((Wrd39.pObj) [0]);

DEFLABEL (label_27)
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd51.uLng) == 26))
    goto label_26;
  (Wrd55.Lng) = (FIXNUM_TO_LONG (Wrd37.Obj));
  (Wrd52.Lng) = (0 - (Wrd55.Lng));
  if (! (LONG_TO_FIXNUM_P (Wrd52.Lng)))
    goto label_26;
  (Wrd56.Obj) = (LONG_TO_FIXNUM (Wrd52.Lng));
  (* (--Rsp)) = (Wrd56.Obj);

DEFLABEL (label_25)
  (Wrd57.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd57.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_88_12]));

DEFLABEL (label_26)
  (Wrd46.Obj) = (current_block [OBJECT_88_1]);
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_88_11]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd46.Obj);
  INVOKE_INTERFACE_0 (40);

DEFLABEL (label_14)
  (* (--Rsp)) = Rvl;
  goto label_25;

DEFLABEL (label_28)
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_88_10]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_88_0]), 1);

DEFLABEL (label_13)
  (Wrd37.Obj) = Rvl;
  goto label_27;

DEFLABEL (label_29)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_88_7]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_INTERFACE_0 (42);

DEFLABEL (label_11)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_23;
  goto label_24;

DEFLABEL (label_31)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_88_6]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_88_0]), 1);

DEFLABEL (label_10)
  (Wrd12.Obj) = Rvl;
  goto label_30;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_89_4 3
#define LABEL_89_5 5
#define LABEL_89_6 7
#define LABEL_89_7 9
#define LABEL_89_8 11
#define LABEL_89_9 13
#define ENVIRONMENT_LABEL_89_3 18
#define DEBUGGING_LABEL_89_2 17
#define OBJECT_89_2 16
#define OBJECT_89_1 15
#define OBJECT_89_0 14
#define FREE_REFERENCES_LABEL_89_0 14
#define NUMBER_OF_LINKER_SECTIONS_89_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_89 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd60;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd57;
  machine_word Wrd50;
  machine_word Wrd46;
  machine_word Wrd51;
  machine_word Wrd53;
  machine_word Wrd56;
  machine_word Wrd52;
  machine_word Wrd45;
  machine_word Wrd37;
  machine_word Wrd39;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd36;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd26;
  machine_word Wrd62;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd13;
  machine_word Wrd15;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_89_4);
      goto selector_add_car_6;

    case 1:
      current_block = (Rpc - LABEL_89_5);
      goto label_8;

    case 2:
      current_block = (Rpc - LABEL_89_6);
      goto label_9;

    case 3:
      current_block = (Rpc - LABEL_89_7);
      goto label_10;

    case 4:
      current_block = (Rpc - LABEL_89_8);
      goto label_11;

    case 5:
      current_block = (Rpc - LABEL_89_9);
      goto label_12;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (selector_add_car_14)
DEFLABEL (selector_add_car_6)
  INTERRUPT_CHECK (26, LABEL_89_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_17;

DEFLABEL (label_16)
  (Wrd11.Obj) = (current_block [OBJECT_89_2]);
  (Wrd12.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = (Wrd12.Obj);

DEFLABEL (label_15)
  (Wrd60.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd60.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_17)
  if (! ((Wrd6.uLng) == 1))
    goto label_27;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd13.Obj) = ((Wrd15.pObj) [0]);

DEFLABEL (label_26)
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd22.uLng) == 26))
    goto label_25;
  (Wrd62.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! ((Wrd62.Lng) < 0))
    goto label_16;

DEFLABEL (label_24)
  (Wrd31.Obj) = (Rsp [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if (! ((Wrd32.uLng) == 1))
    goto label_23;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [1]);
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_22)
  (Wrd40.Obj) = (Rsp [1]);
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if (! ((Wrd41.uLng) == 1))
    goto label_21;
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  (Wrd37.Obj) = ((Wrd39.pObj) [0]);

DEFLABEL (label_20)
  (Wrd52.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd52.uLng) == 26))
    goto label_19;
  (Wrd56.Lng) = (FIXNUM_TO_LONG (Wrd37.Obj));
  (Wrd53.Lng) = (0 - (Wrd56.Lng));
  if (! (LONG_TO_FIXNUM_P (Wrd53.Lng)))
    goto label_19;
  (Wrd51.Obj) = (LONG_TO_FIXNUM (Wrd53.Lng));

DEFLABEL (label_18)
  (Wrd57.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd51.Obj);
  (* (Rhp++)) = (Wrd57.Obj);
  goto label_15;

DEFLABEL (label_19)
  (Wrd46.Obj) = (current_block [OBJECT_89_2]);
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89_9]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd46.Obj);
  INVOKE_INTERFACE_0 (40);

DEFLABEL (label_12)
  (Wrd51.Obj) = Rvl;
  goto label_18;

DEFLABEL (label_21)
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89_8]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_89_0]), 1);

DEFLABEL (label_11)
  (Wrd37.Obj) = Rvl;
  goto label_20;

DEFLABEL (label_23)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89_7]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd31.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_89_1]), 1);

DEFLABEL (label_10)
  (* (--Rsp)) = Rvl;
  goto label_22;

DEFLABEL (label_25)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89_6]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_INTERFACE_0 (42);

DEFLABEL (label_9)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_16;
  goto label_24;

DEFLABEL (label_27)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89_5]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_89_0]), 1);

DEFLABEL (label_8)
  (Wrd13.Obj) = Rvl;
  goto label_26;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_90_4 3
#define LABEL_90_5 5
#define LABEL_90_6 7
#define LABEL_90_7 9
#define LABEL_90_8 11
#define LABEL_90_9 13
#define ENVIRONMENT_LABEL_90_3 18
#define DEBUGGING_LABEL_90_2 17
#define OBJECT_90_2 16
#define OBJECT_90_1 15
#define OBJECT_90_0 14
#define FREE_REFERENCES_LABEL_90_0 14
#define NUMBER_OF_LINKER_SECTIONS_90_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_90 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd57;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd54;
  machine_word Wrd49;
  machine_word Wrd50;
  machine_word Wrd52;
  machine_word Wrd53;
  machine_word Wrd51;
  machine_word Wrd45;
  machine_word Wrd37;
  machine_word Wrd39;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd36;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd26;
  machine_word Wrd59;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd13;
  machine_word Wrd15;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_90_4);
      goto selector_add_cdr_6;

    case 1:
      current_block = (Rpc - LABEL_90_5);
      goto label_8;

    case 2:
      current_block = (Rpc - LABEL_90_6);
      goto label_9;

    case 3:
      current_block = (Rpc - LABEL_90_7);
      goto label_10;

    case 4:
      current_block = (Rpc - LABEL_90_8);
      goto label_11;

    case 5:
      current_block = (Rpc - LABEL_90_9);
      goto label_12;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (selector_add_cdr_14)
DEFLABEL (selector_add_cdr_6)
  INTERRUPT_CHECK (26, LABEL_90_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_17;

DEFLABEL (label_16)
  (Wrd11.Obj) = (current_block [OBJECT_90_2]);
  (Wrd12.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = (Wrd12.Obj);

DEFLABEL (label_15)
  (Wrd57.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd57.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_17)
  if (! ((Wrd6.uLng) == 1))
    goto label_27;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd13.Obj) = ((Wrd15.pObj) [0]);

DEFLABEL (label_26)
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd22.uLng) == 26))
    goto label_25;
  (Wrd59.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! ((Wrd59.Lng) < 0))
    goto label_16;

DEFLABEL (label_24)
  (Wrd31.Obj) = (Rsp [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if (! ((Wrd32.uLng) == 1))
    goto label_23;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [1]);
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_22)
  (Wrd40.Obj) = (Rsp [1]);
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if (! ((Wrd41.uLng) == 1))
    goto label_21;
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  (Wrd37.Obj) = ((Wrd39.pObj) [0]);

DEFLABEL (label_20)
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd51.uLng) == 26))
    goto label_19;
  (Wrd53.Lng) = (FIXNUM_TO_LONG (Wrd37.Obj));
  (Wrd52.Lng) = ((Wrd53.Lng) - 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd52.Lng)))
    goto label_19;
  (Wrd50.Obj) = (LONG_TO_FIXNUM (Wrd52.Lng));

DEFLABEL (label_18)
  (Wrd54.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd50.Obj);
  (* (Rhp++)) = (Wrd54.Obj);
  goto label_15;

DEFLABEL (label_19)
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90_9]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_INTERFACE_0 (34);

DEFLABEL (label_12)
  (Wrd50.Obj) = Rvl;
  goto label_18;

DEFLABEL (label_21)
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90_8]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_90_0]), 1);

DEFLABEL (label_11)
  (Wrd37.Obj) = Rvl;
  goto label_20;

DEFLABEL (label_23)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90_7]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd31.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_90_1]), 1);

DEFLABEL (label_10)
  (* (--Rsp)) = Rvl;
  goto label_22;

DEFLABEL (label_25)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90_6]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_INTERFACE_0 (42);

DEFLABEL (label_9)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_16;
  goto label_24;

DEFLABEL (label_27)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90_5]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_90_0]), 1);

DEFLABEL (label_8)
  (Wrd13.Obj) = Rvl;
  goto label_26;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_91_4 3
#define LABEL_91_5 5
#define ENVIRONMENT_LABEL_91_3 12
#define DEBUGGING_LABEL_91_2 11
#define EXECUTE_CACHE_91_7 7
#define EXECUTE_CACHE_91_6 9
#define FREE_REFERENCES_LABEL_91_0 6
#define NUMBER_OF_LINKER_SECTIONS_91_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_91 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_91_4);
      goto selector_add_cadr_1;

    case 1:
      current_block = (Rpc - LABEL_91_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (selector_add_cadr_4)
DEFLABEL (selector_add_cadr_1)
  INTERRUPT_CHECK (26, LABEL_91_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_91_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_91_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_91_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_91_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_92_4 3
#define LABEL_92_5 5
#define ENVIRONMENT_LABEL_92_3 10
#define DEBUGGING_LABEL_92_2 9
#define EXECUTE_CACHE_92_6 7
#define FREE_REFERENCES_LABEL_92_0 6
#define NUMBER_OF_LINKER_SECTIONS_92_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_92 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_92_4);
      goto selector_add_cddr_1;

    case 1:
      current_block = (Rpc - LABEL_92_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (selector_add_cddr_4)
DEFLABEL (selector_add_cddr_1)
  INTERRUPT_CHECK (26, LABEL_92_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_92_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_92_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_92_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_92_6]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_93_4 3
#define LABEL_93_5 5
#define LABEL_93_6 7
#define LABEL_93_7 9
#define LABEL_93_12 11
#define LABEL_93_9 13
#define LABEL_93_10 15
#define LABEL_93_13 17
#define ENVIRONMENT_LABEL_93_3 27
#define DEBUGGING_LABEL_93_2 26
#define OBJECT_93_2 25
#define OBJECT_93_1 24
#define OBJECT_93_0 23
#define EXECUTE_CACHE_93_11 19
#define EXECUTE_CACHE_93_8 21
#define FREE_REFERENCES_LABEL_93_0 18
#define NUMBER_OF_LINKER_SECTIONS_93_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_93 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd15;
  machine_word Wrd10;
  machine_word Wrd17;
  machine_word Wrd11;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_93_4);
      goto select_map_10;

    case 1:
      current_block = (Rpc - LABEL_93_5);
      goto loop_8;

    case 2:
      current_block = (Rpc - LABEL_93_6);
      goto continuation_7;

    case 3:
      current_block = (Rpc - LABEL_93_7);
      goto continuation_6;

    case 4:
      current_block = (Rpc - LABEL_93_12);
      goto label_12;

    case 5:
      current_block = (Rpc - LABEL_93_9);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_93_10);
      goto continuation_3;

    case 7:
      current_block = (Rpc - LABEL_93_13);
      goto label_13;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (select_map_15)
DEFLABEL (select_map_10)
  INTERRUPT_CHECK (26, LABEL_93_4);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  Rdl = (& (Rsp [6]));
  goto loop_8;

DEFLABEL (loop_16)
DEFLABEL (loop_8)
  DLINK_INTERRUPT_CHECK (25, LABEL_93_5);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_17;
  Rvl = (current_block [OBJECT_93_0]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_17)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93_6]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd14.pObj)));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93_7]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_93_8]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_93_7);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd10.Obj) = (Rsp [4]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_21;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [1]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_20)
  Rdl = (& (Rsp [3]));
  goto loop_8;

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_93_6);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93_9]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93_10]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_93_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_93_10);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd10.Obj) = (Rsp [4]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_19;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_18)
  (Wrd20.Obj) = (Rsp [7]);
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [0]);
  (* (--Rsp)) = (Wrd22.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_93_9);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd7.Obj);
  (Wrd10.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd10.pObj)));
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_19)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93_13]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_93_2]), 1);

DEFLABEL (label_13)
  (Wrd12.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd12.Obj));
  (* (--Rsp)) = Rvl;
  goto label_18;

DEFLABEL (label_21)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93_12]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_93_1]), 1);

DEFLABEL (label_12)
  (Wrd12.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd12.Obj));
  (* (--Rsp)) = Rvl;
  goto label_20;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_94_4 3
#define LABEL_94_5 5
#define LABEL_94_6 7
#define LABEL_94_9 9
#define LABEL_94_7 11
#define LABEL_94_12 13
#define LABEL_94_10 15
#define ENVIRONMENT_LABEL_94_3 25
#define DEBUGGING_LABEL_94_2 24
#define OBJECT_94_2 23
#define OBJECT_94_1 22
#define OBJECT_94_0 21
#define EXECUTE_CACHE_94_11 17
#define EXECUTE_CACHE_94_8 19
#define FREE_REFERENCES_LABEL_94_0 16
#define NUMBER_OF_LINKER_SECTIONS_94_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_94 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd7;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_94_4);
      goto select_for_each_9;

    case 1:
      current_block = (Rpc - LABEL_94_5);
      goto loop_7;

    case 2:
      current_block = (Rpc - LABEL_94_6);
      goto continuation_4;

    case 3:
      current_block = (Rpc - LABEL_94_9);
      goto label_11;

    case 4:
      current_block = (Rpc - LABEL_94_7);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_94_12);
      goto label_12;

    case 6:
      current_block = (Rpc - LABEL_94_10);
      goto continuation_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (select_for_each_14)
DEFLABEL (select_for_each_9)
  INTERRUPT_CHECK (26, LABEL_94_4);
  (Wrd5.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd6.Obj);
  goto loop_7;

DEFLABEL (loop_15)
DEFLABEL (loop_7)
  INTERRUPT_CHECK (26, LABEL_94_5);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_16;
  Rvl = (current_block [OBJECT_94_0]);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_16)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_94_6]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_94_7]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_94_8]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_94_7);
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (Rsp [2]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_20;
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [0]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_19)
  (Wrd14.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd14.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_94_6);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_18;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_17)
  (Rsp [0]) = (Wrd5.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_94_10]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_94_11]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_94_10);
  (Rsp [1]) = Rvl;
  goto loop_7;

DEFLABEL (label_18)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_94_9]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_94_1]), 1);

DEFLABEL (label_11)
  (Wrd5.Obj) = Rvl;
  goto label_17;

DEFLABEL (label_20)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_94_12]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_94_2]), 1);

DEFLABEL (label_12)
  (* (--Rsp)) = Rvl;
  goto label_19;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_95_4 3
#define LABEL_95_5 5
#define ENVIRONMENT_LABEL_95_3 12
#define DEBUGGING_LABEL_95_2 11
#define EXECUTE_CACHE_95_7 7
#define EXECUTE_CACHE_95_6 9
#define FREE_REFERENCES_LABEL_95_0 6
#define NUMBER_OF_LINKER_SECTIONS_95_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_95 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_95_4);
      goto define_classifier_1;

    case 1:
      current_block = (Rpc - LABEL_95_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (define_classifier_4)
DEFLABEL (define_classifier_1)
  INTERRUPT_CHECK (26, LABEL_95_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_95_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_95_5);
  (Rsp [2]) = Rvl;
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd7.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_95_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_96_4 3
#define LABEL_96_5 5
#define ENVIRONMENT_LABEL_96_3 12
#define DEBUGGING_LABEL_96_2 11
#define EXECUTE_CACHE_96_7 7
#define EXECUTE_CACHE_96_6 9
#define FREE_REFERENCES_LABEL_96_0 6
#define NUMBER_OF_LINKER_SECTIONS_96_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_96 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_96_4);
      goto define_compiler_1;

    case 1:
      current_block = (Rpc - LABEL_96_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (define_compiler_4)
DEFLABEL (define_compiler_1)
  INTERRUPT_CHECK (26, LABEL_96_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_96_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_96_5);
  (Rsp [2]) = Rvl;
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd7.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_96_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_97_4 3
#define LABEL_97_5 5
#define ENVIRONMENT_LABEL_97_3 12
#define DEBUGGING_LABEL_97_2 11
#define EXECUTE_CACHE_97_7 7
#define EXECUTE_CACHE_97_6 9
#define FREE_REFERENCES_LABEL_97_0 6
#define NUMBER_OF_LINKER_SECTIONS_97_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_97 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_97_4);
      goto define_expander_1;

    case 1:
      current_block = (Rpc - LABEL_97_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (define_expander_4)
DEFLABEL (define_expander_1)
  INTERRUPT_CHECK (26, LABEL_97_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_97_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_97_5);
  (Rsp [2]) = Rvl;
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd7.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_97_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_98_4 3
#define LABEL_98_5 5
#define ENVIRONMENT_LABEL_98_3 12
#define DEBUGGING_LABEL_98_2 11
#define EXECUTE_CACHE_98_7 7
#define EXECUTE_CACHE_98_6 9
#define FREE_REFERENCES_LABEL_98_0 6
#define NUMBER_OF_LINKER_SECTIONS_98_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_98 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_98_4);
      goto classifier__keyword_1;

    case 1:
      current_block = (Rpc - LABEL_98_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (classifier__keyword_4)
DEFLABEL (classifier__keyword_1)
  INTERRUPT_CHECK (26, LABEL_98_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_98_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_98_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_98_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_98_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_99_4 3
#define LABEL_99_5 5
#define ENVIRONMENT_LABEL_99_3 12
#define DEBUGGING_LABEL_99_2 11
#define EXECUTE_CACHE_99_7 7
#define EXECUTE_CACHE_99_6 9
#define FREE_REFERENCES_LABEL_99_0 6
#define NUMBER_OF_LINKER_SECTIONS_99_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_99 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_99_4);
      goto compiler__keyword_1;

    case 1:
      current_block = (Rpc - LABEL_99_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (compiler__keyword_4)
DEFLABEL (compiler__keyword_1)
  INTERRUPT_CHECK (26, LABEL_99_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_99_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_99_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_99_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_99_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_100_4 3
#define LABEL_100_5 5
#define ENVIRONMENT_LABEL_100_3 12
#define DEBUGGING_LABEL_100_2 11
#define EXECUTE_CACHE_100_7 7
#define EXECUTE_CACHE_100_6 9
#define FREE_REFERENCES_LABEL_100_0 6
#define NUMBER_OF_LINKER_SECTIONS_100_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_100 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_100_4);
      goto expander__keyword_1;

    case 1:
      current_block = (Rpc - LABEL_100_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expander__keyword_4)
DEFLABEL (expander__keyword_1)
  INTERRUPT_CHECK (26, LABEL_100_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_100_5);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_101_4 3
#define LABEL_101_6 5
#define LABEL_101_5 7
#define LABEL_101_8 9
#define ENVIRONMENT_LABEL_101_3 21
#define DEBUGGING_LABEL_101_2 20
#define OBJECT_101_0 19
#define EXECUTE_CACHE_101_10 11
#define EXECUTE_CACHE_101_9 13
#define EXECUTE_CACHE_101_7 15
#define FREE_REFERENCE_101_0 18
#define FREE_REFERENCES_LABEL_101_0 10
#define NUMBER_OF_LINKER_SECTIONS_101_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_101 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_101_4);
      goto item__keyword_3;

    case 1:
      current_block = (Rpc - LABEL_101_6);
      goto label_5;

    case 2:
      current_block = (Rpc - LABEL_101_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_101_8);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (item__keyword_7)
DEFLABEL (item__keyword_3)
  INTERRUPT_CHECK (26, LABEL_101_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_101_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_9;
  Wrd8 = Wrd12;

DEFLABEL (label_8)
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_101_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_101_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_101_0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_101_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_101_8);
  (Wrd5.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_101_0]);
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_101_10]));

DEFLABEL (label_9)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_101_6])), (Wrd9.pObj));

DEFLABEL (label_5)
  (Wrd8.Obj) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_102_4 3
#define LABEL_102_5 5
#define ENVIRONMENT_LABEL_102_3 11
#define DEBUGGING_LABEL_102_2 10
#define OBJECT_102_0 9
#define EXECUTE_CACHE_102_6 7
#define FREE_REFERENCES_LABEL_102_0 6
#define NUMBER_OF_LINKER_SECTIONS_102_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_102 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_102_4);
      goto classifier__form_1;

    case 1:
      current_block = (Rpc - LABEL_102_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (classifier__form_4)
DEFLABEL (classifier__form_1)
  INTERRUPT_CHECK (26, LABEL_102_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_102_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_102_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_102_5);
  (Wrd10.Obj) = (current_block [OBJECT_102_0]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_103_4 3
#define LABEL_103_5 5
#define ENVIRONMENT_LABEL_103_3 11
#define DEBUGGING_LABEL_103_2 10
#define OBJECT_103_0 9
#define EXECUTE_CACHE_103_6 7
#define FREE_REFERENCES_LABEL_103_0 6
#define NUMBER_OF_LINKER_SECTIONS_103_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_103 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_103_4);
      goto compiler__form_1;

    case 1:
      current_block = (Rpc - LABEL_103_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (compiler__form_4)
DEFLABEL (compiler__form_1)
  INTERRUPT_CHECK (26, LABEL_103_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_103_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_103_5);
  (Wrd10.Obj) = (current_block [OBJECT_103_0]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_104_4 3
#define LABEL_104_5 5
#define ENVIRONMENT_LABEL_104_3 11
#define DEBUGGING_LABEL_104_2 10
#define OBJECT_104_0 9
#define EXECUTE_CACHE_104_6 7
#define FREE_REFERENCES_LABEL_104_0 6
#define NUMBER_OF_LINKER_SECTIONS_104_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_104 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_104_4);
      goto expander__form_1;

    case 1:
      current_block = (Rpc - LABEL_104_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expander__form_4)
DEFLABEL (expander__form_1)
  INTERRUPT_CHECK (26, LABEL_104_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_104_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_104_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_104_5);
  (Wrd10.Obj) = (current_block [OBJECT_104_0]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_105_4 3
#define LABEL_105_5 5
#define TAG_105_6 1
#define LABEL_105_8 7
#define LABEL_105_9 9
#define ENVIRONMENT_LABEL_105_3 18
#define DEBUGGING_LABEL_105_2 17
#define EXECUTE_CACHE_105_11 11
#define EXECUTE_CACHE_105_10 13
#define EXECUTE_CACHE_105_7 15
#define FREE_REFERENCES_LABEL_105_0 10
#define NUMBER_OF_LINKER_SECTIONS_105_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_105 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_105_4);
      goto capture_syntactic_environment_4;

    case 1:
      current_block = (Rpc - LABEL_105_5);
      goto lambda_8;

    case 2:
      current_block = (Rpc - LABEL_105_8);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_105_9);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (capture_syntactic_environment_7)
DEFLABEL (capture_syntactic_environment_4)
  INTERRUPT_CHECK (26, LABEL_105_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x505, 2);
  (* (Rhp++)) = (dispatch_base + TAG_105_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_105_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_105_7]));

DEFLABEL (lambda_8)
  CLOSURE_HEADER (LABEL_105_5);

DEFLABEL (lambda_3)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_105_8);
  (* (--Rsp)) = Rvl;
  (Rsp [2]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_9]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_105_10]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_105_9);
  (Rsp [5]) = Rvl;
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_105_11]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_106_4 3
#define LABEL_106_5 5
#define TAG_106_6 1
#define LABEL_106_8 7
#define LABEL_106_9 9
#define ENVIRONMENT_LABEL_106_3 18
#define DEBUGGING_LABEL_106_2 17
#define EXECUTE_CACHE_106_11 11
#define EXECUTE_CACHE_106_10 13
#define EXECUTE_CACHE_106_7 15
#define FREE_REFERENCES_LABEL_106_0 10
#define NUMBER_OF_LINKER_SECTIONS_106_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_106 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_106_4);
      goto capture_expansion_history_4;

    case 1:
      current_block = (Rpc - LABEL_106_5);
      goto lambda_8;

    case 2:
      current_block = (Rpc - LABEL_106_8);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_106_9);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (capture_expansion_history_7)
DEFLABEL (capture_expansion_history_4)
  INTERRUPT_CHECK (26, LABEL_106_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x505, 2);
  (* (Rhp++)) = (dispatch_base + TAG_106_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_106_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_106_7]));

DEFLABEL (lambda_8)
  CLOSURE_HEADER (LABEL_106_5);

DEFLABEL (lambda_3)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_106_8);
  (* (--Rsp)) = Rvl;
  (Rsp [2]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_9]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_106_10]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_106_9);
  (Rsp [5]) = Rvl;
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_106_11]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_107_4 3
#define LABEL_107_5 5
#define TAG_107_6 1
#define LABEL_107_8 7
#define TAG_107_9 2
#define LABEL_107_10 9
#define ENVIRONMENT_LABEL_107_3 19
#define DEBUGGING_LABEL_107_2 18
#define EXECUTE_CACHE_107_7 11
#define FREE_REFERENCE_107_0 14
#define GLOBAL_EXECUTE_CACHE_107_11 16
#define FREE_REFERENCES_LABEL_107_0 10
#define NUMBER_OF_LINKER_SECTIONS_107_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_107 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd14;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_107_4);
      goto call_with_syntax_error_procedure_3;

    case 1:
      current_block = (Rpc - LABEL_107_5);
      goto lambda_8;

    case 2:
      current_block = (Rpc - LABEL_107_8);
      goto lambda_9;

    case 3:
      current_block = (Rpc - LABEL_107_10);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (call_with_syntax_error_procedure_7)
DEFLABEL (call_with_syntax_error_procedure_3)
  INTERRUPT_CHECK (26, LABEL_107_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_107_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_107_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_107_7]));

DEFLABEL (lambda_8)
  CLOSURE_HEADER (LABEL_107_5);

DEFLABEL (lambda_2)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x1fe, 2);
  (* (Rhp++)) = (dispatch_base + TAG_107_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_107_8])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [2]);
  (Rsp [0]) = (Wrd10.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (lambda_9)
  CLOSURE_HEADER (LABEL_107_8);

DEFLABEL (lambda_1)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (Wrd11.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd14.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_107_0]));
  (Wrd17.Obj) = ((Wrd14.pObj) [0]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd18.uLng) == 50)
    goto label_11;
  Wrd13 = Wrd17;

DEFLABEL (label_10)
  (Rsp [0]) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_107_11]));

DEFLABEL (label_11)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_107_10])), (Wrd14.pObj));

DEFLABEL (label_5)
  (Wrd13.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_108_4 3
#define LABEL_108_5 5
#define ENVIRONMENT_LABEL_108_3 12
#define DEBUGGING_LABEL_108_2 11
#define EXECUTE_CACHE_108_6 7
#define FREE_REFERENCE_108_0 10
#define FREE_REFERENCES_LABEL_108_0 6
#define NUMBER_OF_LINKER_SECTIONS_108_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_108 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_108_4);
      goto flatten_body_items_0;

    case 1:
      current_block = (Rpc - LABEL_108_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (flatten_body_items_4)
DEFLABEL (flatten_body_items_0)
  INTERRUPT_CHECK (26, LABEL_108_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_108_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_6;
  Wrd5 = Wrd9;

DEFLABEL (label_5)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_108_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_108_5])), (Wrd6.pObj));

DEFLABEL (label_2)
  (Wrd5.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_109_4 3
#define LABEL_109_5 5
#define LABEL_109_7 7
#define ENVIRONMENT_LABEL_109_3 17
#define DEBUGGING_LABEL_109_2 16
#define OBJECT_109_0 15
#define EXECUTE_CACHE_109_9 9
#define EXECUTE_CACHE_109_8 11
#define EXECUTE_CACHE_109_6 13
#define FREE_REFERENCES_LABEL_109_0 8
#define NUMBER_OF_LINKER_SECTIONS_109_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_109 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd13;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_109_4);
      goto item__list_2;

    case 1:
      current_block = (Rpc - LABEL_109_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_109_7);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (item__list_5)
DEFLABEL (item__list_2)
  INTERRUPT_CHECK (26, LABEL_109_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_109_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_109_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_109_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_6;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.Obj) = (current_block [OBJECT_109_0]);
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (Wrd13.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd13.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_6)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_109_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_109_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_109_7);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_109_9]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_110_4 3
#define LABEL_110_5 5
#define TAG_110_6 1
#define LABEL_110_8 7
#define ENVIRONMENT_LABEL_110_3 14
#define DEBUGGING_LABEL_110_2 13
#define EXECUTE_CACHE_110_9 9
#define EXECUTE_CACHE_110_7 11
#define FREE_REFERENCES_LABEL_110_0 8
#define NUMBER_OF_LINKER_SECTIONS_110_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
syntactic_closures_so_code_110 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_110_4);
      goto reverse_syntactic_environments_2;

    case 1:
      current_block = (Rpc - LABEL_110_5);
      goto lambda_6;

    case 2:
      current_block = (Rpc - LABEL_110_8);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (reverse_syntactic_environments_5)
DEFLABEL (reverse_syntactic_environments_2)
  INTERRUPT_CHECK (26, LABEL_110_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_110_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_110_5])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_110_7]));

DEFLABEL (lambda_6)
  CLOSURE_HEADER (LABEL_110_5);

DEFLABEL (lambda_1)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_110_8]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_110_8);
  (Rsp [1]) = Rvl;
  (Wrd6.Obj) = (* (Rsp++));
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_110_9]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4 3
#define LABEL_6 5
#define LABEL_11 7
#define LABEL_7 9
#define LABEL_9 11
#define LABEL_15 13
#define LABEL_10 15
#define LABEL_13 17
#define LABEL_19 19
#define LABEL_14 21
#define LABEL_17 23
#define LABEL_23 25
#define LABEL_18 27
#define LABEL_21 29
#define LABEL_26 31
#define LABEL_22 33
#define LABEL_24 35
#define LABEL_25 37
#define LABEL_27 39
#define LABEL_28 41
#define LABEL_32 43
#define LABEL_29 45
#define LABEL_30 47
#define LABEL_35 49
#define LABEL_31 51
#define LABEL_33 53
#define LABEL_34 55
#define LABEL_36 57
#define LABEL_37 59
#define LABEL_39 61
#define LABEL_40 63
#define LABEL_44 65
#define LABEL_41 67
#define LABEL_42 69
#define LABEL_47 71
#define LABEL_43 73
#define LABEL_45 75
#define LABEL_50 77
#define LABEL_46 79
#define LABEL_48 81
#define LABEL_53 83
#define LABEL_49 85
#define LABEL_51 87
#define LABEL_56 89
#define LABEL_52 91
#define LABEL_54 93
#define LABEL_55 95
#define LABEL_58 97
#define LABEL_59 99
#define LABEL_63 101
#define LABEL_60 103
#define LABEL_61 105
#define LABEL_66 107
#define LABEL_62 109
#define LABEL_64 111
#define LABEL_69 113
#define LABEL_65 115
#define LABEL_67 117
#define LABEL_72 119
#define LABEL_68 121
#define LABEL_70 123
#define LABEL_75 125
#define LABEL_71 127
#define LABEL_73 129
#define LABEL_78 131
#define LABEL_74 133
#define LABEL_76 135
#define LABEL_81 137
#define LABEL_77 139
#define LABEL_79 141
#define LABEL_84 143
#define LABEL_80 145
#define LABEL_82 147
#define LABEL_83 149
#define LABEL_85 151
#define LABEL_86 153
#define LABEL_90 155
#define LABEL_87 157
#define LABEL_88 159
#define LABEL_93 161
#define LABEL_89 163
#define LABEL_91 165
#define LABEL_96 167
#define LABEL_92 169
#define LABEL_94 171
#define LABEL_99 173
#define LABEL_95 175
#define LABEL_97 177
#define LABEL_102 179
#define LABEL_98 181
#define LABEL_100 183
#define LABEL_101 185
#define LABEL_103 187
#define LABEL_106 189
#define LABEL_104 191
#define LABEL_109 193
#define LABEL_105 195
#define LABEL_107 197
#define LABEL_108 199
#define LABEL_110 201
#define LABEL_113 203
#define LABEL_111 205
#define LABEL_112 207
#define LABEL_114 209
#define LABEL_115 211
#define LABEL_120 213
#define LABEL_116 215
#define LABEL_118 217
#define LABEL_124 219
#define LABEL_119 221
#define LABEL_122 223
#define LABEL_123 225
#define LABEL_126 227
#define LABEL_127 229
#define LABEL_132 231
#define LABEL_128 233
#define LABEL_130 235
#define LABEL_136 237
#define LABEL_131 239
#define LABEL_134 241
#define LABEL_139 243
#define LABEL_135 245
#define LABEL_137 247
#define LABEL_138 249
#define LABEL_141 251
#define LABEL_145 253
#define LABEL_142 255
#define LABEL_143 257
#define LABEL_148 259
#define LABEL_144 261
#define LABEL_146 263
#define LABEL_151 265
#define LABEL_147 267
#define LABEL_149 269
#define LABEL_153 271
#define LABEL_154 273
#define LABEL_150 275
#define LABEL_152 277
#define LABEL_158 279
#define LABEL_156 281
#define LABEL_161 283
#define LABEL_157 285
#define LABEL_159 287
#define LABEL_164 289
#define LABEL_160 291
#define LABEL_162 293
#define LABEL_163 295
#define LABEL_165 297
#define LABEL_169 299
#define LABEL_166 301
#define LABEL_167 303
#define LABEL_172 305
#define LABEL_168 307
#define LABEL_170 309
#define LABEL_175 311
#define LABEL_171 313
#define LABEL_173 315
#define LABEL_178 317
#define LABEL_174 319
#define LABEL_176 321
#define LABEL_177 323
#define LABEL_179 325
#define LABEL_180 327
#define LABEL_184 329
#define LABEL_181 331
#define LABEL_182 333
#define LABEL_187 335
#define LABEL_183 337
#define LABEL_185 339
#define LABEL_192 341
#define LABEL_186 343
#define LABEL_188 345
#define TAG_189 171
#define LABEL_190 347
#define LABEL_191 349
#define LABEL_193 351
#define LABEL_197 353
#define LABEL_194 355
#define LABEL_195 357
#define LABEL_200 359
#define LABEL_196 361
#define LABEL_198 363
#define LABEL_203 365
#define LABEL_199 367
#define LABEL_201 369
#define LABEL_206 371
#define LABEL_202 373
#define LABEL_204 375
#define LABEL_205 377
#define LABEL_207 379
#define LABEL_208 381
#define LABEL_212 383
#define LABEL_209 385
#define LABEL_210 387
#define LABEL_215 389
#define LABEL_211 391
#define LABEL_213 393
#define LABEL_214 395
#define LABEL_216 397
#define LABEL_220 399
#define LABEL_217 401
#define LABEL_218 403
#define LABEL_223 405
#define LABEL_219 407
#define LABEL_221 409
#define LABEL_226 411
#define LABEL_222 413
#define LABEL_224 415
#define LABEL_225 417
#define LABEL_227 419
#define LABEL_228 421
#define LABEL_229 423
#define TAG_230 210
#define LABEL_231 425
#define LABEL_235 427
#define LABEL_232 429
#define LABEL_233 431
#define LABEL_238 433
#define LABEL_234 435
#define LABEL_236 437
#define LABEL_241 439
#define LABEL_237 441
#define LABEL_239 443
#define LABEL_240 445
#define LABEL_242 447
#define LABEL_246 449
#define LABEL_243 451
#define LABEL_244 453
#define LABEL_249 455
#define LABEL_245 457
#define LABEL_247 459
#define LABEL_252 461
#define LABEL_248 463
#define LABEL_250 465
#define LABEL_255 467
#define LABEL_251 469
#define LABEL_253 471
#define LABEL_254 473
#define LABEL_256 475
#define LABEL_260 477
#define LABEL_257 479
#define LABEL_258 481
#define LABEL_263 483
#define LABEL_259 485
#define LABEL_261 487
#define LABEL_262 489
#define LABEL_264 491
#define LABEL_267 493
#define LABEL_265 495
#define LABEL_271 497
#define LABEL_266 499
#define LABEL_269 501
#define LABEL_275 503
#define LABEL_270 505
#define LABEL_273 507
#define LABEL_278 509
#define LABEL_274 511
#define LABEL_276 513
#define LABEL_281 515
#define LABEL_277 517
#define LABEL_279 519
#define LABEL_284 521
#define LABEL_280 523
#define LABEL_282 525
#define LABEL_287 527
#define LABEL_283 529
#define LABEL_285 531
#define LABEL_290 533
#define LABEL_286 535
#define LABEL_288 537
#define LABEL_293 539
#define LABEL_289 541
#define LABEL_291 543
#define LABEL_296 545
#define LABEL_292 547
#define LABEL_294 549
#define LABEL_299 551
#define LABEL_295 553
#define LABEL_297 555
#define LABEL_302 557
#define LABEL_298 559
#define LABEL_300 561
#define LABEL_305 563
#define LABEL_301 565
#define LABEL_303 567
#define LABEL_308 569
#define LABEL_304 571
#define LABEL_306 573
#define LABEL_311 575
#define LABEL_307 577
#define LABEL_309 579
#define LABEL_314 581
#define LABEL_310 583
#define LABEL_312 585
#define LABEL_317 587
#define LABEL_313 589
#define LABEL_315 591
#define LABEL_320 593
#define LABEL_316 595
#define LABEL_318 597
#define LABEL_323 599
#define LABEL_319 601
#define LABEL_321 603
#define LABEL_326 605
#define LABEL_322 607
#define LABEL_324 609
#define LABEL_329 611
#define LABEL_325 613
#define LABEL_327 615
#define LABEL_332 617
#define LABEL_328 619
#define LABEL_330 621
#define LABEL_335 623
#define LABEL_331 625
#define LABEL_333 627
#define LABEL_338 629
#define LABEL_334 631
#define LABEL_336 633
#define LABEL_341 635
#define LABEL_337 637
#define LABEL_339 639
#define LABEL_344 641
#define LABEL_340 643
#define LABEL_342 645
#define LABEL_347 647
#define LABEL_343 649
#define LABEL_345 651
#define LABEL_350 653
#define LABEL_346 655
#define LABEL_348 657
#define LABEL_353 659
#define LABEL_349 661
#define LABEL_351 663
#define LABEL_356 665
#define LABEL_352 667
#define LABEL_354 669
#define LABEL_355 671
#define LABEL_357 673
#define LABEL_358 675
#define LABEL_359 677
#define ENVIRONMENT_LABEL_3 944
#define DEBUGGING_LABEL_2 943
#define PURIFICATION_ROOT 942
#define OBJECT_194 941
#define OBJECT_193 940
#define OBJECT_192 939
#define OBJECT_191 938
#define OBJECT_190 937
#define OBJECT_189 936
#define OBJECT_188 935
#define OBJECT_187 934
#define OBJECT_186 933
#define OBJECT_185 932
#define OBJECT_184 931
#define OBJECT_183 930
#define OBJECT_182 929
#define OBJECT_181 928
#define OBJECT_180 927
#define OBJECT_179 926
#define OBJECT_178 925
#define OBJECT_177 924
#define OBJECT_176 923
#define OBJECT_175 922
#define OBJECT_174 921
#define OBJECT_173 920
#define OBJECT_172 919
#define OBJECT_171 918
#define OBJECT_170 917
#define OBJECT_169 916
#define OBJECT_168 915
#define OBJECT_167 914
#define OBJECT_166 913
#define OBJECT_165 912
#define OBJECT_164 911
#define OBJECT_163 910
#define OBJECT_162 909
#define OBJECT_161 908
#define OBJECT_160 907
#define OBJECT_159 906
#define OBJECT_158 905
#define OBJECT_157 904
#define OBJECT_156 903
#define OBJECT_155 902
#define OBJECT_154 901
#define OBJECT_153 900
#define OBJECT_152 899
#define OBJECT_151 898
#define OBJECT_150 897
#define OBJECT_149 896
#define OBJECT_148 895
#define OBJECT_147 894
#define OBJECT_146 893
#define OBJECT_145 892
#define OBJECT_144 891
#define OBJECT_143 890
#define OBJECT_142 889
#define OBJECT_141 888
#define OBJECT_140 887
#define OBJECT_139 886
#define OBJECT_138 885
#define OBJECT_137 884
#define OBJECT_136 883
#define OBJECT_135 882
#define OBJECT_134 881
#define OBJECT_133 880
#define OBJECT_132 879
#define OBJECT_131 878
#define OBJECT_130 877
#define OBJECT_129 876
#define OBJECT_128 875
#define OBJECT_127 874
#define OBJECT_126 873
#define OBJECT_125 872
#define OBJECT_124 871
#define OBJECT_123 870
#define OBJECT_122 869
#define OBJECT_121 868
#define OBJECT_120 867
#define OBJECT_119 866
#define OBJECT_118 865
#define OBJECT_117 864
#define OBJECT_116 863
#define OBJECT_115 862
#define OBJECT_114 861
#define OBJECT_113 860
#define OBJECT_112 859
#define OBJECT_111 858
#define OBJECT_110 857
#define OBJECT_109 856
#define OBJECT_108 855
#define OBJECT_107 854
#define OBJECT_106 853
#define OBJECT_105 852
#define OBJECT_104 851
#define OBJECT_103 850
#define OBJECT_102 849
#define OBJECT_101 848
#define OBJECT_100 847
#define OBJECT_99 846
#define OBJECT_98 845
#define OBJECT_97 844
#define OBJECT_96 843
#define OBJECT_95 842
#define OBJECT_94 841
#define OBJECT_93 840
#define OBJECT_92 839
#define OBJECT_91 838
#define OBJECT_90 837
#define OBJECT_89 836
#define OBJECT_88 835
#define OBJECT_87 834
#define OBJECT_86 833
#define OBJECT_85 832
#define OBJECT_84 831
#define OBJECT_83 830
#define OBJECT_82 829
#define OBJECT_81 828
#define OBJECT_80 827
#define OBJECT_79 826
#define OBJECT_78 825
#define OBJECT_77 824
#define OBJECT_76 823
#define OBJECT_75 822
#define OBJECT_74 821
#define OBJECT_73 820
#define OBJECT_72 819
#define OBJECT_71 818
#define OBJECT_70 817
#define OBJECT_69 816
#define OBJECT_68 815
#define OBJECT_67 814
#define OBJECT_66 813
#define OBJECT_65 812
#define OBJECT_64 811
#define OBJECT_63 810
#define OBJECT_62 809
#define OBJECT_61 808
#define OBJECT_60 807
#define OBJECT_59 806
#define OBJECT_58 805
#define OBJECT_57 804
#define OBJECT_56 803
#define OBJECT_55 802
#define OBJECT_54 801
#define OBJECT_53 800
#define OBJECT_52 799
#define OBJECT_51 798
#define OBJECT_50 797
#define OBJECT_49 796
#define OBJECT_48 795
#define OBJECT_47 794
#define OBJECT_46 793
#define OBJECT_45 792
#define OBJECT_44 791
#define OBJECT_43 790
#define OBJECT_42 789
#define OBJECT_41 788
#define OBJECT_40 787
#define OBJECT_39 786
#define OBJECT_38 785
#define OBJECT_37 784
#define OBJECT_36 783
#define OBJECT_35 782
#define OBJECT_34 781
#define OBJECT_33 780
#define OBJECT_32 779
#define OBJECT_31 778
#define OBJECT_30 777
#define OBJECT_29 776
#define OBJECT_28 775
#define OBJECT_27 774
#define OBJECT_26 773
#define OBJECT_25 772
#define OBJECT_24 771
#define OBJECT_23 770
#define OBJECT_22 769
#define OBJECT_21 768
#define OBJECT_20 767
#define OBJECT_19 766
#define OBJECT_18 765
#define OBJECT_17 764
#define OBJECT_16 763
#define OBJECT_15 762
#define OBJECT_14 761
#define OBJECT_13 760
#define OBJECT_12 759
#define OBJECT_11 758
#define OBJECT_10 757
#define OBJECT_9 756
#define OBJECT_8 755
#define OBJECT_7 754
#define OBJECT_6 753
#define OBJECT_5 752
#define OBJECT_4 751
#define OBJECT_3 750
#define OBJECT_2 749
#define OBJECT_1 748
#define OBJECT_0 747
#define EXECUTE_CACHE_272 679
#define EXECUTE_CACHE_268 681
#define EXECUTE_CACHE_155 683
#define EXECUTE_CACHE_140 685
#define EXECUTE_CACHE_133 687
#define EXECUTE_CACHE_129 689
#define EXECUTE_CACHE_125 691
#define EXECUTE_CACHE_121 693
#define EXECUTE_CACHE_117 695
#define EXECUTE_CACHE_57 697
#define EXECUTE_CACHE_38 699
#define EXECUTE_CACHE_20 701
#define EXECUTE_CACHE_16 703
#define EXECUTE_CACHE_12 705
#define EXECUTE_CACHE_8 707
#define FREE_REFERENCE_33 710
#define FREE_REFERENCE_32 711
#define FREE_REFERENCE_31 712
#define FREE_REFERENCE_30 713
#define FREE_REFERENCE_29 714
#define FREE_REFERENCE_28 715
#define FREE_REFERENCE_27 716
#define FREE_REFERENCE_26 717
#define FREE_REFERENCE_25 718
#define FREE_REFERENCE_24 719
#define FREE_REFERENCE_23 720
#define FREE_REFERENCE_22 721
#define FREE_REFERENCE_21 722
#define FREE_REFERENCE_20 723
#define FREE_REFERENCE_19 724
#define FREE_REFERENCE_18 725
#define FREE_REFERENCE_17 726
#define FREE_REFERENCE_16 727
#define FREE_REFERENCE_15 728
#define FREE_REFERENCE_14 729
#define FREE_REFERENCE_13 730
#define FREE_REFERENCE_12 731
#define FREE_REFERENCE_11 732
#define FREE_REFERENCE_10 733
#define FREE_REFERENCE_9 734
#define FREE_REFERENCE_8 735
#define FREE_REFERENCE_7 736
#define FREE_REFERENCE_6 737
#define FREE_REFERENCE_5 738
#define FREE_REFERENCE_4 739
#define FREE_REFERENCE_3 740
#define FREE_REFERENCE_2 741
#define FREE_REFERENCE_1 742
#define FREE_REFERENCE_0 743
#define GLOBAL_EXECUTE_CACHE_5 745
#define FREE_REFERENCES_LABEL_0 678
#define NUMBER_OF_LINKER_SECTIONS_1 3

#ifndef WANT_ONLY_DATA

SCHEME_OBJECT *
syntactic_closures_so_878f33995e68d951 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd6;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_6);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_11);
      goto label_245;

    case 3:
      current_block = (Rpc - LABEL_7);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_9);
      goto continuation_4;

    case 5:
      current_block = (Rpc - LABEL_15);
      goto label_246;

    case 6:
      current_block = (Rpc - LABEL_10);
      goto continuation_3;

    case 7:
      current_block = (Rpc - LABEL_13);
      goto continuation_6;

    case 8:
      current_block = (Rpc - LABEL_19);
      goto label_247;

    case 9:
      current_block = (Rpc - LABEL_14);
      goto continuation_5;

    case 10:
      current_block = (Rpc - LABEL_17);
      goto continuation_8;

    case 11:
      current_block = (Rpc - LABEL_23);
      goto label_248;

    case 12:
      current_block = (Rpc - LABEL_18);
      goto continuation_7;

    case 13:
      current_block = (Rpc - LABEL_21);
      goto continuation_10;

    case 14:
      current_block = (Rpc - LABEL_26);
      goto label_249;

    case 15:
      current_block = (Rpc - LABEL_22);
      goto continuation_9;

    case 16:
      current_block = (Rpc - LABEL_24);
      goto continuation_12;

    case 17:
      current_block = (Rpc - LABEL_25);
      goto continuation_11;

    case 18:
      current_block = (Rpc - LABEL_27);
      goto continuation_13;

    case 19:
      current_block = (Rpc - LABEL_28);
      goto continuation_15;

    case 20:
      current_block = (Rpc - LABEL_32);
      goto label_250;

    case 21:
      current_block = (Rpc - LABEL_29);
      goto continuation_14;

    case 22:
      current_block = (Rpc - LABEL_30);
      goto continuation_17;

    case 23:
      current_block = (Rpc - LABEL_35);
      goto label_251;

    case 24:
      current_block = (Rpc - LABEL_31);
      goto continuation_16;

    case 25:
      current_block = (Rpc - LABEL_33);
      goto continuation_19;

    case 26:
      current_block = (Rpc - LABEL_34);
      goto continuation_18;

    case 27:
      current_block = (Rpc - LABEL_36);
      goto continuation_21;

    case 28:
      current_block = (Rpc - LABEL_37);
      goto continuation_20;

    case 29:
      current_block = (Rpc - LABEL_39);
      goto continuation_22;

    case 30:
      current_block = (Rpc - LABEL_40);
      goto continuation_24;

    case 31:
      current_block = (Rpc - LABEL_44);
      goto label_252;

    case 32:
      current_block = (Rpc - LABEL_41);
      goto continuation_23;

    case 33:
      current_block = (Rpc - LABEL_42);
      goto continuation_26;

    case 34:
      current_block = (Rpc - LABEL_47);
      goto label_253;

    case 35:
      current_block = (Rpc - LABEL_43);
      goto continuation_25;

    case 36:
      current_block = (Rpc - LABEL_45);
      goto continuation_28;

    case 37:
      current_block = (Rpc - LABEL_50);
      goto label_254;

    case 38:
      current_block = (Rpc - LABEL_46);
      goto continuation_27;

    case 39:
      current_block = (Rpc - LABEL_48);
      goto continuation_30;

    case 40:
      current_block = (Rpc - LABEL_53);
      goto label_255;

    case 41:
      current_block = (Rpc - LABEL_49);
      goto continuation_29;

    case 42:
      current_block = (Rpc - LABEL_51);
      goto continuation_32;

    case 43:
      current_block = (Rpc - LABEL_56);
      goto label_256;

    case 44:
      current_block = (Rpc - LABEL_52);
      goto continuation_31;

    case 45:
      current_block = (Rpc - LABEL_54);
      goto continuation_34;

    case 46:
      current_block = (Rpc - LABEL_55);
      goto continuation_33;

    case 47:
      current_block = (Rpc - LABEL_58);
      goto continuation_35;

    case 48:
      current_block = (Rpc - LABEL_59);
      goto continuation_37;

    case 49:
      current_block = (Rpc - LABEL_63);
      goto label_257;

    case 50:
      current_block = (Rpc - LABEL_60);
      goto continuation_36;

    case 51:
      current_block = (Rpc - LABEL_61);
      goto continuation_39;

    case 52:
      current_block = (Rpc - LABEL_66);
      goto label_258;

    case 53:
      current_block = (Rpc - LABEL_62);
      goto continuation_38;

    case 54:
      current_block = (Rpc - LABEL_64);
      goto continuation_41;

    case 55:
      current_block = (Rpc - LABEL_69);
      goto label_259;

    case 56:
      current_block = (Rpc - LABEL_65);
      goto continuation_40;

    case 57:
      current_block = (Rpc - LABEL_67);
      goto continuation_43;

    case 58:
      current_block = (Rpc - LABEL_72);
      goto label_260;

    case 59:
      current_block = (Rpc - LABEL_68);
      goto continuation_42;

    case 60:
      current_block = (Rpc - LABEL_70);
      goto continuation_45;

    case 61:
      current_block = (Rpc - LABEL_75);
      goto label_261;

    case 62:
      current_block = (Rpc - LABEL_71);
      goto continuation_44;

    case 63:
      current_block = (Rpc - LABEL_73);
      goto continuation_47;

    case 64:
      current_block = (Rpc - LABEL_78);
      goto label_262;

    case 65:
      current_block = (Rpc - LABEL_74);
      goto continuation_46;

    case 66:
      current_block = (Rpc - LABEL_76);
      goto continuation_49;

    case 67:
      current_block = (Rpc - LABEL_81);
      goto label_263;

    case 68:
      current_block = (Rpc - LABEL_77);
      goto continuation_48;

    case 69:
      current_block = (Rpc - LABEL_79);
      goto continuation_51;

    case 70:
      current_block = (Rpc - LABEL_84);
      goto label_264;

    case 71:
      current_block = (Rpc - LABEL_80);
      goto continuation_50;

    case 72:
      current_block = (Rpc - LABEL_82);
      goto continuation_53;

    case 73:
      current_block = (Rpc - LABEL_83);
      goto continuation_52;

    case 74:
      current_block = (Rpc - LABEL_85);
      goto continuation_54;

    case 75:
      current_block = (Rpc - LABEL_86);
      goto continuation_56;

    case 76:
      current_block = (Rpc - LABEL_90);
      goto label_265;

    case 77:
      current_block = (Rpc - LABEL_87);
      goto continuation_55;

    case 78:
      current_block = (Rpc - LABEL_88);
      goto continuation_58;

    case 79:
      current_block = (Rpc - LABEL_93);
      goto label_266;

    case 80:
      current_block = (Rpc - LABEL_89);
      goto continuation_57;

    case 81:
      current_block = (Rpc - LABEL_91);
      goto continuation_60;

    case 82:
      current_block = (Rpc - LABEL_96);
      goto label_267;

    case 83:
      current_block = (Rpc - LABEL_92);
      goto continuation_59;

    case 84:
      current_block = (Rpc - LABEL_94);
      goto continuation_62;

    case 85:
      current_block = (Rpc - LABEL_99);
      goto label_268;

    case 86:
      current_block = (Rpc - LABEL_95);
      goto continuation_61;

    case 87:
      current_block = (Rpc - LABEL_97);
      goto continuation_64;

    case 88:
      current_block = (Rpc - LABEL_102);
      goto label_269;

    case 89:
      current_block = (Rpc - LABEL_98);
      goto continuation_63;

    case 90:
      current_block = (Rpc - LABEL_100);
      goto continuation_66;

    case 91:
      current_block = (Rpc - LABEL_101);
      goto continuation_65;

    case 92:
      current_block = (Rpc - LABEL_103);
      goto continuation_67;

    case 93:
      current_block = (Rpc - LABEL_106);
      goto label_270;

    case 94:
      current_block = (Rpc - LABEL_104);
      goto continuation_69;

    case 95:
      current_block = (Rpc - LABEL_109);
      goto label_271;

    case 96:
      current_block = (Rpc - LABEL_105);
      goto continuation_68;

    case 97:
      current_block = (Rpc - LABEL_107);
      goto continuation_71;

    case 98:
      current_block = (Rpc - LABEL_108);
      goto continuation_70;

    case 99:
      current_block = (Rpc - LABEL_110);
      goto continuation_72;

    case 100:
      current_block = (Rpc - LABEL_113);
      goto label_272;

    case 101:
      current_block = (Rpc - LABEL_111);
      goto continuation_74;

    case 102:
      current_block = (Rpc - LABEL_112);
      goto continuation_73;

    case 103:
      current_block = (Rpc - LABEL_114);
      goto continuation_75;

    case 104:
      current_block = (Rpc - LABEL_115);
      goto continuation_77;

    case 105:
      current_block = (Rpc - LABEL_120);
      goto label_273;

    case 106:
      current_block = (Rpc - LABEL_116);
      goto continuation_76;

    case 107:
      current_block = (Rpc - LABEL_118);
      goto continuation_79;

    case 108:
      current_block = (Rpc - LABEL_124);
      goto label_274;

    case 109:
      current_block = (Rpc - LABEL_119);
      goto continuation_78;

    case 110:
      current_block = (Rpc - LABEL_122);
      goto continuation_81;

    case 111:
      current_block = (Rpc - LABEL_123);
      goto continuation_80;

    case 112:
      current_block = (Rpc - LABEL_126);
      goto continuation_82;

    case 113:
      current_block = (Rpc - LABEL_127);
      goto continuation_84;

    case 114:
      current_block = (Rpc - LABEL_132);
      goto label_275;

    case 115:
      current_block = (Rpc - LABEL_128);
      goto continuation_83;

    case 116:
      current_block = (Rpc - LABEL_130);
      goto continuation_86;

    case 117:
      current_block = (Rpc - LABEL_136);
      goto label_276;

    case 118:
      current_block = (Rpc - LABEL_131);
      goto continuation_85;

    case 119:
      current_block = (Rpc - LABEL_134);
      goto continuation_88;

    case 120:
      current_block = (Rpc - LABEL_139);
      goto label_277;

    case 121:
      current_block = (Rpc - LABEL_135);
      goto continuation_87;

    case 122:
      current_block = (Rpc - LABEL_137);
      goto continuation_90;

    case 123:
      current_block = (Rpc - LABEL_138);
      goto continuation_89;

    case 124:
      current_block = (Rpc - LABEL_141);
      goto continuation_92;

    case 125:
      current_block = (Rpc - LABEL_145);
      goto label_278;

    case 126:
      current_block = (Rpc - LABEL_142);
      goto continuation_91;

    case 127:
      current_block = (Rpc - LABEL_143);
      goto continuation_94;

    case 128:
      current_block = (Rpc - LABEL_148);
      goto label_279;

    case 129:
      current_block = (Rpc - LABEL_144);
      goto continuation_93;

    case 130:
      current_block = (Rpc - LABEL_146);
      goto continuation_96;

    case 131:
      current_block = (Rpc - LABEL_151);
      goto label_280;

    case 132:
      current_block = (Rpc - LABEL_147);
      goto continuation_95;

    case 133:
      current_block = (Rpc - LABEL_149);
      goto continuation_98;

    case 134:
      current_block = (Rpc - LABEL_153);
      goto label_281;

    case 135:
      current_block = (Rpc - LABEL_154);
      goto label_282;

    case 136:
      current_block = (Rpc - LABEL_150);
      goto continuation_97;

    case 137:
      current_block = (Rpc - LABEL_152);
      goto continuation_99;

    case 138:
      current_block = (Rpc - LABEL_158);
      goto label_283;

    case 139:
      current_block = (Rpc - LABEL_156);
      goto continuation_101;

    case 140:
      current_block = (Rpc - LABEL_161);
      goto label_284;

    case 141:
      current_block = (Rpc - LABEL_157);
      goto continuation_100;

    case 142:
      current_block = (Rpc - LABEL_159);
      goto continuation_103;

    case 143:
      current_block = (Rpc - LABEL_164);
      goto label_285;

    case 144:
      current_block = (Rpc - LABEL_160);
      goto continuation_102;

    case 145:
      current_block = (Rpc - LABEL_162);
      goto continuation_105;

    case 146:
      current_block = (Rpc - LABEL_163);
      goto continuation_104;

    case 147:
      current_block = (Rpc - LABEL_165);
      goto continuation_107;

    case 148:
      current_block = (Rpc - LABEL_169);
      goto label_286;

    case 149:
      current_block = (Rpc - LABEL_166);
      goto continuation_106;

    case 150:
      current_block = (Rpc - LABEL_167);
      goto continuation_109;

    case 151:
      current_block = (Rpc - LABEL_172);
      goto label_287;

    case 152:
      current_block = (Rpc - LABEL_168);
      goto continuation_108;

    case 153:
      current_block = (Rpc - LABEL_170);
      goto continuation_111;

    case 154:
      current_block = (Rpc - LABEL_175);
      goto label_288;

    case 155:
      current_block = (Rpc - LABEL_171);
      goto continuation_110;

    case 156:
      current_block = (Rpc - LABEL_173);
      goto continuation_113;

    case 157:
      current_block = (Rpc - LABEL_178);
      goto label_289;

    case 158:
      current_block = (Rpc - LABEL_174);
      goto continuation_112;

    case 159:
      current_block = (Rpc - LABEL_176);
      goto continuation_115;

    case 160:
      current_block = (Rpc - LABEL_177);
      goto continuation_114;

    case 161:
      current_block = (Rpc - LABEL_179);
      goto continuation_116;

    case 162:
      current_block = (Rpc - LABEL_180);
      goto continuation_118;

    case 163:
      current_block = (Rpc - LABEL_184);
      goto label_290;

    case 164:
      current_block = (Rpc - LABEL_181);
      goto continuation_117;

    case 165:
      current_block = (Rpc - LABEL_182);
      goto continuation_123;

    case 166:
      current_block = (Rpc - LABEL_187);
      goto label_291;

    case 167:
      current_block = (Rpc - LABEL_183);
      goto continuation_119;

    case 168:
      current_block = (Rpc - LABEL_185);
      goto continuation_125;

    case 169:
      current_block = (Rpc - LABEL_192);
      goto label_292;

    case 170:
      current_block = (Rpc - LABEL_186);
      goto continuation_124;

    case 171:
      current_block = (Rpc - LABEL_188);
      goto lambda_342;

    case 172:
      current_block = (Rpc - LABEL_190);
      goto continuation_127;

    case 173:
      current_block = (Rpc - LABEL_191);
      goto continuation_126;

    case 174:
      current_block = (Rpc - LABEL_193);
      goto continuation_129;

    case 175:
      current_block = (Rpc - LABEL_197);
      goto label_293;

    case 176:
      current_block = (Rpc - LABEL_194);
      goto continuation_128;

    case 177:
      current_block = (Rpc - LABEL_195);
      goto continuation_131;

    case 178:
      current_block = (Rpc - LABEL_200);
      goto label_294;

    case 179:
      current_block = (Rpc - LABEL_196);
      goto continuation_130;

    case 180:
      current_block = (Rpc - LABEL_198);
      goto continuation_133;

    case 181:
      current_block = (Rpc - LABEL_203);
      goto label_295;

    case 182:
      current_block = (Rpc - LABEL_199);
      goto continuation_132;

    case 183:
      current_block = (Rpc - LABEL_201);
      goto continuation_135;

    case 184:
      current_block = (Rpc - LABEL_206);
      goto label_296;

    case 185:
      current_block = (Rpc - LABEL_202);
      goto continuation_134;

    case 186:
      current_block = (Rpc - LABEL_204);
      goto continuation_137;

    case 187:
      current_block = (Rpc - LABEL_205);
      goto continuation_136;

    case 188:
      current_block = (Rpc - LABEL_207);
      goto continuation_138;

    case 189:
      current_block = (Rpc - LABEL_208);
      goto continuation_140;

    case 190:
      current_block = (Rpc - LABEL_212);
      goto label_297;

    case 191:
      current_block = (Rpc - LABEL_209);
      goto continuation_139;

    case 192:
      current_block = (Rpc - LABEL_210);
      goto continuation_142;

    case 193:
      current_block = (Rpc - LABEL_215);
      goto label_298;

    case 194:
      current_block = (Rpc - LABEL_211);
      goto continuation_141;

    case 195:
      current_block = (Rpc - LABEL_213);
      goto continuation_144;

    case 196:
      current_block = (Rpc - LABEL_214);
      goto continuation_143;

    case 197:
      current_block = (Rpc - LABEL_216);
      goto continuation_146;

    case 198:
      current_block = (Rpc - LABEL_220);
      goto label_299;

    case 199:
      current_block = (Rpc - LABEL_217);
      goto continuation_145;

    case 200:
      current_block = (Rpc - LABEL_218);
      goto continuation_148;

    case 201:
      current_block = (Rpc - LABEL_223);
      goto label_300;

    case 202:
      current_block = (Rpc - LABEL_219);
      goto continuation_147;

    case 203:
      current_block = (Rpc - LABEL_221);
      goto continuation_150;

    case 204:
      current_block = (Rpc - LABEL_226);
      goto label_301;

    case 205:
      current_block = (Rpc - LABEL_222);
      goto continuation_149;

    case 206:
      current_block = (Rpc - LABEL_224);
      goto continuation_156;

    case 207:
      current_block = (Rpc - LABEL_225);
      goto continuation_151;

    case 208:
      current_block = (Rpc - LABEL_227);
      goto continuation_158;

    case 209:
      current_block = (Rpc - LABEL_228);
      goto continuation_157;

    case 210:
      current_block = (Rpc - LABEL_229);
      goto lambda_343;

    case 211:
      current_block = (Rpc - LABEL_231);
      goto continuation_159;

    case 212:
      current_block = (Rpc - LABEL_235);
      goto label_302;

    case 213:
      current_block = (Rpc - LABEL_232);
      goto continuation_153;

    case 214:
      current_block = (Rpc - LABEL_233);
      goto continuation_161;

    case 215:
      current_block = (Rpc - LABEL_238);
      goto label_303;

    case 216:
      current_block = (Rpc - LABEL_234);
      goto continuation_160;

    case 217:
      current_block = (Rpc - LABEL_236);
      goto continuation_163;

    case 218:
      current_block = (Rpc - LABEL_241);
      goto label_304;

    case 219:
      current_block = (Rpc - LABEL_237);
      goto continuation_162;

    case 220:
      current_block = (Rpc - LABEL_239);
      goto continuation_165;

    case 221:
      current_block = (Rpc - LABEL_240);
      goto continuation_164;

    case 222:
      current_block = (Rpc - LABEL_242);
      goto continuation_167;

    case 223:
      current_block = (Rpc - LABEL_246);
      goto label_305;

    case 224:
      current_block = (Rpc - LABEL_243);
      goto continuation_166;

    case 225:
      current_block = (Rpc - LABEL_244);
      goto continuation_169;

    case 226:
      current_block = (Rpc - LABEL_249);
      goto label_306;

    case 227:
      current_block = (Rpc - LABEL_245);
      goto continuation_168;

    case 228:
      current_block = (Rpc - LABEL_247);
      goto continuation_171;

    case 229:
      current_block = (Rpc - LABEL_252);
      goto label_307;

    case 230:
      current_block = (Rpc - LABEL_248);
      goto continuation_170;

    case 231:
      current_block = (Rpc - LABEL_250);
      goto continuation_173;

    case 232:
      current_block = (Rpc - LABEL_255);
      goto label_308;

    case 233:
      current_block = (Rpc - LABEL_251);
      goto continuation_172;

    case 234:
      current_block = (Rpc - LABEL_253);
      goto continuation_175;

    case 235:
      current_block = (Rpc - LABEL_254);
      goto continuation_174;

    case 236:
      current_block = (Rpc - LABEL_256);
      goto continuation_177;

    case 237:
      current_block = (Rpc - LABEL_260);
      goto label_309;

    case 238:
      current_block = (Rpc - LABEL_257);
      goto continuation_176;

    case 239:
      current_block = (Rpc - LABEL_258);
      goto continuation_179;

    case 240:
      current_block = (Rpc - LABEL_263);
      goto label_310;

    case 241:
      current_block = (Rpc - LABEL_259);
      goto continuation_178;

    case 242:
      current_block = (Rpc - LABEL_261);
      goto continuation_181;

    case 243:
      current_block = (Rpc - LABEL_262);
      goto continuation_180;

    case 244:
      current_block = (Rpc - LABEL_264);
      goto continuation_182;

    case 245:
      current_block = (Rpc - LABEL_267);
      goto label_311;

    case 246:
      current_block = (Rpc - LABEL_265);
      goto continuation_184;

    case 247:
      current_block = (Rpc - LABEL_271);
      goto label_312;

    case 248:
      current_block = (Rpc - LABEL_266);
      goto continuation_183;

    case 249:
      current_block = (Rpc - LABEL_269);
      goto continuation_186;

    case 250:
      current_block = (Rpc - LABEL_275);
      goto label_313;

    case 251:
      current_block = (Rpc - LABEL_270);
      goto continuation_185;

    case 252:
      current_block = (Rpc - LABEL_273);
      goto continuation_188;

    case 253:
      current_block = (Rpc - LABEL_278);
      goto label_314;

    case 254:
      current_block = (Rpc - LABEL_274);
      goto continuation_187;

    case 255:
      current_block = (Rpc - LABEL_276);
      goto continuation_190;

    case 256:
      current_block = (Rpc - LABEL_281);
      goto label_315;

    case 257:
      current_block = (Rpc - LABEL_277);
      goto continuation_189;

    case 258:
      current_block = (Rpc - LABEL_279);
      goto continuation_192;

    case 259:
      current_block = (Rpc - LABEL_284);
      goto label_316;

    case 260:
      current_block = (Rpc - LABEL_280);
      goto continuation_191;

    case 261:
      current_block = (Rpc - LABEL_282);
      goto continuation_194;

    case 262:
      current_block = (Rpc - LABEL_287);
      goto label_317;

    case 263:
      current_block = (Rpc - LABEL_283);
      goto continuation_193;

    case 264:
      current_block = (Rpc - LABEL_285);
      goto continuation_196;

    case 265:
      current_block = (Rpc - LABEL_290);
      goto label_318;

    case 266:
      current_block = (Rpc - LABEL_286);
      goto continuation_195;

    case 267:
      current_block = (Rpc - LABEL_288);
      goto continuation_198;

    case 268:
      current_block = (Rpc - LABEL_293);
      goto label_319;

    case 269:
      current_block = (Rpc - LABEL_289);
      goto continuation_197;

    case 270:
      current_block = (Rpc - LABEL_291);
      goto continuation_200;

    case 271:
      current_block = (Rpc - LABEL_296);
      goto label_320;

    case 272:
      current_block = (Rpc - LABEL_292);
      goto continuation_199;

    case 273:
      current_block = (Rpc - LABEL_294);
      goto continuation_202;

    case 274:
      current_block = (Rpc - LABEL_299);
      goto label_321;

    case 275:
      current_block = (Rpc - LABEL_295);
      goto continuation_201;

    case 276:
      current_block = (Rpc - LABEL_297);
      goto continuation_204;

    case 277:
      current_block = (Rpc - LABEL_302);
      goto label_322;

    case 278:
      current_block = (Rpc - LABEL_298);
      goto continuation_203;

    case 279:
      current_block = (Rpc - LABEL_300);
      goto continuation_206;

    case 280:
      current_block = (Rpc - LABEL_305);
      goto label_323;

    case 281:
      current_block = (Rpc - LABEL_301);
      goto continuation_205;

    case 282:
      current_block = (Rpc - LABEL_303);
      goto continuation_208;

    case 283:
      current_block = (Rpc - LABEL_308);
      goto label_324;

    case 284:
      current_block = (Rpc - LABEL_304);
      goto continuation_207;

    case 285:
      current_block = (Rpc - LABEL_306);
      goto continuation_210;

    case 286:
      current_block = (Rpc - LABEL_311);
      goto label_325;

    case 287:
      current_block = (Rpc - LABEL_307);
      goto continuation_209;

    case 288:
      current_block = (Rpc - LABEL_309);
      goto continuation_212;

    case 289:
      current_block = (Rpc - LABEL_314);
      goto label_326;

    case 290:
      current_block = (Rpc - LABEL_310);
      goto continuation_211;

    case 291:
      current_block = (Rpc - LABEL_312);
      goto continuation_214;

    case 292:
      current_block = (Rpc - LABEL_317);
      goto label_327;

    case 293:
      current_block = (Rpc - LABEL_313);
      goto continuation_213;

    case 294:
      current_block = (Rpc - LABEL_315);
      goto continuation_216;

    case 295:
      current_block = (Rpc - LABEL_320);
      goto label_328;

    case 296:
      current_block = (Rpc - LABEL_316);
      goto continuation_215;

    case 297:
      current_block = (Rpc - LABEL_318);
      goto continuation_218;

    case 298:
      current_block = (Rpc - LABEL_323);
      goto label_329;

    case 299:
      current_block = (Rpc - LABEL_319);
      goto continuation_217;

    case 300:
      current_block = (Rpc - LABEL_321);
      goto continuation_220;

    case 301:
      current_block = (Rpc - LABEL_326);
      goto label_330;

    case 302:
      current_block = (Rpc - LABEL_322);
      goto continuation_219;

    case 303:
      current_block = (Rpc - LABEL_324);
      goto continuation_222;

    case 304:
      current_block = (Rpc - LABEL_329);
      goto label_331;

    case 305:
      current_block = (Rpc - LABEL_325);
      goto continuation_221;

    case 306:
      current_block = (Rpc - LABEL_327);
      goto continuation_224;

    case 307:
      current_block = (Rpc - LABEL_332);
      goto label_332;

    case 308:
      current_block = (Rpc - LABEL_328);
      goto continuation_223;

    case 309:
      current_block = (Rpc - LABEL_330);
      goto continuation_226;

    case 310:
      current_block = (Rpc - LABEL_335);
      goto label_333;

    case 311:
      current_block = (Rpc - LABEL_331);
      goto continuation_225;

    case 312:
      current_block = (Rpc - LABEL_333);
      goto continuation_228;

    case 313:
      current_block = (Rpc - LABEL_338);
      goto label_334;

    case 314:
      current_block = (Rpc - LABEL_334);
      goto continuation_227;

    case 315:
      current_block = (Rpc - LABEL_336);
      goto continuation_230;

    case 316:
      current_block = (Rpc - LABEL_341);
      goto label_335;

    case 317:
      current_block = (Rpc - LABEL_337);
      goto continuation_229;

    case 318:
      current_block = (Rpc - LABEL_339);
      goto continuation_232;

    case 319:
      current_block = (Rpc - LABEL_344);
      goto label_336;

    case 320:
      current_block = (Rpc - LABEL_340);
      goto continuation_231;

    case 321:
      current_block = (Rpc - LABEL_342);
      goto continuation_234;

    case 322:
      current_block = (Rpc - LABEL_347);
      goto label_337;

    case 323:
      current_block = (Rpc - LABEL_343);
      goto continuation_233;

    case 324:
      current_block = (Rpc - LABEL_345);
      goto continuation_236;

    case 325:
      current_block = (Rpc - LABEL_350);
      goto label_338;

    case 326:
      current_block = (Rpc - LABEL_346);
      goto continuation_235;

    case 327:
      current_block = (Rpc - LABEL_348);
      goto continuation_238;

    case 328:
      current_block = (Rpc - LABEL_353);
      goto label_339;

    case 329:
      current_block = (Rpc - LABEL_349);
      goto continuation_237;

    case 330:
      current_block = (Rpc - LABEL_351);
      goto continuation_240;

    case 331:
      current_block = (Rpc - LABEL_356);
      goto label_340;

    case 332:
      current_block = (Rpc - LABEL_352);
      goto continuation_239;

    case 333:
      current_block = (Rpc - LABEL_354);
      goto continuation_242;

    case 334:
      current_block = (Rpc - LABEL_355);
      goto continuation_241;

    case 335:
      current_block = (Rpc - LABEL_357);
      goto label_345;

    case 336:
      current_block = (Rpc - LABEL_358);
      goto label_346;

    case 337:
      current_block = (Rpc - LABEL_359);
      goto expression_244;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_244)
  (current_block [ENVIRONMENT_LABEL_3]) = (Rrb [REGBLOCK_ENV]);
  INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_358])), current_block, (& (current_block [FREE_REFERENCES_LABEL_0])), NUMBER_OF_LINKER_SECTIONS_1);

DEFLABEL (label_346)
  (* (--Rsp)) = (ULONG_TO_FIXNUM (1UL));

DEFLABEL (label_345)
  {
    static const short sections [] =
      {
	0,
	1,
	1,
	2,
	3,
	1,
	1,
	1,
	1,
	1,
	2,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	0,
	0,
	1,
	1,
	0,
	0,
	0,
	0,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	2,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	2,
	1,
	1,
	1,
	1,
	2,
	1,
	1,
	1,
	1,
	2,
	2,
	2,
	1,
	1,
	1,
	1,
	2,
	1,
	1,
	2,
	1,
	3,
	2,
	1,
	2,
	1,
	3,
	1
      };
    unsigned long counter = (OBJECT_DATUM (* Rsp));
    SCHEME_OBJECT blocks;
    SCHEME_OBJECT * sub_block;
    short section;
    if (counter > 110)
      goto label_344;
    blocks = (current_block [OBJECT_194]);
    sub_block = (OBJECT_ADDRESS (MEMORY_REF (blocks, counter)));
    (sub_block [(OBJECT_DATUM (sub_block [0]))]) = (Rrb [REGBLOCK_ENV]);
    section = (sections [counter]);
    (* Rsp) = (ULONG_TO_FIXNUM (counter + 1));
    INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_357])), sub_block, (sub_block + (2 + (OBJECT_DATUM (sub_block [1])))), section);
  }

DEFLABEL (label_344)
  Rsp += 1;
  (Wrd5.Obj) = (Rrb [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_1]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_2]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_3]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_7);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_6);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_2]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_538;
  Wrd12 = Wrd16;

DEFLABEL (label_537)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_10);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_5]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_9);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_536;
  Wrd11 = Wrd15;

DEFLABEL (label_535)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_14);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_7]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_13);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_6]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_534;
  Wrd12 = Wrd16;

DEFLABEL (label_533)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_18);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_9]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_17);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_8]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_532;
  Wrd12 = Wrd16;

DEFLABEL (label_531)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_22);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_11]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_21);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_10]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_530;
  Wrd12 = Wrd16;

DEFLABEL (label_529)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_25);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_14]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_12]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_13]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_27);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_15]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_16]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_29);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_16]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_28);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_15]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_528;
  Wrd12 = Wrd16;

DEFLABEL (label_527)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_31);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_17]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_30);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_526;
  Wrd11 = Wrd15;

DEFLABEL (label_525)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_34);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_18]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_33);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37]))));
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_37);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_21]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_36);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_19]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_20]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_39);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_22]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_23]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8]));

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_41);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_23]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_40);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_22]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_524;
  Wrd12 = Wrd16;

DEFLABEL (label_523)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12]));

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_43);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_24]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_26)
  INTERRUPT_CHECK (27, LABEL_42);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_522;
  Wrd11 = Wrd15;

DEFLABEL (label_521)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16]));

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_46);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_26]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_45);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_25]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_520;
  Wrd12 = Wrd16;

DEFLABEL (label_519)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_49);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_28]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_48);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_27]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_518;
  Wrd12 = Wrd16;

DEFLABEL (label_517)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20]));

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_52);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_29]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_32)
  INTERRUPT_CHECK (27, LABEL_51);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_27]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_516;
  Wrd12 = Wrd16;

DEFLABEL (label_515)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_57]));

DEFLABEL (continuation_33)
  INTERRUPT_CHECK (27, LABEL_55);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_32]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_34)
  INTERRUPT_CHECK (27, LABEL_54);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_30]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_31]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_35)
  INTERRUPT_CHECK (27, LABEL_58);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_59]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_33]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_34]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8]));

DEFLABEL (continuation_36)
  INTERRUPT_CHECK (27, LABEL_60);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_34]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_37)
  INTERRUPT_CHECK (27, LABEL_59);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_61]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_33]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_514;
  Wrd12 = Wrd16;

DEFLABEL (label_513)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12]));

DEFLABEL (continuation_38)
  INTERRUPT_CHECK (27, LABEL_62);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_35]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_39)
  INTERRUPT_CHECK (27, LABEL_61);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_512;
  Wrd11 = Wrd15;

DEFLABEL (label_511)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16]));

DEFLABEL (continuation_40)
  INTERRUPT_CHECK (27, LABEL_65);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_36]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_41)
  INTERRUPT_CHECK (27, LABEL_64);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_25]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_510;
  Wrd12 = Wrd16;

DEFLABEL (label_509)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20]));

DEFLABEL (continuation_42)
  INTERRUPT_CHECK (27, LABEL_68);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_37]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_43)
  INTERRUPT_CHECK (27, LABEL_67);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_27]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_508;
  Wrd12 = Wrd16;

DEFLABEL (label_507)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20]));

DEFLABEL (continuation_44)
  INTERRUPT_CHECK (27, LABEL_71);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_38]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_45)
  INTERRUPT_CHECK (27, LABEL_70);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_73]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_74]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_27]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_506;
  Wrd12 = Wrd16;

DEFLABEL (label_505)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_57]));

DEFLABEL (continuation_46)
  INTERRUPT_CHECK (27, LABEL_74);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_40]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_47)
  INTERRUPT_CHECK (27, LABEL_73);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_76]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_77]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_39]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_504;
  Wrd12 = Wrd16;

DEFLABEL (label_503)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20]));

DEFLABEL (continuation_48)
  INTERRUPT_CHECK (27, LABEL_77);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_41]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_49)
  INTERRUPT_CHECK (27, LABEL_76);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_79]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_80]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_39]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_502;
  Wrd12 = Wrd16;

DEFLABEL (label_501)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_57]));

DEFLABEL (continuation_50)
  INTERRUPT_CHECK (27, LABEL_80);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_43]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_51)
  INTERRUPT_CHECK (27, LABEL_79);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_42]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_500;
  Wrd12 = Wrd16;

DEFLABEL (label_499)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20]));

DEFLABEL (continuation_52)
  INTERRUPT_CHECK (27, LABEL_83);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_46]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_53)
  INTERRUPT_CHECK (27, LABEL_82);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_44]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_45]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_54)
  INTERRUPT_CHECK (27, LABEL_85);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_86]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_87]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_47]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_48]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8]));

DEFLABEL (continuation_55)
  INTERRUPT_CHECK (27, LABEL_87);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_48]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_56)
  INTERRUPT_CHECK (27, LABEL_86);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_88]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_47]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_498;
  Wrd12 = Wrd16;

DEFLABEL (label_497)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12]));

DEFLABEL (continuation_57)
  INTERRUPT_CHECK (27, LABEL_89);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_49]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_58)
  INTERRUPT_CHECK (27, LABEL_88);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_91]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_92]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_496;
  Wrd11 = Wrd15;

DEFLABEL (label_495)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16]));

DEFLABEL (continuation_59)
  INTERRUPT_CHECK (27, LABEL_92);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_51]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_60)
  INTERRUPT_CHECK (27, LABEL_91);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_94]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_50]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_494;
  Wrd12 = Wrd16;

DEFLABEL (label_493)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20]));

DEFLABEL (continuation_61)
  INTERRUPT_CHECK (27, LABEL_95);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_53]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_62)
  INTERRUPT_CHECK (27, LABEL_94);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_98]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_52]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_492;
  Wrd12 = Wrd16;

DEFLABEL (label_491)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20]));

DEFLABEL (continuation_63)
  INTERRUPT_CHECK (27, LABEL_98);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_55]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_64)
  INTERRUPT_CHECK (27, LABEL_97);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_54]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_490;
  Wrd12 = Wrd16;

DEFLABEL (label_489)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20]));

DEFLABEL (continuation_65)
  INTERRUPT_CHECK (27, LABEL_101);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_58]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_66)
  INTERRUPT_CHECK (27, LABEL_100);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_56]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_57]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_67)
  INTERRUPT_CHECK (27, LABEL_103);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_104]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_5]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_488;
  Wrd11 = Wrd15;

DEFLABEL (label_487)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16]));

DEFLABEL (continuation_68)
  INTERRUPT_CHECK (27, LABEL_105);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_60]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_69)
  INTERRUPT_CHECK (27, LABEL_104);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_107]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_108]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_59]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_5]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_486;
  Wrd12 = Wrd16;

DEFLABEL (label_485)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20]));

DEFLABEL (continuation_70)
  INTERRUPT_CHECK (27, LABEL_108);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_63]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_71)
  INTERRUPT_CHECK (27, LABEL_107);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_110]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_61]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_62]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_72)
  INTERRUPT_CHECK (27, LABEL_110);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_112]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_64]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_5]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_484;
  Wrd12 = Wrd16;

DEFLABEL (label_483)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20]));

DEFLABEL (continuation_73)
  INTERRUPT_CHECK (27, LABEL_112);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_67]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_74)
  INTERRUPT_CHECK (27, LABEL_111);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_65]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_66]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_75)
  INTERRUPT_CHECK (27, LABEL_114);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_68]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_15]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_69]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_117]));

DEFLABEL (continuation_76)
  INTERRUPT_CHECK (27, LABEL_116);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_70]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_77)
  INTERRUPT_CHECK (27, LABEL_115);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_119]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_15]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_482;
  Wrd12 = Wrd16;

DEFLABEL (label_481)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_121]));

DEFLABEL (continuation_78)
  INTERRUPT_CHECK (27, LABEL_119);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_71]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_79)
  INTERRUPT_CHECK (27, LABEL_118);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_122]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_123]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_480;
  Wrd11 = Wrd15;

DEFLABEL (label_479)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_125]));

DEFLABEL (continuation_80)
  INTERRUPT_CHECK (27, LABEL_123);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_74]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_81)
  INTERRUPT_CHECK (27, LABEL_122);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_72]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_73]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_82)
  INTERRUPT_CHECK (27, LABEL_126);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_127]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_128]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_75]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_76]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_129]));

DEFLABEL (continuation_83)
  INTERRUPT_CHECK (27, LABEL_128);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_77]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_84)
  INTERRUPT_CHECK (27, LABEL_127);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_130]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_131]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_75]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_478;
  Wrd12 = Wrd16;

DEFLABEL (label_477)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_133]));

DEFLABEL (continuation_85)
  INTERRUPT_CHECK (27, LABEL_131);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_78]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_86)
  INTERRUPT_CHECK (27, LABEL_130);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_134]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_135]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_476;
  Wrd11 = Wrd15;

DEFLABEL (label_475)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_125]));

DEFLABEL (continuation_87)
  INTERRUPT_CHECK (27, LABEL_135);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_80]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_88)
  INTERRUPT_CHECK (27, LABEL_134);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_137]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_138]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_79]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_474;
  Wrd12 = Wrd16;

DEFLABEL (label_473)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_140]));

DEFLABEL (continuation_89)
  INTERRUPT_CHECK (27, LABEL_138);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_83]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_90)
  INTERRUPT_CHECK (27, LABEL_137);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_141]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_142]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_81]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_82]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_129]));

DEFLABEL (continuation_91)
  INTERRUPT_CHECK (27, LABEL_142);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_84]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_92)
  INTERRUPT_CHECK (27, LABEL_141);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_144]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_81]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_8]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_472;
  Wrd12 = Wrd16;

DEFLABEL (label_471)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_133]));

DEFLABEL (continuation_93)
  INTERRUPT_CHECK (27, LABEL_144);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_85]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_94)
  INTERRUPT_CHECK (27, LABEL_143);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_146]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_147]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_8]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_470;
  Wrd11 = Wrd15;

DEFLABEL (label_469)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_125]));

DEFLABEL (continuation_95)
  INTERRUPT_CHECK (27, LABEL_147);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_87]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_96)
  INTERRUPT_CHECK (27, LABEL_146);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_149]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_150]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_86]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_8]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_468;
  Wrd12 = Wrd16;

DEFLABEL (label_467)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_140]));

DEFLABEL (continuation_97)
  INTERRUPT_CHECK (27, LABEL_150);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_88]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_98)
  INTERRUPT_CHECK (27, LABEL_149);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_152]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_466;
  Wrd8 = Wrd12;

DEFLABEL (label_465)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_10]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_464;
  Wrd14 = Wrd18;

DEFLABEL (label_463)
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_155]));

DEFLABEL (continuation_99)
  INTERRUPT_CHECK (27, LABEL_152);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_156]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_157]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_10]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_462;
  Wrd11 = Wrd15;

DEFLABEL (label_461)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_125]));

DEFLABEL (continuation_100)
  INTERRUPT_CHECK (27, LABEL_157);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_90]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_101)
  INTERRUPT_CHECK (27, LABEL_156);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_159]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_160]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_89]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_10]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_460;
  Wrd12 = Wrd16;

DEFLABEL (label_459)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_140]));

DEFLABEL (continuation_102)
  INTERRUPT_CHECK (27, LABEL_160);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_91]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_103)
  INTERRUPT_CHECK (27, LABEL_159);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_162]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_163]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_6]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_10]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_458;
  Wrd12 = Wrd16;

DEFLABEL (label_457)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_140]));

DEFLABEL (continuation_104)
  INTERRUPT_CHECK (27, LABEL_163);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_94]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_105)
  INTERRUPT_CHECK (27, LABEL_162);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_165]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_166]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_92]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_93]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_129]));

DEFLABEL (continuation_106)
  INTERRUPT_CHECK (27, LABEL_166);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_95]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_107)
  INTERRUPT_CHECK (27, LABEL_165);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_168]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_92]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_456;
  Wrd12 = Wrd16;

DEFLABEL (label_455)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_133]));

DEFLABEL (continuation_108)
  INTERRUPT_CHECK (27, LABEL_168);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_96]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_109)
  INTERRUPT_CHECK (27, LABEL_167);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_170]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_171]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_454;
  Wrd11 = Wrd15;

DEFLABEL (label_453)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_125]));

DEFLABEL (continuation_110)
  INTERRUPT_CHECK (27, LABEL_171);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_98]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_111)
  INTERRUPT_CHECK (27, LABEL_170);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_173]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_174]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_97]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_452;
  Wrd12 = Wrd16;

DEFLABEL (label_451)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_140]));

DEFLABEL (continuation_112)
  INTERRUPT_CHECK (27, LABEL_174);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_100]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_113)
  INTERRUPT_CHECK (27, LABEL_173);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_176]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_177]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_99]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_450;
  Wrd12 = Wrd16;

DEFLABEL (label_449)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_140]));

DEFLABEL (continuation_114)
  INTERRUPT_CHECK (27, LABEL_177);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_103]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_115)
  INTERRUPT_CHECK (27, LABEL_176);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_179]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_101]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_102]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_116)
  INTERRUPT_CHECK (27, LABEL_179);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_180]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_181]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_104]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_105]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_106]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_117]));

DEFLABEL (continuation_117)
  INTERRUPT_CHECK (27, LABEL_181);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_107]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_118)
  INTERRUPT_CHECK (27, LABEL_180);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_182]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_183]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_105]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_12]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_448;
  Wrd12 = Wrd16;

DEFLABEL (label_447)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_121]));

DEFLABEL (continuation_119)
  INTERRUPT_CHECK (27, LABEL_183);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_189);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_188])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_108]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_123)
  INTERRUPT_CHECK (27, LABEL_182);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_185]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_186]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_12]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_446;
  Wrd11 = Wrd15;

DEFLABEL (label_445)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_125]));

DEFLABEL (continuation_124)
  INTERRUPT_CHECK (27, LABEL_186);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_110]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_125)
  INTERRUPT_CHECK (27, LABEL_185);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_190]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_191]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_109]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_12]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_444;
  Wrd12 = Wrd16;

DEFLABEL (label_443)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_140]));

DEFLABEL (continuation_126)
  INTERRUPT_CHECK (27, LABEL_191);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_114]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_127)
  INTERRUPT_CHECK (27, LABEL_190);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_193]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_194]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_111]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_112]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_113]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_117]));

DEFLABEL (continuation_128)
  INTERRUPT_CHECK (27, LABEL_194);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_115]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_129)
  INTERRUPT_CHECK (27, LABEL_193);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_195]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_196]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_112]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_442;
  Wrd12 = Wrd16;

DEFLABEL (label_441)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_121]));

DEFLABEL (continuation_130)
  INTERRUPT_CHECK (27, LABEL_196);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_116]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_131)
  INTERRUPT_CHECK (27, LABEL_195);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_198]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_199]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_440;
  Wrd11 = Wrd15;

DEFLABEL (label_439)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_125]));

DEFLABEL (continuation_132)
  INTERRUPT_CHECK (27, LABEL_199);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_117]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_133)
  INTERRUPT_CHECK (27, LABEL_198);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_201]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_202]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_86]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_438;
  Wrd12 = Wrd16;

DEFLABEL (label_437)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_140]));

DEFLABEL (continuation_134)
  INTERRUPT_CHECK (27, LABEL_202);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_119]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_135)
  INTERRUPT_CHECK (27, LABEL_201);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_204]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_205]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_118]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_436;
  Wrd12 = Wrd16;

DEFLABEL (label_435)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_140]));

DEFLABEL (continuation_136)
  INTERRUPT_CHECK (27, LABEL_205);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_122]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_137)
  INTERRUPT_CHECK (27, LABEL_204);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_207]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_120]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_121]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_138)
  INTERRUPT_CHECK (27, LABEL_207);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_208]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_209]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_123]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_15]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_124]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_117]));

DEFLABEL (continuation_139)
  INTERRUPT_CHECK (27, LABEL_209);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_125]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_140)
  INTERRUPT_CHECK (27, LABEL_208);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_210]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_211]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_15]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_434;
  Wrd12 = Wrd16;

DEFLABEL (label_433)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_121]));

DEFLABEL (continuation_141)
  INTERRUPT_CHECK (27, LABEL_211);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_126]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_142)
  INTERRUPT_CHECK (27, LABEL_210);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_213]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_214]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_432;
  Wrd11 = Wrd15;

DEFLABEL (label_431)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_125]));

DEFLABEL (continuation_143)
  INTERRUPT_CHECK (27, LABEL_214);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_130]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_144)
  INTERRUPT_CHECK (27, LABEL_213);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_216]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_217]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_127]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_128]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_129]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_117]));

DEFLABEL (continuation_145)
  INTERRUPT_CHECK (27, LABEL_217);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_131]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_146)
  INTERRUPT_CHECK (27, LABEL_216);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_218]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_219]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_128]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_430;
  Wrd12 = Wrd16;

DEFLABEL (label_429)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_121]));

DEFLABEL (continuation_147)
  INTERRUPT_CHECK (27, LABEL_219);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_132]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_148)
  INTERRUPT_CHECK (27, LABEL_218);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_221]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_222]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_428;
  Wrd11 = Wrd15;

DEFLABEL (label_427)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_125]));

DEFLABEL (continuation_149)
  INTERRUPT_CHECK (27, LABEL_222);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_134]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_150)
  INTERRUPT_CHECK (27, LABEL_221);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_224]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_225]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_133]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_426;
  Wrd12 = Wrd16;

DEFLABEL (label_425)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_140]));

DEFLABEL (continuation_151)
  INTERRUPT_CHECK (27, LABEL_225);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_230);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_229])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_138]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_156)
  INTERRUPT_CHECK (27, LABEL_224);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_227]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_228]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_135]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_136]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_137]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_117]));

DEFLABEL (continuation_157)
  INTERRUPT_CHECK (27, LABEL_228);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_141]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_158)
  INTERRUPT_CHECK (27, LABEL_227);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_231]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_139]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_140]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_159)
  INTERRUPT_CHECK (27, LABEL_231);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_233]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_234]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_136]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_16]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_424;
  Wrd12 = Wrd16;

DEFLABEL (label_423)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_121]));

DEFLABEL (continuation_160)
  INTERRUPT_CHECK (27, LABEL_234);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_142]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_161)
  INTERRUPT_CHECK (27, LABEL_233);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_236]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_237]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_16]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_422;
  Wrd11 = Wrd15;

DEFLABEL (label_421)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_125]));

DEFLABEL (continuation_162)
  INTERRUPT_CHECK (27, LABEL_237);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_144]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_163)
  INTERRUPT_CHECK (27, LABEL_236);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_239]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_240]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_143]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_16]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_420;
  Wrd12 = Wrd16;

DEFLABEL (label_419)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_140]));

DEFLABEL (continuation_164)
  INTERRUPT_CHECK (27, LABEL_240);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_148]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_165)
  INTERRUPT_CHECK (27, LABEL_239);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_242]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_243]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_145]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_146]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_147]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_117]));

DEFLABEL (continuation_166)
  INTERRUPT_CHECK (27, LABEL_243);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_149]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_167)
  INTERRUPT_CHECK (27, LABEL_242);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_244]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_245]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_146]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_17]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_418;
  Wrd12 = Wrd16;

DEFLABEL (label_417)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_121]));

DEFLABEL (continuation_168)
  INTERRUPT_CHECK (27, LABEL_245);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_150]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_169)
  INTERRUPT_CHECK (27, LABEL_244);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_247]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_248]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_17]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_416;
  Wrd11 = Wrd15;

DEFLABEL (label_415)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_125]));

DEFLABEL (continuation_170)
  INTERRUPT_CHECK (27, LABEL_248);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_151]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_171)
  INTERRUPT_CHECK (27, LABEL_247);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_250]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_251]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_109]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_17]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_414;
  Wrd12 = Wrd16;

DEFLABEL (label_413)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_140]));

DEFLABEL (continuation_172)
  INTERRUPT_CHECK (27, LABEL_251);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_153]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_173)
  INTERRUPT_CHECK (27, LABEL_250);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_253]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_254]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_152]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_17]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_412;
  Wrd12 = Wrd16;

DEFLABEL (label_411)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_140]));

DEFLABEL (continuation_174)
  INTERRUPT_CHECK (27, LABEL_254);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_156]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_175)
  INTERRUPT_CHECK (27, LABEL_253);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_256]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_257]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_154]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_15]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_155]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_117]));

DEFLABEL (continuation_176)
  INTERRUPT_CHECK (27, LABEL_257);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_157]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_177)
  INTERRUPT_CHECK (27, LABEL_256);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_258]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_259]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_15]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_18]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_410;
  Wrd12 = Wrd16;

DEFLABEL (label_409)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_121]));

DEFLABEL (continuation_178)
  INTERRUPT_CHECK (27, LABEL_259);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_158]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_179)
  INTERRUPT_CHECK (27, LABEL_258);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_261]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_262]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_18]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_408;
  Wrd11 = Wrd15;

DEFLABEL (label_407)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_125]));

DEFLABEL (continuation_180)
  INTERRUPT_CHECK (27, LABEL_262);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_161]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_181)
  INTERRUPT_CHECK (27, LABEL_261);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_264]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_159]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_160]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_182)
  INTERRUPT_CHECK (27, LABEL_264);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_265]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_266]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_19]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_406;
  Wrd11 = Wrd15;

DEFLABEL (label_405)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_268]));

DEFLABEL (continuation_183)
  INTERRUPT_CHECK (27, LABEL_266);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_162]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_184)
  INTERRUPT_CHECK (27, LABEL_265);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_269]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_270]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_19]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_404;
  Wrd11 = Wrd15;

DEFLABEL (label_403)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_272]));

DEFLABEL (continuation_185)
  INTERRUPT_CHECK (27, LABEL_270);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_163]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_186)
  INTERRUPT_CHECK (27, LABEL_269);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_273]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_274]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_20]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_402;
  Wrd11 = Wrd15;

DEFLABEL (label_401)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_268]));

DEFLABEL (continuation_187)
  INTERRUPT_CHECK (27, LABEL_274);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_164]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_188)
  INTERRUPT_CHECK (27, LABEL_273);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_276]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_277]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_21]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_400;
  Wrd11 = Wrd15;

DEFLABEL (label_399)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_268]));

DEFLABEL (continuation_189)
  INTERRUPT_CHECK (27, LABEL_277);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_165]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_190)
  INTERRUPT_CHECK (27, LABEL_276);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_279]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_280]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_20]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_398;
  Wrd11 = Wrd15;

DEFLABEL (label_397)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_272]));

DEFLABEL (continuation_191)
  INTERRUPT_CHECK (27, LABEL_280);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_166]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_192)
  INTERRUPT_CHECK (27, LABEL_279);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_282]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_283]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_21]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_396;
  Wrd11 = Wrd15;

DEFLABEL (label_395)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_272]));

DEFLABEL (continuation_193)
  INTERRUPT_CHECK (27, LABEL_283);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_167]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_194)
  INTERRUPT_CHECK (27, LABEL_282);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_285]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_286]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_22]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_394;
  Wrd11 = Wrd15;

DEFLABEL (label_393)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_268]));

DEFLABEL (continuation_195)
  INTERRUPT_CHECK (27, LABEL_286);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_168]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_196)
  INTERRUPT_CHECK (27, LABEL_285);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_288]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_289]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_23]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_392;
  Wrd11 = Wrd15;

DEFLABEL (label_391)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_268]));

DEFLABEL (continuation_197)
  INTERRUPT_CHECK (27, LABEL_289);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_169]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_198)
  INTERRUPT_CHECK (27, LABEL_288);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_291]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_292]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_24]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_390;
  Wrd11 = Wrd15;

DEFLABEL (label_389)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_268]));

DEFLABEL (continuation_199)
  INTERRUPT_CHECK (27, LABEL_292);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_170]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_200)
  INTERRUPT_CHECK (27, LABEL_291);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_294]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_295]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_25]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_388;
  Wrd11 = Wrd15;

DEFLABEL (label_387)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_268]));

DEFLABEL (continuation_201)
  INTERRUPT_CHECK (27, LABEL_295);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_171]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_202)
  INTERRUPT_CHECK (27, LABEL_294);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_297]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_298]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_22]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_386;
  Wrd11 = Wrd15;

DEFLABEL (label_385)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_272]));

DEFLABEL (continuation_203)
  INTERRUPT_CHECK (27, LABEL_298);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_172]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_204)
  INTERRUPT_CHECK (27, LABEL_297);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_300]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_301]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_23]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_384;
  Wrd11 = Wrd15;

DEFLABEL (label_383)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_272]));

DEFLABEL (continuation_205)
  INTERRUPT_CHECK (27, LABEL_301);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_173]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_206)
  INTERRUPT_CHECK (27, LABEL_300);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_303]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_304]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_24]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_382;
  Wrd11 = Wrd15;

DEFLABEL (label_381)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_272]));

DEFLABEL (continuation_207)
  INTERRUPT_CHECK (27, LABEL_304);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_174]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_208)
  INTERRUPT_CHECK (27, LABEL_303);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_306]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_307]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_25]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_380;
  Wrd11 = Wrd15;

DEFLABEL (label_379)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_272]));

DEFLABEL (continuation_209)
  INTERRUPT_CHECK (27, LABEL_307);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_175]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_210)
  INTERRUPT_CHECK (27, LABEL_306);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_309]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_310]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_26]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_378;
  Wrd11 = Wrd15;

DEFLABEL (label_377)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_268]));

DEFLABEL (continuation_211)
  INTERRUPT_CHECK (27, LABEL_310);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_176]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_212)
  INTERRUPT_CHECK (27, LABEL_309);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_312]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_313]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_27]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_376;
  Wrd11 = Wrd15;

DEFLABEL (label_375)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_268]));

DEFLABEL (continuation_213)
  INTERRUPT_CHECK (27, LABEL_313);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_177]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_214)
  INTERRUPT_CHECK (27, LABEL_312);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_315]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_316]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_28]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_374;
  Wrd11 = Wrd15;

DEFLABEL (label_373)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_268]));

DEFLABEL (continuation_215)
  INTERRUPT_CHECK (27, LABEL_316);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_178]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_216)
  INTERRUPT_CHECK (27, LABEL_315);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_318]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_319]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_29]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_372;
  Wrd11 = Wrd15;

DEFLABEL (label_371)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_268]));

DEFLABEL (continuation_217)
  INTERRUPT_CHECK (27, LABEL_319);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_179]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_218)
  INTERRUPT_CHECK (27, LABEL_318);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_321]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_322]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_30]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_370;
  Wrd11 = Wrd15;

DEFLABEL (label_369)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_268]));

DEFLABEL (continuation_219)
  INTERRUPT_CHECK (27, LABEL_322);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_180]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_220)
  INTERRUPT_CHECK (27, LABEL_321);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_324]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_325]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_31]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_368;
  Wrd11 = Wrd15;

DEFLABEL (label_367)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_268]));

DEFLABEL (continuation_221)
  INTERRUPT_CHECK (27, LABEL_325);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_181]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_222)
  INTERRUPT_CHECK (27, LABEL_324);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_327]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_328]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_32]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_366;
  Wrd11 = Wrd15;

DEFLABEL (label_365)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_268]));

DEFLABEL (continuation_223)
  INTERRUPT_CHECK (27, LABEL_328);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_182]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_224)
  INTERRUPT_CHECK (27, LABEL_327);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_330]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_331]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_33]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_364;
  Wrd11 = Wrd15;

DEFLABEL (label_363)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_268]));

DEFLABEL (continuation_225)
  INTERRUPT_CHECK (27, LABEL_331);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_183]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_226)
  INTERRUPT_CHECK (27, LABEL_330);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_333]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_334]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_26]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_362;
  Wrd11 = Wrd15;

DEFLABEL (label_361)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_272]));

DEFLABEL (continuation_227)
  INTERRUPT_CHECK (27, LABEL_334);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_184]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_228)
  INTERRUPT_CHECK (27, LABEL_333);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_336]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_337]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_27]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_360;
  Wrd11 = Wrd15;

DEFLABEL (label_359)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_272]));

DEFLABEL (continuation_229)
  INTERRUPT_CHECK (27, LABEL_337);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_185]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_230)
  INTERRUPT_CHECK (27, LABEL_336);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_339]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_340]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_28]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_358;
  Wrd11 = Wrd15;

DEFLABEL (label_357)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_272]));

DEFLABEL (continuation_231)
  INTERRUPT_CHECK (27, LABEL_340);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_186]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_232)
  INTERRUPT_CHECK (27, LABEL_339);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_342]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_343]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_29]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_356;
  Wrd11 = Wrd15;

DEFLABEL (label_355)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_272]));

DEFLABEL (continuation_233)
  INTERRUPT_CHECK (27, LABEL_343);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_187]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_234)
  INTERRUPT_CHECK (27, LABEL_342);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_345]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_346]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_30]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_354;
  Wrd11 = Wrd15;

DEFLABEL (label_353)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_272]));

DEFLABEL (continuation_235)
  INTERRUPT_CHECK (27, LABEL_346);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_188]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_236)
  INTERRUPT_CHECK (27, LABEL_345);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_348]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_349]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_31]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_352;
  Wrd11 = Wrd15;

DEFLABEL (label_351)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_272]));

DEFLABEL (continuation_237)
  INTERRUPT_CHECK (27, LABEL_349);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_189]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_238)
  INTERRUPT_CHECK (27, LABEL_348);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_351]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_352]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_32]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_350;
  Wrd11 = Wrd15;

DEFLABEL (label_349)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_272]));

DEFLABEL (continuation_239)
  INTERRUPT_CHECK (27, LABEL_352);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_190]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_240)
  INTERRUPT_CHECK (27, LABEL_351);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_354]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_355]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_33]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_348;
  Wrd11 = Wrd15;

DEFLABEL (label_347)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_272]));

DEFLABEL (continuation_241)
  INTERRUPT_CHECK (27, LABEL_355);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_193]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_242)
  INTERRUPT_CHECK (27, LABEL_354);
  (Wrd5.Obj) = (current_block [OBJECT_191]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_192]);
  (Rsp [2]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (label_348)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_356])), (Wrd12.pObj));

DEFLABEL (label_340)
  (Wrd11.Obj) = Rvl;
  goto label_347;

DEFLABEL (label_350)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_353])), (Wrd12.pObj));

DEFLABEL (label_339)
  (Wrd11.Obj) = Rvl;
  goto label_349;

DEFLABEL (label_352)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_350])), (Wrd12.pObj));

DEFLABEL (label_338)
  (Wrd11.Obj) = Rvl;
  goto label_351;

DEFLABEL (label_354)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_347])), (Wrd12.pObj));

DEFLABEL (label_337)
  (Wrd11.Obj) = Rvl;
  goto label_353;

DEFLABEL (label_356)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_344])), (Wrd12.pObj));

DEFLABEL (label_336)
  (Wrd11.Obj) = Rvl;
  goto label_355;

DEFLABEL (label_358)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_341])), (Wrd12.pObj));

DEFLABEL (label_335)
  (Wrd11.Obj) = Rvl;
  goto label_357;

DEFLABEL (label_360)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_338])), (Wrd12.pObj));

DEFLABEL (label_334)
  (Wrd11.Obj) = Rvl;
  goto label_359;

DEFLABEL (label_362)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_335])), (Wrd12.pObj));

DEFLABEL (label_333)
  (Wrd11.Obj) = Rvl;
  goto label_361;

DEFLABEL (label_364)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_332])), (Wrd12.pObj));

DEFLABEL (label_332)
  (Wrd11.Obj) = Rvl;
  goto label_363;

DEFLABEL (label_366)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_329])), (Wrd12.pObj));

DEFLABEL (label_331)
  (Wrd11.Obj) = Rvl;
  goto label_365;

DEFLABEL (label_368)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_326])), (Wrd12.pObj));

DEFLABEL (label_330)
  (Wrd11.Obj) = Rvl;
  goto label_367;

DEFLABEL (label_370)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_323])), (Wrd12.pObj));

DEFLABEL (label_329)
  (Wrd11.Obj) = Rvl;
  goto label_369;

DEFLABEL (label_372)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_320])), (Wrd12.pObj));

DEFLABEL (label_328)
  (Wrd11.Obj) = Rvl;
  goto label_371;

DEFLABEL (label_374)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_317])), (Wrd12.pObj));

DEFLABEL (label_327)
  (Wrd11.Obj) = Rvl;
  goto label_373;

DEFLABEL (label_376)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_314])), (Wrd12.pObj));

DEFLABEL (label_326)
  (Wrd11.Obj) = Rvl;
  goto label_375;

DEFLABEL (label_378)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_311])), (Wrd12.pObj));

DEFLABEL (label_325)
  (Wrd11.Obj) = Rvl;
  goto label_377;

DEFLABEL (label_380)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_308])), (Wrd12.pObj));

DEFLABEL (label_324)
  (Wrd11.Obj) = Rvl;
  goto label_379;

DEFLABEL (label_382)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_305])), (Wrd12.pObj));

DEFLABEL (label_323)
  (Wrd11.Obj) = Rvl;
  goto label_381;

DEFLABEL (label_384)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_302])), (Wrd12.pObj));

DEFLABEL (label_322)
  (Wrd11.Obj) = Rvl;
  goto label_383;

DEFLABEL (label_386)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_299])), (Wrd12.pObj));

DEFLABEL (label_321)
  (Wrd11.Obj) = Rvl;
  goto label_385;

DEFLABEL (label_388)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_296])), (Wrd12.pObj));

DEFLABEL (label_320)
  (Wrd11.Obj) = Rvl;
  goto label_387;

DEFLABEL (label_390)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_293])), (Wrd12.pObj));

DEFLABEL (label_319)
  (Wrd11.Obj) = Rvl;
  goto label_389;

DEFLABEL (label_392)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_290])), (Wrd12.pObj));

DEFLABEL (label_318)
  (Wrd11.Obj) = Rvl;
  goto label_391;

DEFLABEL (label_394)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_287])), (Wrd12.pObj));

DEFLABEL (label_317)
  (Wrd11.Obj) = Rvl;
  goto label_393;

DEFLABEL (label_396)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_284])), (Wrd12.pObj));

DEFLABEL (label_316)
  (Wrd11.Obj) = Rvl;
  goto label_395;

DEFLABEL (label_398)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_281])), (Wrd12.pObj));

DEFLABEL (label_315)
  (Wrd11.Obj) = Rvl;
  goto label_397;

DEFLABEL (label_400)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_278])), (Wrd12.pObj));

DEFLABEL (label_314)
  (Wrd11.Obj) = Rvl;
  goto label_399;

DEFLABEL (label_402)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_275])), (Wrd12.pObj));

DEFLABEL (label_313)
  (Wrd11.Obj) = Rvl;
  goto label_401;

DEFLABEL (label_404)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_271])), (Wrd12.pObj));

DEFLABEL (label_312)
  (Wrd11.Obj) = Rvl;
  goto label_403;

DEFLABEL (label_406)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_267])), (Wrd12.pObj));

DEFLABEL (label_311)
  (Wrd11.Obj) = Rvl;
  goto label_405;

DEFLABEL (label_408)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_263])), (Wrd12.pObj));

DEFLABEL (label_310)
  (Wrd11.Obj) = Rvl;
  goto label_407;

DEFLABEL (label_410)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_260])), (Wrd13.pObj));

DEFLABEL (label_309)
  (Wrd12.Obj) = Rvl;
  goto label_409;

DEFLABEL (label_412)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_255])), (Wrd13.pObj));

DEFLABEL (label_308)
  (Wrd12.Obj) = Rvl;
  goto label_411;

DEFLABEL (label_414)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_252])), (Wrd13.pObj));

DEFLABEL (label_307)
  (Wrd12.Obj) = Rvl;
  goto label_413;

DEFLABEL (label_416)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_249])), (Wrd12.pObj));

DEFLABEL (label_306)
  (Wrd11.Obj) = Rvl;
  goto label_415;

DEFLABEL (label_418)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_246])), (Wrd13.pObj));

DEFLABEL (label_305)
  (Wrd12.Obj) = Rvl;
  goto label_417;

DEFLABEL (label_420)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_241])), (Wrd13.pObj));

DEFLABEL (label_304)
  (Wrd12.Obj) = Rvl;
  goto label_419;

DEFLABEL (label_422)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_238])), (Wrd12.pObj));

DEFLABEL (label_303)
  (Wrd11.Obj) = Rvl;
  goto label_421;

DEFLABEL (label_424)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_235])), (Wrd13.pObj));

DEFLABEL (label_302)
  (Wrd12.Obj) = Rvl;
  goto label_423;

DEFLABEL (label_426)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_226])), (Wrd13.pObj));

DEFLABEL (label_301)
  (Wrd12.Obj) = Rvl;
  goto label_425;

DEFLABEL (label_428)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_223])), (Wrd12.pObj));

DEFLABEL (label_300)
  (Wrd11.Obj) = Rvl;
  goto label_427;

DEFLABEL (label_430)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_220])), (Wrd13.pObj));

DEFLABEL (label_299)
  (Wrd12.Obj) = Rvl;
  goto label_429;

DEFLABEL (label_432)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_215])), (Wrd12.pObj));

DEFLABEL (label_298)
  (Wrd11.Obj) = Rvl;
  goto label_431;

DEFLABEL (label_434)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_212])), (Wrd13.pObj));

DEFLABEL (label_297)
  (Wrd12.Obj) = Rvl;
  goto label_433;

DEFLABEL (label_436)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_206])), (Wrd13.pObj));

DEFLABEL (label_296)
  (Wrd12.Obj) = Rvl;
  goto label_435;

DEFLABEL (label_438)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_203])), (Wrd13.pObj));

DEFLABEL (label_295)
  (Wrd12.Obj) = Rvl;
  goto label_437;

DEFLABEL (label_440)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_200])), (Wrd12.pObj));

DEFLABEL (label_294)
  (Wrd11.Obj) = Rvl;
  goto label_439;

DEFLABEL (label_442)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_197])), (Wrd13.pObj));

DEFLABEL (label_293)
  (Wrd12.Obj) = Rvl;
  goto label_441;

DEFLABEL (label_444)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_192])), (Wrd13.pObj));

DEFLABEL (label_292)
  (Wrd12.Obj) = Rvl;
  goto label_443;

DEFLABEL (label_446)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_187])), (Wrd12.pObj));

DEFLABEL (label_291)
  (Wrd11.Obj) = Rvl;
  goto label_445;

DEFLABEL (label_448)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_184])), (Wrd13.pObj));

DEFLABEL (label_290)
  (Wrd12.Obj) = Rvl;
  goto label_447;

DEFLABEL (label_450)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_178])), (Wrd13.pObj));

DEFLABEL (label_289)
  (Wrd12.Obj) = Rvl;
  goto label_449;

DEFLABEL (label_452)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_175])), (Wrd13.pObj));

DEFLABEL (label_288)
  (Wrd12.Obj) = Rvl;
  goto label_451;

DEFLABEL (label_454)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_172])), (Wrd12.pObj));

DEFLABEL (label_287)
  (Wrd11.Obj) = Rvl;
  goto label_453;

DEFLABEL (label_456)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_169])), (Wrd13.pObj));

DEFLABEL (label_286)
  (Wrd12.Obj) = Rvl;
  goto label_455;

DEFLABEL (label_458)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_164])), (Wrd13.pObj));

DEFLABEL (label_285)
  (Wrd12.Obj) = Rvl;
  goto label_457;

DEFLABEL (label_460)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_161])), (Wrd13.pObj));

DEFLABEL (label_284)
  (Wrd12.Obj) = Rvl;
  goto label_459;

DEFLABEL (label_462)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_158])), (Wrd12.pObj));

DEFLABEL (label_283)
  (Wrd11.Obj) = Rvl;
  goto label_461;

DEFLABEL (label_464)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_154])), (Wrd15.pObj));

DEFLABEL (label_282)
  (Wrd14.Obj) = Rvl;
  goto label_463;

DEFLABEL (label_466)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_153])), (Wrd9.pObj));

DEFLABEL (label_281)
  (Wrd8.Obj) = Rvl;
  goto label_465;

DEFLABEL (label_468)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_151])), (Wrd13.pObj));

DEFLABEL (label_280)
  (Wrd12.Obj) = Rvl;
  goto label_467;

DEFLABEL (label_470)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_148])), (Wrd12.pObj));

DEFLABEL (label_279)
  (Wrd11.Obj) = Rvl;
  goto label_469;

DEFLABEL (label_472)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_145])), (Wrd13.pObj));

DEFLABEL (label_278)
  (Wrd12.Obj) = Rvl;
  goto label_471;

DEFLABEL (label_474)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_139])), (Wrd13.pObj));

DEFLABEL (label_277)
  (Wrd12.Obj) = Rvl;
  goto label_473;

DEFLABEL (label_476)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_136])), (Wrd12.pObj));

DEFLABEL (label_276)
  (Wrd11.Obj) = Rvl;
  goto label_475;

DEFLABEL (label_478)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_132])), (Wrd13.pObj));

DEFLABEL (label_275)
  (Wrd12.Obj) = Rvl;
  goto label_477;

DEFLABEL (label_480)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_124])), (Wrd12.pObj));

DEFLABEL (label_274)
  (Wrd11.Obj) = Rvl;
  goto label_479;

DEFLABEL (label_482)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_120])), (Wrd13.pObj));

DEFLABEL (label_273)
  (Wrd12.Obj) = Rvl;
  goto label_481;

DEFLABEL (label_484)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_113])), (Wrd13.pObj));

DEFLABEL (label_272)
  (Wrd12.Obj) = Rvl;
  goto label_483;

DEFLABEL (label_486)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_109])), (Wrd13.pObj));

DEFLABEL (label_271)
  (Wrd12.Obj) = Rvl;
  goto label_485;

DEFLABEL (label_488)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_106])), (Wrd12.pObj));

DEFLABEL (label_270)
  (Wrd11.Obj) = Rvl;
  goto label_487;

DEFLABEL (label_490)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_102])), (Wrd13.pObj));

DEFLABEL (label_269)
  (Wrd12.Obj) = Rvl;
  goto label_489;

DEFLABEL (label_492)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_99])), (Wrd13.pObj));

DEFLABEL (label_268)
  (Wrd12.Obj) = Rvl;
  goto label_491;

DEFLABEL (label_494)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_96])), (Wrd13.pObj));

DEFLABEL (label_267)
  (Wrd12.Obj) = Rvl;
  goto label_493;

DEFLABEL (label_496)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_93])), (Wrd12.pObj));

DEFLABEL (label_266)
  (Wrd11.Obj) = Rvl;
  goto label_495;

DEFLABEL (label_498)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_90])), (Wrd13.pObj));

DEFLABEL (label_265)
  (Wrd12.Obj) = Rvl;
  goto label_497;

DEFLABEL (label_500)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_84])), (Wrd13.pObj));

DEFLABEL (label_264)
  (Wrd12.Obj) = Rvl;
  goto label_499;

DEFLABEL (label_502)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_81])), (Wrd13.pObj));

DEFLABEL (label_263)
  (Wrd12.Obj) = Rvl;
  goto label_501;

DEFLABEL (label_504)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_78])), (Wrd13.pObj));

DEFLABEL (label_262)
  (Wrd12.Obj) = Rvl;
  goto label_503;

DEFLABEL (label_506)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75])), (Wrd13.pObj));

DEFLABEL (label_261)
  (Wrd12.Obj) = Rvl;
  goto label_505;

DEFLABEL (label_508)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_72])), (Wrd13.pObj));

DEFLABEL (label_260)
  (Wrd12.Obj) = Rvl;
  goto label_507;

DEFLABEL (label_510)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_69])), (Wrd13.pObj));

DEFLABEL (label_259)
  (Wrd12.Obj) = Rvl;
  goto label_509;

DEFLABEL (label_512)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_66])), (Wrd12.pObj));

DEFLABEL (label_258)
  (Wrd11.Obj) = Rvl;
  goto label_511;

DEFLABEL (label_514)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_63])), (Wrd13.pObj));

DEFLABEL (label_257)
  (Wrd12.Obj) = Rvl;
  goto label_513;

DEFLABEL (label_516)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_56])), (Wrd13.pObj));

DEFLABEL (label_256)
  (Wrd12.Obj) = Rvl;
  goto label_515;

DEFLABEL (label_518)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_53])), (Wrd13.pObj));

DEFLABEL (label_255)
  (Wrd12.Obj) = Rvl;
  goto label_517;

DEFLABEL (label_520)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_50])), (Wrd13.pObj));

DEFLABEL (label_254)
  (Wrd12.Obj) = Rvl;
  goto label_519;

DEFLABEL (label_522)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_47])), (Wrd12.pObj));

DEFLABEL (label_253)
  (Wrd11.Obj) = Rvl;
  goto label_521;

DEFLABEL (label_524)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_44])), (Wrd13.pObj));

DEFLABEL (label_252)
  (Wrd12.Obj) = Rvl;
  goto label_523;

DEFLABEL (label_526)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_35])), (Wrd12.pObj));

DEFLABEL (label_251)
  (Wrd11.Obj) = Rvl;
  goto label_525;

DEFLABEL (label_528)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_32])), (Wrd13.pObj));

DEFLABEL (label_250)
  (Wrd12.Obj) = Rvl;
  goto label_527;

DEFLABEL (label_530)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_26])), (Wrd13.pObj));

DEFLABEL (label_249)
  (Wrd12.Obj) = Rvl;
  goto label_529;

DEFLABEL (label_532)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_23])), (Wrd13.pObj));

DEFLABEL (label_248)
  (Wrd12.Obj) = Rvl;
  goto label_531;

DEFLABEL (label_534)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_19])), (Wrd13.pObj));

DEFLABEL (label_247)
  (Wrd12.Obj) = Rvl;
  goto label_533;

DEFLABEL (label_536)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_15])), (Wrd12.pObj));

DEFLABEL (label_246)
  (Wrd11.Obj) = Rvl;
  goto label_535;

DEFLABEL (label_538)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_11])), (Wrd13.pObj));

DEFLABEL (label_245)
  (Wrd12.Obj) = Rvl;
  goto label_537;

DEFLABEL (lambda_342)
  CLOSURE_HEADER (LABEL_188);

DEFLABEL (lambda_121)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Rsp [1]) = ((SCHEME_OBJECT) 0);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (lambda_343)
  CLOSURE_HEADER (LABEL_229);

DEFLABEL (lambda_154)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_232]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_153)
  INTERRUPT_CHECK (27, LABEL_232);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

static const struct liarc_code_S arr_decl_syntactic_closures_so_878f33995e68d951 [110] =
  {
    { "syntactic_closures_so_code_1", 1, syntactic_closures_so_code_1 },
    { "syntactic_closures_so_code_2", 20, syntactic_closures_so_code_2 },
    { "syntactic_closures_so_code_3", 8, syntactic_closures_so_code_3 },
    { "syntactic_closures_so_code_4", 7, syntactic_closures_so_code_4 },
    { "syntactic_closures_so_code_5", 5, syntactic_closures_so_code_5 },
    { "syntactic_closures_so_code_6", 5, syntactic_closures_so_code_6 },
    { "syntactic_closures_so_code_7", 5, syntactic_closures_so_code_7 },
    { "syntactic_closures_so_code_8", 2, syntactic_closures_so_code_8 },
    { "syntactic_closures_so_code_9", 2, syntactic_closures_so_code_9 },
    { "syntactic_closures_so_code_10", 2, syntactic_closures_so_code_10 },
    { "syntactic_closures_so_code_11", 2, syntactic_closures_so_code_11 },
    { "syntactic_closures_so_code_12", 31, syntactic_closures_so_code_12 },
    { "syntactic_closures_so_code_13", 3, syntactic_closures_so_code_13 },
    { "syntactic_closures_so_code_14", 5, syntactic_closures_so_code_14 },
    { "syntactic_closures_so_code_15", 2, syntactic_closures_so_code_15 },
    { "syntactic_closures_so_code_16", 2, syntactic_closures_so_code_16 },
    { "syntactic_closures_so_code_17", 2, syntactic_closures_so_code_17 },
    { "syntactic_closures_so_code_18", 2, syntactic_closures_so_code_18 },
    { "syntactic_closures_so_code_19", 2, syntactic_closures_so_code_19 },
    { "syntactic_closures_so_code_20", 2, syntactic_closures_so_code_20 },
    { "syntactic_closures_so_code_21", 13, syntactic_closures_so_code_21 },
    { "syntactic_closures_so_code_22", 11, syntactic_closures_so_code_22 },
    { "syntactic_closures_so_code_23", 2, syntactic_closures_so_code_23 },
    { "syntactic_closures_so_code_24", 12, syntactic_closures_so_code_24 },
    { "syntactic_closures_so_code_25", 13, syntactic_closures_so_code_25 },
    { "syntactic_closures_so_code_26", 1, syntactic_closures_so_code_26 },
    { "syntactic_closures_so_code_27", 3, syntactic_closures_so_code_27 },
    { "syntactic_closures_so_code_28", 3, syntactic_closures_so_code_28 },
    { "syntactic_closures_so_code_29", 2, syntactic_closures_so_code_29 },
    { "syntactic_closures_so_code_30", 6, syntactic_closures_so_code_30 },
    { "syntactic_closures_so_code_31", 8, syntactic_closures_so_code_31 },
    { "syntactic_closures_so_code_32", 5, syntactic_closures_so_code_32 },
    { "syntactic_closures_so_code_33", 2, syntactic_closures_so_code_33 },
    { "syntactic_closures_so_code_34", 2, syntactic_closures_so_code_34 },
    { "syntactic_closures_so_code_35", 9, syntactic_closures_so_code_35 },
    { "syntactic_closures_so_code_36", 8, syntactic_closures_so_code_36 },
    { "syntactic_closures_so_code_37", 6, syntactic_closures_so_code_37 },
    { "syntactic_closures_so_code_38", 6, syntactic_closures_so_code_38 },
    { "syntactic_closures_so_code_39", 6, syntactic_closures_so_code_39 },
    { "syntactic_closures_so_code_40", 1, syntactic_closures_so_code_40 },
    { "syntactic_closures_so_code_41", 1, syntactic_closures_so_code_41 },
    { "syntactic_closures_so_code_42", 1, syntactic_closures_so_code_42 },
    { "syntactic_closures_so_code_43", 1, syntactic_closures_so_code_43 },
    { "syntactic_closures_so_code_44", 4, syntactic_closures_so_code_44 },
    { "syntactic_closures_so_code_45", 1, syntactic_closures_so_code_45 },
    { "syntactic_closures_so_code_46", 1, syntactic_closures_so_code_46 },
    { "syntactic_closures_so_code_47", 5, syntactic_closures_so_code_47 },
    { "syntactic_closures_so_code_48", 4, syntactic_closures_so_code_48 },
    { "syntactic_closures_so_code_49", 3, syntactic_closures_so_code_49 },
    { "syntactic_closures_so_code_50", 1, syntactic_closures_so_code_50 },
    { "syntactic_closures_so_code_51", 2, syntactic_closures_so_code_51 },
    { "syntactic_closures_so_code_52", 3, syntactic_closures_so_code_52 },
    { "syntactic_closures_so_code_53", 9, syntactic_closures_so_code_53 },
    { "syntactic_closures_so_code_54", 8, syntactic_closures_so_code_54 },
    { "syntactic_closures_so_code_55", 2, syntactic_closures_so_code_55 },
    { "syntactic_closures_so_code_56", 2, syntactic_closures_so_code_56 },
    { "syntactic_closures_so_code_57", 1, syntactic_closures_so_code_57 },
    { "syntactic_closures_so_code_58", 4, syntactic_closures_so_code_58 },
    { "syntactic_closures_so_code_59", 1, syntactic_closures_so_code_59 },
    { "syntactic_closures_so_code_60", 4, syntactic_closures_so_code_60 },
    { "syntactic_closures_so_code_61", 1, syntactic_closures_so_code_61 },
    { "syntactic_closures_so_code_62", 2, syntactic_closures_so_code_62 },
    { "syntactic_closures_so_code_63", 3, syntactic_closures_so_code_63 },
    { "syntactic_closures_so_code_64", 3, syntactic_closures_so_code_64 },
    { "syntactic_closures_so_code_65", 4, syntactic_closures_so_code_65 },
    { "syntactic_closures_so_code_66", 4, syntactic_closures_so_code_66 },
    { "syntactic_closures_so_code_67", 4, syntactic_closures_so_code_67 },
    { "syntactic_closures_so_code_68", 1, syntactic_closures_so_code_68 },
    { "syntactic_closures_so_code_69", 4, syntactic_closures_so_code_69 },
    { "syntactic_closures_so_code_70", 2, syntactic_closures_so_code_70 },
    { "syntactic_closures_so_code_71", 1, syntactic_closures_so_code_71 },
    { "syntactic_closures_so_code_72", 6, syntactic_closures_so_code_72 },
    { "syntactic_closures_so_code_73", 2, syntactic_closures_so_code_73 },
    { "syntactic_closures_so_code_74", 2, syntactic_closures_so_code_74 },
    { "syntactic_closures_so_code_75", 1, syntactic_closures_so_code_75 },
    { "syntactic_closures_so_code_76", 1, syntactic_closures_so_code_76 },
    { "syntactic_closures_so_code_77", 1, syntactic_closures_so_code_77 },
    { "syntactic_closures_so_code_78", 2, syntactic_closures_so_code_78 },
    { "syntactic_closures_so_code_79", 10, syntactic_closures_so_code_79 },
    { "syntactic_closures_so_code_80", 1, syntactic_closures_so_code_80 },
    { "syntactic_closures_so_code_81", 1, syntactic_closures_so_code_81 },
    { "syntactic_closures_so_code_82", 4, syntactic_closures_so_code_82 },
    { "syntactic_closures_so_code_83", 1, syntactic_closures_so_code_83 },
    { "syntactic_closures_so_code_84", 3, syntactic_closures_so_code_84 },
    { "syntactic_closures_so_code_85", 4, syntactic_closures_so_code_85 },
    { "syntactic_closures_so_code_86", 3, syntactic_closures_so_code_86 },
    { "syntactic_closures_so_code_87", 4, syntactic_closures_so_code_87 },
    { "syntactic_closures_so_code_88", 8, syntactic_closures_so_code_88 },
    { "syntactic_closures_so_code_89", 6, syntactic_closures_so_code_89 },
    { "syntactic_closures_so_code_90", 6, syntactic_closures_so_code_90 },
    { "syntactic_closures_so_code_91", 2, syntactic_closures_so_code_91 },
    { "syntactic_closures_so_code_92", 2, syntactic_closures_so_code_92 },
    { "syntactic_closures_so_code_93", 8, syntactic_closures_so_code_93 },
    { "syntactic_closures_so_code_94", 7, syntactic_closures_so_code_94 },
    { "syntactic_closures_so_code_95", 2, syntactic_closures_so_code_95 },
    { "syntactic_closures_so_code_96", 2, syntactic_closures_so_code_96 },
    { "syntactic_closures_so_code_97", 2, syntactic_closures_so_code_97 },
    { "syntactic_closures_so_code_98", 2, syntactic_closures_so_code_98 },
    { "syntactic_closures_so_code_99", 2, syntactic_closures_so_code_99 },
    { "syntactic_closures_so_code_100", 2, syntactic_closures_so_code_100 },
    { "syntactic_closures_so_code_101", 4, syntactic_closures_so_code_101 },
    { "syntactic_closures_so_code_102", 2, syntactic_closures_so_code_102 },
    { "syntactic_closures_so_code_103", 2, syntactic_closures_so_code_103 },
    { "syntactic_closures_so_code_104", 2, syntactic_closures_so_code_104 },
    { "syntactic_closures_so_code_105", 4, syntactic_closures_so_code_105 },
    { "syntactic_closures_so_code_106", 4, syntactic_closures_so_code_106 },
    { "syntactic_closures_so_code_107", 4, syntactic_closures_so_code_107 },
    { "syntactic_closures_so_code_108", 2, syntactic_closures_so_code_108 },
    { "syntactic_closures_so_code_109", 3, syntactic_closures_so_code_109 },
    { "syntactic_closures_so_code_110", 3, syntactic_closures_so_code_110 }
  };

int
decl_syntactic_closures_so_878f33995e68d951 (void)
{
  DECLARE_SUBCODE_MULTIPLE (arr_decl_syntactic_closures_so_878f33995e68d951);
  return (0);
}

DECLARE_COMPILED_CODE ("syntactic-closures.so", 338, decl_syntactic_closures_so_878f33995e68d951, syntactic_closures_so_878f33995e68d951)

#endif /* !WANT_ONLY_DATA */

#ifndef WANT_ONLY_CODE

static const unsigned char prog_syntactic_closures_so_data_878f33995e68d951 [18353] =
  "\xb1\x07\x81\x02\xed\x20\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x08\x28"
  "\x0d\xb9\x23\x22\x29\x21\x17\x2b\xba\x1d\xb0\x82\x88\x1d\x0c\xb1"
  "\x0d\xbb\x25\xb3\x0d\xbb\x24\x28\x0d\xbc\x28\x0d\xbd\x28\x0d\xbe"
  "\x28\x0d\x28\x0d\x28\x0d\xbf\x28\x0d\x28\x0d\x1c\x28\x0d\x1c\x28"
  "\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x83\x88\x28\x0d\x1c\x28"
  "\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d"
  "\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x84\x88\x0d\x1c\x0d\x1c\x24"
  "\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x85\x88\x0c"
  "\x1b\x28\x0d\x1c\x28\xb5\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x86\x88\xc1"
  "\x1c\x0d\x1c\x24\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xc2"
  "\x1c\x1d\x1b\x25\x1b\x24\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x0d\x1c\x28\x1b"
  "\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb3\x24\x28"
  "\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28"
  "\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x0c\x1b\xc1\x1c\x0d\x1c\x0d\x1c\x1b\x24\x28\x0d"
  "\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x1b\x28"
  "\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d"
  "\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28"
  "\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\xb4\x28\x0d\xbc"
  "\x28\x0d\x1c\x28\x0d\x1c\x28\x1b\x28\x1b\x28\x0d\x1c\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x0d\x1c\x28\x0d\x1c\x28\x0d"
  "\x1c\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x0d\x1c\x23\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x24\x28\x1b\x23"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x24\x28\x1b"
  "\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x24\x28"
  "\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28"
  "\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x1b\x1b\x08\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x1b\x28"
  "\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x08\x28\x0d\x1c\x28\x1b"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28"
  "\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x08\x06\x07\x85\xc2\x1c\x02\x0c\x0d\x1c\x1b\x24\x28\xb6\x28"
  "\x0d\x28\x0d\x1c\x28\x0d\x1c\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x1b\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x08\x28\x1b\x23\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x06\x07\x85\x1b\x02\x28\x0d\x1c\x23"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b"
  "\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x1b\x24\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x0d\x1c\x0c\x06\x07\x85\x1b\x02\x28\x1b\x28"
  "\xb5\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x07\x28\x1b\x28\x0d\x1c\x28\x0d"
  "\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x0d\x1c"
  "\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d"
  "\x0c\x28\x0d\x1c\x28\xb5\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x28\x1b\x28\x0d\x23\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x0c\x1b\x0c\x06\x07\x85\x1b\x02\x28\x0d\x1c\x28"
  "\x1b\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\xb5\x28\x1b\x28\x1b"
  "\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b"
  "\x0c\x06\x07\x85\x1b\x02\x28\x1b\x28\x1b\x28\x0d\x1c\x28\x1b\x28"
  "\x0d\x1c\x28\x1b\x28\x0d\x1c\x28\x1b\x28\x0d\x1c\x28\xb5\x28\x0d"
  "\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x0c\x28\x1b\x28"
  "\x1b\x28\x0d\x1c\x28\x1b\x28\x0d\x1c\x28\x1b\x28\x0d\x1c\x28\x1b"
  "\x28\x0d\x1c\x28\xb5\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x0c"
  "\x28\x1b\x28\x1b\x28\x0d\x1c\x28\x1b\x28\x0d\x1c\x28\x1b\x28\x0d"
  "\x1c\x28\x1b\x28\x0d\x1c\x28\xb5\x28\x0d\x1c\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x0d\x1c\x0c\x28\x1b\x28\x1b\x28\x0d\x1c\x28\x1b\x28\x0d\x1c\x28"
  "\x1b\x28\x1b\x28\x0d\x1c\x28\xb5\x28\x0d\xbd\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x0c\x28\x0d\x1c\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c"
  "\x28\x1b\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x28\x1b"
  "\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x28\x1b\x23\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x28\x0d\x28\x1b\x28\x0d"
  "\x28\x0d\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x28\x0d\x23\x22\x29\x21\x9f\x2b\x1c\x1d\xb0"
  "\x02\x88\x28\x0d\x1c\x23\x22\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88"
  "\x08\x0c\x1b\x28\xb6\x28\xb7\x28\x1b\x28\x1b\x28\x0d\x1c\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x1b\x28\x0d\x1c\x28\x0d\x1c\x28\x1b\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1d\x28"
  "\x1b\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x28\x1b\x23\x22\x29\x21\x9f\x2b\x1c\x1d\xb0"
  "\x02\x88\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x08\x0d\x1c\x28\xb6\x28\x0d\x28\x0d\x1c\x23\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x28\x0d\x1c"
  "\x28\x0d\x1c\x28\x0d\x1c\x28\x1b\x28\x1b\x28\x0d\x1c\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x0c\x1b\x1d\x28\x1b\x28\x1b"
  "\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x0d\x1c\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x28\x0d\x1c\x28\x0d\x23\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x1b\x23\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x08\x28\x0d\x1c\x23\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x0d\x1c\x28\x1b\x28\x0d\x1c"
  "\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x0c\x28\x1b\x23\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c"
  "\x28\x1b\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28"
  "\x0d\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x07\x28"
  "\x1b\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x0d\x1c\x28\x1b"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x0c\x28\x1b\x28\x0d\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x28\x0d\x1c"
  "\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x1b\x28"
  "\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x0d\x1c\x24\x28\x0d\x1c\x23\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x28\x1b\x23\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x08\x0d\x28\x1b\x28\x0d\x1c\x28\x1b\x28\x0d"
  "\x28\x0d\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x0d\x23\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x0d\x1c\x23\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x0d\x1c\x23\x22\x29"
  "\x21\x9f\x2b\x1c\x1d\xb0\x02\x88\x28\x0d\x23\x22\x29\x21\x9f\x2b"
  "\x1c\x1d\xb0\x02\x88\x0c\x28\x1b\x23\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x08\x0c\x28\x0d\x1c\x28\x1b\x28\x1b\x28"
  "\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x0d\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x28\x1b\x23\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x28\x1b\x23\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x08\x22\x29"
  "\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x08\x1b\x1b\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x28\x0d\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b"
  "\x80\x1b\x28\x0d\x28\x0d\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x80\x1b\x1b\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x87\x1b\x1b\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x1b\x1b\x08\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x1b\x1b\x1d\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x0d"
  "\x1c\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x1b\x23\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1b\x24\x28\x1b\x28\x1b\x28"
  "\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x08\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x08\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x08\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x28\x0d\x1c\x28\x1b\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28"
  "\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x28\x0d\x26\x1b\x24\x28\x0d\x1c\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x24\x28"
  "\x0d\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x08\x28"
  "\x0d\x1c\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x28\x0d\xb8\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x17\x1c\x88\x1b\x0d\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x17\x0d\x1b\x1b\x0d\x1b\xb0\x0d\x0d\x1b\x1b\x1b\x1b\x1b"
  "\x0d\x0d\x0d\x0d\x1b\x0d\x0d\x17\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d"
  "\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x1b"
  "\x1b\x1b\xb3\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x0d\x17\x08\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x17\x0d\x0d\x1c\x1b\x0c\x1b\x2a\x1b\x0d\x1c\x1b\x0d\x0d\x1c\x1b"
  "\x0c\x0d\x1c\x1b\x08\x89\x1b\x2a\x1b\x0d\x1c\x1b\x0d\x1c\x1b\x1b"
  "\x2a\x1b\x0c\x1b\x08\x88\x1b\x2a\x1b\x0d\x1c\x0d\x0d\x1c\x0d\x0c"
  "\x1b\x08\x88\x1b\x2a\x0d\x0d\x1c\x0c\x1b\x2a\x0d\x1b\x1b\x2a\x1b"
  "\x0d\x1c\x0d\x1b\x0d\x1c\x1b\x0c\x0d\x1c\x1b\x08\x89\x1b\x2a\x1b"
  "\x1b\x1b\x0d\x1c\x0c\x1b\x08\x88\x1b\x2a\x1b\x1b\x1b\x2a\x1b\x0d"
  "\x1c\x1b\x0d\x1c\x1b\x0d\x1c\x1b\x0c\x1b\x1b\x08\x89\x1b\x1b\x0d"
  "\x1b\x1b\x1b\x1b\x0d\x1c\x1b\x0c\x1b\x08\x88\x1b\x0d\x1c\x1b\x0d"
  "\x1c\x0c\x1b\x08\x88\x1b\x1b\x0d\x1c\x1b\x9a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x9a\x0d\x0d\x1c\x0c\x1b\x2a\x1b\x1b\x0d\x1c\x0d\x1c\x1b\x1b"
  "\x9c\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x9c\x0d\x1b\x1b\x1b"
  "\x2a\x1b\x0d\x1b\x1b\x1b\x1b\x1b\x1b\x9c\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x9c\x1b\x0d\x1c\x1b\x0d\x1c\x1b\x0d\x1c\x1b\x0d"
  "\x1c\x1b\x1b\x1b\x08\x8a\x1b\x1b\x1b\x1b\x1b\x1b\x9c\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x9c\x1b\x0d\x1c\x1b\x1b\x0d\x1c\x1b"
  "\x1b\x1b\x1b\x0d\x1c\x0d\x1c\x0d\x1c\x1b\x1b\x08\x8b\x1b\x1b\x1b"
  "\x1b\x1b\x1b\x9c\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x9c\x1b"
  "\x1b\x1b\x1b\x1b\x1b\x0d\x1c\x1b\x1b\x08\x89\x1b\x1b\x1b\x1b\xb5"
  "\x1b\x1b\x1b\x9e\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x9e\x1b\x0d\x1c\x0d\x1c\x08\x1b\x1b\x1b\x1b\x1b\x1b\xb7"
  "\xb6\x1b\x0d\x1b\x0d\x1b\x1b\x1b\x0d\x1b\x17\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x17\x1b\x0d\x1c\x1b"
  "\x0d\x1c\x1b\x0d\x1c\x1b\xc3\x0d\x1c\x1b\x1b\x1b\x08\x8a\x1b\x1b"
  "\x1b\x0d\x1b\x1b\x1b\x1b\x1b\xb4\x1b\x1b\x1b\x1b\x1b\x0d\x1b\x1b"
  "\x1b\x1b\x1b\x1b\xb1\x0d\x17\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x08\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\xb2\x2a\x17\x28\x0d\x26\x1b\x1b\x1b\x1b\x1b\x0d"
  "\x1b\x1b\x1b\x1b\x0d\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\xb3\x1b\x1b"
  "\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x24\x28\x1b\x28"
  "\x0d\x28\x1b\x28\x1b\x28\x1b\x28\x0d\x28\x1b\x28\x0d\x28\x1b\x28"
  "\x1b\x28\x0d\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x02\x84\x01\x2f\x61\x66\x73\x2f\x63\x73\x61\x69\x6c\x2e"
  "\x6d\x69\x74\x2e\x65\x64\x75\x2f\x67\x72\x6f\x75\x70\x2f\x6d\x61"
  "\x63\x2f\x70\x72\x6f\x6a\x65\x63\x74\x73\x2f\x73\x63\x68\x65\x6d"
  "\x65\x2f\x76\x37\x2f\x64\x69\x73\x74\x2f\x73\x6e\x61\x70\x73\x68"
  "\x6f\x74\x2e\x70\x6b\x67\x2f\x32\x30\x30\x37\x30\x39\x30\x39\x2f"
  "\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x32\x30\x30"
  "\x37\x30\x39\x30\x39\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d"
  "\x65\x2f\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x63\x6c\x6f\x73"
  "\x75\x72\x65\x73\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66"
  "\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x04\x08"
  "\x73\x79\x6e\x74\x61\x78\x2a\x02\xd3\x02\x04\x84\x06\x03\x0a\x02"
  "\x02\x05\x6c\x69\x73\x74\x12\x2a\x72\x65\x6e\x61\x6d\x65\x2d\x64"
  "\x61\x74\x61\x62\x61\x73\x65\x2a\x02\x0e\x73\x65\x6c\x65\x63\x74"
  "\x2d\x6f\x62\x6a\x65\x63\x74\x03\x03\x06\x6c\x69\x73\x74\x3f\x05"
  "\x1a\x65\x72\x72\x6f\x72\x3a\x77\x72\x6f\x6e\x67\x2d\x74\x79\x70"
  "\x65\x2d\x61\x72\x67\x75\x6d\x65\x6e\x74\x04\x20\x67\x75\x61\x72"
  "\x61\x6e\x74\x65\x65\x2d\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d"
  "\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x02\x18\x69\x6e\x69"
  "\x74\x69\x61\x6c\x2d\x72\x65\x6e\x61\x6d\x65\x2d\x64\x61\x74\x61"
  "\x62\x61\x73\x65\x05\x13\x73\x68\x61\x6c\x6c\x6f\x77\x2d\x66\x6c"
  "\x75\x69\x64\x2d\x62\x69\x6e\x64\x03\x21\x73\x79\x6e\x74\x61\x63"
  "\x74\x69\x63\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x2f"
  "\x74\x6f\x70\x2d\x6c\x65\x76\x65\x6c\x3f\x03\x1f\x6f\x75\x74\x70"
  "\x75\x74\x2f\x70\x6f\x73\x74\x2d\x70\x72\x6f\x63\x65\x73\x73\x2d"
  "\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x04\x17\x6d\x61\x6b\x65"
  "\x2d\x74\x6f\x70\x2d\x6c\x65\x76\x65\x6c\x2d\x68\x69\x73\x74\x6f"
  "\x72\x79\x09\x03\x25\x6d\x61\x6b\x65\x2d\x74\x6f\x70\x2d\x6c\x65"
  "\x76\x65\x6c\x2d\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e"
  "\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x0a\x03\x10\x6f\x75\x74\x70"
  "\x75\x74\x2f\x73\x65\x71\x75\x65\x6e\x63\x65\x0b\x05\x14\x63\x6f"
  "\x6d\x70\x69\x6c\x65\x2f\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e"
  "\x73\x0c\x03\x1d\x63\x6f\x6d\x70\x69\x6c\x65\x2d\x62\x6f\x64\x79"
  "\x2d\x69\x74\x65\x6d\x73\x2f\x74\x6f\x70\x2d\x6c\x65\x76\x65\x6c"
  "\x0d\x07\x14\x63\x6c\x61\x73\x73\x69\x66\x79\x2f\x62\x6f\x64\x79"
  "\x2d\x66\x6f\x72\x6d\x73\x0e\x0e\xe7\x02\x2a\x81\x87\x02\xe6\x02"
  "\x28\x81\x83\x02\xe5\x02\x26\x81\x87\x02\xe4\x02\x24\x81\x85\x02"
  "\xe3\x02\x22\x81\x85\x02\xe2\x02\x20\x81\x85\x02\xe1\x02\x1e\x81"
  "\x85\x02\xe0\x02\x1c\x81\x83\x02\xdf\x02\x1a\x81\x87\x02\xde\x02"
  "\x18\x81\x85\x02\xdd\x02\x16\x81\x83\x02\xdc\x02\x14\x81\x87\x02"
  "\xdb\x02\x12\x81\x85\x02\xda\x02\x10\x81\x83\x02\xd9\x02\x0e\x81"
  "\x83\x02\xd8\x02\x0c\x81\x87\x02\xd7\x02\x0a\x81\x85\x02\xd6\x02"
  "\x08\x81\x85\x02\xd5\x02\x06\x81\x85\x02\xd4\x02\x04\x84\x06\x29"
  "\x4f\x0f\x02\x03\x0e\x62\x69\x6e\x64\x69\x6e\x67\x2d\x69\x74\x65"
  "\x6d\x3f\x10\x03\x18\x63\x6f\x6d\x70\x69\x6c\x65\x2d\x69\x74\x65"
  "\x6d\x2f\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x11\x03\x12\x62"
  "\x69\x6e\x64\x69\x6e\x67\x2d\x69\x74\x65\x6d\x2f\x6e\x61\x6d\x65"
  "\x12\x03\x13\x62\x69\x6e\x64\x69\x6e\x67\x2d\x69\x74\x65\x6d\x2f"
  "\x76\x61\x6c\x75\x65\x13\x03\x14\x6b\x65\x79\x77\x6f\x72\x64\x2d"
  "\x76\x61\x6c\x75\x65\x2d\x69\x74\x65\x6d\x3f\x14\x03\x1e\x6b\x65"
  "\x79\x77\x6f\x72\x64\x2d\x76\x61\x6c\x75\x65\x2d\x69\x74\x65\x6d"
  "\x2f\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x15\x04\x23\x6f\x75"
  "\x74\x70\x75\x74\x2f\x74\x6f\x70\x2d\x6c\x65\x76\x65\x6c\x2d\x73"
  "\x79\x6e\x74\x61\x78\x2d\x64\x65\x66\x69\x6e\x69\x74\x69\x6f\x6e"
  "\x04\x1c\x6f\x75\x74\x70\x75\x74\x2f\x74\x6f\x70\x2d\x6c\x65\x76"
  "\x65\x6c\x2d\x64\x65\x66\x69\x6e\x69\x74\x69\x6f\x6e\x09\xef\x02"
  "\x12\x81\x85\x02\xee\x02\x10\x81\x87\x02\xed\x02\x0e\x81\x85\x02"
  "\xec\x02\x0c\x81\x85\x02\xeb\x02\x0a\x81\x85\x02\xea\x02\x08\x81"
  "\x83\x02\xe9\x02\x06\x81\x83\x02\xe8\x02\x04\x83\x04\x11\x25\x16"
  "\x02\x16\x64\x65\x63\x6c\x61\x72\x61\x74\x69\x6f\x6e\x2d\x69\x74"
  "\x65\x6d\x2f\x74\x65\x78\x74\x17\x17\x63\x6f\x6d\x70\x69\x6c\x65"
  "\x2d\x69\x74\x65\x6d\x2f\x74\x6f\x70\x2d\x6c\x65\x76\x65\x6c\x18"
  "\x03\x03\x1f\x65\x78\x74\x72\x61\x63\x74\x2d\x64\x65\x63\x6c\x61"
  "\x72\x61\x74\x69\x6f\x6e\x73\x2d\x66\x72\x6f\x6d\x2d\x62\x6f\x64"
  "\x79\x19\x04\x04\x6d\x61\x70\x1a\x04\x1a\x6f\x75\x74\x70\x75\x74"
  "\x2f\x74\x6f\x70\x2d\x6c\x65\x76\x65\x6c\x2d\x73\x65\x71\x75\x65"
  "\x6e\x63\x65\x04\xf6\x02\x10\x81\x85\x02\xf5\x02\x0e\x81\x89\x02"
  "\xf4\x02\x0c\x81\x85\x02\xf3\x02\x0a\x81\x89\x02\xf2\x02\x08\x84"
  "\x06\xf1\x02\x06\x81\x83\x02\xf0\x02\x04\x83\x04\x0f\x1c\x1b\x02"
  "\x05\x69\x74\x65\x6d\x11\x03\x06\x69\x74\x65\x6d\x3f\x1c\x05\x03"
  "\x12\x67\x65\x74\x2d\x69\x74\x65\x6d\x2d\x63\x6f\x6d\x70\x69\x6c"
  "\x65\x72\x1d\x04\x19\x65\x72\x72\x6f\x72\x3a\x62\x61\x64\x2d\x72"
  "\x61\x6e\x67\x65\x2d\x61\x72\x67\x75\x6d\x65\x6e\x74\x1e\x05\xfb"
  "\x02\x0c\x81\x83\x02\xfa\x02\x0a\x81\x85\x02\xf9\x02\x08\x81\x83"
  "\x02\xf8\x02\x06\x81\x83\x02\xf7\x02\x04\x83\x04\x0b\x19\x1f\x02"
  "\x04\x63\x64\x72\x20\x0f\x69\x74\x65\x6d\x2d\x63\x6f\x6d\x70\x69"
  "\x6c\x65\x72\x73\x21\x02\x03\x0c\x69\x74\x65\x6d\x2f\x72\x65\x63"
  "\x6f\x72\x64\x22\x04\x05\x61\x73\x73\x71\x23\x03\x17\x72\x65\x63"
  "\x6f\x72\x64\x2d\x74\x79\x70\x65\x2d\x64\x65\x73\x63\x72\x69\x70"
  "\x74\x6f\x72\x04\x80\x03\x0c\x81\x89\x02\xff\x02\x0a\x81\x87\x02"
  "\xfe\x02\x08\x81\x83\x02\xfd\x02\x06\x81\x85\x02\xfc\x02\x04\x83"
  "\x04\x0b\x18\x24\x02\x08\x09\x73\x65\x74\x2d\x63\x64\x72\x21\x25"
  "\x02\x21\x02\x21\x02\x04\x23\x02\x85\x03\x0c\x81\x87\x02\x84\x03"
  "\x0a\x81\x87\x02\x83\x03\x08\x81\x85\x02\x82\x03\x06\x81\x87\x02"
  "\x81\x03\x04\x84\x06\x0b\x17\x26\x02\x09\x05\x14\x63\x6c\x61\x73"
  "\x73\x69\x66\x79\x2f\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x27"
  "\x03\x11\x03\x87\x03\x06\x81\x87\x02\x86\x03\x04\x85\x08\x05\x0d"
  "\x28\x02\x0a\x02\x06\x17\x63\x6f\x6d\x70\x69\x6c\x65\x2f\x73\x75"
  "\x62\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x73\x29\x02\x89\x03"
  "\x06\x81\x89\x02\x88\x03\x04\x85\x08\x05\x0d\x2a\x02\x0b\x06\x17"
  "\x63\x6c\x61\x73\x73\x69\x66\x79\x2f\x73\x75\x62\x65\x78\x70\x72"
  "\x65\x73\x73\x69\x6f\x6e\x2b\x03\x11\x03\x8b\x03\x06\x81\x89\x02"
  "\x8a\x03\x04\x86\x0a\x05\x0d\x2c\x02\x0c\x05\x0b\x73\x65\x6c\x65"
  "\x63\x74\x2d\x6d\x61\x70\x2d\x06\x16\x63\x6f\x6d\x70\x69\x6c\x65"
  "\x2f\x73\x75\x62\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x2e\x03"
  "\x8d\x03\x06\x81\x87\x02\x8c\x03\x04\x86\x0a\x05\x0d\x2f\x02\x0d"
  "\x23\x43\x6f\x6d\x62\x69\x6e\x61\x74\x69\x6f\x6e\x20\x6d\x75\x73"
  "\x74\x20\x62\x65\x20\x61\x20\x70\x72\x6f\x70\x65\x72\x20\x6c\x69"
  "\x73\x74\x3a\x20\x04\x63\x61\x72\x30\x0b\x73\x65\x6c\x65\x63\x74"
  "\x2d\x63\x61\x72\x31\x0b\x73\x65\x6c\x65\x63\x74\x2d\x63\x64\x72"
  "\x32\x11\x04\x03\x0c\x69\x64\x65\x6e\x74\x69\x66\x69\x65\x72\x3f"
  "\x33\x03\x13\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x63\x6c\x6f"
  "\x73\x75\x72\x65\x3f\x34\x04\x12\x6c\x6f\x6f\x6b\x75\x70\x2d\x69"
  "\x64\x65\x6e\x74\x69\x66\x69\x65\x72\x35\x03\x0e\x6b\x65\x79\x77"
  "\x6f\x72\x64\x2d\x69\x74\x65\x6d\x3f\x36\x04\x11\x69\x74\x65\x6d"
  "\x2f\x6e\x65\x77\x2d\x68\x69\x73\x74\x6f\x72\x79\x37\x06\x2b\x04"
  "\x15\x6d\x61\x6b\x65\x2d\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e"
  "\x2d\x69\x74\x65\x6d\x38\x03\x1e\x73\x79\x6e\x74\x61\x63\x74\x69"
  "\x63\x2d\x63\x6c\x6f\x73\x75\x72\x65\x2f\x65\x6e\x76\x69\x72\x6f"
  "\x6e\x6d\x65\x6e\x74\x39\x03\x19\x73\x74\x72\x69\x70\x2d\x6b\x65"
  "\x79\x77\x6f\x72\x64\x2d\x76\x61\x6c\x75\x65\x2d\x69\x74\x65\x6d"
  "\x3a\x03\x17\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x63\x6c\x6f"
  "\x73\x75\x72\x65\x2f\x66\x6f\x72\x6d\x3b\x03\x1d\x73\x79\x6e\x74"
  "\x61\x63\x74\x69\x63\x2d\x63\x6c\x6f\x73\x75\x72\x65\x2f\x66\x72"
  "\x65\x65\x2d\x6e\x61\x6d\x65\x73\x3c\x03\x10\x6f\x75\x74\x70\x75"
  "\x74\x2f\x63\x6f\x6e\x73\x74\x61\x6e\x74\x03\x11\x63\x6c\x61\x73"
  "\x73\x69\x66\x69\x65\x72\x2d\x69\x74\x65\x6d\x3f\x3d\x05\x16\x6d"
  "\x61\x6b\x65\x2d\x6b\x65\x79\x77\x6f\x72\x64\x2d\x72\x65\x66\x2d"
  "\x69\x74\x65\x6d\x3e\x05\x1a\x68\x69\x73\x74\x6f\x72\x79\x2f\x72"
  "\x65\x70\x6c\x61\x63\x65\x2d\x72\x65\x64\x75\x63\x74\x69\x6f\x6e"
  "\x3f\x05\x24\x6d\x61\x6b\x65\x2d\x66\x69\x6c\x74\x65\x72\x65\x64"
  "\x2d\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69\x72"
  "\x6f\x6e\x6d\x65\x6e\x74\x40\x03\x0f\x63\x6f\x6d\x70\x69\x6c\x65"
  "\x72\x2d\x69\x74\x65\x6d\x3f\x41\x03\x1b\x63\x6c\x61\x73\x73\x69"
  "\x66\x69\x65\x72\x2d\x69\x74\x65\x6d\x2f\x63\x6c\x61\x73\x73\x69"
  "\x66\x69\x65\x72\x42\x06\x0e\x63\x6c\x61\x73\x73\x69\x66\x79\x2f"
  "\x66\x6f\x72\x6d\x43\x03\x0f\x65\x78\x70\x61\x6e\x64\x65\x72\x2d"
  "\x69\x74\x65\x6d\x3f\x44\x06\x12\x63\x6c\x61\x73\x73\x69\x66\x79"
  "\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x45\x03\x07\x12\x63\x6c\x61"
  "\x73\x73\x69\x66\x79\x2f\x65\x78\x70\x61\x6e\x64\x65\x72\x05\x0d"
  "\x73\x79\x6e\x74\x61\x78\x2d\x65\x72\x72\x6f\x72\x46\x06\x18\x63"
  "\x6c\x61\x73\x73\x69\x66\x79\x2f\x73\x75\x62\x65\x78\x70\x72\x65"
  "\x73\x73\x69\x6f\x6e\x73\x47\x03\x11\x04\x1a\x04\x13\x6f\x75\x74"
  "\x70\x75\x74\x2f\x63\x6f\x6d\x62\x69\x6e\x61\x74\x69\x6f\x6e\x48"
  "\x1d\xac\x03\x40\x81\x85\x02\xab\x03\x3e\x81\x89\x02\xaa\x03\x3c"
  "\x81\x83\x02\xa9\x03\x3a\x81\x83\x02\xa8\x03\x38\x81\x8b\x02\xa7"
  "\x03\x36\x81\x93\x02\xa6\x03\x34\x81\x8d\x02\xa5\x03\x32\x81\x8b"
  "\x02\xa4\x03\x30\x81\x8b\x02\xa3\x03\x2e\x81\x8d\x02\xa2\x03\x2c"
  "\x81\x8b\x02\xa1\x03\x2a\x81\x8b\x02\xa0\x03\x28\x81\x8b\x02\x9f"
  "\x03\x26\x81\x8d\x02\x9e\x03\x24\x81\x8b\x02\x9d\x03\x22\x81\x8f"
  "\x02\x9c\x03\x20\x81\x8b\x02\x9b\x03\x1e\x81\x8b\x02\x9a\x03\x1c"
  "\x81\x8b\x02\x99\x03\x1a\x81\x89\x02\x98\x03\x18\x81\x83\x02\x97"
  "\x03\x16\x81\x8b\x02\x96\x03\x14\x81\x89\x02\x95\x03\x12\x81\x8b"
  "\x02\x94\x03\x10\x81\x93\x02\x93\x03\x0e\x81\x8d\x02\x92\x03\x0c"
  "\x81\x89\x02\x91\x03\x0a\x81\x8d\x02\x90\x03\x08\x81\x89\x02\x8f"
  "\x03\x06\x81\x89\x02\x8e\x03\x04\x86\x0a\x3f\x82\x01\x49\x02\x0e"
  "\x04\x38\x03\x17\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2d\x69\x74\x65"
  "\x6d\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x4a\x03\xaf\x03\x08\x81"
  "\x87\x02\xae\x03\x06\x81\x83\x02\xad\x03\x04\x86\x0a\x07\x0f\x4b"
  "\x02\x0f\x03\x1a\x65\x78\x70\x61\x6e\x64\x65\x72\x2d\x69\x74\x65"
  "\x6d\x2f\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x4c\x05\x16"
  "\x68\x69\x73\x74\x6f\x72\x79\x2f\x61\x64\x64\x2d\x72\x65\x64\x75"
  "\x63\x74\x69\x6f\x6e\x4d\x03\x17\x65\x78\x70\x61\x6e\x64\x65\x72"
  "\x2d\x69\x74\x65\x6d\x2f\x65\x78\x70\x61\x6e\x64\x65\x72\x4e\x06"
  "\x43\x05\xb4\x03\x0c\x81\x93\x02\xb3\x03\x0a\x81\x8d\x02\xb2\x03"
  "\x08\x81\x8d\x02\xb1\x03\x06\x81\x8b\x02\xb0\x03\x04\x87\x0c\x0b"
  "\x17\x4f\x02\x10\x06\x17\x68\x69\x73\x74\x6f\x72\x79\x2f\x61\x64"
  "\x64\x2d\x73\x75\x62\x70\x72\x6f\x62\x6c\x65\x6d\x50\x06\x43\x03"
  "\xb6\x03\x06\x81\x8b\x02\xb5\x03\x04\x87\x0c\x05\x0d\x51\x02\x11"
  "\x05\x2d\x07\x11\x63\x6c\x61\x73\x73\x69\x66\x79\x2f\x73\x75\x62"
  "\x66\x6f\x72\x6d\x52\x03\xb8\x03\x06\x81\x87\x02\xb7\x03\x04\x87"
  "\x0c\x05\x0d\x53\x02\x12\x1b\x6e\x75\x6c\x6c\x2d\x73\x79\x6e\x74"
  "\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e"
  "\x74\x54\x02\x06\x43\x02\xba\x03\x06\x81\x89\x02\xb9\x03\x04\x85"
  "\x08\x05\x0d\x55\x02\x13\x54\x02\x07\x52\x02\xbc\x03\x06\x81\x8b"
  "\x02\xbb\x03\x04\x86\x0a\x05\x0d\x56\x02\x14\x54\x02\x07\x12\x63"
  "\x6c\x61\x73\x73\x69\x66\x79\x2f\x73\x75\x62\x66\x6f\x72\x6d\x73"
  "\x57\x02\xbe\x03\x06\x81\x8b\x02\xbd\x03\x04\x86\x0a\x05\x0d\x58"
  "\x02\x15\x07\x0e\x04\x0f\x6d\x61\x6b\x65\x2d\x62\x6f\x64\x79\x2d"
  "\x69\x74\x65\x6d\x59\x03\xc0\x03\x06\x81\x8b\x02\xbf\x03\x04\x87"
  "\x0c\x05\x0d\x5a\x02\x16\x20\x30\x03\x11\x73\x65\x6c\x65\x63\x74"
  "\x6f\x72\x2f\x61\x64\x64\x2d\x63\x61\x72\x5b\x03\x09\x72\x65\x76"
  "\x65\x72\x73\x65\x21\x5c\x03\x0b\x69\x74\x65\x6d\x2d\x3e\x6c\x69"
  "\x73\x74\x5d\x07\x52\x03\x13\x6e\x75\x6c\x6c\x2d\x62\x69\x6e\x64"
  "\x69\x6e\x67\x2d\x69\x74\x65\x6d\x3f\x5e\x03\x11\x73\x65\x6c\x65"
  "\x63\x74\x6f\x72\x2f\x61\x64\x64\x2d\x63\x64\x72\x5f\x07\xcd\x03"
  "\x1c\x81\x95\x02\xcc\x03\x1a\x81\x95\x02\xcb\x03\x18\x81\x95\x02"
  "\xca\x03\x16\x81\x95\x02\xc9\x03\x14\x81\x95\x02\xc8\x03\x12\x81"
  "\x97\x02\xc7\x03\x10\x81\x95\x02\xc6\x03\x0e\x81\x9f\x02\xc5\x03"
  "\x0c\x81\x97\x02\xc4\x03\x0a\x81\x95\x02\xc3\x03\x08\x81\x93\x02"
  "\xc2\x03\x06\x81\x91\x02\xc1\x03\x04\x87\x0c\x1b\x2e\x60\x02\x17"
  "\x20\x30\x03\x12\x64\x65\x63\x6c\x61\x72\x61\x74\x69\x6f\x6e\x2d"
  "\x69\x74\x65\x6d\x3f\x61\x03\x5c\x03\xd8\x03\x18\x81\x85\x02\xd7"
  "\x03\x16\x81\x87\x02\xd6\x03\x14\x81\x87\x02\xd5\x03\x12\x81\x87"
  "\x02\xd4\x03\x10\x81\x87\x02\xd3\x03\x0e\x81\x87\x02\xd2\x03\x0c"
  "\x81\x87\x02\xd1\x03\x0a\x81\x87\x02\xd0\x03\x08\x81\x89\x02\xcf"
  "\x03\x06\x81\x87\x02\xce\x03\x04\x83\x04\x17\x22\x5c\x02\x18\x03"
  "\x14\x03\x18\x6b\x65\x79\x77\x6f\x72\x64\x2d\x76\x61\x6c\x75\x65"
  "\x2d\x69\x74\x65\x6d\x2f\x69\x74\x65\x6d\x62\x03\xda\x03\x06\x81"
  "\x83\x02\xd9\x03\x04\x83\x04\x05\x0d\x63\x02\x19\x0d\x6f\x62\x6a"
  "\x65\x63\x74\x2d\x74\x79\x70\x65\x3f\x64\x1e\x14\x6c\x69\x73\x74"
  "\x20\x6f\x66\x20\x69\x64\x65\x6e\x74\x69\x66\x69\x65\x72\x73\x17"
  "\x6d\x61\x6b\x65\x2d\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x63"
  "\x6c\x6f\x73\x75\x72\x65\x65\x33\x02\x04\x06\x17\x67\x75\x61\x72"
  "\x61\x6e\x74\x65\x65\x2d\x6c\x69\x73\x74\x2d\x6f\x66\x2d\x74\x79"
  "\x70\x65\x04\x05\x6d\x65\x6d\x71\x66\x05\x18\x25\x6d\x61\x6b\x65"
  "\x2d\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x63\x6c\x6f\x73\x75"
  "\x72\x65\x67\x03\x3b\x03\x3c\x03\x34\x03\x33\x09\xe6\x03\x1a\x81"
  "\x89\x02\xe5\x03\x18\x81\x87\x02\xe4\x03\x16\x81\x87\x02\xe3\x03"
  "\x14\x81\x87\x02\xe2\x03\x12\x81\x83\x02\xe1\x03\x10\x81\x87\x02"
  "\xe0\x03\x0e\x81\x87\x02\xdf\x03\x0c\x81\x87\x02\xde\x03\x0a\x81"
  "\x87\x02\xdd\x03\x08\x81\x8d\x02\xdc\x03\x06\x81\x87\x02\xdb\x03"
  "\x04\x85\x08\x19\x37\x68\x02\x1a\x20\x30\x03\x34\x03\x3b\x03\xf3"
  "\x03\x1c\x81\x85\x02\xf2\x03\x1a\x81\x83\x02\xf1\x03\x18\x81\x87"
  "\x02\xf0\x03\x16\x81\x83\x02\xef\x03\x14\x81\x83\x02\xee\x03\x12"
  "\xfd\xff\x03\xed\x03\x10\x81\x83\x02\xec\x03\x0e\x81\x85\x02\xeb"
  "\x03\x0c\x81\x83\x02\xea\x03\x0a\x81\x85\x02\xe9\x03\x08\x81\x83"
  "\x02\xe8\x03\x06\x81\x83\x02\xe7\x03\x04\x83\x04\x1b\x25\x69\x02"
  "\x1b\x05\x65\x02\xf4\x03\x04\x84\x06\x03\x0a\x6a\x02\x1c\x64\x1e"
  "\x03\x16\x73\x79\x6e\x74\x68\x65\x74\x69\x63\x2d\x69\x64\x65\x6e"
  "\x74\x69\x66\x69\x65\x72\x3f\x6b\x02\xf7\x03\x08\x81\x83\x02\xf6"
  "\x03\x06\x83\x04\xf5\x03\x04\x81\x83\x02\x07\x12\x6c\x02\x1d\x03"
  "\x34\x03\x3b\x03\x33\x04\xfa\x03\x08\x81\x83\x02\xf9\x03\x06\x81"
  "\x83\x02\xf8\x03\x04\x83\x04\x07\x11\x6d\x02\x1e\x54\x02\x04\x0d"
  "\x63\x6c\x6f\x73\x65\x2d\x73\x79\x6e\x74\x61\x78\x6e\x02\xfc\x03"
  "\x06\x81\x85\x02\xfb\x03\x04\x83\x04\x05\x0d\x6f\x02\x1f\x13\x69"
  "\x64\x65\x6e\x74\x69\x66\x69\x65\x72\x2d\x3e\x73\x79\x6d\x62\x6f"
  "\x6c\x70\x0b\x69\x64\x65\x6e\x74\x69\x66\x69\x65\x72\x64\x1e\x03"
  "\x34\x05\x03\x3b\x04\x82\x04\x0e\x81\x85\x02\x81\x04\x0c\x81\x83"
  "\x02\x80\x04\x0a\x81\x85\x02\xff\x03\x08\x81\x85\x02\xfe\x03\x06"
  "\x81\x85\x02\xfd\x03\x04\x83\x04\x0d\x1e\x71\x02\x20\x04\x35\x04"
  "\x07\x69\x74\x65\x6d\x3d\x3f\x72\x03\x0f\x76\x61\x72\x69\x61\x62"
  "\x6c\x65\x2d\x69\x74\x65\x6d\x3f\x73\x03\x13\x76\x61\x72\x69\x61"
  "\x62\x6c\x65\x2d\x69\x74\x65\x6d\x2f\x6e\x61\x6d\x65\x74\x05\x8a"
  "\x04\x12\x81\x89\x02\x89\x04\x10\x81\x87\x02\x88\x04\x0e\x81\x87"
  "\x02\x87\x04\x0c\x81\x87\x02\x86\x04\x0a\x81\x85\x02\x85\x04\x08"
  "\x81\x89\x02\x84\x04\x06\x81\x89\x02\x83\x04\x04\x86\x0a\x11\x1e"
  "\x75\x02\x21\x03\x20\x69\x6e\x74\x65\x72\x6e\x61\x6c\x2d\x73\x79"
  "\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d"
  "\x65\x6e\x74\x3f\x76\x03\x21\x74\x6f\x70\x2d\x6c\x65\x76\x65\x6c"
  "\x2d\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69\x72"
  "\x6f\x6e\x6d\x65\x6e\x74\x3f\x77\x03\x0d\x65\x6e\x76\x69\x72\x6f"
  "\x6e\x6d\x65\x6e\x74\x3f\x78\x03\x20\x66\x69\x6c\x74\x65\x72\x65"
  "\x64\x2d\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69"
  "\x72\x6f\x6e\x6d\x65\x6e\x74\x3f\x79\x03\x1c\x6e\x75\x6c\x6c\x2d"
  "\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69\x72\x6f"
  "\x6e\x6d\x65\x6e\x74\x3f\x7a\x06\x8f\x04\x0c\x81\x85\x02\x8e\x04"
  "\x0a\x81\x85\x02\x8d\x04\x08\x81\x85\x02\x8c\x04\x06\x81\x83\x02"
  "\x8b\x04\x04\x83\x04\x0b\x19\x7b\x02\x22\x02\x16\x73\x79\x6e\x74"
  "\x61\x63\x74\x69\x63\x20\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e"
  "\x74\x03\x17\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76"
  "\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x3f\x7c\x05\x03\x91\x04\x06\x81"
  "\x85\x02\x90\x04\x04\x84\x06\x05\x0f\x7d\x02\x23\x03\x77\x03\x19"
  "\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72\x2d\x65\x6e\x76\x69"
  "\x72\x6f\x6e\x6d\x65\x6e\x74\x3f\x03\x93\x04\x06\x81\x83\x02\x92"
  "\x04\x04\x83\x04\x05\x0d\x7e\x02\x24\x26\x50\x72\x65\x6d\x61\x74"
  "\x75\x72\x65\x20\x72\x65\x66\x65\x72\x65\x6e\x63\x65\x20\x74\x6f"
  "\x20\x72\x65\x73\x65\x72\x76\x65\x64\x20\x6e\x61\x6d\x65\x3a\x35"
  "\x0b\x69\x64\x65\x6e\x74\x69\x66\x69\x65\x72\x64\x1e\x04\x1d\x73"
  "\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69\x72\x6f\x6e"
  "\x6d\x65\x6e\x74\x2f\x6c\x6f\x6f\x6b\x75\x70\x7f\x03\x34\x03\x13"
  "\x6d\x61\x6b\x65\x2d\x76\x61\x72\x69\x61\x62\x6c\x65\x2d\x69\x74"
  "\x65\x6d\x80\x01\x03\x14\x72\x65\x73\x65\x72\x76\x65\x64\x2d\x6e"
  "\x61\x6d\x65\x2d\x69\x74\x65\x6d\x3f\x81\x01\x03\x0d\x69\x74\x65"
  "\x6d\x2f\x68\x69\x73\x74\x6f\x72\x79\x82\x01\x05\x03\x39\x05\x46"
  "\x03\x3b\x04\x35\x0b\x9c\x04\x14\x81\x87\x02\x9b\x04\x12\x81\x87"
  "\x02\x9a\x04\x10\x81\x87\x02\x99\x04\x0e\x81\x87\x02\x98\x04\x0c"
  "\x81\x87\x02\x97\x04\x0a\x81\x83\x02\x96\x04\x08\x81\x85\x02\x95"
  "\x04\x06\x81\x87\x02\x94\x04\x04\x84\x06\x13\x33\x83\x01\x02\x25"
  "\x7f\x16\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x20\x65\x6e\x76\x69"
  "\x72\x6f\x6e\x6d\x65\x6e\x74\x64\x1e\x03\x76\x03\x77\x04\x26\x69"
  "\x6e\x74\x65\x72\x6e\x61\x6c\x2d\x73\x79\x6e\x74\x61\x63\x74\x69"
  "\x63\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x2f\x6c\x6f"
  "\x6f\x6b\x75\x70\x64\x03\x78\x04\x27\x74\x6f\x70\x2d\x6c\x65\x76"
  "\x65\x6c\x2d\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76"
  "\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x2f\x6c\x6f\x6f\x6b\x75\x70\x84"
  "\x01\x03\x79\x04\x13\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74"
  "\x2f\x6c\x6f\x6f\x6b\x75\x70\x85\x01\x03\x7a\x04\x26\x66\x69\x6c"
  "\x74\x65\x72\x65\x64\x2d\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d"
  "\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x2f\x6c\x6f\x6f\x6b"
  "\x75\x70\x86\x01\x05\x04\x22\x6e\x75\x6c\x6c\x2d\x73\x79\x6e\x74"
  "\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e"
  "\x74\x2f\x6c\x6f\x6f\x6b\x75\x70\x87\x01\x0c\xa4\x04\x12\x81\x85"
  "\x02\xa3\x04\x10\x81\x85\x02\xa2\x04\x0e\x81\x83\x02\xa1\x04\x0c"
  "\x81\x85\x02\xa0\x04\x0a\x81\x85\x02\x9f\x04\x08\x81\x85\x02\x9e"
  "\x04\x06\x81\x85\x02\x9d\x04\x04\x84\x06\x11\x32\x88\x01\x02\x26"
  "\x1d\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69\x72"
  "\x6f\x6e\x6d\x65\x6e\x74\x2f\x64\x65\x66\x69\x6e\x65\x89\x01\x16"
  "\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x20\x65\x6e\x76\x69\x72\x6f"
  "\x6e\x6d\x65\x6e\x74\x03\x76\x03\x77\x05\x26\x69\x6e\x74\x65\x72"
  "\x6e\x61\x6c\x2d\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e"
  "\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x2f\x64\x65\x66\x69\x6e\x65"
  "\x8a\x01\x03\x78\x05\x27\x74\x6f\x70\x2d\x6c\x65\x76\x65\x6c\x2d"
  "\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69\x72\x6f"
  "\x6e\x6d\x65\x6e\x74\x2f\x64\x65\x66\x69\x6e\x65\x8b\x01\x03\x79"
  "\x05\x13\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x2f\x64\x65"
  "\x66\x69\x6e\x65\x8c\x01\x03\x7a\x05\x26\x66\x69\x6c\x74\x65\x72"
  "\x65\x64\x2d\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76"
  "\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x2f\x64\x65\x66\x69\x6e\x65\x8d"
  "\x01\x05\x05\x22\x6e\x75\x6c\x6c\x2d\x73\x79\x6e\x74\x61\x63\x74"
  "\x69\x63\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x2f\x64"
  "\x65\x66\x69\x6e\x65\x8e\x01\x0c\xaa\x04\x0e\x81\x87\x02\xa9\x04"
  "\x0c\x81\x87\x02\xa8\x04\x0a\x81\x87\x02\xa7\x04\x08\x81\x87\x02"
  "\xa6\x04\x06\x81\x87\x02\xa5\x04\x04\x85\x08\x0d\x29\x8f\x01\x02"
  "\x27\x1d\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69"
  "\x72\x6f\x6e\x6d\x65\x6e\x74\x2f\x72\x65\x6e\x61\x6d\x65\x90\x01"
  "\x16\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x20\x65\x6e\x76\x69\x72"
  "\x6f\x6e\x6d\x65\x6e\x74\x03\x76\x03\x77\x04\x26\x69\x6e\x74\x65"
  "\x72\x6e\x61\x6c\x2d\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65"
  "\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x2f\x72\x65\x6e\x61\x6d"
  "\x65\x91\x01\x03\x78\x04\x27\x74\x6f\x70\x2d\x6c\x65\x76\x65\x6c"
  "\x2d\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69\x72"
  "\x6f\x6e\x6d\x65\x6e\x74\x2f\x72\x65\x6e\x61\x6d\x65\x92\x01\x03"
  "\x79\x04\x13\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x2f\x72"
  "\x65\x6e\x61\x6d\x65\x93\x01\x03\x7a\x04\x26\x66\x69\x6c\x74\x65"
  "\x72\x65\x64\x2d\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e"
  "\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x2f\x72\x65\x6e\x61\x6d\x65"
  "\x94\x01\x05\x04\x22\x6e\x75\x6c\x6c\x2d\x73\x79\x6e\x74\x61\x63"
  "\x74\x69\x63\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x2f"
  "\x72\x65\x6e\x61\x6d\x65\x95\x01\x0c\xb0\x04\x0e\x81\x85\x02\xaf"
  "\x04\x0c\x81\x85\x02\xae\x04\x0a\x81\x85\x02\xad\x04\x08\x81\x85"
  "\x02\xac\x04\x06\x81\x85\x02\xab\x04\x04\x84\x06\x0d\x29\x96\x01"
  "\x02\x28\x23\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76"
  "\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x2d\x3e\x65\x6e\x76\x69\x72\x6f"
  "\x6e\x6d\x65\x6e\x74\x97\x01\x16\x73\x79\x6e\x74\x61\x63\x74\x69"
  "\x63\x20\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x03\x76\x03"
  "\x77\x03\x2c\x69\x6e\x74\x65\x72\x6e\x61\x6c\x2d\x73\x79\x6e\x74"
  "\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e"
  "\x74\x2d\x3e\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x98\x01"
  "\x03\x78\x03\x2d\x74\x6f\x70\x2d\x6c\x65\x76\x65\x6c\x2d\x73\x79"
  "\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d"
  "\x65\x6e\x74\x2d\x3e\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74"
  "\x78\x03\x79\x03\x7a\x03\x2c\x66\x69\x6c\x74\x65\x72\x65\x64\x2d"
  "\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69\x72\x6f"
  "\x6e\x6d\x65\x6e\x74\x2d\x3e\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65"
  "\x6e\x74\x99\x01\x05\x03\x28\x6e\x75\x6c\x6c\x2d\x73\x79\x6e\x74"
  "\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e"
  "\x74\x2d\x3e\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x0b\xb6"
  "\x04\x0e\x81\x83\x02\xb5\x04\x0c\x81\x83\x02\xb4\x04\x0a\x81\x83"
  "\x02\xb3\x04\x08\x81\x83\x02\xb2\x04\x06\x81\x83\x02\xb1\x04\x04"
  "\x83\x04\x0d\x27\x9a\x01\x02\x29\x31\x43\x61\x6e\x27\x74\x20\x6c"
  "\x6f\x6f\x6b\x75\x70\x20\x6e\x61\x6d\x65\x20\x69\x6e\x20\x6e\x75"
  "\x6c\x6c\x20\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x20\x65\x6e\x76"
  "\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x3a\x04\x06\x65\x72\x72\x6f\x72"
  "\x9b\x01\x02\xb7\x04\x04\x84\x06\x03\x0a\x9c\x01\x02\x2a\x2f\x43"
  "\x61\x6e\x27\x74\x20\x62\x69\x6e\x64\x20\x6e\x61\x6d\x65\x20\x69"
  "\x6e\x20\x6e\x75\x6c\x6c\x20\x73\x79\x6e\x74\x61\x63\x74\x69\x63"
  "\x20\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x3a\x05\x9b\x01"
  "\x02\xb8\x04\x04\x85\x08\x03\x0a\x9d\x01\x02\x2b\x31\x43\x61\x6e"
  "\x27\x74\x20\x72\x65\x6e\x61\x6d\x65\x20\x6e\x61\x6d\x65\x20\x69"
  "\x6e\x20\x6e\x75\x6c\x6c\x20\x73\x79\x6e\x74\x61\x63\x74\x69\x63"
  "\x20\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x3a\x04\x9b\x01"
  "\x02\xb9\x04\x04\x84\x06\x03\x0a\x9e\x01\x02\x2c\x2e\x43\x61\x6e"
  "\x27\x74\x20\x65\x76\x61\x6c\x75\x61\x74\x65\x20\x69\x6e\x20\x6e"
  "\x75\x6c\x6c\x20\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x20\x65\x6e"
  "\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x2e\x03\x9b\x01\x02\xba\x04"
  "\x04\x83\x04\x03\x0a\x9f\x01\x02\x2d\x12\x73\x79\x6e\x74\x61\x63"
  "\x74\x69\x63\x20\x6b\x65\x79\x77\x6f\x72\x64\x04\x19\x65\x6e\x76"
  "\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x2d\x6c\x6f\x6f\x6b\x75\x70\x2d"
  "\x6d\x61\x63\x72\x6f\x03\x1c\x03\x0b\x70\x72\x6f\x63\x65\x64\x75"
  "\x72\x65\x3f\x04\x17\x65\x72\x72\x6f\x72\x3a\x77\x72\x6f\x6e\x67"
  "\x2d\x74\x79\x70\x65\x2d\x64\x61\x74\x75\x6d\x04\x29\x6e\x6f\x6e"
  "\x2d\x68\x79\x67\x69\x65\x6e\x69\x63\x2d\x6d\x61\x63\x72\x6f\x2d"
  "\x74\x72\x61\x6e\x73\x66\x6f\x72\x6d\x65\x72\x2d\x3e\x65\x78\x70"
  "\x61\x6e\x64\x65\x72\x06\xbe\x04\x0a\x81\x87\x02\xbd\x04\x08\x81"
  "\x87\x02\xbc\x04\x06\x81\x85\x02\xbb\x04\x04\x84\x06\x09\x18\xa0"
  "\x01\x02\x2e\x05\x19\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74"
  "\x2d\x64\x65\x66\x69\x6e\x65\x2d\x6d\x61\x63\x72\x6f\x02\xbf\x04"
  "\x04\x85\x08\x03\xa1\x01\x02\x2f\x03\x1c\x72\x65\x6e\x61\x6d\x65"
  "\x2d\x74\x6f\x70\x2d\x6c\x65\x76\x65\x6c\x2d\x69\x64\x65\x6e\x74"
  "\x69\x66\x69\x65\x72\xa2\x01\x02\xc0\x04\x04\x84\x06\x03\xa3\x01"
  "\x02\x30\x20\x74\x6f\x70\x2d\x6c\x65\x76\x65\x6c\x20\x73\x79\x6e"
  "\x74\x61\x63\x74\x69\x63\x20\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65"
  "\x6e\x74\x0a\x04\x03\x05\x1e\x03\x7a\x04\x26\x25\x6d\x61\x6b\x65"
  "\x2d\x74\x6f\x70\x2d\x6c\x65\x76\x65\x6c\x2d\x73\x79\x6e\x74\x61"
  "\x63\x74\x69\x63\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74"
  "\x1e\x06\xc5\x04\x0c\x81\x83\x02\xc4\x04\x0a\x81\x83\x02\xc3\x04"
  "\x08\x81\x83\x02\xc2\x04\x06\x81\x83\x02\xc1\x04\x04\x83\x04\x0b"
  "\x1c\xa4\x01\x02\x31\x20\x03\x26\x74\x6f\x70\x2d\x6c\x65\x76\x65"
  "\x6c\x2d\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69"
  "\x72\x6f\x6e\x6d\x65\x6e\x74\x2f\x62\x6f\x75\x6e\x64\xa5\x01\x03"
  "\x27\x74\x6f\x70\x2d\x6c\x65\x76\x65\x6c\x2d\x73\x79\x6e\x74\x61"
  "\x63\x74\x69\x63\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74"
  "\x2f\x70\x61\x72\x65\x6e\x74\xa6\x01\x04\x23\x04\x7f\x05\xc9\x04"
  "\x0a\x81\x87\x02\xc8\x04\x08\x81\x87\x02\xc7\x04\x06\x81\x85\x02"
  "\xc6\x04\x04\x84\x06\x09\x16\xa7\x01\x02\x32\x25\x02\x03\xa5\x01"
  "\x04\x23\x04\x2b\x73\x65\x74\x2d\x74\x6f\x70\x2d\x6c\x65\x76\x65"
  "\x6c\x2d\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69"
  "\x72\x6f\x6e\x6d\x65\x6e\x74\x2f\x62\x6f\x75\x6e\x64\x21\xa8\x01"
  "\x04\xcc\x04\x08\x81\x89\x02\xcb\x04\x06\x81\x87\x02\xca\x04\x04"
  "\x85\x08\x07\x13\xa9\x01\x02\x33\x03\xa2\x01\x02\xcd\x04\x04\x84"
  "\x06\x03\xa2\x01\x02\x34\x03\xa6\x01\x03\x97\x01\x03\xcf\x04\x06"
  "\x81\x83\x02\xce\x04\x04\x83\x04\x05\x0d\xaa\x01\x02\x35\x24\x6d"
  "\x61\x6b\x65\x2d\x69\x6e\x74\x65\x72\x6e\x61\x6c\x2d\x73\x79\x6e"
  "\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65"
  "\x6e\x74\xab\x01\x04\x02\x0f\x6d\x61\x6b\x65\x2d\x72\x65\x6e\x61"
  "\x6d\x65\x2d\x69\x64\x06\x25\x25\x6d\x61\x6b\x65\x2d\x69\x6e\x74"
  "\x65\x72\x6e\x61\x6c\x2d\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d"
  "\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\xac\x01\x04\xd2\x04"
  "\x08\x81\x89\x02\xd1\x04\x06\x81\x83\x02\xd0\x04\x04\x83\x04\x07"
  "\x13\xad\x01\x02\x36\x20\x03\x25\x69\x6e\x74\x65\x72\x6e\x61\x6c"
  "\x2d\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69\x72"
  "\x6f\x6e\x6d\x65\x6e\x74\x2f\x62\x6f\x75\x6e\x64\xae\x01\x03\x24"
  "\x69\x6e\x74\x65\x72\x6e\x61\x6c\x2d\x73\x79\x6e\x74\x61\x63\x74"
  "\x69\x63\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x2f\x66"
  "\x72\x65\x65\xaf\x01\x03\x26\x69\x6e\x74\x65\x72\x6e\x61\x6c\x2d"
  "\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69\x72\x6f"
  "\x6e\x6d\x65\x6e\x74\x2f\x70\x61\x72\x65\x6e\x74\xb0\x01\x04\x23"
  "\x04\x7f\x04\x29\x73\x65\x74\x2d\x69\x6e\x74\x65\x72\x6e\x61\x6c"
  "\x2d\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69\x72"
  "\x6f\x6e\x6d\x65\x6e\x74\x2f\x66\x72\x65\x65\x21\xb1\x01\x07\xdb"
  "\x04\x14\x81\x89\x02\xda\x04\x12\x81\x87\x02\xd9\x04\x10\x81\x85"
  "\x02\xd8\x04\x0e\x81\x8b\x02\xd7\x04\x0c\x81\x87\x02\xd6\x04\x0a"
  "\x81\x89\x02\xd5\x04\x08\x81\x85\x02\xd4\x04\x06\x81\x87\x02\xd3"
  "\x04\x04\x84\x06\x13\x24\xb2\x01\x02\x37\x26\x50\x72\x65\x6d\x61"
  "\x74\x75\x72\x65\x20\x72\x65\x66\x65\x72\x65\x6e\x63\x65\x20\x74"
  "\x6f\x20\x72\x65\x73\x65\x72\x76\x65\x64\x20\x6e\x61\x6d\x65\x3a"
  "\x21\x43\x61\x6e\x27\x74\x20\x64\x65\x66\x69\x6e\x65\x20\x6e\x61"
  "\x6d\x65\x3b\x20\x61\x6c\x72\x65\x61\x64\x79\x20\x66\x72\x65\x65"
  "\x3a\x25\x02\x03\xae\x01\x03\xaf\x01\x04\x23\x03\x81\x01\x04\x9b"
  "\x01\x03\x82\x01\x04\x2a\x73\x65\x74\x2d\x69\x6e\x74\x65\x72\x6e"
  "\x61\x6c\x2d\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76"
  "\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x2f\x62\x6f\x75\x6e\x64\x21\x25"
  "\x05\x46\x09\xe3\x04\x12\x81\x89\x02\xe2\x04\x10\x81\x89\x02\xe1"
  "\x04\x0e\x81\x89\x02\xe0\x04\x0c\x81\x8b\x02\xdf\x04\x0a\x81\x89"
  "\x02\xde\x04\x08\x81\x89\x02\xdd\x04\x06\x81\x87\x02\xdc\x04\x04"
  "\x85\x08\x11\x29\x23\x02\x38\x03\x2c\x69\x6e\x74\x65\x72\x6e\x61"
  "\x6c\x2d\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69"
  "\x72\x6f\x6e\x6d\x65\x6e\x74\x2f\x72\x65\x6e\x61\x6d\x65\x2d\x73"
  "\x74\x61\x74\x65\xb3\x01\x04\x12\x72\x65\x6e\x61\x6d\x65\x2d\x69"
  "\x64\x65\x6e\x74\x69\x66\x69\x65\x72\x03\xe5\x04\x06\x81\x85\x02"
  "\xe4\x04\x04\x84\x06\x05\x0d\xb4\x01\x02\x39\x03\xb0\x01\x03\x97"
  "\x01\x03\xe7\x04\x06\x81\x83\x02\xe6\x04\x04\x83\x04\x05\x0d\xb5"
  "\x01\x02\x3a\x05\x25\x25\x6d\x61\x6b\x65\x2d\x66\x69\x6c\x74\x65"
  "\x72\x65\x64\x2d\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e"
  "\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\xb6\x01\x02\xe8\x04\x04\x85"
  "\x08\x03\x0a\xb7\x01\x02\x3b\x03\x25\x66\x69\x6c\x74\x65\x72\x65"
  "\x64\x2d\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69"
  "\x72\x6f\x6e\x6d\x65\x6e\x74\x2f\x6e\x61\x6d\x65\x73\xb8\x01\x04"
  "\x7f\x03\x30\x66\x69\x6c\x74\x65\x72\x65\x64\x2d\x73\x79\x6e\x74"
  "\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e"
  "\x74\x2f\x65\x6c\x73\x65\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65"
  "\x6e\x74\xb9\x01\x03\x31\x66\x69\x6c\x74\x65\x72\x65\x64\x2d\x73"
  "\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69\x72\x6f\x6e"
  "\x6d\x65\x6e\x74\x2f\x6e\x61\x6d\x65\x73\x2d\x65\x6e\x76\x69\x72"
  "\x6f\x6e\x6d\x65\x6e\x74\xba\x01\x04\x66\x06\xec\x04\x0a\x81\x89"
  "\x02\xeb\x04\x08\x81\x87\x02\xea\x04\x06\x81\x85\x02\xe9\x04\x04"
  "\x84\x06\x09\x17\xbb\x01\x02\x3c\x33\x43\x61\x6e\x27\x74\x20\x62"
  "\x69\x6e\x64\x20\x6e\x61\x6d\x65\x20\x69\x6e\x20\x66\x69\x6c\x74"
  "\x65\x72\x65\x64\x20\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x20\x65"
  "\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x3a\x06\x9b\x01\x02\xed"
  "\x04\x04\x85\x08\x03\x0a\xbc\x01\x02\x3d\x03\xb8\x01\x04\x90\x01"
  "\x03\xb9\x01\x03\xba\x01\x04\x66\x06\xf1\x04\x0a\x81\x89\x02\xf0"
  "\x04\x08\x81\x87\x02\xef\x04\x06\x81\x85\x02\xee\x04\x04\x84\x06"
  "\x09\x17\x66\x02\x3e\x32\x43\x61\x6e\x27\x74\x20\x65\x76\x61\x6c"
  "\x75\x61\x74\x65\x20\x69\x6e\x20\x66\x69\x6c\x74\x65\x72\x65\x64"
  "\x20\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x20\x65\x6e\x76\x69\x72"
  "\x6f\x6e\x6d\x65\x6e\x74\x3a\x04\x9b\x01\x02\xf2\x04\x04\x83\x04"
  "\x03\x0a\x9b\x01\x02\x3f\x03\x22\x04\x0a\x6d\x61\x6b\x65\x2d\x69"
  "\x74\x65\x6d\x03\xf4\x04\x06\x81\x85\x02\xf3\x04\x04\x84\x06\x05"
  "\x0d\xbd\x01\x02\x40\x03\x22\x02\xf7\x04\x08\x81\x87\x02\xf6\x04"
  "\x06\x81\x85\x02\xf5\x04\x04\x84\x06\x07\x0e\xbe\x01\x02\x41\x04"
  "\x11\x6d\x61\x6b\x65\x2d\x72\x65\x63\x6f\x72\x64\x2d\x74\x79\x70"
  "\x65\xbf\x01\x04\x15\x64\x65\x66\x69\x6e\x65\x2d\x69\x74\x65\x6d"
  "\x2d\x63\x6f\x6d\x70\x69\x6c\x65\x72\xc0\x01\x03\xfa\x04\x08\x81"
  "\x89\x02\xf9\x04\x06\x81\x87\x02\xf8\x04\x04\x85\x08\x07\x0f\xc1"
  "\x01\x02\x42\x03\x11\x72\x65\x63\x6f\x72\x64\x2d\x70\x72\x65\x64"
  "\x69\x63\x61\x74\x65\xc2\x01\x03\x22\x03\xfe\x04\x0a\x81\x85\x02"
  "\xfd\x04\x08\x81\x85\x02\xfc\x04\x06\x81\x83\x02\xfb\x04\x04\x83"
  "\x04\x09\x11\xc3\x01\x02\x43\x04\x10\x72\x65\x63\x6f\x72\x64\x2d"
  "\x61\x63\x63\x65\x73\x73\x6f\x72\xc4\x01\x03\x22\x03\x82\x05\x0a"
  "\x81\x85\x02\x81\x05\x08\x81\x85\x02\x80\x05\x06\x81\x85\x02\xff"
  "\x04\x04\x84\x06\x09\x11\xc5\x01\x02\x44\x23\x20\x6d\x61\x79\x20"
  "\x6e\x6f\x74\x20\x62\x65\x20\x75\x73\x65\x64\x20\x61\x73\x20\x61"
  "\x6e\x20\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x3a\x03\x82\x01"
  "\x04\x0e\x73\x74\x72\x69\x6e\x67\x2d\x61\x70\x70\x65\x6e\x64\x03"
  "\x16\x68\x69\x73\x74\x6f\x72\x79\x2f\x6f\x72\x69\x67\x69\x6e\x61"
  "\x6c\x2d\x66\x6f\x72\x6d\xc6\x01\x05\x46\x05\x86\x05\x0a\x81\x87"
  "\x02\x85\x05\x08\x81\x87\x02\x84\x05\x06\x81\x85\x02\x83\x05\x04"
  "\x84\x06\x09\x16\xc7\x01\x02\x45\x0e\x52\x65\x73\x65\x72\x76\x65"
  "\x64\x20\x6e\x61\x6d\x65\x04\x18\x69\x6c\x6c\x65\x67\x61\x6c\x2d"
  "\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x2d\x69\x74\x65\x6d\xc8"
  "\x01\x02\x87\x05\x04\x83\x04\x03\x0a\xc9\x01\x02\x46\x03\x3d\x03"
  "\x41\x03\x44\x03\x14\x05\x8b\x05\x0a\x81\x85\x02\x8a\x05\x08\x81"
  "\x85\x02\x89\x05\x06\x81\x83\x02\x88\x05\x04\x83\x04\x09\x15\xca"
  "\x01\x02\x47\x16\x6b\x65\x79\x77\x6f\x72\x64\x2d\x69\x74\x65\x6d"
  "\x2d\x63\x6f\x6d\x70\x69\x6c\x65\x72\xcb\x01\x02\x05\x0f\x6d\x61"
  "\x6b\x65\x2d\x69\x74\x65\x6d\x2d\x74\x79\x70\x65\xcc\x01\x02\x8d"
  "\x05\x06\x81\x87\x02\x8c\x05\x04\x84\x06\x05\x0d\xcd\x01\x02\x48"
  "\x12\x53\x79\x6e\x74\x61\x63\x74\x69\x63\x20\x6b\x65\x79\x77\x6f"
  "\x72\x64\x04\xc8\x01\x02\x8e\x05\x04\x83\x04\x03\x0a\xce\x01\x02"
  "\x49\x18\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x6b\x65\x79\x77"
  "\x6f\x72\x64\x2d\x3e\x69\x74\x65\x6d\x03\x70\x04\x18\x6d\x61\x6b"
  "\x65\x2d\x6b\x65\x79\x77\x6f\x72\x64\x2d\x76\x61\x6c\x75\x65\x2d"
  "\x69\x74\x65\x6d\xcf\x01\x04\x38\x04\x18\x6f\x75\x74\x70\x75\x74"
  "\x2f\x61\x63\x63\x65\x73\x73\x2d\x72\x65\x66\x65\x72\x65\x6e\x63"
  "\x65\x02\x17\x6f\x75\x74\x70\x75\x74\x2f\x74\x68\x65\x2d\x65\x6e"
  "\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x04\x48\x07\x94\x05\x0e\x81"
  "\x85\x02\x93\x05\x0c\x81\x83\x02\x92\x05\x0a\x81\x83\x02\x91\x05"
  "\x08\x81\x89\x02\x90\x05\x06\x81\x87\x02\x8f\x05\x04\x85\x08\x0d"
  "\x1f\x48\x02\x4a\x03\x74\x03\x10\x6f\x75\x74\x70\x75\x74\x2f\x76"
  "\x61\x72\x69\x61\x62\x6c\x65\x03\x96\x05\x06\x81\x83\x02\x95\x05"
  "\x04\x83\x04\x05\x0d\xd0\x01\x02\x4b\x03\x19\x65\x78\x70\x72\x65"
  "\x73\x73\x69\x6f\x6e\x2d\x69\x74\x65\x6d\x2f\x63\x6f\x6d\x70\x69"
  "\x6c\x65\x72\xd1\x01\x02\x98\x05\x06\x81\x83\x02\x97\x05\x04\x83"
  "\x04\x05\x0b\xd2\x01\x02\x4c\x05\x1d\x6d\x61\x6b\x65\x2d\x73\x70"
  "\x65\x63\x69\x61\x6c\x2d\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e"
  "\x2d\x69\x74\x65\x6d\xd3\x01\x02\x99\x05\x04\x84\x06\x03\xd4\x01"
  "\x02\x4d\x02\x12\x6f\x75\x74\x70\x75\x74\x2f\x75\x6e\x61\x73\x73"
  "\x69\x67\x6e\x65\x64\x02\x9a\x05\x04\x83\x04\x03\xd5\x01\x02\x4e"
  "\x0c\x44\x65\x63\x6c\x61\x72\x61\x74\x69\x6f\x6e\x04\xc8\x01\x02"
  "\x9b\x05\x04\x83\x04\x03\x0a\xd6\x01\x02\x4f\x03\x15\x62\x6f\x64"
  "\x79\x2d\x69\x74\x65\x6d\x2f\x63\x6f\x6d\x70\x6f\x6e\x65\x6e\x74"
  "\x73\xd7\x01\x04\x13\x63\x6f\x6d\x70\x69\x6c\x65\x2d\x62\x6f\x64"
  "\x79\x2d\x69\x74\x65\x6d\x73\xd8\x01\x03\x9d\x05\x06\x81\x85\x02"
  "\x9c\x05\x04\x83\x04\x05\x0d\xd9\x01\x02\x50\x0f\x45\x6d\x70\x74"
  "\x79\x20\x73\x65\x71\x75\x65\x6e\x63\x65\x03\x13\x66\x6c\x61\x74"
  "\x74\x65\x6e\x2d\x62\x6f\x64\x79\x2d\x69\x74\x65\x6d\x73\xda\x01"
  "\x04\x1a\x04\xc8\x01\x03\x0b\x03\x10\x03\x11\x03\x13\x03\x14\x03"
  "\x12\x04\x12\x6f\x75\x74\x70\x75\x74\x2f\x64\x65\x66\x69\x6e\x69"
  "\x74\x69\x6f\x6e\x0b\xa7\x05\x16\x81\x87\x02\xa6\x05\x14\x81\x85"
  "\x02\xa5\x05\x12\x81\x85\x02\xa4\x05\x10\x81\x83\x02\xa3\x05\x0e"
  "\x81\x83\x02\xa2\x05\x0c\x83\x04\xa1\x05\x0a\x81\x87\x02\xa0\x05"
  "\x08\x81\x85\x02\x9f\x05\x06\x81\x87\x02\x9e\x05\x04\x84\x06\x15"
  "\x2f\x1a\x02\x51\x0b\x44\x65\x66\x69\x6e\x69\x74\x69\x6f\x6e\x04"
  "\xc8\x01\x02\xa8\x05\x04\x83\x04\x03\x0a\x0b\x02\x52\x0b\x44\x65"
  "\x66\x69\x6e\x69\x74\x69\x6f\x6e\x04\xc8\x01\x02\xa9\x05\x04\x83"
  "\x04\x03\x0a\xdb\x01\x02\x53\x04\x90\x01\x03\x80\x01\x05\x89\x01"
  "\x04\xad\x05\x0a\x81\x89\x02\xac\x05\x08\x81\x87\x02\xab\x05\x06"
  "\x81\x85\x02\xaa\x05\x04\x84\x06\x09\x13\xdc\x01\x02\x54\xae\x05"
  "\x04\x84\x06\x03\xdd\x01\x02\x55\x30\x20\xb1\x05\x08\x81\x89\x02"
  "\xb0\x05\x06\x81\x87\x02\xaf\x05\x04\x85\x08\x07\x0c\xde\x01\x02"
  "\x56\x30\x20\xb5\x05\x0a\x81\x89\x02\xb4\x05\x08\x81\x89\x02\xb3"
  "\x05\x06\x81\x87\x02\xb2\x05\x04\x85\x08\x09\x0e\xdf\x01\x02\x57"
  "\x30\x20\xb8\x05\x08\x81\x8b\x02\xb7\x05\x06\x81\x89\x02\xb6\x05"
  "\x04\x86\x0a\x07\x0d\xe0\x01\x02\x58\x30\x03\x0a\x6c\x61\x73\x74"
  "\x2d\x70\x61\x69\x72\x02\xbc\x05\x0a\x81\x83\x02\xbb\x05\x08\x81"
  "\x83\x02\xba\x05\x06\x81\x85\x02\xb9\x05\x04\x83\x04\x09\x10\xe1"
  "\x01\x02\x59\x20\x30\x04\x09\x6c\x69\x73\x74\x2d\x72\x65\x66\x04"
  "\x0a\x6c\x69\x73\x74\x2d\x74\x61\x69\x6c\x04\x0f\x73\x65\x6c\x65"
  "\x63\x74\x6f\x72\x2f\x61\x70\x70\x6c\x79\xe2\x01\x04\xc4\x05\x12"
  "\x81\x85\x02\xc3\x05\x10\x81\x85\x02\xc2\x05\x0e\x81\x87\x02\xc1"
  "\x05\x0c\x81\x87\x02\xc0\x05\x0a\x81\x87\x02\xbf\x05\x08\x81\x87"
  "\x02\xbe\x05\x06\x81\x87\x02\xbd\x05\x04\x84\x06\x11\x1e\xe3\x01"
  "\x02\x5a\x20\x30\xca\x05\x0e\x81\x85\x02\xc9\x05\x0c\x81\x85\x02"
  "\xc8\x05\x0a\x81\x83\x02\xc7\x05\x08\x81\x83\x02\xc6\x05\x06\x81"
  "\x83\x02\xc5\x05\x04\x83\x04\x0d\x13\xe4\x01\x02\x5b\x20\x30\xd0"
  "\x05\x0e\x81\x85\x02\xcf\x05\x0c\x81\x85\x02\xce\x05\x0a\x81\x83"
  "\x02\xcd\x05\x08\x81\x83\x02\xcc\x05\x06\x81\x83\x02\xcb\x05\x04"
  "\x83\x04\x0d\x13\xe5\x01\x02\x5c\x03\x5f\x03\x5b\x03\xd2\x05\x06"
  "\x81\x83\x02\xd1\x05\x04\x83\x04\x05\x0d\xe6\x01\x02\x5d\x03\x5f"
  "\x02\xd4\x05\x06\x81\x83\x02\xd3\x05\x04\x83\x04\x05\x0b\xe7\x01"
  "\x02\x5e\x30\x20\x03\x5f\x03\x5b\x03\xdc\x05\x12\xfd\xff\x03\xdb"
  "\x05\x10\xfd\xff\x03\xda\x05\x0e\xfd\xff\x03\xd9\x05\x0c\xfd\xff"
  "\x03\xd8\x05\x0a\xfd\xff\x03\xd7\x05\x08\xfd\xff\x03\xd6\x05\x06"
  "\xff\xff\x03\xd5\x05\x04\x85\x08\x11\x1c\xe8\x01\x02\x5f\x30\x20"
  "\x02\x03\x5b\x03\x5f\x03\xe3\x05\x10\x81\x8b\x02\xe2\x05\x0e\x81"
  "\x8f\x02\xe1\x05\x0c\x81\x8d\x02\xe0\x05\x0a\x81\x8b\x02\xdf\x05"
  "\x08\x81\x8b\x02\xde\x05\x06\x81\x8b\x02\xdd\x05\x04\x85\x08\x0f"
  "\x1a\x30\x02\x60\x03\x15\x6d\x61\x6b\x65\x2d\x63\x6c\x61\x73\x73"
  "\x69\x66\x69\x65\x72\x2d\x69\x74\x65\x6d\x20\x05\x89\x01\x03\xe5"
  "\x05\x06\x81\x87\x02\xe4\x05\x04\x85\x08\x05\x0d\xe9\x01\x02\x61"
  "\x03\x13\x6d\x61\x6b\x65\x2d\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2d"
  "\x69\x74\x65\x6d\xea\x01\x05\x89\x01\x03\xe7\x05\x06\x81\x87\x02"
  "\xe6\x05\x04\x85\x08\x05\x0d\xeb\x01\x02\x62\x04\x13\x6d\x61\x6b"
  "\x65\x2d\x65\x78\x70\x61\x6e\x64\x65\x72\x2d\x69\x74\x65\x6d\xec"
  "\x01\x05\x89\x01\x03\xe9\x05\x06\x81\x87\x02\xe8\x05\x04\x85\x08"
  "\x05\x0d\xed\x01\x02\x63\x03\x20\x03\x0e\x69\x74\x65\x6d\x2d\x3e"
  "\x6b\x65\x79\x77\x6f\x72\x64\xee\x01\x03\xeb\x05\x06\x81\x83\x02"
  "\xea\x05\x04\x83\x04\x05\x0d\xef\x01\x02\x64\x03\xea\x01\x03\xee"
  "\x01\x03\xed\x05\x06\x81\x83\x02\xec\x05\x04\x83\x04\x05\x0d\xf0"
  "\x01\x02\x65\x04\xec\x01\x03\xee\x01\x03\xef\x05\x06\x81\x85\x02"
  "\xee\x05\x04\x84\x06\x05\x0d\xec\x01\x02\x66\x08\x6b\x65\x79\x77"
  "\x6f\x72\x64\x54\x02\x03\xab\x01\x05\x89\x01\x04\x6e\x04\xf3\x05"
  "\x0a\x81\x85\x02\xf2\x05\x08\x81\x83\x02\xf1\x05\x06\x81\x85\x02"
  "\xf0\x05\x04\x83\x04\x09\x16\xf1\x01\x02\x67\x03\x14\x63\x6c\x61"
  "\x73\x73\x69\x66\x69\x65\x72\x2d\x3e\x6b\x65\x79\x77\x6f\x72\x64"
  "\xf2\x01\x02\xf5\x05\x06\x81\x83\x02\xf4\x05\x04\x83\x04\x05\x0c"
  "\xf3\x01\x02\x68\x03\x12\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2d\x3e"
  "\x6b\x65\x79\x77\x6f\x72\x64\xf4\x01\x02\xf7\x05\x06\x81\x83\x02"
  "\xf6\x05\x04\x83\x04\x05\x0c\xf5\x01\x02\x69\x04\x12\x65\x78\x70"
  "\x61\x6e\x64\x65\x72\x2d\x3e\x6b\x65\x79\x77\x6f\x72\x64\xf6\x01"
  "\x02\xf9\x05\x06\x81\x85\x02\xf8\x05\x04\x84\x06\x05\x0c\xf7\x01"
  "\x02\x6a\x03\x11\x63\x6c\x61\x73\x73\x69\x66\x69\x65\x72\x2d\x3e"
  "\x66\x6f\x72\x6d\xf8\x01\x05\x3f\x06\x43\x04\xfd\x05\x0a\x81\x8d"
  "\x02\xfc\x05\x08\x81\x8b\x02\xfb\x05\x06\x81\x8b\x02\xfa\x05\x04"
  "\x83\x04\x09\x13\xf9\x01\x02\x6b\x03\xf8\x01\x05\x3f\x06\x43\x04"
  "\x81\x06\x0a\x81\x8d\x02\x80\x06\x08\x81\x8b\x02\xff\x05\x06\x81"
  "\x8b\x02\xfe\x05\x04\x83\x04\x09\x13\xfa\x01\x02\x6c\x04\x06\x61"
  "\x70\x70\x6c\x79\x02\x46\x02\x03\x1a\x63\x61\x70\x74\x75\x72\x65"
  "\x2d\x65\x78\x70\x61\x6e\x73\x69\x6f\x6e\x2d\x68\x69\x73\x74\x6f"
  "\x72\x79\x46\x02\x85\x06\x0a\x81\x85\x02\x84\x06\x08\x81\x85\x02"
  "\x83\x06\x06\x81\x85\x02\x82\x06\x04\x83\x04\x09\x14\xfb\x01\x02"
  "\x6d\x5d\x02\x04\x0b\x61\x70\x70\x65\x6e\x64\x2d\x6d\x61\x70\x02"
  "\x87\x06\x06\x81\x83\x02\x86\x06\x04\x83\x04\x05\x0d\xfc\x01\x02"
  "\x6e\x03\x0b\x62\x6f\x64\x79\x2d\x69\x74\x65\x6d\x3f\xfd\x01\x03"
  "\xd7\x01\x03\xda\x01\x04\x8a\x06\x08\x81\x83\x02\x89\x06\x06\x81"
  "\x83\x02\x88\x06\x04\x83\x04\x07\x12\xfe\x01\x02\x6f\x03\x1e\x63"
  "\x61\x70\x74\x75\x72\x65\x2d\x73\x79\x6e\x74\x61\x63\x74\x69\x63"
  "\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x04\x6e\x03\x8d"
  "\x06\x08\x81\x87\x02\x8c\x06\x06\x81\x85\x02\x8b\x06\x04\x84\x06"
  "\x07\x0f\xff\x01\x6f\x80\x02\x80\x02\x0e\x73\x65\x6c\x65\x63\x74"
  "\x2d\x63\x64\x64\x64\x64\x72\xff\x01\x04\xfe\x01\x04\xfc\x01\x04"
  "\xfb\x01\x04\xfa\x01\x04\xf9\x01\x04\xf7\x01\x04\xf5\x01\x04\xf3"
  "\x01\x04\xf1\x01\x04\xec\x01\x04\xf0\x01\x04\xef\x01\x04\xed\x01"
  "\x04\xeb\x01\x04\xe9\x01\x04\x30\x04\xe8\x01\x04\xe7\x01\x04\xe6"
  "\x01\x04\x15\x1f\x72\x65\x76\x65\x72\x73\x65\x2d\x73\x79\x6e\x74"
  "\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e"
  "\x74\x73\x5d\xda\x01\x21\x63\x61\x6c\x6c\x2d\x77\x69\x74\x68\x2d"
  "\x73\x79\x6e\x74\x61\x78\x2d\x65\x72\x72\x6f\x72\x2d\x70\x72\x6f"
  "\x63\x65\x64\x75\x72\x65\x46\x0f\x65\x78\x70\x61\x6e\x64\x65\x72"
  "\x2d\x3e\x66\x6f\x72\x6d\x0f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2d"
  "\x3e\x66\x6f\x72\x6d\xf8\x01\xee\x01\xf6\x01\xf4\x01\xf2\x01\x10"
  "\x64\x65\x66\x69\x6e\x65\x2d\x65\x78\x70\x61\x6e\x64\x65\x72\x10"
  "\x64\x65\x66\x69\x6e\x65\x2d\x63\x6f\x6d\x70\x69\x6c\x65\x72\x12"
  "\x64\x65\x66\x69\x6e\x65\x2d\x63\x6c\x61\x73\x73\x69\x66\x69\x65"
  "\x72\x10\x73\x65\x6c\x65\x63\x74\x2d\x66\x6f\x72\x2d\x65\x61\x63"
  "\x68\x2d\x12\x73\x65\x6c\x65\x63\x74\x6f\x72\x2f\x61\x64\x64\x2d"
  "\x63\x64\x64\x72\x12\x73\x65\x6c\x65\x63\x74\x6f\x72\x2f\x61\x64"
  "\x64\x2d\x63\x61\x64\x72\x15\x0e\x73\x65\x6c\x65\x63\x74\x2d\x63"
  "\x64\x64\x64\x61\x72\x0e\x73\x65\x6c\x65\x63\x74\x2d\x63\x64\x64"
  "\x61\x64\x72\x0e\x73\x65\x6c\x65\x63\x74\x2d\x63\x64\x64\x61\x61"
  "\x72\x0e\x73\x65\x6c\x65\x63\x74\x2d\x63\x64\x61\x64\x64\x72\x0e"
  "\x73\x65\x6c\x65\x63\x74\x2d\x63\x64\x61\x64\x61\x72\x0e\x73\x65"
  "\x6c\x65\x63\x74\x2d\x63\x64\x61\x61\x64\x72\x0e\x73\x65\x6c\x65"
  "\x63\x74\x2d\x63\x64\x61\x61\x61\x72\x0e\x73\x65\x6c\x65\x63\x74"
  "\x2d\x63\x61\x64\x64\x64\x72\x0e\x73\x65\x6c\x65\x63\x74\x2d\x63"
  "\x61\x64\x64\x61\x72\x0e\x73\x65\x6c\x65\x63\x74\x2d\x63\x61\x64"
  "\x61\x64\x72\x0e\x73\x65\x6c\x65\x63\x74\x2d\x63\x61\x64\x61\x61"
  "\x72\x0e\x73\x65\x6c\x65\x63\x74\x2d\x63\x61\x61\x64\x64\x72\x0e"
  "\x73\x65\x6c\x65\x63\x74\x2d\x63\x61\x61\x64\x61\x72\x0e\x73\x65"
  "\x6c\x65\x63\x74\x2d\x63\x61\x61\x61\x64\x72\x0e\x73\x65\x6c\x65"
  "\x63\x74\x2d\x63\x61\x61\x61\x61\x72\x0d\x73\x65\x6c\x65\x63\x74"
  "\x2d\x63\x64\x64\x64\x72\x80\x02\x0d\x73\x65\x6c\x65\x63\x74\x2d"
  "\x63\x64\x64\x61\x72\xff\x01\x0d\x73\x65\x6c\x65\x63\x74\x2d\x63"
  "\x64\x61\x64\x72\xfe\x01\x0d\x73\x65\x6c\x65\x63\x74\x2d\x63\x64"
  "\x61\x61\x72\xfc\x01\x0d\x73\x65\x6c\x65\x63\x74\x2d\x63\x61\x64"
  "\x64\x72\xfb\x01\x0d\x73\x65\x6c\x65\x63\x74\x2d\x63\x61\x64\x61"
  "\x72\xfa\x01\x0d\x73\x65\x6c\x65\x63\x74\x2d\x63\x61\x61\x64\x72"
  "\xf9\x01\x0d\x73\x65\x6c\x65\x63\x74\x2d\x63\x61\x61\x61\x72\xf8"
  "\x01\x0c\x73\x65\x6c\x65\x63\x74\x2d\x63\x64\x64\x72\xf7\x01\x0c"
  "\x73\x65\x6c\x65\x63\x74\x2d\x63\x64\x61\x72\xf6\x01\x0c\x73\x65"
  "\x6c\x65\x63\x74\x2d\x63\x61\x64\x72\xf5\x01\x0c\x73\x65\x6c\x65"
  "\x63\x74\x2d\x63\x61\x61\x72\xf4\x01\x32\x31\x5e\x5f\x5b\xe2\x01"
  "\xc6\x01\x50\x3f\x4d\x09\x0f\x62\x69\x6e\x64\x2d\x76\x61\x72\x69"
  "\x61\x62\x6c\x65\x21\x0b\xe5\x01\x04\xe4\x01\x04\xe3\x01\x04\xe1"
  "\x01\x04\xe0\x01\x04\xdf\x01\x04\xde\x01\x04\xdd\x01\x04\xdc\x01"
  "\x04\x0b\x17\x6d\x61\x6b\x65\x2d\x6e\x75\x6c\x6c\x2d\x62\x69\x6e"
  "\x64\x69\x6e\x67\x2d\x69\x74\x65\x6d\x14\x3c\x6e\x75\x6c\x6c\x2d"
  "\x62\x69\x6e\x64\x69\x6e\x67\x2d\x69\x74\x65\x6d\x3e\xf3\x01\x13"
  "\x12\x6e\x75\x6c\x6c\x2d\x62\x69\x6e\x64\x69\x6e\x67\x2d\x69\x74"
  "\x65\x6d\xdb\x01\x04\x12\x06\x76\x61\x6c\x75\x65\xf2\x01\x10\x12"
  "\x6d\x61\x6b\x65\x2d\x62\x69\x6e\x64\x69\x6e\x67\x2d\x69\x74\x65"
  "\x6d\x0f\x3c\x62\x69\x6e\x64\x69\x6e\x67\x2d\x69\x74\x65\x6d\x3e"
  "\xf1\x01\xd7\x01\x0d\x62\x69\x6e\x64\x69\x6e\x67\x2d\x69\x74\x65"
  "\x6d\x05\x6e\x61\x6d\x65\xf0\x01\xf2\x01\x0b\x04\xfd\x01\x0b\x63"
  "\x6f\x6d\x70\x6f\x6e\x65\x6e\x74\x73\xfd\x01\x59\x0c\x3c\x62\x6f"
  "\x64\x79\x2d\x69\x74\x65\x6d\x3e\xf2\x01\xd8\x01\x1a\x04\x17\x0a"
  "\x62\x6f\x64\x79\x2d\x69\x74\x65\x6d\xfd\x01\xd9\x01\x04\x61\x05"
  "\x74\x65\x78\x74\xfd\x01\x16\x6d\x61\x6b\x65\x2d\x64\x65\x63\x6c"
  "\x61\x72\x61\x74\x69\x6f\x6e\x2d\x69\x74\x65\x6d\x13\x3c\x64\x65"
  "\x63\x6c\x61\x72\x61\x74\x69\x6f\x6e\x2d\x69\x74\x65\x6d\x3e\xef"
  "\x01\x11\x75\x6e\x61\x73\x73\x69\x67\x6e\x65\x64\x2d\x69\x74\x65"
  "\x6d\x3f\x11\x64\x65\x63\x6c\x61\x72\x61\x74\x69\x6f\x6e\x2d\x69"
  "\x74\x65\x6d\xfd\x01\xd6\x01\x04\x15\x6d\x61\x6b\x65\x2d\x75\x6e"
  "\x61\x73\x73\x69\x67\x6e\x65\x64\x2d\x69\x74\x65\x6d\x12\x3c\x75"
  "\x6e\x61\x73\x73\x69\x67\x6e\x65\x64\x2d\x69\x74\x65\x6d\x3e\xfd"
  "\x01\x10\x75\x6e\x61\x73\x73\x69\x67\x6e\x65\x64\x2d\x69\x74\x65"
  "\x6d\xd5\x01\x04\x1b\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x2d"
  "\x69\x74\x65\x6d\x2f\x61\x6e\x6e\x6f\x74\x61\x74\x69\x6f\x6e\x38"
  "\xd4\x01\x04\xd1\x01\x0b\x61\x6e\x6e\x6f\x74\x61\x74\x69\x6f\x6e"
  "\xee\x01\x11\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x2d\x69\x74"
  "\x65\x6d\x3f\xd3\x01\x12\x3c\x65\x78\x70\x72\x65\x73\x73\x69\x6f"
  "\x6e\x2d\x69\x74\x65\x6d\x3e\xed\x01\x74\x10\x65\x78\x70\x72\x65"
  "\x73\x73\x69\x6f\x6e\x2d\x69\x74\x65\x6d\x09\x63\x6f\x6d\x70\x69"
  "\x6c\x65\x72\xec\x01\xee\x01\xd2\x01\x04\x73\xf0\x01\x80\x01\x10"
  "\x3c\x76\x61\x72\x69\x61\x62\x6c\x65\x2d\x69\x74\x65\x6d\x3e\xee"
  "\x01\x0e\x76\x61\x72\x69\x61\x62\x6c\x65\x2d\x69\x74\x65\x6d\xf0"
  "\x01\xd0\x01\x04\x15\x3e\x48\x04\x62\x0b\x65\x78\x70\x72\x65\x73"
  "\x73\x69\x6f\x6e\xf0\x01\x14\x05\x69\x74\x65\x6d\xeb\x01\xcf\x01"
  "\x15\x3c\x6b\x65\x79\x77\x6f\x72\x64\x2d\x76\x61\x6c\x75\x65\x2d"
  "\x69\x74\x65\x6d\x3e\xe9\x01\x4c\x13\x6b\x65\x79\x77\x6f\x72\x64"
  "\x2d\x76\x61\x6c\x75\x65\x2d\x69\x74\x65\x6d\xeb\x01\xf0\x01\x4e"
  "\x44\x09\x65\x78\x70\x61\x6e\x64\x65\x72\x4a\x41\xec\x01\xea\x01"
  "\x10\x3c\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2d\x69\x74\x65\x6d\x3e"
  "\xf0\x01\x42\x0e\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2d\x69\x74\x65"
  "\x6d\xec\x01\x3d\x0b\x63\x6c\x61\x73\x73\x69\x66\x69\x65\x72\xec"
  "\x01\x20\x12\x3c\x63\x6c\x61\x73\x73\x69\x66\x69\x65\x72\x2d\x69"
  "\x74\x65\x6d\x3e\xeb\x01\x10\x63\x6c\x61\x73\x73\x69\x66\x69\x65"
  "\x72\x2d\x69\x74\x65\x6d\xec\x01\x81\x01\xcb\x01\x12\x6d\x61\x6b"
  "\x65\x2d\x6b\x65\x79\x77\x6f\x72\x64\x2d\x74\x79\x70\x65\xec\x01"
  "\x36\xce\x01\x04\xcd\x01\x04\xca\x01\x04\x18\x6d\x61\x6b\x65\x2d"
  "\x72\x65\x73\x65\x72\x76\x65\x64\x2d\x6e\x61\x6d\x65\x2d\x69\x74"
  "\x65\x6d\x15\x3c\x72\x65\x73\x65\x72\x76\x65\x64\x2d\x6e\x61\x6d"
  "\x65\x2d\x69\x74\x65\x6d\x3e\xea\x01\x13\x72\x65\x73\x65\x72\x76"
  "\x65\x64\x2d\x6e\x61\x6d\x65\x2d\x69\x74\x65\x6d\xc9\x01\x04\x22"
  "\xc8\x01\x0e\x69\x74\x65\x6d\x2d\x61\x63\x63\x65\x73\x73\x6f\x72"
  "\xe8\x01\x0f\x69\x74\x65\x6d\x2d\x70\x72\x65\x64\x69\x63\x61\x74"
  "\x65\xe7\x01\xcc\x01\x72\xc7\x01\x04\xc5\x01\x04\xc3\x01\x04\xc1"
  "\x01\x04\xbe\x01\x04\x07\x72\x65\x63\x6f\x72\x64\x82\x01\x37\xbd"
  "\x01\x04\x1c\x08\x68\x69\x73\x74\x6f\x72\x79\xb9\x01\x99\x01\x94"
  "\x01\x8d\x01\x86\x01\x40\x9b\x01\x04\x66\x04\xbc\x01\x04\xbb\x01"
  "\x04\xb7\x01\x04\xba\x01\x11\x65\x6c\x73\x65\x2d\x65\x6e\x76\x69"
  "\x72\x6f\x6e\x6d\x65\x6e\x74\xe6\x01\xb8\x01\x12\x6e\x61\x6d\x65"
  "\x73\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\xe5\x01\x79"
  "\x06\x6e\x61\x6d\x65\x73\xe4\x01\xb6\x01\x21\x3c\x66\x69\x6c\x74"
  "\x65\x72\x65\x64\x2d\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65"
  "\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x3e\xe3\x01\xe4\x01\xe5"
  "\x01\xe6\x01\xb3\x01\x98\x01\x91\x01\x8a\x01\x64\xab\x01\xb5\x01"
  "\x04\xb4\x01\x04\x23\x04\xb2\x01\x04\xad\x01\x04\xb1\x01\x0d\x72"
  "\x65\x6e\x61\x6d\x65\x2d\x73\x74\x61\x74\x65\xe6\x01\xaf\x01\x25"
  "\x05\x66\x72\x65\x65\xe5\x01\xae\x01\xb0\x01\x76\xac\x01\x21\x3c"
  "\x69\x6e\x74\x65\x72\x6e\x61\x6c\x2d\x73\x79\x6e\x74\x61\x63\x74"
  "\x69\x63\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x3e\xe4"
  "\x01\x07\x70\x61\x72\x65\x6e\x74\xe2\x01\x06\x62\x6f\x75\x6e\x64"
  "\xe1\x01\xe5\x01\xe6\x01\xa8\x01\x78\x92\x01\x8b\x01\x84\x01\x0a"
  "\xaa\x01\x04\xa2\x01\x04\xa9\x01\x04\xa7\x01\x04\xa4\x01\x04\xa5"
  "\x01\xa6\x01\xe1\x01\x77\xe2\x01\x1e\x22\x3c\x74\x6f\x70\x2d\x6c"
  "\x65\x76\x65\x6c\x2d\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65"
  "\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x3e\xe6\x01\xe2\x01\xe1"
  "\x01\x54\x93\x01\x8c\x01\x85\x01\x95\x01\x8e\x01\x87\x01\xa3\x01"
  "\x04\xa1\x01\x04\xa0\x01\x04\x9f\x01\x04\x9e\x01\x04\x9d\x01\x04"
  "\x9c\x01\x04\x7a\x21\x25\x6d\x61\x6b\x65\x2d\x6e\x75\x6c\x6c\x2d"
  "\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69\x72\x6f"
  "\x6e\x6d\x65\x6e\x74\xe5\x01\x1d\x3c\x6e\x75\x6c\x6c\x2d\x73\x79"
  "\x6e\x74\x61\x63\x74\x69\x63\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d"
  "\x65\x6e\x74\x3e\xe2\x01\x3b\x97\x01\x90\x01\x89\x01\x7f\x35\x7c"
  "\x0d\x69\x64\x65\x6e\x74\x69\x66\x69\x65\x72\x3d\x3f\x70\x1a\x6d"
  "\x61\x6b\x65\x2d\x73\x79\x6e\x74\x68\x65\x74\x69\x63\x2d\x69\x64"
  "\x65\x6e\x74\x69\x66\x69\x65\x72\x6b\x33\x6e\x19\x73\x74\x72\x69"
  "\x70\x2d\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x63\x6c\x6f\x73"
  "\x75\x72\x65\x73\x65\x11\x9a\x01\x04\x96\x01\x04\x8f\x01\x04\x88"
  "\x01\x04\x83\x01\x04\x7e\x04\x7d\x04\x7b\x04\x75\x04\x71\x04\x6f"
  "\x04\x6d\x04\x6c\x06\x6a\x04\x69\x04\x68\x04\x11\x3c\x05\x66\x6f"
  "\x72\x6d\xe1\x01\x39\x0b\x66\x72\x65\x65\x2d\x6e\x61\x6d\x65\x73"
  "\xe0\x01\x34\x0c\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\xdf"
  "\x01\x67\x11\x6c\x6f\x63\x61\x6c\x2d\x61\x73\x73\x69\x67\x6e\x6d"
  "\x65\x6e\x74\x14\x3c\x73\x79\x6e\x74\x61\x63\x74\x69\x63\x2d\x63"
  "\x6c\x6f\x73\x75\x72\x65\x3e\xde\x01\xdf\x01\xe0\x01\xe1\x01\x3a"
  "\x19\x0e\x0e\x63\x6c\x61\x73\x73\x69\x66\x79\x2f\x62\x6f\x64\x79"
  "\x47\x2b\x27\x57\x52\x45\x43\x29\x2e\x0c\x13\x63\x6f\x6d\x70\x69"
  "\x6c\x65\x2f\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x21\xc0\x01"
  "\x1d\x11\x0d\x18\x07\x73\x79\x6e\x74\x61\x78\x19\x63\x04\x5c\x04"
  "\x60\x04\x5a\x04\x58\x04\x56\x04\x55\x04\x53\x04\x51\x04\x4f\x04"
  "\x4b\x04\x49\x04\x2f\x04\x2c\x04\x2a\x04\x28\x04\x26\x04\x24\x04"
  "\x1f\x04\x1b\x04\x16\x04\x0f\x04\x04\x19\x05\x10\x64\x65\x66\x69"
  "\x6e\x65\x2d\x6d\x75\x6c\x74\x69\x70\x6c\x65\x02\xde\x01\xe2\x01"
  "\xe6\x01\xe4\x01\xe3\x01\x07\x3c\x69\x74\x65\x6d\x3e\xea\x01\xeb"
  "\x01\xf0\x01\xcb\x01\x10\x3c\x65\x78\x70\x61\x6e\x64\x65\x72\x2d"
  "\x69\x74\x65\x6d\x3e\xe9\x01\xee\x01\xed\x01\xfd\x01\xef\x01\xf2"
  "\x01\xf1\x01\xf3\x01\x31\x32\xf4\x01\xf5\x01\xf6\x01\xf7\x01\xf8"
  "\x01\xf9\x01\xfa\x01\xfb\x01\xfc\x01\xfe\x01\xff\x01\x80\x02\x23"
  "\x04\xbf\x01\x04\x13\x72\x65\x63\x6f\x72\x64\x2d\x63\x6f\x6e\x73"
  "\x74\x72\x75\x63\x74\x6f\x72\x03\xc2\x01\x04\xc4\x01\x02\xe5\x01"
  "\x04\x10\x72\x65\x63\x6f\x72\x64\x2d\x6d\x6f\x64\x69\x66\x69\x65"
  "\x72\x05\xcc\x01\x04\x11\x69\x74\x65\x6d\x2d\x63\x6f\x6e\x73\x74"
  "\x72\x75\x63\x74\x6f\x72\x03\xe7\x01\x04\xec\x01\x04\x14\x6b\x65"
  "\x79\x77\x6f\x72\x64\x2d\x63\x6f\x6e\x73\x74\x72\x75\x63\x74\x6f"
  "\x72\x04\xe8\x01\x04\xc0\x01\x03\x5b\x03\x5f\x10\xd2\x02\xa6\x05"
  "\x80\x80\x04\xd1\x02\xa4\x05\x81\x81\x02\xd0\x02\xa2\x05\x81\x81"
  "\x02\xcf\x02\xa0\x05\x81\x85\x02\xce\x02\x9e\x05\x81\x83\x02\xcd"
  "\x02\x9c\x05\x81\x85\x02\xcc\x02\x9a\x05\x81\x87\x02\xcb\x02\x98"
  "\x05\x81\x83\x02\xca\x02\x96\x05\x81\x85\x02\xc9\x02\x94\x05\x81"
  "\x87\x02\xc8\x02\x92\x05\x81\x83\x02\xc7\x02\x90\x05\x81\x85\x02"
  "\xc6\x02\x8e\x05\x81\x87\x02\xc5\x02\x8c\x05\x81\x83\x02\xc4\x02"
  "\x8a\x05\x81\x85\x02\xc3\x02\x88\x05\x81\x87\x02\xc2\x02\x86\x05"
  "\x81\x83\x02\xc1\x02\x84\x05\x81\x85\x02\xc0\x02\x82\x05\x81\x87"
  "\x02\xbf\x02\x80\x05\x81\x83\x02\xbe\x02\xfe\x04\x81\x85\x02\xbd"
  "\x02\xfc\x04\x81\x87\x02\xbc\x02\xfa\x04\x81\x83\x02\xbb\x02\xf8"
  "\x04\x81\x85\x02\xba\x02\xf6\x04\x81\x87\x02\xb9\x02\xf4\x04\x81"
  "\x83\x02\xb8\x02\xf2\x04\x81\x85\x02\xb7\x02\xf0\x04\x81\x87\x02"
  "\xb6\x02\xee\x04\x81\x83\x02\xb5\x02\xec\x04\x81\x85\x02\xb4\x02"
  "\xea\x04\x81\x87\x02\xb3\x02\xe8\x04\x81\x83\x02\xb2\x02\xe6\x04"
  "\x81\x85\x02\xb1\x02\xe4\x04\x81\x87\x02\xb0\x02\xe2\x04\x81\x83"
  "\x02\xaf\x02\xe0\x04\x81\x85\x02\xae\x02\xde\x04\x81\x87\x02\xad"
  "\x02\xdc\x04\x81\x83\x02\xac\x02\xda\x04\x81\x85\x02\xab\x02\xd8"
  "\x04\x81\x87\x02\xaa\x02\xd6\x04\x81\x83\x02\xa9\x02\xd4\x04\x81"
  "\x85\x02\xa8\x02\xd2\x04\x81\x87\x02\xa7\x02\xd0\x04\x81\x83\x02"
  "\xa6\x02\xce\x04\x81\x85\x02\xa5\x02\xcc\x04\x81\x87\x02\xa4\x02"
  "\xca\x04\x81\x83\x02\xa3\x02\xc8\x04\x81\x85\x02\xa2\x02\xc6\x04"
  "\x81\x87\x02\xa1\x02\xc4\x04\x81\x83\x02\xa0\x02\xc2\x04\x81\x85"
  "\x02\x9f\x02\xc0\x04\x81\x87\x02\x9e\x02\xbe\x04\x81\x83\x02\x9d"
  "\x02\xbc\x04\x81\x85\x02\x9c\x02\xba\x04\x81\x87\x02\x9b\x02\xb8"
  "\x04\x81\x83\x02\x9a\x02\xb6\x04\x81\x85\x02\x99\x02\xb4\x04\x81"
  "\x87\x02\x98\x02\xb2\x04\x81\x83\x02\x97\x02\xb0\x04\x81\x85\x02"
  "\x96\x02\xae\x04\x81\x87\x02\x95\x02\xac\x04\x81\x83\x02\x94\x02"
  "\xaa\x04\x81\x85\x02\x93\x02\xa8\x04\x81\x87\x02\x92\x02\xa6\x04"
  "\x81\x83\x02\x91\x02\xa4\x04\x81\x85\x02\x90\x02\xa2\x04\x81\x87"
  "\x02\x8f\x02\xa0\x04\x81\x83\x02\x8e\x02\x9e\x04\x81\x85\x02\x8d"
  "\x02\x9c\x04\x81\x87\x02\x8c\x02\x9a\x04\x81\x83\x02\x8b\x02\x98"
  "\x04\x81\x85\x02\x8a\x02\x96\x04\x81\x87\x02\x89\x02\x94\x04\x81"
  "\x83\x02\x88\x02\x92\x04\x81\x85\x02\x87\x02\x90\x04\x81\x87\x02"
  "\x86\x02\x8e\x04\x81\x83\x02\x85\x02\x8c\x04\x81\x85\x02\x84\x02"
  "\x8a\x04\x81\x87\x02\x83\x02\x88\x04\x81\x83\x02\x82\x02\x86\x04"
  "\x81\x85\x02\x81\x02\x84\x04\x81\x87\x02\x80\x02\x82\x04\x81\x83"
  "\x02\xff\x01\x80\x04\x81\x85\x02\xfe\x01\xfe\x03\x81\x87\x02\xfd"
  "\x01\xfc\x03\x81\x83\x02\xfc\x01\xfa\x03\x81\x85\x02\xfb\x01\xf8"
  "\x03\x81\x87\x02\xfa\x01\xf6\x03\x81\x83\x02\xf9\x01\xf4\x03\x81"
  "\x85\x02\xf8\x01\xf2\x03\x81\x87\x02\xf7\x01\xf0\x03\x81\x83\x02"
  "\xf6\x01\xee\x03\x81\x87\x02\xf5\x01\xec\x03\x81\x83\x02\xf4\x01"
  "\xea\x03\x81\x85\x02\xf3\x01\xe8\x03\x81\x83\x02\xf2\x01\xe6\x03"
  "\x81\x85\x02\xf1\x01\xe4\x03\x81\x87\x02\xf0\x01\xe2\x03\x81\x83"
  "\x02\xef\x01\xe0\x03\x81\x85\x02\xee\x01\xde\x03\x81\x89\x02\xed"
  "\x01\xdc\x03\x81\x83\x02\xec\x01\xda\x03\x81\x85\x02\xeb\x01\xd8"
  "\x03\x81\x83\x02\xea\x01\xd6\x03\x81\x85\x02\xe9\x01\xd4\x03\x81"
  "\x89\x02\xe8\x01\xd2\x03\x81\x83\x02\xe7\x01\xd0\x03\x81\x85\x02"
  "\xe6\x01\xce\x03\x81\x89\x02\xe5\x01\xcc\x03\x81\x83\x02\xe4\x01"
  "\xca\x03\x81\x85\x02\xe3\x01\xc8\x03\x81\x87\x02\xe2\x01\xc6\x03"
  "\x81\x83\x02\xe1\x01\xc4\x03\x81\x85\x02\xe0\x01\xc2\x03\x81\x89"
  "\x02\xdf\x01\xc0\x03\x81\x83\x02\xde\x01\xbe\x03\x81\x85\x02\xdd"
  "\x01\xbc\x03\x81\x83\x02\xdc\x01\xba\x03\x81\x85\x02\xdb\x01\xb8"
  "\x03\x81\x89\x02\xda\x01\xb6\x03\x81\x83\x02\xd9\x01\xb4\x03\x81"
  "\x85\x02\xd8\x01\xb2\x03\x81\x87\x02\xd7\x01\xb0\x03\x81\x83\x02"
  "\xd6\x01\xae\x03\x81\x85\x02\xd5\x01\xac\x03\x81\x89\x02\xd4\x01"
  "\xaa\x03\x81\x83\x02\xd3\x01\xa8\x03\x81\x85\x02\xd2\x01\xa6\x03"
  "\x81\x85\x02\xd1\x01\xa4\x03\x81\x83\x02\xd0\x01\xa2\x03\x81\x85"
  "\x02\xcf\x01\xa0\x03\x81\x83\x02\xce\x01\x9e\x03\x81\x85\x02\xcd"
  "\x01\x9c\x03\x81\x89\x02\xcc\x01\x9a\x03\x81\x83\x02\xcb\x01\x98"
  "\x03\x81\x85\x02\xca\x01\x96\x03\x81\x87\x02\xc9\x01\x94\x03\x81"
  "\x83\x02\xc8\x01\x92\x03\x81\x85\x02\xc7\x01\x90\x03\x81\x89\x02"
  "\xc6\x01\x8e\x03\x81\x83\x02\xc5\x01\x8c\x03\x81\x85\x02\xc4\x01"
  "\x8a\x03\x81\x83\x02\xc3\x01\x88\x03\x81\x85\x02\xc2\x01\x86\x03"
  "\x81\x87\x02\xc1\x01\x84\x03\x81\x83\x02\xc0\x01\x82\x03\x81\x85"
  "\x02\xbf\x01\x80\x03\x81\x89\x02\xbe\x01\xfe\x02\x81\x83\x02\xbd"
  "\x01\xfc\x02\x81\x83\x02\xbc\x01\xfa\x02\x81\x85\x02\xbb\x01\xf8"
  "\x02\x81\x83\x02\xba\x01\xf6\x02\x81\x85\x02\xb9\x01\xf4\x02\x81"
  "\x89\x02\xb8\x01\xf2\x02\x81\x83\x02\xb7\x01\xf0\x02\x81\x85\x02"
  "\xb6\x01\xee\x02\x81\x89\x02\xb5\x01\xec\x02\x81\x83\x02\xb4\x01"
  "\xea\x02\x81\x85\x02\xb3\x01\xe8\x02\x81\x87\x02\xb2\x01\xe6\x02"
  "\x81\x83\x02\xb1\x01\xe4\x02\x81\x85\x02\xb0\x01\xe2\x02\x81\x89"
  "\x02\xaf\x01\xe0\x02\x81\x83\x02\xae\x01\xde\x02\x81\x85\x02\xad"
  "\x01\xdc\x02\x81\x83\x02\xac\x01\xda\x02\x81\x85\x02\xab\x01\xd8"
  "\x02\x81\x85\x02\xaa\x01\xd6\x02\x81\x89\x02\xa9\x01\xd4\x02\x81"
  "\x83\x02\xa8\x01\xd2\x02\x81\x85\x02\xa7\x01\xd0\x02\x81\x87\x02"
  "\xa6\x01\xce\x02\x81\x83\x02\xa5\x01\xcc\x02\x81\x85\x02\xa4\x01"
  "\xca\x02\x81\x89\x02\xa3\x01\xc8\x02\x81\x83\x02\xa2\x01\xc6\x02"
  "\x81\x83\x02\xa1\x01\xc4\x02\x81\x85\x02\xa0\x01\xc2\x02\x81\x83"
  "\x02\x9f\x01\xc0\x02\x81\x85\x02\x9e\x01\xbe\x02\x81\x89\x02\x9d"
  "\x01\xbc\x02\x81\x83\x02\x9c\x01\xba\x02\x81\x85\x02\x9b\x01\xb8"
  "\x02\x81\x89\x02\x9a\x01\xb6\x02\x81\x83\x02\x99\x01\xb4\x02\x81"
  "\x85\x02\x98\x01\xb2\x02\x81\x87\x02\x97\x01\xb0\x02\x81\x83\x02"
  "\x96\x01\xae\x02\x81\x85\x02\x95\x01\xac\x02\x81\x89\x02\x94\x01"
  "\xaa\x02\x81\x83\x02\x93\x01\xa8\x02\x81\x85\x02\x92\x01\xa6\x02"
  "\x81\x83\x02\x91\x01\xa4\x02\x81\x85\x02\x90\x01\xa2\x02\x81\x89"
  "\x02\x8f\x01\xa0\x02\x81\x83\x02\x8e\x01\x9e\x02\x81\x85\x02\x8d"
  "\x01\x9c\x02\x81\x89\x02\x8c\x01\x9a\x02\x81\x83\x02\x8b\x01\x98"
  "\x02\x81\x87\x02\x8a\x01\x96\x02\x81\x83\x02\x89\x01\x94\x02\x81"
  "\x85\x02\x88\x01\x92\x02\x81\x87\x02\x87\x01\x90\x02\x81\x85\x02"
  "\x86\x01\x8e\x02\x81\x83\x02\x85\x01\x8c\x02\x81\x85\x02\x84\x01"
  "\x8a\x02\x81\x89\x02\x83\x01\x88\x02\x81\x83\x02\x82\x01\x86\x02"
  "\x81\x85\x02\x81\x01\x84\x02\x81\x87\x02\x80\x01\x82\x02\x81\x83"
  "\x02\x7f\x80\x02\x81\x85\x02\x7e\xfe\x01\x81\x89\x02\x7d\xfc\x01"
  "\x81\x83\x02\x7c\xfa\x01\x81\x85\x02\x7b\xf8\x01\x81\x83\x02\x7a"
  "\xf6\x01\x81\x85\x02\x79\xf4\x01\x81\x89\x02\x78\xf2\x01\x81\x83"
  "\x02\x77\xf0\x01\x81\x85\x02\x76\xee\x01\x81\x87\x02\x75\xec\x01"
  "\x81\x83\x02\x74\xea\x01\x81\x85\x02\x73\xe8\x01\x81\x89\x02\x72"
  "\xe6\x01\x81\x83\x02\x71\xe4\x01\x81\x83\x02\x70\xe2\x01\x81\x85"
  "\x02\x6f\xe0\x01\x81\x83\x02\x6e\xde\x01\x81\x85\x02\x6d\xdc\x01"
  "\x81\x87\x02\x6c\xda\x01\x81\x83\x02\x6b\xd8\x01\x81\x85\x02\x6a"
  "\xd6\x01\x81\x89\x02\x69\xd4\x01\x81\x83\x02\x68\xd2\x01\x81\x83"
  "\x02\x67\xd0\x01\x81\x85\x02\x66\xce\x01\x81\x83\x02\x65\xcc\x01"
  "\x81\x89\x02\x64\xca\x01\x81\x83\x02\x63\xc8\x01\x81\x85\x02\x62"
  "\xc6\x01\x81\x83\x02\x61\xc4\x01\x81\x85\x02\x60\xc2\x01\x81\x89"
  "\x02\x5f\xc0\x01\x81\x83\x02\x5e\xbe\x01\x81\x87\x02\x5d\xbc\x01"
  "\x81\x83\x02\x5c\xba\x01\x81\x85\x02\x5b\xb8\x01\x81\x83\x02\x5a"
  "\xb6\x01\x81\x85\x02\x59\xb4\x01\x81\x89\x02\x58\xb2\x01\x81\x83"
  "\x02\x57\xb0\x01\x81\x85\x02\x56\xae\x01\x81\x89\x02\x55\xac\x01"
  "\x81\x83\x02\x54\xaa\x01\x81\x85\x02\x53\xa8\x01\x81\x89\x02\x52"
  "\xa6\x01\x81\x83\x02\x51\xa4\x01\x81\x85\x02\x50\xa2\x01\x81\x87"
  "\x02\x4f\xa0\x01\x81\x83\x02\x4e\x9e\x01\x81\x85\x02\x4d\x9c\x01"
  "\x81\x89\x02\x4c\x9a\x01\x81\x83\x02\x4b\x98\x01\x81\x83\x02\x4a"
  "\x96\x01\x81\x85\x02\x49\x94\x01\x81\x83\x02\x48\x92\x01\x81\x85"
  "\x02\x47\x90\x01\x81\x89\x02\x46\x8e\x01\x81\x83\x02\x45\x8c\x01"
  "\x81\x85\x02\x44\x8a\x01\x81\x89\x02\x43\x88\x01\x81\x83\x02\x42"
  "\x86\x01\x81\x85\x02\x41\x84\x01\x81\x89\x02\x40\x82\x01\x81\x83"
  "\x02\x3f\x80\x01\x81\x85\x02\x3e\x7e\x81\x89\x02\x3d\x7c\x81\x83"
  "\x02\x3c\x7a\x81\x85\x02\x3b\x78\x81\x89\x02\x3a\x76\x81\x83\x02"
  "\x39\x74\x81\x85\x02\x38\x72\x81\x89\x02\x37\x70\x81\x83\x02\x36"
  "\x6e\x81\x85\x02\x35\x6c\x81\x87\x02\x34\x6a\x81\x83\x02\x33\x68"
  "\x81\x85\x02\x32\x66\x81\x89\x02\x31\x64\x81\x83\x02\x30\x62\x81"
  "\x83\x02\x2f\x60\x81\x85\x02\x2e\x5e\x81\x83\x02\x2d\x5c\x81\x85"
  "\x02\x2c\x5a\x81\x89\x02\x2b\x58\x81\x83\x02\x2a\x56\x81\x85\x02"
  "\x29\x54\x81\x89\x02\x28\x52\x81\x83\x02\x27\x50\x81\x85\x02\x26"
  "\x4e\x81\x89\x02\x25\x4c\x81\x83\x02\x24\x4a\x81\x85\x02\x23\x48"
  "\x81\x87\x02\x22\x46\x81\x83\x02\x21\x44\x81\x85\x02\x20\x42\x81"
  "\x89\x02\x1f\x40\x81\x83\x02\x1e\x3e\x81\x83\x02\x1d\x3c\x81\x85"
  "\x02\x1c\x3a\x81\x83\x02\x1b\x38\x81\x85\x02\x1a\x36\x81\x83\x02"
  "\x19\x34\x81\x85\x02\x18\x32\x81\x87\x02\x17\x30\x81\x83\x02\x16"
  "\x2e\x81\x85\x02\x15\x2c\x81\x89\x02\x14\x2a\x81\x83\x02\x13\x28"
  "\x81\x83\x02\x12\x26\x81\x85\x02\x11\x24\x81\x83\x02\x10\x22\x81"
  "\x85\x02\x0f\x20\x81\x89\x02\x0e\x1e\x81\x83\x02\x0d\x1c\x81\x85"
  "\x02\x0c\x1a\x81\x89\x02\x0b\x18\x81\x83\x02\x0a\x16\x81\x85\x02"
  "\x09\x14\x81\x89\x02\x08\x12\x81\x83\x02\x07\x10\x81\x85\x02\x06"
  "\x0e\x81\x87\x02\x05\x0c\x81\x83\x02\x04\x0a\x81\x85\x02\x03\x08"
  "\x81\x89\x02\x02\x06\x81\x83\x02\x01\x04\x81\x83\x02\xa5\x05\xb1"
  "\x07";

SCHEME_OBJECT *
syntactic_closures_so_data_878f33995e68d951 (entry_count_t dispatch_base)
{
  SCHEME_OBJECT ccb;
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES_FOR_DATA ();

  ccb = (unstackify (((unsigned char *) (& (prog_syntactic_closures_so_data_878f33995e68d951 [0]))), (sizeof (prog_syntactic_closures_so_data_878f33995e68d951)), dispatch_base));
  current_block = (OBJECT_ADDRESS (ccb));
  return (& (current_block [LABEL_359]));
}

DECLARE_COMPILED_DATA_NS ("syntactic-closures.so", syntactic_closures_so_data_878f33995e68d951)

#endif /* !WANT_ONLY_CODE */

DECLARE_DYNAMIC_INITIALIZATION ("syntactic-closures.so", "ed99205bca3e5ad3")
