/* Emacs: this is -*- C -*- code, */
/* generated 2007-09-09T13:46:41-0400 by Liar version UNKNOWN. */

#include "liarc.h"

#define LABEL_1_4 3
#define LABEL_1_5 5
#define ENVIRONMENT_LABEL_1_3 10
#define DEBUGGING_LABEL_1_2 9
#define OBJECT_1_0 8
#define FREE_REFERENCE_1_0 7
#define FREE_REFERENCES_LABEL_1_0 6
#define NUMBER_OF_LINKER_SECTIONS_1_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_1_4);
      goto make_package_0;

    case 1:
      current_block = (Rpc - LABEL_1_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_package_4)
DEFLABEL (make_package_0)
  INTERRUPT_CHECK (26, LABEL_1_4);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_0]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_6;
  Wrd6 = Wrd10;

DEFLABEL (label_5)
  (Wrd20.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd21.Obj) = (Rsp [0]);
  (Wrd22.Obj) = (current_block [OBJECT_1_0]);
  (* (Rhp++)) = (Wrd20.Obj);
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd21.Obj);
  (* (Rhp++)) = (Wrd22.Obj);
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (Wrd14.pObj) = (& (Rhp [-6]));
  Rvl = (MAKE_POINTER_OBJECT (62, (Wrd14.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_5])), (Wrd7.pObj));

DEFLABEL (label_2)
  (Wrd6.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_2_4 3
#define LABEL_2_5 5
#define LABEL_2_6 7
#define ENVIRONMENT_LABEL_2_3 14
#define DEBUGGING_LABEL_2_2 13
#define OBJECT_2_2 12
#define OBJECT_2_1 11
#define OBJECT_2_0 10
#define FREE_REFERENCE_2_0 9
#define FREE_REFERENCES_LABEL_2_0 8
#define NUMBER_OF_LINKER_SECTIONS_2_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd15;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_2_4);
      goto packageP_2;

    case 1:
      current_block = (Rpc - LABEL_2_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_2_6);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (packageP_7)
DEFLABEL (packageP_2)
  INTERRUPT_CHECK (26, LABEL_2_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 62)
    goto label_10;

DEFLABEL (label_9)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_8)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_10)
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_14;
  Wrd9 = Wrd13;

DEFLABEL (label_13)
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd24.Obj) = (Rsp [1]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd25.uLng) == 62))
    goto label_12;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [0]);
  (Wrd23.Lng) = (FIXNUM_TO_LONG (Wrd22.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd23.Lng))))
    goto label_12;
  (Wrd15.Obj) = ((Wrd21.pObj) [1]);

DEFLABEL (label_11)
  (Wrd31.Obj) = (* (Rsp++));
  if (! ((Wrd15.Obj) == (Wrd31.Obj)))
    goto label_9;
  Rvl = (current_block [OBJECT_2_2]);
  goto label_8;

DEFLABEL (label_12)
  (Wrd26.Obj) = (Rsp [1]);
  (Wrd27.Obj) = (current_block [OBJECT_2_0]);
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_6]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_1]), 2);

DEFLABEL (label_5)
  (Wrd15.Obj) = Rvl;
  goto label_11;

DEFLABEL (label_14)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_5])), (Wrd10.pObj));

DEFLABEL (label_4)
  (Wrd9.Obj) = Rvl;
  goto label_13;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_3_4 3
#define ENVIRONMENT_LABEL_3_3 7
#define DEBUGGING_LABEL_3_2 6
#define OBJECT_3_1 5
#define OBJECT_3_0 4
#define FREE_REFERENCES_LABEL_3_0 4
#define NUMBER_OF_LINKER_SECTIONS_3_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_3_4);
      goto package_parent_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (package_parent_3)
DEFLABEL (package_parent_0)
  INTERRUPT_CHECK (26, LABEL_3_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_3_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4_4 3
#define ENVIRONMENT_LABEL_4_3 7
#define DEBUGGING_LABEL_4_2 6
#define OBJECT_4_1 5
#define OBJECT_4_0 4
#define FREE_REFERENCES_LABEL_4_0 4
#define NUMBER_OF_LINKER_SECTIONS_4_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4_4);
      goto package_children_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (package_children_3)
DEFLABEL (package_children_0)
  INTERRUPT_CHECK (26, LABEL_4_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_4_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_5_4 3
#define ENVIRONMENT_LABEL_5_3 8
#define DEBUGGING_LABEL_5_2 7
#define OBJECT_5_2 6
#define OBJECT_5_1 5
#define OBJECT_5_0 4
#define FREE_REFERENCES_LABEL_5_0 4
#define NUMBER_OF_LINKER_SECTIONS_5_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_5_4);
      goto set_package_childrenB_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (set_package_childrenB_3)
DEFLABEL (set_package_childrenB_0)
  INTERRUPT_CHECK (26, LABEL_5_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_5_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_5_2]), 3);

DEFLABEL (label_5)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd17.Lng))))
    goto label_4;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd15.pObj) [3]) = (Wrd10.Obj);
  Rvl = (current_block [OBJECT_5_1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_6_4 3
#define ENVIRONMENT_LABEL_6_3 7
#define DEBUGGING_LABEL_6_2 6
#define OBJECT_6_1 5
#define OBJECT_6_0 4
#define FREE_REFERENCES_LABEL_6_0 4
#define NUMBER_OF_LINKER_SECTIONS_6_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_6_4);
      goto package__name_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (package__name_3)
DEFLABEL (package__name_0)
  INTERRUPT_CHECK (26, LABEL_6_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_6_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_6_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [4]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_7_4 3
#define ENVIRONMENT_LABEL_7_3 7
#define DEBUGGING_LABEL_7_2 6
#define OBJECT_7_1 5
#define OBJECT_7_0 4
#define FREE_REFERENCES_LABEL_7_0 4
#define NUMBER_OF_LINKER_SECTIONS_7_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_7 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_7_4);
      goto package_environment_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (package_environment_3)
DEFLABEL (package_environment_0)
  INTERRUPT_CHECK (26, LABEL_7_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_7_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [5]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_8_4 3
#define ENVIRONMENT_LABEL_8_3 8
#define DEBUGGING_LABEL_8_2 7
#define OBJECT_8_2 6
#define OBJECT_8_1 5
#define OBJECT_8_0 4
#define FREE_REFERENCES_LABEL_8_0 4
#define NUMBER_OF_LINKER_SECTIONS_8_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_8_4);
      goto set_package_environmentB_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (set_package_environmentB_3)
DEFLABEL (set_package_environmentB_0)
  INTERRUPT_CHECK (26, LABEL_8_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_8_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd19.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_8_2]), 3);

DEFLABEL (label_5)
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd17.Lng))))
    goto label_4;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd15.pObj) [5]) = (Wrd10.Obj);
  Rvl = (current_block [OBJECT_8_1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_9_4 3
#define LABEL_9_5 5
#define ENVIRONMENT_LABEL_9_3 12
#define DEBUGGING_LABEL_9_2 11
#define EXECUTE_CACHE_9_6 7
#define FREE_REFERENCE_9_0 10
#define FREE_REFERENCES_LABEL_9_0 6
#define NUMBER_OF_LINKER_SECTIONS_9_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_9_4);
      goto package_nameP_0;

    case 1:
      current_block = (Rpc - LABEL_9_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (package_nameP_4)
DEFLABEL (package_nameP_0)
  INTERRUPT_CHECK (26, LABEL_9_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9_0]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_6;
  Wrd7 = Wrd11;

DEFLABEL (label_5)
  (Rsp [1]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_9_5])), (Wrd8.pObj));

DEFLABEL (label_2)
  (Wrd7.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_10_4 3
#define LABEL_10_5 5
#define ENVIRONMENT_LABEL_10_3 10
#define DEBUGGING_LABEL_10_2 9
#define OBJECT_10_2 8
#define OBJECT_10_1 7
#define OBJECT_10_0 6
#define FREE_REFERENCES_LABEL_10_0 6
#define NUMBER_OF_LINKER_SECTIONS_10_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_10 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_10_4);
      goto package_reference_1;

    case 1:
      current_block = (Rpc - LABEL_10_5);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (package_reference_5)
DEFLABEL (package_reference_1)
  INTERRUPT_CHECK (26, LABEL_10_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_7;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd13.Lng))))
    goto label_7;
  (Wrd5.Obj) = ((Wrd11.pObj) [5]);

DEFLABEL (label_6)
  (Rsp [0]) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_2]), 2);

DEFLABEL (label_7)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_10_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_1]), 2);

DEFLABEL (label_3)
  (Wrd5.Obj) = Rvl;
  goto label_6;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_11_4 3
#define LABEL_11_5 5
#define LABEL_11_7 7
#define LABEL_11_8 9
#define LABEL_11_13 11
#define LABEL_11_16 13
#define LABEL_11_10 15
#define LABEL_11_11 17
#define LABEL_11_14 19
#define TAG_11_15 8
#define LABEL_11_20 21
#define LABEL_11_21 23
#define LABEL_11_18 25
#define LABEL_11_23 27
#define ENVIRONMENT_LABEL_11_3 58
#define DEBUGGING_LABEL_11_2 57
#define OBJECT_11_7 56
#define OBJECT_11_6 55
#define OBJECT_11_5 54
#define OBJECT_11_4 53
#define OBJECT_11_3 52
#define OBJECT_11_2 51
#define OBJECT_11_1 50
#define OBJECT_11_0 49
#define EXECUTE_CACHE_11_25 29
#define EXECUTE_CACHE_11_24 31
#define EXECUTE_CACHE_11_22 33
#define EXECUTE_CACHE_11_19 35
#define EXECUTE_CACHE_11_17 37
#define EXECUTE_CACHE_11_12 39
#define EXECUTE_CACHE_11_9 41
#define EXECUTE_CACHE_11_6 43
#define FREE_REFERENCE_11_0 46
#define FREE_ASSIGNMENT_11_0 48
#define FREE_REFERENCES_LABEL_11_0 28
#define NUMBER_OF_LINKER_SECTIONS_11_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_11 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd6;
  machine_word Wrd12;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd42;
  machine_word Wrd37;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd26;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd20;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_11_4);
      goto finalize_package_record_typeB_14;

    case 1:
      current_block = (Rpc - LABEL_11_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_11_7);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_11_8);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_11_13);
      goto label_16;

    case 5:
      current_block = (Rpc - LABEL_11_16);
      goto label_17;

    case 6:
      current_block = (Rpc - LABEL_11_10);
      goto continuation_12;

    case 7:
      current_block = (Rpc - LABEL_11_11);
      goto lambda_11;

    case 8:
      current_block = (Rpc - LABEL_11_14);
      goto loop_22;

    case 9:
      current_block = (Rpc - LABEL_11_20);
      goto label_19;

    case 10:
      current_block = (Rpc - LABEL_11_21);
      goto label_18;

    case 11:
      current_block = (Rpc - LABEL_11_18);
      goto continuation_9;

    case 12:
      current_block = (Rpc - LABEL_11_23);
      goto continuation_10;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (finalize_package_record_typeB_21)
DEFLABEL (finalize_package_record_typeB_14)
  INTERRUPT_CHECK (26, LABEL_11_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_11_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_11_1]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_11_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_8]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_11_8);
  (* (--Rsp)) = Rvl;
  (Wrd5.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_11_0]));
  (Wrd13.Obj) = ((Wrd5.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_28;

DEFLABEL (label_27)
  ((Wrd5.pObj) [0]) = Rvl;

DEFLABEL (label_26)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd29.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_11_15);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_11_14])));
  Rhp += 1;
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd29.pObj)));
  (* (--Rsp)) = (Wrd30.Obj);
  Wrd27 = Wrd29;
  (Wrd28.Obj) = (Rsp [1]);
  ((Wrd27.pObj) [2]) = (Wrd28.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11_0]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_25;
  Wrd20 = Wrd24;

DEFLABEL (label_24)
  (Rsp [1]) = (Wrd20.Obj);
  goto loop_6;

DEFLABEL (label_25)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_11_16])), (Wrd21.pObj));

DEFLABEL (label_17)
  (Wrd20.Obj) = Rvl;
  goto label_24;

DEFLABEL (label_28)
  if ((Wrd13.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_27;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_11_13])), (Wrd5.pObj), Rvl);

DEFLABEL (label_16)
  goto label_26;

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_11_7);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_10]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_11]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_11_2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_12]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_11_10);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_17]));

DEFLABEL (lambda_23)
DEFLABEL (lambda_11)
  INTERRUPT_CHECK (26, LABEL_11_11);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_18]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_11_3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_19]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_11_18);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_23]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_24]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_11_23);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_25]));

DEFLABEL (loop_22)
  CLOSURE_HEADER (LABEL_11_14);

DEFLABEL (loop_6)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd33.Obj) = (Rsp [1]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 62))
    goto label_32;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd32.Lng))))
    goto label_32;
  (Wrd24.Obj) = (Rsp [0]);
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [2]);
  ((Wrd30.pObj) [1]) = (Wrd26.Obj);

DEFLABEL (label_31)
  (Wrd5.Obj) = (Rsp [0]);
  (Rsp [0]) = (Wrd5.Obj);
  (Wrd15.Obj) = (Rsp [1]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 62))
    goto label_30;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd14.Lng))))
    goto label_30;
  (Wrd6.Obj) = ((Wrd12.pObj) [3]);

DEFLABEL (label_29)
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_22]));

DEFLABEL (label_30)
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.Obj) = (current_block [OBJECT_11_6]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_21]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_11_7]), 2);

DEFLABEL (label_18)
  (Wrd6.Obj) = Rvl;
  goto label_29;

DEFLABEL (label_32)
  (Wrd35.Obj) = (Rsp [1]);
  (Wrd36.Obj) = (current_block [OBJECT_11_4]);
  (Wrd38.Obj) = (Rsp [0]);
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd37.Obj) = ((Wrd39.pObj) [2]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_20]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_11_5]), 3);

DEFLABEL (label_19)
  goto label_31;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_12_4 3
#define LABEL_12_5 5
#define LABEL_12_6 7
#define LABEL_12_7 9
#define LABEL_12_8 11
#define LABEL_12_9 13
#define ENVIRONMENT_LABEL_12_3 20
#define DEBUGGING_LABEL_12_2 19
#define OBJECT_12_4 18
#define OBJECT_12_3 17
#define OBJECT_12_2 16
#define OBJECT_12_1 15
#define OBJECT_12_0 14
#define FREE_REFERENCES_LABEL_12_0 14
#define NUMBER_OF_LINKER_SECTIONS_12_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_12 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd40;
  machine_word Wrd32;
  machine_word Wrd34;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd44;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd41;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd27;
  machine_word Wrd18;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd25;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_12_4);
      goto package_child_9;

    case 1:
      current_block = (Rpc - LABEL_12_5);
      goto label_11;

    case 2:
      current_block = (Rpc - LABEL_12_6);
      goto loop_7;

    case 3:
      current_block = (Rpc - LABEL_12_7);
      goto label_12;

    case 4:
      current_block = (Rpc - LABEL_12_8);
      goto label_13;

    case 5:
      current_block = (Rpc - LABEL_12_9);
      goto label_14;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (package_child_16)
DEFLABEL (package_child_9)
  INTERRUPT_CHECK (26, LABEL_12_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_19;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_19;
  (Wrd7.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_18)
  goto loop_7;

DEFLABEL (label_19)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_12_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_1]), 2);

DEFLABEL (label_11)
  (* (--Rsp)) = Rvl;
  goto label_18;

DEFLABEL (loop_17)
DEFLABEL (loop_7)
  INTERRUPT_CHECK (26, LABEL_12_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_20;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_20)
  if (! ((Wrd6.uLng) == 1))
    goto label_28;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [0]);

DEFLABEL (label_27)
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd25.uLng) == 62))
    goto label_26;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [0]);
  (Wrd24.Lng) = (FIXNUM_TO_LONG (Wrd23.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd24.Lng))))
    goto label_26;
  (Wrd18.Obj) = ((Wrd22.pObj) [4]);

DEFLABEL (label_25)
  (Wrd31.Obj) = (Rsp [2]);
  if ((Wrd31.Obj) == (Wrd18.Obj))
    goto label_23;
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd36.uLng) == 1))
    goto label_22;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd32.Obj) = ((Wrd34.pObj) [1]);

DEFLABEL (label_21)
  (Rsp [0]) = (Wrd32.Obj);
  goto loop_7;

DEFLABEL (label_22)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_9]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_4]), 1);

DEFLABEL (label_14)
  (Wrd32.Obj) = Rvl;
  goto label_21;

DEFLABEL (label_23)
  (Wrd41.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd41.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd46.Obj) = (Rsp [0]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if (! ((Wrd47.uLng) == 1))
    goto label_24;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  Rvl = ((Wrd44.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_24)
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_2]), 1);

DEFLABEL (label_26)
  (Wrd27.Obj) = (current_block [OBJECT_12_3]);
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_8]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_1]), 2);

DEFLABEL (label_13)
  (Wrd18.Obj) = Rvl;
  goto label_25;

DEFLABEL (label_28)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_7]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_2]), 1);

DEFLABEL (label_12)
  (Wrd9.Obj) = Rvl;
  goto label_27;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_13_4 3
#define LABEL_13_5 5
#define LABEL_13_6 7
#define LABEL_13_7 9
#define LABEL_13_8 11
#define ENVIRONMENT_LABEL_13_3 17
#define DEBUGGING_LABEL_13_2 16
#define OBJECT_13_3 15
#define OBJECT_13_2 14
#define OBJECT_13_1 13
#define OBJECT_13_0 12
#define FREE_REFERENCES_LABEL_13_0 12
#define NUMBER_OF_LINKER_SECTIONS_13_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_13 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd46;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd31;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd27;
  machine_word Wrd29;
  machine_word Wrd30;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd11;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd59;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd7;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_13_4);
      goto package_name_7;

    case 1:
      current_block = (Rpc - LABEL_13_5);
      goto loop_5;

    case 2:
      current_block = (Rpc - LABEL_13_6);
      goto label_11;

    case 3:
      current_block = (Rpc - LABEL_13_7);
      goto label_9;

    case 4:
      current_block = (Rpc - LABEL_13_8);
      goto label_10;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (package_name_13)
DEFLABEL (package_name_7)
  INTERRUPT_CHECK (26, LABEL_13_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_13_0]);
  (Rsp [1]) = (Wrd6.Obj);
  goto loop_5;

DEFLABEL (loop_14)
DEFLABEL (loop_5)
  INTERRUPT_CHECK (26, LABEL_13_5);
  (Wrd53.Obj) = (Rsp [0]);
  (Wrd54.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if (! ((Wrd54.uLng) == 62))
    goto label_21;
  (Wrd50.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd51.Obj) = ((Wrd50.pObj) [0]);
  (Wrd52.Lng) = (FIXNUM_TO_LONG (Wrd51.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd52.Lng))))
    goto label_21;
  (Wrd7.Obj) = ((Wrd50.pObj) [2]);
  if (! ((Wrd7.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_16;

DEFLABEL (label_15)
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_16)
  (Wrd20.Obj) = (Rsp [0]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 62))
    goto label_20;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd19.Lng))))
    goto label_20;
  (Wrd11.Obj) = ((Wrd17.pObj) [4]);

DEFLABEL (label_19)
  (Wrd30.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = (Wrd30.Obj);
  (Wrd29.pObj) = (& (Rhp [-2]));
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd29.pObj)));
  (Rsp [1]) = (Wrd27.Obj);
  (Wrd40.Obj) = (Rsp [0]);
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if (! ((Wrd41.uLng) == 62))
    goto label_18;
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  (Wrd38.Obj) = ((Wrd37.pObj) [0]);
  (Wrd39.Lng) = (FIXNUM_TO_LONG (Wrd38.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd39.Lng))))
    goto label_18;
  (Wrd31.Obj) = ((Wrd37.pObj) [2]);

DEFLABEL (label_17)
  (Rsp [0]) = (Wrd31.Obj);
  goto loop_5;

DEFLABEL (label_18)
  (Wrd42.Obj) = (Rsp [0]);
  (Wrd43.Obj) = (current_block [OBJECT_13_1]);
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_8]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_13_2]), 2);

DEFLABEL (label_10)
  (Wrd31.Obj) = Rvl;
  goto label_17;

DEFLABEL (label_20)
  (Wrd22.Obj) = (Rsp [0]);
  (Wrd23.Obj) = (current_block [OBJECT_13_3]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_7]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_13_2]), 2);

DEFLABEL (label_9)
  (Wrd11.Obj) = Rvl;
  goto label_19;

DEFLABEL (label_21)
  (Wrd55.Obj) = (Rsp [0]);
  (Wrd56.Obj) = (current_block [OBJECT_13_1]);
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_6]))));
  (* (--Rsp)) = (Wrd59.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd55.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_13_2]), 2);

DEFLABEL (label_11)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_15;
  goto label_16;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_14_4 3
#define LABEL_14_5 5
#define LABEL_14_6 7
#define LABEL_14_8 9
#define LABEL_14_7 11
#define LABEL_14_10 13
#define ENVIRONMENT_LABEL_14_3 22
#define DEBUGGING_LABEL_14_2 21
#define OBJECT_14_1 20
#define OBJECT_14_0 19
#define EXECUTE_CACHE_14_9 15
#define FREE_REFERENCE_14_0 18
#define FREE_REFERENCES_LABEL_14_0 14
#define NUMBER_OF_LINKER_SECTIONS_14_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_14 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd9;
  machine_word Wrd10;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd7;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_14_4);
      goto name__package_8;

    case 1:
      current_block = (Rpc - LABEL_14_5);
      goto label_10;

    case 2:
      current_block = (Rpc - LABEL_14_6);
      goto loop_6;

    case 3:
      current_block = (Rpc - LABEL_14_8);
      goto label_11;

    case 4:
      current_block = (Rpc - LABEL_14_7);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_14_10);
      goto label_12;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (name__package_14)
DEFLABEL (name__package_8)
  INTERRUPT_CHECK (26, LABEL_14_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14_0]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_17;
  Wrd7 = Wrd11;

DEFLABEL (label_16)
  (Rsp [1]) = (Wrd7.Obj);
  goto loop_6;

DEFLABEL (label_17)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_14_5])), (Wrd8.pObj));

DEFLABEL (label_10)
  (Wrd7.Obj) = Rvl;
  goto label_16;

DEFLABEL (loop_15)
DEFLABEL (loop_6)
  INTERRUPT_CHECK (26, LABEL_14_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_18;
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_18)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_7]))));
  (* (--Rsp)) = (Wrd11.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_23;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_22)
  (Wrd21.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_9]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_14_7);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_19;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_19)
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_21;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_20)
  (Rsp [1]) = (Wrd7.Obj);
  (Wrd16.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_6;

DEFLABEL (label_21)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_10]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_1]), 1);

DEFLABEL (label_12)
  (Wrd7.Obj) = Rvl;
  goto label_20;

DEFLABEL (label_23)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_8]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_0]), 1);

DEFLABEL (label_11)
  (* (--Rsp)) = Rvl;
  goto label_22;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_15_4 3
#define LABEL_15_5 5
#define ENVIRONMENT_LABEL_15_3 12
#define DEBUGGING_LABEL_15_2 11
#define EXECUTE_CACHE_15_7 7
#define EXECUTE_CACHE_15_6 9
#define FREE_REFERENCES_LABEL_15_0 6
#define NUMBER_OF_LINKER_SECTIONS_15_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_15 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_15_4);
      goto environment__package_1;

    case 1:
      current_block = (Rpc - LABEL_15_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (environment__package_4)
DEFLABEL (environment__package_1)
  INTERRUPT_CHECK (26, LABEL_15_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_15_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_5;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_7]));

DEFLABEL (label_5)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_16_4 3
#define LABEL_16_5 5
#define LABEL_16_6 7
#define LABEL_16_7 9
#define LABEL_16_9 11
#define ENVIRONMENT_LABEL_16_3 21
#define DEBUGGING_LABEL_16_2 20
#define OBJECT_16_4 19
#define OBJECT_16_3 18
#define OBJECT_16_2 17
#define OBJECT_16_1 16
#define OBJECT_16_0 15
#define EXECUTE_CACHE_16_8 13
#define FREE_REFERENCES_LABEL_16_0 12
#define NUMBER_OF_LINKER_SECTIONS_16_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_16 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_16_4);
      goto interpreter_environment__package_6;

    case 1:
      current_block = (Rpc - LABEL_16_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_16_6);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_16_7);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_16_9);
      goto label_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (interpreter_environment__package_10)
DEFLABEL (interpreter_environment__package_6)
  INTERRUPT_CHECK (26, LABEL_16_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_16_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_16_1]), 2);

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_16_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_11;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_11)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_6]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_16_0]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_16_2]), 2);

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_16_6);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_16_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_14;
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 62))
    goto label_17;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd15.Lng))))
    goto label_17;
  (Wrd7.Obj) = ((Wrd13.pObj) [5]);

DEFLABEL (label_16)
  (Wrd23.Obj) = (Rsp [1]);
  if ((Wrd23.Obj) == (Wrd7.Obj))
    goto label_13;

DEFLABEL (label_14)
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_12;

DEFLABEL (label_13)
  Rvl = (Rsp [0]);

DEFLABEL (label_12)
DEFLABEL (label_15)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_17)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_16_3]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_9]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_16_4]), 2);

DEFLABEL (label_8)
  (Wrd7.Obj) = Rvl;
  goto label_16;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_17_4 3
#define LABEL_17_5 5
#define LABEL_17_6 7
#define LABEL_17_9 9
#define LABEL_17_8 11
#define LABEL_17_12 13
#define LABEL_17_7 15
#define LABEL_17_14 17
#define LABEL_17_11 19
#define ENVIRONMENT_LABEL_17_3 33
#define DEBUGGING_LABEL_17_2 32
#define OBJECT_17_2 31
#define OBJECT_17_1 30
#define OBJECT_17_0 29
#define EXECUTE_CACHE_17_15 21
#define EXECUTE_CACHE_17_13 23
#define EXECUTE_CACHE_17_10 25
#define FREE_REFERENCE_17_0 28
#define FREE_REFERENCES_LABEL_17_0 20
#define NUMBER_OF_LINKER_SECTIONS_17_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_17 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_17_4);
      goto find_package_11;

    case 1:
      current_block = (Rpc - LABEL_17_5);
      goto label_13;

    case 2:
      current_block = (Rpc - LABEL_17_6);
      goto loop_9;

    case 3:
      current_block = (Rpc - LABEL_17_9);
      goto label_14;

    case 4:
      current_block = (Rpc - LABEL_17_8);
      goto continuation_4;

    case 5:
      current_block = (Rpc - LABEL_17_12);
      goto label_16;

    case 6:
      current_block = (Rpc - LABEL_17_7);
      goto continuation_5;

    case 7:
      current_block = (Rpc - LABEL_17_14);
      goto label_15;

    case 8:
      current_block = (Rpc - LABEL_17_11);
      goto continuation_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (find_package_18)
DEFLABEL (find_package_11)
  INTERRUPT_CHECK (26, LABEL_17_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_17_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_21;
  Wrd5 = Wrd9;

DEFLABEL (label_20)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd11.Obj);
  goto loop_9;

DEFLABEL (label_21)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_17_5])), (Wrd6.pObj));

DEFLABEL (label_13)
  (Wrd5.Obj) = Rvl;
  goto label_20;

DEFLABEL (loop_19)
DEFLABEL (loop_9)
  INTERRUPT_CHECK (26, LABEL_17_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_22;
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_22)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_7]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_8]))));
  (* (--Rsp)) = (Wrd14.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_30;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_29)
  (Wrd24.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_10]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_17_8);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_26;
  (Wrd5.Obj) = Rvl;
  Rsp = (& (Rsp [2]));

DEFLABEL (label_25)
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd10.uLng) == 1))
    goto label_24;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [1]);

DEFLABEL (label_23)
  (Rsp [0]) = (Wrd6.Obj);
  goto loop_9;

DEFLABEL (label_24)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_14]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_2]), 1);

DEFLABEL (label_15)
  (Wrd6.Obj) = Rvl;
  goto label_23;

DEFLABEL (label_26)
  (Wrd18.Obj) = (current_block [OBJECT_17_1]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_11]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd25.Obj) = (Rsp [4]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 1))
    goto label_28;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [1]);
  (* (--Rsp)) = (Wrd24.Obj);

DEFLABEL (label_27)
  (Wrd31.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd31.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_13]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_17_11);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_15]));

DEFLABEL (label_28)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_12]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_2]), 1);

DEFLABEL (label_16)
  (* (--Rsp)) = Rvl;
  goto label_27;

DEFLABEL (label_30)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_9]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_0]), 1);

DEFLABEL (label_14)
  (* (--Rsp)) = Rvl;
  goto label_29;

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_17_7);
  (Wrd5.Obj) = Rvl;
  goto label_25;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_18_4 3
#define LABEL_18_5 5
#define LABEL_18_7 7
#define LABEL_18_6 9
#define LABEL_18_8 11
#define ENVIRONMENT_LABEL_18_3 16
#define DEBUGGING_LABEL_18_2 15
#define OBJECT_18_2 14
#define OBJECT_18_1 13
#define OBJECT_18_0 12
#define FREE_REFERENCES_LABEL_18_0 12
#define NUMBER_OF_LINKER_SECTIONS_18_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_18 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd15;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd23;
  machine_word Wrd30;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd22;
  machine_word Wrd17;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd5;
  machine_word Wrd7;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_18_4);
      goto list_difference_7;

    case 1:
      current_block = (Rpc - LABEL_18_5);
      goto loop_5;

    case 2:
      current_block = (Rpc - LABEL_18_7);
      goto label_9;

    case 3:
      current_block = (Rpc - LABEL_18_6);
      goto continuation_4;

    case 4:
      current_block = (Rpc - LABEL_18_8);
      goto label_10;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (list_difference_12)
DEFLABEL (list_difference_7)
  INTERRUPT_CHECK (26, LABEL_18_4);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd7.Obj);
  Rdl = (& (Rsp [4]));
  goto loop_5;

DEFLABEL (loop_13)
DEFLABEL (loop_5)
  DLINK_INTERRUPT_CHECK (25, LABEL_18_5);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [1]);
  if (! ((Wrd5.Obj) == (Wrd8.Obj)))
    goto label_14;
  Rvl = (current_block [OBJECT_18_0]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_14)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_6]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_18;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [1]);
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_17)
  Rdl = (& (Rsp [2]));
  goto loop_5;

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_18_6);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_16;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [0]);

DEFLABEL (label_15)
  (Wrd20.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd20.Obj);
  (Wrd22.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd22.pObj)));
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_16)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_8]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_18_2]), 1);

DEFLABEL (label_10)
  (Wrd12.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd7.Obj) = Rvl;
  goto label_15;

DEFLABEL (label_18)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_7]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_18_1]), 1);

DEFLABEL (label_9)
  (Wrd23.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd23.Obj));
  (* (--Rsp)) = Rvl;
  goto label_17;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_19_4 3
#define LABEL_19_7 5
#define LABEL_19_5 7
#define LABEL_19_8 9
#define LABEL_19_9 11
#define LABEL_19_10 13
#define LABEL_19_11 15
#define LABEL_19_13 17
#define LABEL_19_14 19
#define LABEL_19_15 21
#define LABEL_19_18 23
#define LABEL_19_16 25
#define ENVIRONMENT_LABEL_19_3 46
#define DEBUGGING_LABEL_19_2 45
#define OBJECT_19_8 44
#define OBJECT_19_7 43
#define OBJECT_19_6 42
#define OBJECT_19_5 41
#define OBJECT_19_4 40
#define OBJECT_19_3 39
#define OBJECT_19_2 38
#define OBJECT_19_1 37
#define OBJECT_19_0 36
#define EXECUTE_CACHE_19_17 27
#define EXECUTE_CACHE_19_12 29
#define EXECUTE_CACHE_19_6 31
#define FREE_REFERENCE_19_1 34
#define FREE_REFERENCE_19_0 35
#define FREE_REFERENCES_LABEL_19_0 26
#define NUMBER_OF_LINKER_SECTIONS_19_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_19 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd27;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd13;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd44;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd30;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd51;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd52;
  machine_word Wrd110;
  machine_word Wrd106;
  machine_word Wrd105;
  machine_word Wrd102;
  machine_word Wrd101;
  machine_word Wrd100;
  machine_word Wrd104;
  machine_word Wrd103;
  machine_word Wrd91;
  machine_word Wrd93;
  machine_word Wrd94;
  machine_word Wrd90;
  machine_word Wrd87;
  machine_word Wrd86;
  machine_word Wrd75;
  machine_word Wrd83;
  machine_word Wrd82;
  machine_word Wrd81;
  machine_word Wrd85;
  machine_word Wrd65;
  machine_word Wrd67;
  machine_word Wrd69;
  machine_word Wrd68;
  machine_word Wrd74;
  machine_word Wrd73;
  machine_word Wrd72;
  machine_word Wrd59;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd60;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_19_4);
      goto package_add_childB_14;

    case 1:
      current_block = (Rpc - LABEL_19_7);
      goto continuation_10;

    case 2:
      current_block = (Rpc - LABEL_19_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_19_8);
      goto label_19;

    case 4:
      current_block = (Rpc - LABEL_19_9);
      goto label_20;

    case 5:
      current_block = (Rpc - LABEL_19_10);
      goto label_21;

    case 6:
      current_block = (Rpc - LABEL_19_11);
      goto label_18;

    case 7:
      current_block = (Rpc - LABEL_19_13);
      goto label_17;

    case 8:
      current_block = (Rpc - LABEL_19_14);
      goto label_16;

    case 9:
      current_block = (Rpc - LABEL_19_15);
      goto lambda_3;

    case 10:
      current_block = (Rpc - LABEL_19_18);
      goto continuation_2;

    case 11:
      current_block = (Rpc - LABEL_19_16);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (package_add_childB_23)
DEFLABEL (package_add_childB_14)
  INTERRUPT_CHECK (26, LABEL_19_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_19_5);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_34;
  (Wrd7.Obj) = (Rsp [4]);
  if ((Wrd7.Obj) == (current_block [OBJECT_19_4]))
    goto label_31;
  if (! ((Wrd7.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_29;

DEFLABEL (label_30)
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_7]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd48.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd49.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd49.Obj);
  (Wrd50.Obj) = (current_block [OBJECT_19_5]);
  (* (--Rsp)) = (Wrd50.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_12]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_19_7);

DEFLABEL (label_29)
  (Wrd37.Obj) = (Rsp [0]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd38.uLng) == 62))
    goto label_28;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [0]);
  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd35.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd36.Lng))))
    goto label_28;
  (Wrd30.Obj) = (Rsp [3]);
  ((Wrd34.pObj) [5]) = (Wrd30.Obj);

DEFLABEL (label_27)
  (Wrd20.Obj) = (Rsp [0]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 62))
    goto label_26;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd19.Lng))))
    goto label_26;
  (Wrd13.Obj) = (current_block [OBJECT_19_0]);
  ((Wrd17.pObj) [3]) = (Wrd13.Obj);

DEFLABEL (label_25)
  goto lambda_3;

DEFLABEL (label_26)
  (Wrd22.Obj) = (Rsp [0]);
  (Wrd23.Obj) = (current_block [OBJECT_19_1]);
  (Wrd24.Obj) = (current_block [OBJECT_19_0]);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_14]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_3]), 3);

DEFLABEL (label_16)
  goto label_25;

DEFLABEL (label_28)
  (Wrd39.Obj) = (Rsp [0]);
  (Wrd40.Obj) = (current_block [OBJECT_19_6]);
  (Wrd41.Obj) = (Rsp [3]);
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_13]))));
  (* (--Rsp)) = (Wrd44.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_3]), 3);

DEFLABEL (label_17)
  goto label_27;

DEFLABEL (label_31)
  (Wrd52.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_19_1]));
  (Wrd55.Obj) = ((Wrd52.pObj) [0]);
  (Wrd56.uLng) = (OBJECT_TYPE (Wrd55.Obj));
  if ((Wrd56.uLng) == 50)
    goto label_33;
  Wrd51 = Wrd55;

DEFLABEL (label_32)
  if ((Wrd51.Obj) == ((SCHEME_OBJECT) 0))
    goto label_30;
  goto label_29;

DEFLABEL (label_33)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_19_11])), (Wrd52.pObj));

DEFLABEL (label_18)
  (Wrd51.Obj) = Rvl;
  goto label_32;

DEFLABEL (label_34)
  (Wrd60.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_19_0]));
  (Wrd63.Obj) = ((Wrd60.pObj) [0]);
  (Wrd64.uLng) = (OBJECT_TYPE (Wrd63.Obj));
  if ((Wrd64.uLng) == 50)
    goto label_39;
  Wrd59 = Wrd63;

DEFLABEL (label_38)
  (Wrd72.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd73.Obj) = (Rsp [1]);
  (Wrd74.Obj) = (current_block [OBJECT_19_0]);
  (* (Rhp++)) = (Wrd72.Obj);
  (* (Rhp++)) = (Wrd59.Obj);
  (* (Rhp++)) = (Wrd73.Obj);
  (* (Rhp++)) = (Wrd74.Obj);
  (Wrd68.Obj) = (Rsp [2]);
  (Wrd69.Obj) = (Rsp [3]);
  (* (Rhp++)) = (Wrd68.Obj);
  (* (Rhp++)) = (Wrd69.Obj);
  (Wrd67.pObj) = (& (Rhp [-6]));
  (Wrd65.Obj) = (MAKE_POINTER_OBJECT (62, (Wrd67.pObj)));
  (Rsp [0]) = (Wrd65.Obj);
  (Wrd85.uLng) = (OBJECT_TYPE (Wrd73.Obj));
  if (! ((Wrd85.uLng) == 62))
    goto label_37;
  (Wrd81.pObj) = (OBJECT_ADDRESS (Wrd73.Obj));
  (Wrd82.Obj) = ((Wrd81.pObj) [0]);
  (Wrd83.Lng) = (FIXNUM_TO_LONG (Wrd82.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd83.Lng))))
    goto label_37;
  (Wrd75.Obj) = ((Wrd81.pObj) [3]);

DEFLABEL (label_36)
  (Wrd94.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd94.Obj);
  (* (Rhp++)) = (Wrd75.Obj);
  (Wrd93.pObj) = (& (Rhp [-2]));
  (Wrd91.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd93.pObj)));
  (Wrd103.Obj) = (Rsp [1]);
  (Wrd104.uLng) = (OBJECT_TYPE (Wrd103.Obj));
  if (! ((Wrd104.uLng) == 62))
    goto label_35;
  (Wrd100.pObj) = (OBJECT_ADDRESS (Wrd103.Obj));
  (Wrd101.Obj) = ((Wrd100.pObj) [0]);
  (Wrd102.Lng) = (FIXNUM_TO_LONG (Wrd101.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd102.Lng))))
    goto label_35;
  ((Wrd100.pObj) [3]) = (Wrd91.Obj);
  goto label_25;

DEFLABEL (label_35)
  (Wrd105.Obj) = (Rsp [1]);
  (Wrd106.Obj) = (current_block [OBJECT_19_1]);
  (Wrd110.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_10]))));
  (* (--Rsp)) = (Wrd110.Obj);
  (* (--Rsp)) = (Wrd91.Obj);
  (* (--Rsp)) = (Wrd106.Obj);
  (* (--Rsp)) = (Wrd105.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_3]), 3);

DEFLABEL (label_21)
  goto label_25;

DEFLABEL (label_37)
  (Wrd86.Obj) = (Rsp [1]);
  (Wrd87.Obj) = (current_block [OBJECT_19_1]);
  (Wrd90.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_9]))));
  (* (--Rsp)) = (Wrd90.Obj);
  (* (--Rsp)) = (Wrd87.Obj);
  (* (--Rsp)) = (Wrd86.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_2]), 2);

DEFLABEL (label_20)
  (Wrd75.Obj) = Rvl;
  goto label_36;

DEFLABEL (label_39)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_19_8])), (Wrd60.pObj));

DEFLABEL (label_19)
  (Wrd59.Obj) = Rvl;
  goto label_38;

DEFLABEL (lambda_24)
DEFLABEL (lambda_3)
  INTERRUPT_CHECK (26, LABEL_19_15);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_17]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_19_16);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_41;

DEFLABEL (label_40)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_41)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_18]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_19_7]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_8]), 3);

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_19_18);
  goto label_40;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_20_4 3
#define LABEL_20_5 5
#define LABEL_20_6 7
#define LABEL_20_7 9
#define ENVIRONMENT_LABEL_20_3 19
#define DEBUGGING_LABEL_20_2 18
#define OBJECT_20_2 17
#define OBJECT_20_1 16
#define OBJECT_20_0 15
#define FREE_REFERENCE_20_1 11
#define FREE_REFERENCE_20_0 12
#define FREE_ASSIGNMENT_20_0 14
#define FREE_REFERENCES_LABEL_20_0 10
#define NUMBER_OF_LINKER_SECTIONS_20_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_20 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd40;
  machine_word Wrd34;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd35;
  machine_word Wrd28;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd22;
  machine_word Wrd12;
  machine_word Wrd14;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd17;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_20_4);
      goto initialize_packageB_1;

    case 1:
      current_block = (Rpc - LABEL_20_5);
      goto label_3;

    case 2:
      current_block = (Rpc - LABEL_20_6);
      goto label_4;

    case 3:
      current_block = (Rpc - LABEL_20_7);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (initialize_packageB_7)
DEFLABEL (initialize_packageB_1)
  INTERRUPT_CHECK (26, LABEL_20_4);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_20_0]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_14;
  Wrd6 = Wrd10;

DEFLABEL (label_13)
  (Wrd17.Obj) = ((SCHEME_OBJECT) 0);
  (Wrd19.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd21.Obj) = (current_block [OBJECT_20_0]);
  (* (Rhp++)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (* (Rhp++)) = (Wrd21.Obj);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (Wrd14.pObj) = (& (Rhp [-6]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (62, (Wrd14.pObj)));
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_20_0]));
  (Wrd30.Obj) = ((Wrd22.pObj) [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd31.uLng) == 50)
    goto label_12;

DEFLABEL (label_11)
  ((Wrd22.pObj) [0]) = (Wrd12.Obj);

DEFLABEL (label_10)
  (Wrd35.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_20_1]));
  (Wrd38.Obj) = ((Wrd35.pObj) [0]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if ((Wrd39.uLng) == 50)
    goto label_9;
  Wrd34 = Wrd38;

DEFLABEL (label_8)
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd40.Obj) = (current_block [OBJECT_20_1]);
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  INVOKE_PRIMITIVE ((current_block [OBJECT_20_2]), 3);

DEFLABEL (label_9)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_20_7])), (Wrd35.pObj));

DEFLABEL (label_5)
  (Wrd34.Obj) = Rvl;
  goto label_8;

DEFLABEL (label_12)
  (Wrd28.Obj) = (MAKE_OBJECT (50, (Wrd17.uLng)));
  if ((Wrd30.Obj) == (Wrd28.Obj))
    goto label_11;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_20_6])), (Wrd22.pObj), (Wrd12.Obj));

DEFLABEL (label_4)
  goto label_10;

DEFLABEL (label_14)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_20_5])), (Wrd7.pObj));

DEFLABEL (label_3)
  (Wrd6.Obj) = Rvl;
  goto label_13;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_21_4 3
#define LABEL_21_6 5
#define LABEL_21_5 7
#define LABEL_21_7 9
#define LABEL_21_10 11
#define LABEL_21_12 13
#define LABEL_21_14 15
#define TAG_21_15 6
#define LABEL_21_17 17
#define LABEL_21_21 19
#define LABEL_21_19 21
#define LABEL_21_23 23
#define LABEL_21_25 25
#define TAG_21_26 11
#define LABEL_21_27 27
#define LABEL_21_29 29
#define LABEL_21_31 31
#define LABEL_21_34 33
#define LABEL_21_35 35
#define ENVIRONMENT_LABEL_21_3 81
#define DEBUGGING_LABEL_21_2 80
#define OBJECT_21_6 79
#define OBJECT_21_5 78
#define OBJECT_21_4 77
#define OBJECT_21_3 76
#define OBJECT_21_2 75
#define OBJECT_21_1 74
#define OBJECT_21_0 73
#define EXECUTE_CACHE_21_39 37
#define EXECUTE_CACHE_21_38 39
#define EXECUTE_CACHE_21_37 41
#define EXECUTE_CACHE_21_36 43
#define EXECUTE_CACHE_21_33 45
#define EXECUTE_CACHE_21_32 47
#define EXECUTE_CACHE_21_30 49
#define EXECUTE_CACHE_21_28 51
#define EXECUTE_CACHE_21_24 53
#define EXECUTE_CACHE_21_22 55
#define EXECUTE_CACHE_21_20 57
#define EXECUTE_CACHE_21_18 59
#define EXECUTE_CACHE_21_16 61
#define EXECUTE_CACHE_21_13 63
#define EXECUTE_CACHE_21_11 65
#define EXECUTE_CACHE_21_9 67
#define EXECUTE_CACHE_21_8 69
#define FREE_REFERENCE_21_0 72
#define FREE_REFERENCES_LABEL_21_0 36
#define NUMBER_OF_LINKER_SECTIONS_21_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_21 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd5;
  machine_word Wrd15;
  machine_word Wrd21;
  machine_word Wrd23;
  machine_word Wrd24;
  machine_word Wrd18;
  machine_word Wrd19;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd10;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_21_4);
      goto load_package_set_24;

    case 1:
      current_block = (Rpc - LABEL_21_6);
      goto label_26;

    case 2:
      current_block = (Rpc - LABEL_21_5);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_21_7);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_21_10);
      goto continuation_2;

    case 5:
      current_block = (Rpc - LABEL_21_12);
      goto continuation_3;

    case 6:
      current_block = (Rpc - LABEL_21_14);
      goto lambda_29;

    case 7:
      current_block = (Rpc - LABEL_21_17);
      goto continuation_8;

    case 8:
      current_block = (Rpc - LABEL_21_21);
      goto continuation_10;

    case 9:
      current_block = (Rpc - LABEL_21_19);
      goto continuation_9;

    case 10:
      current_block = (Rpc - LABEL_21_23);
      goto continuation_11;

    case 11:
      current_block = (Rpc - LABEL_21_25);
      goto lambda_30;

    case 12:
      current_block = (Rpc - LABEL_21_27);
      goto continuation_12;

    case 13:
      current_block = (Rpc - LABEL_21_29);
      goto continuation_13;

    case 14:
      current_block = (Rpc - LABEL_21_31);
      goto continuation_18;

    case 15:
      current_block = (Rpc - LABEL_21_34);
      goto continuation_15;

    case 16:
      current_block = (Rpc - LABEL_21_35);
      goto continuation_14;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (load_package_set_28)
DEFLABEL (load_package_set_24)
  INTERRUPT_CHECK (26, LABEL_21_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_21_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_35;
  Wrd8 = Wrd12;

DEFLABEL (label_34)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_7]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_21_7);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_21_10);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_13]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_21_12);
  (Rsp [1]) = Rvl;
  (Wrd9.Obj) = (current_block [OBJECT_21_0]);
  (Wrd10.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Wrd11.Obj) = (Rsp [5]);
  if ((Wrd11.Obj) == (current_block [OBJECT_21_1]))
    goto label_32;
  Wrd13 = Wrd11;
  goto label_31;

DEFLABEL (label_32)
  (Wrd13.Obj) = (current_block [OBJECT_21_2]);

DEFLABEL (label_31)
DEFLABEL (label_33)
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  (Rsp [2]) = (Wrd14.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd19.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_21_15);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_21_14])));
  Rhp += 3;
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd19.pObj)));
  Wrd24 = Wrd19;
  ((Wrd24.pObj) [2]) = (Wrd14.Obj);
  (Wrd23.Obj) = (Rsp [1]);
  ((Wrd24.pObj) [3]) = (Wrd23.Obj);
  (Wrd21.Obj) = (Rsp [0]);
  ((Wrd24.pObj) [4]) = (Wrd21.Obj);
  (Rsp [2]) = (Wrd18.Obj);
  (Rsp [1]) = (Wrd21.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_16]));

DEFLABEL (label_35)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_21_6])), (Wrd9.pObj));

DEFLABEL (label_26)
  (Wrd8.Obj) = Rvl;
  goto label_34;

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_21_5);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_9]));

DEFLABEL (lambda_29)
  CLOSURE_HEADER (LABEL_21_14);

DEFLABEL (lambda_21)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_18]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_21_17);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_19]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_20]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_21_19);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_38;

DEFLABEL (label_37)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_23]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_24]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_21_23);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_21_26);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_21_25])));
  Rhp += 1;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd7 = Wrd6;
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [4]);
  ((Wrd7.pObj) [2]) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_27]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd16.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (current_block [OBJECT_21_4]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_28]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_21_27);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_36;
  (Wrd7.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd7.Obj);
  (Rsp [1]) = Rvl;
  (Wrd10.Obj) = (Rsp [3]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [2]);
  (Rsp [3]) = (Wrd9.Obj);
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_36)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_31]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [5]);
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [2]);
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_32]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_21_31);
  (Wrd5.Obj) = (Rsp [2]);
  (Rsp [3]) = (Wrd5.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_37]));

DEFLABEL (label_38)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_21]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [3]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (current_block [OBJECT_21_3]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_22]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_21_21);
  goto label_37;

DEFLABEL (lambda_30)
  CLOSURE_HEADER (LABEL_21_25);

DEFLABEL (lambda_17)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_29]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_30]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_21_29);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_39;
  (Wrd14.Obj) = (Rsp [2]);
  (Rsp [0]) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (Rsp [1]) = (Wrd15.Obj);
  (Wrd16.Obj) = (current_block [OBJECT_21_5]);
  (Rsp [2]) = (Wrd16.Obj);
  (Wrd17.Obj) = (current_block [OBJECT_21_6]);
  (Rsp [3]) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_33]));

DEFLABEL (label_39)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_34]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21_35]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_36]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_21_35);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_39]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_21_34);
  (Wrd5.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd5.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_38]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_22_4 3
#define LABEL_22_7 5
#define LABEL_22_5 7
#define LABEL_22_6 9
#define LABEL_22_8 11
#define ENVIRONMENT_LABEL_22_3 34
#define DEBUGGING_LABEL_22_2 33
#define OBJECT_22_9 32
#define OBJECT_22_8 31
#define OBJECT_22_7 30
#define OBJECT_22_6 29
#define OBJECT_22_5 28
#define OBJECT_22_4 27
#define OBJECT_22_3 26
#define OBJECT_22_2 25
#define OBJECT_22_1 24
#define OBJECT_22_0 23
#define EXECUTE_CACHE_22_12 13
#define EXECUTE_CACHE_22_11 15
#define EXECUTE_CACHE_22_10 17
#define EXECUTE_CACHE_22_9 19
#define FREE_REFERENCE_22_0 22
#define FREE_REFERENCES_LABEL_22_0 12
#define NUMBER_OF_LINKER_SECTIONS_22_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_22 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd28;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd14;
  machine_word Wrd33;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_22_4);
      goto package_set_pathname_10;

    case 1:
      current_block = (Rpc - LABEL_22_7);
      goto label_12;

    case 2:
      current_block = (Rpc - LABEL_22_5);
      goto continuation_9;

    case 3:
      current_block = (Rpc - LABEL_22_6);
      goto continuation_8;

    case 4:
      current_block = (Rpc - LABEL_22_8);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (package_set_pathname_14)
DEFLABEL (package_set_pathname_10)
  INTERRUPT_CHECK (26, LABEL_22_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  if ((Wrd11.Obj) == (current_block [OBJECT_22_0]))
    goto label_21;
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_20)
  (Wrd14.Obj) = (Rsp [0]);
  if ((Wrd14.Obj) == (current_block [OBJECT_22_1]))
    goto label_19;
  if ((Wrd14.Obj) == (current_block [OBJECT_22_3]))
    goto label_18;
  if ((Wrd14.Obj) == (current_block [OBJECT_22_5]))
    goto label_16;
  (Wrd21.Obj) = (current_block [OBJECT_22_7]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd21.Obj);
  goto label_15;

DEFLABEL (label_16)
  (Wrd28.Obj) = (current_block [OBJECT_22_6]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd28.Obj);

DEFLABEL (label_15)
DEFLABEL (label_17)
  (Wrd22.Obj) = (current_block [OBJECT_22_8]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_8]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_9]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_22_8);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_12]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_22_6);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_11]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_22_5);
  (Rsp [0]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_22_9]);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_10]));

DEFLABEL (label_18)
  (Wrd30.Obj) = (current_block [OBJECT_22_4]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd30.Obj);
  goto label_17;

DEFLABEL (label_19)
  (Wrd32.Obj) = (current_block [OBJECT_22_2]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd32.Obj);
  goto label_17;

DEFLABEL (label_21)
  (Wrd34.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_22_0]));
  (Wrd37.Obj) = ((Wrd34.pObj) [0]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if ((Wrd38.uLng) == 50)
    goto label_23;
  Wrd33 = Wrd37;

DEFLABEL (label_22)
  (* (--Rsp)) = (Wrd33.Obj);
  goto label_20;

DEFLABEL (label_23)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_22_7])), (Wrd34.pObj));

DEFLABEL (label_12)
  (Wrd33.Obj) = Rvl;
  goto label_22;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_23_4 3
#define LABEL_23_5 5
#define LABEL_23_9 7
#define LABEL_23_7 9
#define LABEL_23_10 11
#define LABEL_23_11 13
#define TAG_23_12 5
#define LABEL_23_14 15
#define LABEL_23_16 17
#define ENVIRONMENT_LABEL_23_3 35
#define DEBUGGING_LABEL_23_2 34
#define OBJECT_23_0 33
#define EXECUTE_CACHE_23_18 19
#define EXECUTE_CACHE_23_17 21
#define EXECUTE_CACHE_23_15 23
#define EXECUTE_CACHE_23_13 25
#define EXECUTE_CACHE_23_8 27
#define EXECUTE_CACHE_23_6 29
#define FREE_REFERENCE_23_0 32
#define FREE_REFERENCES_LABEL_23_0 18
#define NUMBER_OF_LINKER_SECTIONS_23_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_23 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd20;
  machine_word Wrd18;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_23_4);
      goto filename__compiled_object_8;

    case 1:
      current_block = (Rpc - LABEL_23_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_23_9);
      goto continuation_5;

    case 3:
      current_block = (Rpc - LABEL_23_7);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_23_10);
      goto label_10;

    case 5:
      current_block = (Rpc - LABEL_23_11);
      goto lambda_13;

    case 6:
      current_block = (Rpc - LABEL_23_14);
      goto continuation_2;

    case 7:
      current_block = (Rpc - LABEL_23_16);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (filename__compiled_object_12)
DEFLABEL (filename__compiled_object_8)
  INTERRUPT_CHECK (26, LABEL_23_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_23_5);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_7]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_23_7);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_15;

DEFLABEL (label_14)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_15)
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_23_0]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_17;
  Wrd7 = Wrd11;

DEFLABEL (label_16)
  if (! ((Wrd7.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_14;
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_9]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd20.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_23_12);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_23_11])));
  Rhp += 1;
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd20.pObj)));
  Wrd21 = Wrd20;
  (Wrd22.Obj) = (Rsp [2]);
  ((Wrd21.pObj) [2]) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_13]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_23_9);
  goto label_14;

DEFLABEL (label_17)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_23_10])), (Wrd8.pObj));

DEFLABEL (label_10)
  (Wrd7.Obj) = Rvl;
  goto label_16;

DEFLABEL (lambda_13)
  CLOSURE_HEADER (LABEL_23_11);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_23_0]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_15]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_23_14);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_17]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_23_16);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_18]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_24_4 3
#define ENVIRONMENT_LABEL_24_3 5
#define DEBUGGING_LABEL_24_2 4
#define FREE_REFERENCES_LABEL_24_0 4
#define NUMBER_OF_LINKER_SECTIONS_24_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_24 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd9;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_24_4);
      goto make_package_file_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_package_file_3)
DEFLABEL (make_package_file_0)
  INTERRUPT_CHECK (26, LABEL_24_4);
  (Wrd12.Obj) = (MAKE_OBJECT (0, 4));
  (Wrd13.Obj) = (Rsp [0]);
  (Wrd14.Obj) = (Rsp [1]);
  (Wrd15.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd15.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-5]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd7.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_25_4 3
#define ENVIRONMENT_LABEL_25_3 7
#define DEBUGGING_LABEL_25_2 6
#define OBJECT_25_1 5
#define OBJECT_25_0 4
#define FREE_REFERENCES_LABEL_25_0 4
#define NUMBER_OF_LINKER_SECTIONS_25_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_25 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_25_4);
      goto package_file_tag_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (package_file_tag_3)
DEFLABEL (package_file_tag_0)
  INTERRUPT_CHECK (26, LABEL_25_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_25_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_25_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_26_4 3
#define ENVIRONMENT_LABEL_26_3 7
#define DEBUGGING_LABEL_26_2 6
#define OBJECT_26_1 5
#define OBJECT_26_0 4
#define FREE_REFERENCES_LABEL_26_0 4
#define NUMBER_OF_LINKER_SECTIONS_26_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_26 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_26_4);
      goto package_file_version_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (package_file_version_3)
DEFLABEL (package_file_version_0)
  INTERRUPT_CHECK (26, LABEL_26_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_26_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_26_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_27_4 3
#define ENVIRONMENT_LABEL_27_3 7
#define DEBUGGING_LABEL_27_2 6
#define OBJECT_27_1 5
#define OBJECT_27_0 4
#define FREE_REFERENCES_LABEL_27_0 4
#define NUMBER_OF_LINKER_SECTIONS_27_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_27 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_27_4);
      goto package_file_descriptions_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (package_file_descriptions_3)
DEFLABEL (package_file_descriptions_0)
  INTERRUPT_CHECK (26, LABEL_27_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_27_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_27_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_28_4 3
#define ENVIRONMENT_LABEL_28_3 7
#define DEBUGGING_LABEL_28_2 6
#define OBJECT_28_1 5
#define OBJECT_28_0 4
#define FREE_REFERENCES_LABEL_28_0 4
#define NUMBER_OF_LINKER_SECTIONS_28_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_28 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_28_4);
      goto package_file_loads_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (package_file_loads_3)
DEFLABEL (package_file_loads_0)
  INTERRUPT_CHECK (26, LABEL_28_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_28_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_28_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [4]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_29_4 3
#define ENVIRONMENT_LABEL_29_3 5
#define DEBUGGING_LABEL_29_2 4
#define FREE_REFERENCES_LABEL_29_0 4
#define NUMBER_OF_LINKER_SECTIONS_29_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_29 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_29_4);
      goto make_package_description_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_package_description_3)
DEFLABEL (make_package_description_0)
  INTERRUPT_CHECK (26, LABEL_29_4);
  (Wrd14.Obj) = (MAKE_OBJECT (0, 6));
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (Wrd10.Obj) = (Rsp [4]);
  (Wrd11.Obj) = (Rsp [5]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd7.pObj) = (& (Rhp [-7]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd7.pObj)));
  Rsp = (& (Rsp [6]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_30_4 3
#define ENVIRONMENT_LABEL_30_3 7
#define DEBUGGING_LABEL_30_2 6
#define OBJECT_30_1 5
#define OBJECT_30_0 4
#define FREE_REFERENCES_LABEL_30_0 4
#define NUMBER_OF_LINKER_SECTIONS_30_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_30 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_30_4);
      goto package_description_name_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (package_description_name_3)
DEFLABEL (package_description_name_0)
  INTERRUPT_CHECK (26, LABEL_30_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_30_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_30_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_31_4 3
#define ENVIRONMENT_LABEL_31_3 7
#define DEBUGGING_LABEL_31_2 6
#define OBJECT_31_1 5
#define OBJECT_31_0 4
#define FREE_REFERENCES_LABEL_31_0 4
#define NUMBER_OF_LINKER_SECTIONS_31_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_31 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_31_4);
      goto package_description_ancestors_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (package_description_ancestors_3)
DEFLABEL (package_description_ancestors_0)
  INTERRUPT_CHECK (26, LABEL_31_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_31_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_31_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_32_4 3
#define ENVIRONMENT_LABEL_32_3 7
#define DEBUGGING_LABEL_32_2 6
#define OBJECT_32_1 5
#define OBJECT_32_0 4
#define FREE_REFERENCES_LABEL_32_0 4
#define NUMBER_OF_LINKER_SECTIONS_32_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_32 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_32_4);
      goto package_description_internal_names_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (package_description_internal_names_3)
DEFLABEL (package_description_internal_names_0)
  INTERRUPT_CHECK (26, LABEL_32_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_32_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_32_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_33_4 3
#define ENVIRONMENT_LABEL_33_3 7
#define DEBUGGING_LABEL_33_2 6
#define OBJECT_33_1 5
#define OBJECT_33_0 4
#define FREE_REFERENCES_LABEL_33_0 4
#define NUMBER_OF_LINKER_SECTIONS_33_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_33 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_33_4);
      goto package_description_exports_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (package_description_exports_3)
DEFLABEL (package_description_exports_0)
  INTERRUPT_CHECK (26, LABEL_33_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_33_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [4]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_34_4 3
#define ENVIRONMENT_LABEL_34_3 7
#define DEBUGGING_LABEL_34_2 6
#define OBJECT_34_1 5
#define OBJECT_34_0 4
#define FREE_REFERENCES_LABEL_34_0 4
#define NUMBER_OF_LINKER_SECTIONS_34_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_34 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_34_4);
      goto package_description_imports_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (package_description_imports_3)
DEFLABEL (package_description_imports_0)
  INTERRUPT_CHECK (26, LABEL_34_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_34_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [5]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_35_4 3
#define ENVIRONMENT_LABEL_35_3 7
#define DEBUGGING_LABEL_35_2 6
#define OBJECT_35_1 5
#define OBJECT_35_0 4
#define FREE_REFERENCES_LABEL_35_0 4
#define NUMBER_OF_LINKER_SECTIONS_35_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_35 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_35_4);
      goto package_description_extensionP_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (package_description_extensionP_3)
DEFLABEL (package_description_extensionP_0)
  INTERRUPT_CHECK (26, LABEL_35_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_35_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [6]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_36_4 3
#define ENVIRONMENT_LABEL_36_3 5
#define DEBUGGING_LABEL_36_2 4
#define FREE_REFERENCES_LABEL_36_0 4
#define NUMBER_OF_LINKER_SECTIONS_36_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_36 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd9;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_36_4);
      goto make_load_description_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_load_description_3)
DEFLABEL (make_load_description_0)
  INTERRUPT_CHECK (26, LABEL_36_4);
  (Wrd12.Obj) = (MAKE_OBJECT (0, 4));
  (Wrd13.Obj) = (Rsp [0]);
  (Wrd14.Obj) = (Rsp [1]);
  (Wrd15.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd15.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-5]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd7.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_37_4 3
#define ENVIRONMENT_LABEL_37_3 7
#define DEBUGGING_LABEL_37_2 6
#define OBJECT_37_1 5
#define OBJECT_37_0 4
#define FREE_REFERENCES_LABEL_37_0 4
#define NUMBER_OF_LINKER_SECTIONS_37_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_37 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_37_4);
      goto load_description_name_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (load_description_name_3)
DEFLABEL (load_description_name_0)
  INTERRUPT_CHECK (26, LABEL_37_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_37_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_37_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_38_4 3
#define ENVIRONMENT_LABEL_38_3 7
#define DEBUGGING_LABEL_38_2 6
#define OBJECT_38_1 5
#define OBJECT_38_0 4
#define FREE_REFERENCES_LABEL_38_0 4
#define NUMBER_OF_LINKER_SECTIONS_38_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_38 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_38_4);
      goto load_description_file_cases_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (load_description_file_cases_3)
DEFLABEL (load_description_file_cases_0)
  INTERRUPT_CHECK (26, LABEL_38_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_38_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_39_4 3
#define ENVIRONMENT_LABEL_39_3 7
#define DEBUGGING_LABEL_39_2 6
#define OBJECT_39_1 5
#define OBJECT_39_0 4
#define FREE_REFERENCES_LABEL_39_0 4
#define NUMBER_OF_LINKER_SECTIONS_39_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_39 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_39_4);
      goto load_description_initializations_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (load_description_initializations_3)
DEFLABEL (load_description_initializations_0)
  INTERRUPT_CHECK (26, LABEL_39_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_39_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_39_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_40_4 3
#define ENVIRONMENT_LABEL_40_3 7
#define DEBUGGING_LABEL_40_2 6
#define OBJECT_40_1 5
#define OBJECT_40_0 4
#define FREE_REFERENCES_LABEL_40_0 4
#define NUMBER_OF_LINKER_SECTIONS_40_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_40 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_40_4);
      goto load_description_finalizations_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (load_description_finalizations_3)
DEFLABEL (load_description_finalizations_0)
  INTERRUPT_CHECK (26, LABEL_40_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_40_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_40_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [4]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_41_4 3
#define LABEL_41_5 5
#define LABEL_41_6 7
#define LABEL_41_7 9
#define LABEL_41_8 11
#define LABEL_41_10 13
#define LABEL_41_11 15
#define LABEL_41_9 17
#define LABEL_41_13 19
#define LABEL_41_14 21
#define ENVIRONMENT_LABEL_41_3 37
#define DEBUGGING_LABEL_41_2 36
#define OBJECT_41_7 35
#define OBJECT_41_6 34
#define OBJECT_41_5 33
#define OBJECT_41_4 32
#define OBJECT_41_3 31
#define OBJECT_41_2 30
#define OBJECT_41_1 29
#define OBJECT_41_0 28
#define EXECUTE_CACHE_41_12 23
#define FREE_REFERENCE_41_1 26
#define FREE_REFERENCE_41_0 27
#define FREE_REFERENCES_LABEL_41_0 22
#define NUMBER_OF_LINKER_SECTIONS_41_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_41 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd24;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd95;
  machine_word Wrd92;
  machine_word Wrd91;
  machine_word Wrd82;
  machine_word Wrd88;
  machine_word Wrd87;
  machine_word Wrd86;
  machine_word Wrd90;
  machine_word Wrd89;
  machine_word Wrd74;
  machine_word Wrd79;
  machine_word Wrd78;
  machine_word Wrd75;
  machine_word Wrd73;
  machine_word Wrd69;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd54;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd53;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd38;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd21;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd19;
  machine_word Wrd9;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_41_4);
      goto package_fileP_12;

    case 1:
      current_block = (Rpc - LABEL_41_5);
      goto label_14;

    case 2:
      current_block = (Rpc - LABEL_41_6);
      goto label_15;

    case 3:
      current_block = (Rpc - LABEL_41_7);
      goto label_16;

    case 4:
      current_block = (Rpc - LABEL_41_8);
      goto label_17;

    case 5:
      current_block = (Rpc - LABEL_41_10);
      goto label_18;

    case 6:
      current_block = (Rpc - LABEL_41_11);
      goto label_19;

    case 7:
      current_block = (Rpc - LABEL_41_9);
      goto continuation_10;

    case 8:
      current_block = (Rpc - LABEL_41_13);
      goto label_20;

    case 9:
      current_block = (Rpc - LABEL_41_14);
      goto label_21;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (package_fileP_23)
DEFLABEL (package_fileP_12)
  INTERRUPT_CHECK (26, LABEL_41_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 10)
    goto label_25;

DEFLABEL (label_24)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_25)
  if (! ((Wrd6.uLng) == 10))
    goto label_42;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd9.Obj) = (MAKE_OBJECT (26, (Wrd13.uLng)));

DEFLABEL (label_41)
  if (! ((Wrd9.Obj) == (current_block [OBJECT_41_1])))
    goto label_24;
  (Wrd30.Obj) = (Rsp [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_40;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd29.Lng))))
    goto label_40;
  (Wrd21.Obj) = ((Wrd27.pObj) [1]);

DEFLABEL (label_39)
  if (! ((Wrd21.Obj) == (current_block [OBJECT_41_4])))
    goto label_24;
  (Wrd47.Obj) = (Rsp [0]);
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd47.Obj));
  if (! ((Wrd48.uLng) == 10))
    goto label_38;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  (Wrd45.Obj) = ((Wrd44.pObj) [0]);
  (Wrd46.Lng) = (FIXNUM_TO_LONG (Wrd45.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd46.Lng))))
    goto label_38;
  (Wrd38.Obj) = ((Wrd44.pObj) [2]);

DEFLABEL (label_37)
  if (! (INDEX_FIXNUM_P (Wrd38.Obj)))
    goto label_24;
  (Wrd63.Obj) = (Rsp [0]);
  (Wrd64.uLng) = (OBJECT_TYPE (Wrd63.Obj));
  if (! ((Wrd64.uLng) == 10))
    goto label_36;
  (Wrd60.pObj) = (OBJECT_ADDRESS (Wrd63.Obj));
  (Wrd61.Obj) = ((Wrd60.pObj) [0]);
  (Wrd62.Lng) = (FIXNUM_TO_LONG (Wrd61.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd62.Lng))))
    goto label_36;
  (Wrd54.Obj) = ((Wrd60.pObj) [2]);

DEFLABEL (label_35)
  if (! ((Wrd54.Obj) == (current_block [OBJECT_41_6])))
    goto label_24;
  (Wrd73.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_9]))));
  (* (--Rsp)) = (Wrd73.Obj);
  (Wrd75.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_41_0]));
  (Wrd78.Obj) = ((Wrd75.pObj) [0]);
  (Wrd79.uLng) = (OBJECT_TYPE (Wrd78.Obj));
  if ((Wrd79.uLng) == 50)
    goto label_34;
  Wrd74 = Wrd78;

DEFLABEL (label_33)
  (* (--Rsp)) = (Wrd74.Obj);
  (Wrd89.Obj) = (Rsp [2]);
  (Wrd90.uLng) = (OBJECT_TYPE (Wrd89.Obj));
  if (! ((Wrd90.uLng) == 10))
    goto label_32;
  (Wrd86.pObj) = (OBJECT_ADDRESS (Wrd89.Obj));
  (Wrd87.Obj) = ((Wrd86.pObj) [0]);
  (Wrd88.Lng) = (FIXNUM_TO_LONG (Wrd87.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd88.Lng))))
    goto label_32;
  (Wrd82.Obj) = ((Wrd86.pObj) [3]);
  (* (--Rsp)) = (Wrd82.Obj);

DEFLABEL (label_31)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_12]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_41_9);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_26;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_26)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_30;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd15.Lng))))
    goto label_30;
  (Wrd9.Obj) = ((Wrd13.pObj) [4]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_29)
  (Wrd25.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_41_1]));
  (Wrd28.Obj) = ((Wrd25.pObj) [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 50)
    goto label_28;
  Wrd24 = Wrd28;

DEFLABEL (label_27)
  (Rsp [1]) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_12]));

DEFLABEL (label_28)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_41_14])), (Wrd25.pObj));

DEFLABEL (label_21)
  (Wrd24.Obj) = Rvl;
  goto label_27;

DEFLABEL (label_30)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_41_7]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_13]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_3]), 2);

DEFLABEL (label_20)
  (* (--Rsp)) = Rvl;
  goto label_29;

DEFLABEL (label_32)
  (Wrd91.Obj) = (Rsp [2]);
  (Wrd92.Obj) = (current_block [OBJECT_41_6]);
  (Wrd95.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_11]))));
  (* (--Rsp)) = (Wrd95.Obj);
  (* (--Rsp)) = (Wrd92.Obj);
  (* (--Rsp)) = (Wrd91.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_3]), 2);

DEFLABEL (label_19)
  (* (--Rsp)) = Rvl;
  goto label_31;

DEFLABEL (label_34)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_41_10])), (Wrd75.pObj));

DEFLABEL (label_18)
  (Wrd74.Obj) = Rvl;
  goto label_33;

DEFLABEL (label_36)
  (Wrd65.Obj) = (Rsp [0]);
  (Wrd66.Obj) = (current_block [OBJECT_41_5]);
  (Wrd69.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_8]))));
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd66.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_3]), 2);

DEFLABEL (label_17)
  (Wrd54.Obj) = Rvl;
  goto label_35;

DEFLABEL (label_38)
  (Wrd49.Obj) = (Rsp [0]);
  (Wrd50.Obj) = (current_block [OBJECT_41_5]);
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_7]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_3]), 2);

DEFLABEL (label_16)
  (Wrd38.Obj) = Rvl;
  goto label_37;

DEFLABEL (label_40)
  (Wrd32.Obj) = (Rsp [0]);
  (Wrd33.Obj) = (current_block [OBJECT_41_2]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_6]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_3]), 2);

DEFLABEL (label_15)
  (Wrd21.Obj) = Rvl;
  goto label_39;

DEFLABEL (label_42)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_5]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_0]), 1);

DEFLABEL (label_14)
  (Wrd9.Obj) = Rvl;
  goto label_41;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_42_4 3
#define LABEL_42_5 5
#define LABEL_42_7 7
#define LABEL_42_6 9
#define LABEL_42_10 11
#define LABEL_42_11 13
#define LABEL_42_9 15
#define LABEL_42_14 17
#define LABEL_42_15 19
#define LABEL_42_13 21
#define LABEL_42_18 23
#define LABEL_42_19 25
#define LABEL_42_17 27
#define LABEL_42_21 29
#define LABEL_42_22 31
#define LABEL_42_20 33
#define LABEL_42_23 35
#define ENVIRONMENT_LABEL_42_3 59
#define DEBUGGING_LABEL_42_2 58
#define OBJECT_42_8 57
#define OBJECT_42_7 56
#define OBJECT_42_6 55
#define OBJECT_42_5 54
#define OBJECT_42_4 53
#define OBJECT_42_3 52
#define OBJECT_42_2 51
#define OBJECT_42_1 50
#define OBJECT_42_0 49
#define EXECUTE_CACHE_42_24 37
#define EXECUTE_CACHE_42_16 39
#define EXECUTE_CACHE_42_12 41
#define EXECUTE_CACHE_42_8 43
#define FREE_REFERENCE_42_2 46
#define FREE_REFERENCE_42_1 47
#define FREE_REFERENCE_42_0 48
#define FREE_REFERENCES_LABEL_42_0 36
#define NUMBER_OF_LINKER_SECTIONS_42_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_42 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd18;
  machine_word Wrd24;
  machine_word Wrd22;
  machine_word Wrd25;
  machine_word Wrd10;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd26;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd23;
  machine_word Wrd19;
  machine_word Wrd9;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_42_4);
      goto package_descriptionP_14;

    case 1:
      current_block = (Rpc - LABEL_42_5);
      goto label_16;

    case 2:
      current_block = (Rpc - LABEL_42_7);
      goto label_17;

    case 3:
      current_block = (Rpc - LABEL_42_6);
      goto continuation_4;

    case 4:
      current_block = (Rpc - LABEL_42_10);
      goto label_18;

    case 5:
      current_block = (Rpc - LABEL_42_11);
      goto label_19;

    case 6:
      current_block = (Rpc - LABEL_42_9);
      goto continuation_6;

    case 7:
      current_block = (Rpc - LABEL_42_14);
      goto label_20;

    case 8:
      current_block = (Rpc - LABEL_42_15);
      goto label_21;

    case 9:
      current_block = (Rpc - LABEL_42_13);
      goto continuation_8;

    case 10:
      current_block = (Rpc - LABEL_42_18);
      goto label_22;

    case 11:
      current_block = (Rpc - LABEL_42_19);
      goto label_23;

    case 12:
      current_block = (Rpc - LABEL_42_17);
      goto continuation_10;

    case 13:
      current_block = (Rpc - LABEL_42_21);
      goto label_24;

    case 14:
      current_block = (Rpc - LABEL_42_22);
      goto label_25;

    case 15:
      current_block = (Rpc - LABEL_42_20);
      goto continuation_12;

    case 16:
      current_block = (Rpc - LABEL_42_23);
      goto label_26;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (package_descriptionP_28)
DEFLABEL (package_descriptionP_14)
  INTERRUPT_CHECK (26, LABEL_42_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 10)
    goto label_30;

DEFLABEL (label_29)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_30)
  if (! ((Wrd6.uLng) == 10))
    goto label_57;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd9.Obj) = (MAKE_OBJECT (26, (Wrd13.uLng)));

DEFLABEL (label_56)
  if (! ((Wrd9.Obj) == (current_block [OBJECT_42_1])))
    goto label_29;
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_6]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd33.Obj) = (Rsp [1]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 10))
    goto label_55;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd32.Lng))))
    goto label_55;
  (Wrd26.Obj) = ((Wrd30.pObj) [1]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_54)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_8]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_42_6);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_31;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_31)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_42_0]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_53;
  Wrd10 = Wrd14;

DEFLABEL (label_52)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd25.Obj) = (Rsp [2]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 10))
    goto label_51;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [0]);
  (Wrd24.Lng) = (FIXNUM_TO_LONG (Wrd23.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd24.Lng))))
    goto label_51;
  (Wrd18.Obj) = ((Wrd22.pObj) [2]);
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_50)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_12]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_42_9);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_32;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_32)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_13]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_42_1]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_49;
  Wrd10 = Wrd14;

DEFLABEL (label_48)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd25.Obj) = (Rsp [2]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 10))
    goto label_47;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [0]);
  (Wrd24.Lng) = (FIXNUM_TO_LONG (Wrd23.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd24.Lng))))
    goto label_47;
  (Wrd18.Obj) = ((Wrd22.pObj) [3]);
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_46)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_16]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_42_13);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_33;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_33)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_17]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_42_2]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_45;
  Wrd10 = Wrd14;

DEFLABEL (label_44)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd25.Obj) = (Rsp [2]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 10))
    goto label_43;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [0]);
  (Wrd24.Lng) = (FIXNUM_TO_LONG (Wrd23.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd24.Lng))))
    goto label_43;
  (Wrd18.Obj) = ((Wrd22.pObj) [4]);
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_42)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_16]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_42_17);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_34;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_34)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_20]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_42_2]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_41;
  Wrd10 = Wrd14;

DEFLABEL (label_40)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd25.Obj) = (Rsp [2]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 10))
    goto label_39;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [0]);
  (Wrd24.Lng) = (FIXNUM_TO_LONG (Wrd23.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd24.Lng))))
    goto label_39;
  (Wrd18.Obj) = ((Wrd22.pObj) [5]);
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_38)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_16]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_42_20);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_35;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_35)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_37;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd15.Lng))))
    goto label_37;
  (Wrd7.Obj) = ((Wrd13.pObj) [6]);

DEFLABEL (label_36)
  (Rsp [0]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_24]));

DEFLABEL (label_37)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_42_8]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_23]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_3]), 2);

DEFLABEL (label_26)
  (Wrd7.Obj) = Rvl;
  goto label_36;

DEFLABEL (label_39)
  (Wrd27.Obj) = (Rsp [2]);
  (Wrd28.Obj) = (current_block [OBJECT_42_7]);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_22]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_3]), 2);

DEFLABEL (label_25)
  (* (--Rsp)) = Rvl;
  goto label_38;

DEFLABEL (label_41)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_42_21])), (Wrd11.pObj));

DEFLABEL (label_24)
  (Wrd10.Obj) = Rvl;
  goto label_40;

DEFLABEL (label_43)
  (Wrd27.Obj) = (Rsp [2]);
  (Wrd28.Obj) = (current_block [OBJECT_42_6]);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_19]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_3]), 2);

DEFLABEL (label_23)
  (* (--Rsp)) = Rvl;
  goto label_42;

DEFLABEL (label_45)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_42_18])), (Wrd11.pObj));

DEFLABEL (label_22)
  (Wrd10.Obj) = Rvl;
  goto label_44;

DEFLABEL (label_47)
  (Wrd27.Obj) = (Rsp [2]);
  (Wrd28.Obj) = (current_block [OBJECT_42_5]);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_15]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_3]), 2);

DEFLABEL (label_21)
  (* (--Rsp)) = Rvl;
  goto label_46;

DEFLABEL (label_49)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_42_14])), (Wrd11.pObj));

DEFLABEL (label_20)
  (Wrd10.Obj) = Rvl;
  goto label_48;

DEFLABEL (label_51)
  (Wrd27.Obj) = (Rsp [2]);
  (Wrd28.Obj) = (current_block [OBJECT_42_4]);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_11]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_3]), 2);

DEFLABEL (label_19)
  (* (--Rsp)) = Rvl;
  goto label_50;

DEFLABEL (label_53)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_42_10])), (Wrd11.pObj));

DEFLABEL (label_18)
  (Wrd10.Obj) = Rvl;
  goto label_52;

DEFLABEL (label_55)
  (Wrd35.Obj) = (Rsp [1]);
  (Wrd36.Obj) = (current_block [OBJECT_42_2]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_7]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_3]), 2);

DEFLABEL (label_17)
  (* (--Rsp)) = Rvl;
  goto label_54;

DEFLABEL (label_57)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_5]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_0]), 1);

DEFLABEL (label_16)
  (Wrd9.Obj) = Rvl;
  goto label_56;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_43_5 3
#define LABEL_43_6 5
#define LABEL_43_4 7
#define LABEL_43_7 9
#define LABEL_43_8 11
#define LABEL_43_9 13
#define LABEL_43_10 15
#define LABEL_43_11 17
#define LABEL_43_12 19
#define LABEL_43_13 21
#define LABEL_43_15 23
#define LABEL_43_14 25
#define LABEL_43_17 27
#define LABEL_43_18 29
#define ENVIRONMENT_LABEL_43_3 45
#define DEBUGGING_LABEL_43_2 44
#define OBJECT_43_10 43
#define OBJECT_43_9 42
#define OBJECT_43_8 41
#define OBJECT_43_7 40
#define OBJECT_43_6 39
#define OBJECT_43_5 38
#define OBJECT_43_4 37
#define OBJECT_43_3 36
#define OBJECT_43_2 35
#define OBJECT_43_1 34
#define OBJECT_43_0 33
#define EXECUTE_CACHE_43_16 31
#define FREE_REFERENCES_LABEL_43_0 30
#define NUMBER_OF_LINKER_SECTIONS_43_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_43 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd32;
  machine_word Wrd30;
  machine_word Wrd49;
  machine_word Wrd41;
  machine_word Wrd22;
  machine_word Wrd18;
  machine_word Wrd7;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd86;
  machine_word Wrd83;
  machine_word Wrd82;
  machine_word Wrd73;
  machine_word Wrd79;
  machine_word Wrd78;
  machine_word Wrd77;
  machine_word Wrd81;
  machine_word Wrd80;
  machine_word Wrd70;
  machine_word Wrd58;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd66;
  machine_word Wrd56;
  machine_word Wrd96;
  machine_word Wrd93;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd91;
  machine_word Wrd88;
  machine_word Wrd51;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd38;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd35;
  machine_word Wrd31;
  machine_word Wrd21;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd148;
  machine_word Wrd145;
  machine_word Wrd144;
  machine_word Wrd133;
  machine_word Wrd141;
  machine_word Wrd140;
  machine_word Wrd139;
  machine_word Wrd143;
  machine_word Wrd142;
  machine_word Wrd123;
  machine_word Wrd127;
  machine_word Wrd126;
  machine_word Wrd125;
  machine_word Wrd131;
  machine_word Wrd121;
  machine_word Wrd158;
  machine_word Wrd155;
  machine_word Wrd120;
  machine_word Wrd119;
  machine_word Wrd118;
  machine_word Wrd153;
  machine_word Wrd150;
  machine_word Wrd116;
  machine_word Wrd113;
  machine_word Wrd112;
  machine_word Wrd103;
  machine_word Wrd109;
  machine_word Wrd108;
  machine_word Wrd107;
  machine_word Wrd111;
  machine_word Wrd110;
  machine_word Wrd100;
  machine_word Wrd19;
  machine_word Wrd9;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_43_5);
      goto continuation_15;

    case 1:
      current_block = (Rpc - LABEL_43_6);
      goto continuation_6;

    case 2:
      current_block = (Rpc - LABEL_43_4);
      goto link_descriptionP_19;

    case 3:
      current_block = (Rpc - LABEL_43_7);
      goto label_21;

    case 4:
      current_block = (Rpc - LABEL_43_8);
      goto label_26;

    case 5:
      current_block = (Rpc - LABEL_43_9);
      goto label_28;

    case 6:
      current_block = (Rpc - LABEL_43_10);
      goto label_27;

    case 7:
      current_block = (Rpc - LABEL_43_11);
      goto label_22;

    case 8:
      current_block = (Rpc - LABEL_43_12);
      goto label_23;

    case 9:
      current_block = (Rpc - LABEL_43_13);
      goto label_25;

    case 10:
      current_block = (Rpc - LABEL_43_15);
      goto label_24;

    case 11:
      current_block = (Rpc - LABEL_43_14);
      goto continuation_10;

    case 12:
      current_block = (Rpc - LABEL_43_17);
      goto label_29;

    case 13:
      current_block = (Rpc - LABEL_43_18);
      goto label_30;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (link_descriptionP_32)
DEFLABEL (link_descriptionP_19)
  INTERRUPT_CHECK (26, LABEL_43_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 10)
    goto label_34;

DEFLABEL (label_33)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_34)
  if (! ((Wrd6.uLng) == 10))
    goto label_63;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd9.Obj) = (MAKE_OBJECT (26, (Wrd13.uLng)));

DEFLABEL (label_62)
  if ((Wrd9.Obj) == (current_block [OBJECT_43_1]))
    goto label_50;
  (Wrd26.Obj) = (Rsp [0]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd27.uLng) == 10))
    goto label_49;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [0]);
  (Wrd21.Obj) = (MAKE_OBJECT (26, (Wrd25.uLng)));

DEFLABEL (label_48)
  if (! ((Wrd21.Obj) == (current_block [OBJECT_43_10])))
    goto label_33;
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_6]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd45.Obj) = (Rsp [1]);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd45.Obj));
  if (! ((Wrd46.uLng) == 10))
    goto label_47;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd43.Obj) = ((Wrd42.pObj) [0]);
  (Wrd44.Lng) = (FIXNUM_TO_LONG (Wrd43.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd44.Lng))))
    goto label_47;
  (Wrd38.Obj) = ((Wrd42.pObj) [1]);
  (* (--Rsp)) = (Wrd38.Obj);

DEFLABEL (label_46)
  (Wrd88.Obj) = (current_block [OBJECT_43_4]);
  (Wrd91.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 29L) < ((unsigned long) (Wrd91.Lng))))
    goto label_45;
  (Wrd53.uLng) = (OBJECT_DATUM (Wrd88.Obj));
  (Wrd54.Obj) = (Rsp [0]);
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if ((Wrd53.Obj) == (Wrd55.Obj))
    goto label_44;

DEFLABEL (label_43)
  (Wrd56.Obj) = (current_block [OBJECT_43_6]);
  (* (--Rsp)) = (Wrd56.Obj);
  (Wrd66.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 5L) < ((unsigned long) (Wrd66.Lng)))
    goto label_36;

DEFLABEL (label_35)
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_5]), 2);

DEFLABEL (label_36)
  (Wrd60.uLng) = (OBJECT_DATUM (Wrd56.Obj));
  (Wrd61.Obj) = (Rsp [1]);
  (Wrd62.uLng) = (OBJECT_TYPE (Wrd61.Obj));
  if ((Wrd60.Obj) == (Wrd62.Obj))
    goto label_38;
  (Wrd58.Obj) = (current_block [OBJECT_43_8]);
  goto label_37;

DEFLABEL (label_38)
  (Wrd58.Obj) = (current_block [OBJECT_43_7]);

DEFLABEL (label_37)
DEFLABEL (label_42)
  Rsp = (& (Rsp [3]));
  if ((Wrd58.Obj) == ((SCHEME_OBJECT) 0))
    goto label_33;

DEFLABEL (label_41)
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_14]))));
  (* (--Rsp)) = (Wrd70.Obj);
  (Wrd80.Obj) = (Rsp [1]);
  (Wrd81.uLng) = (OBJECT_TYPE (Wrd80.Obj));
  if (! ((Wrd81.uLng) == 10))
    goto label_40;
  (Wrd77.pObj) = (OBJECT_ADDRESS (Wrd80.Obj));
  (Wrd78.Obj) = ((Wrd77.pObj) [0]);
  (Wrd79.Lng) = (FIXNUM_TO_LONG (Wrd78.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd79.Lng))))
    goto label_40;
  (Wrd73.Obj) = ((Wrd77.pObj) [2]);
  (* (--Rsp)) = (Wrd73.Obj);

DEFLABEL (label_39)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43_16]));

DEFLABEL (label_40)
  (Wrd82.Obj) = (Rsp [1]);
  (Wrd83.Obj) = (current_block [OBJECT_43_9]);
  (Wrd86.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_15]))));
  (* (--Rsp)) = (Wrd86.Obj);
  (* (--Rsp)) = (Wrd83.Obj);
  (* (--Rsp)) = (Wrd82.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_3]), 2);

DEFLABEL (label_24)
  (* (--Rsp)) = Rvl;
  goto label_39;

DEFLABEL (label_44)
  Rsp = (& (Rsp [2]));
  goto label_41;

DEFLABEL (label_45)
  (Wrd93.Obj) = (Rsp [0]);
  (Wrd96.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_13]))));
  (* (--Rsp)) = (Wrd96.Obj);
  (* (--Rsp)) = (Wrd93.Obj);
  (* (--Rsp)) = (Wrd88.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_5]), 2);

DEFLABEL (label_25)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_43;
  goto label_44;

DEFLABEL (label_47)
  (Wrd47.Obj) = (Rsp [1]);
  (Wrd48.Obj) = (current_block [OBJECT_43_2]);
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_12]))));
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_3]), 2);

DEFLABEL (label_23)
  (* (--Rsp)) = Rvl;
  goto label_46;

DEFLABEL (label_49)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_11]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_0]), 1);

DEFLABEL (label_22)
  (Wrd21.Obj) = Rvl;
  goto label_48;

DEFLABEL (label_50)
  (Wrd100.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_5]))));
  (* (--Rsp)) = (Wrd100.Obj);
  (Wrd110.Obj) = (Rsp [1]);
  (Wrd111.uLng) = (OBJECT_TYPE (Wrd110.Obj));
  if (! ((Wrd111.uLng) == 10))
    goto label_61;
  (Wrd107.pObj) = (OBJECT_ADDRESS (Wrd110.Obj));
  (Wrd108.Obj) = ((Wrd107.pObj) [0]);
  (Wrd109.Lng) = (FIXNUM_TO_LONG (Wrd108.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd109.Lng))))
    goto label_61;
  (Wrd103.Obj) = ((Wrd107.pObj) [1]);
  (* (--Rsp)) = (Wrd103.Obj);

DEFLABEL (label_60)
  (Wrd150.Obj) = (current_block [OBJECT_43_4]);
  (Wrd153.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 29L) < ((unsigned long) (Wrd153.Lng))))
    goto label_59;
  (Wrd118.uLng) = (OBJECT_DATUM (Wrd150.Obj));
  (Wrd119.Obj) = (Rsp [0]);
  (Wrd120.uLng) = (OBJECT_TYPE (Wrd119.Obj));
  if ((Wrd118.Obj) == (Wrd120.Obj))
    goto label_58;

DEFLABEL (label_57)
  (Wrd121.Obj) = (current_block [OBJECT_43_6]);
  (* (--Rsp)) = (Wrd121.Obj);
  (Wrd131.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd131.Lng))))
    goto label_35;
  (Wrd125.uLng) = (OBJECT_DATUM (Wrd121.Obj));
  (Wrd126.Obj) = (Rsp [1]);
  (Wrd127.uLng) = (OBJECT_TYPE (Wrd126.Obj));
  if ((Wrd125.Obj) == (Wrd127.Obj))
    goto label_52;
  (Wrd123.Obj) = (current_block [OBJECT_43_8]);
  goto label_51;

DEFLABEL (label_52)
  (Wrd123.Obj) = (current_block [OBJECT_43_7]);

DEFLABEL (label_51)
DEFLABEL (label_56)
  Rsp = (& (Rsp [3]));
  if ((Wrd123.Obj) == ((SCHEME_OBJECT) 0))
    goto label_33;

DEFLABEL (label_55)
  (Wrd142.Obj) = (Rsp [0]);
  (Wrd143.uLng) = (OBJECT_TYPE (Wrd142.Obj));
  if (! ((Wrd143.uLng) == 10))
    goto label_54;
  (Wrd139.pObj) = (OBJECT_ADDRESS (Wrd142.Obj));
  (Wrd140.Obj) = ((Wrd139.pObj) [0]);
  (Wrd141.Lng) = (FIXNUM_TO_LONG (Wrd140.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd141.Lng))))
    goto label_54;
  (Wrd133.Obj) = ((Wrd139.pObj) [2]);

DEFLABEL (label_53)
  (Rsp [0]) = (Wrd133.Obj);
  goto label_39;

DEFLABEL (label_54)
  (Wrd144.Obj) = (Rsp [0]);
  (Wrd145.Obj) = (current_block [OBJECT_43_9]);
  (Wrd148.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_10]))));
  (* (--Rsp)) = (Wrd148.Obj);
  (* (--Rsp)) = (Wrd145.Obj);
  (* (--Rsp)) = (Wrd144.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_3]), 2);

DEFLABEL (label_27)
  (Wrd133.Obj) = Rvl;
  goto label_53;

DEFLABEL (label_58)
  Rsp = (& (Rsp [2]));
  goto label_55;

DEFLABEL (label_59)
  (Wrd155.Obj) = (Rsp [0]);
  (Wrd158.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_9]))));
  (* (--Rsp)) = (Wrd158.Obj);
  (* (--Rsp)) = (Wrd155.Obj);
  (* (--Rsp)) = (Wrd150.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_5]), 2);

DEFLABEL (label_28)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_57;
  goto label_58;

DEFLABEL (label_61)
  (Wrd112.Obj) = (Rsp [1]);
  (Wrd113.Obj) = (current_block [OBJECT_43_2]);
  (Wrd116.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_8]))));
  (* (--Rsp)) = (Wrd116.Obj);
  (* (--Rsp)) = (Wrd113.Obj);
  (* (--Rsp)) = (Wrd112.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_3]), 2);

DEFLABEL (label_26)
  (* (--Rsp)) = Rvl;
  goto label_60;

DEFLABEL (label_63)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_7]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_0]), 1);

DEFLABEL (label_21)
  (Wrd9.Obj) = Rvl;
  goto label_62;

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_43_14);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_74;
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_73;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd15.Lng))))
    goto label_73;
  (Wrd7.Obj) = ((Wrd13.pObj) [3]);

DEFLABEL (label_72)
  (Rsp [0]) = (Wrd7.Obj);
  (Wrd41.Obj) = (current_block [OBJECT_43_4]);
  (Wrd44.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 29L) < ((unsigned long) (Wrd44.Lng))))
    goto label_71;
  (Wrd24.uLng) = (OBJECT_DATUM (Wrd41.Obj));
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd24.Obj) == (Wrd26.Obj))
    goto label_69;

DEFLABEL (label_68)
  (Wrd27.Obj) = (current_block [OBJECT_43_6]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd38.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 5L) < ((unsigned long) (Wrd38.Lng)))
    goto label_64;
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_5]), 2);

DEFLABEL (label_64)
  (Wrd30.uLng) = (OBJECT_DATUM (Wrd27.Obj));
  (Wrd31.Obj) = (Rsp [1]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd30.Obj) == (Wrd32.Obj))
    goto label_66;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_65;

DEFLABEL (label_66)
  Rvl = (current_block [OBJECT_43_7]);

DEFLABEL (label_65)
DEFLABEL (label_67)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_69)
  Rvl = (current_block [OBJECT_43_7]);

DEFLABEL (label_70)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_71)
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_18]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_5]), 2);

DEFLABEL (label_30)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_68;
  goto label_69;

DEFLABEL (label_73)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_43_1]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_17]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_43_3]), 2);

DEFLABEL (label_29)
  (Wrd7.Obj) = Rvl;
  goto label_72;

DEFLABEL (label_74)
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_70;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_43_6);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_33;
  goto label_41;

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_43_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_33;
  goto label_55;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_44_4 3
#define LABEL_44_5 5
#define LABEL_44_7 7
#define LABEL_44_6 9
#define LABEL_44_11 11
#define LABEL_44_9 13
#define LABEL_44_13 15
#define LABEL_44_14 17
#define LABEL_44_15 19
#define LABEL_44_10 21
#define LABEL_44_16 23
#define LABEL_44_17 25
#define LABEL_44_18 27
#define LABEL_44_20 29
#define LABEL_44_19 31
#define LABEL_44_21 33
#define LABEL_44_22 35
#define LABEL_44_23 37
#define LABEL_44_24 39
#define ENVIRONMENT_LABEL_44_3 64
#define DEBUGGING_LABEL_44_2 63
#define OBJECT_44_15 62
#define OBJECT_44_14 61
#define OBJECT_44_13 60
#define OBJECT_44_12 59
#define OBJECT_44_11 58
#define OBJECT_44_10 57
#define OBJECT_44_9 56
#define OBJECT_44_8 55
#define OBJECT_44_7 54
#define OBJECT_44_6 53
#define OBJECT_44_5 52
#define OBJECT_44_4 51
#define OBJECT_44_3 50
#define OBJECT_44_2 49
#define OBJECT_44_1 48
#define OBJECT_44_0 47
#define EXECUTE_CACHE_44_12 41
#define EXECUTE_CACHE_44_8 43
#define FREE_REFERENCE_44_0 46
#define FREE_REFERENCES_LABEL_44_0 40
#define NUMBER_OF_LINKER_SECTIONS_44_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_44 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd8;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd40;
  machine_word Wrd42;
  machine_word Wrd29;
  machine_word Wrd25;
  machine_word Wrd59;
  machine_word Wrd56;
  machine_word Wrd54;
  machine_word Wrd51;
  machine_word Wrd43;
  machine_word Wrd41;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd7;
  machine_word Wrd15;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd27;
  machine_word Wrd24;
  machine_word Wrd14;
  machine_word Wrd20;
  machine_word Wrd18;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd11;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd26;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd23;
  machine_word Wrd19;
  machine_word Wrd9;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_44_4);
      goto load_descriptionP_24;

    case 1:
      current_block = (Rpc - LABEL_44_5);
      goto label_26;

    case 2:
      current_block = (Rpc - LABEL_44_7);
      goto label_27;

    case 3:
      current_block = (Rpc - LABEL_44_6);
      goto continuation_4;

    case 4:
      current_block = (Rpc - LABEL_44_11);
      goto label_28;

    case 5:
      current_block = (Rpc - LABEL_44_9);
      goto continuation_20;

    case 6:
      current_block = (Rpc - LABEL_44_13);
      goto label_29;

    case 7:
      current_block = (Rpc - LABEL_44_14);
      goto label_30;

    case 8:
      current_block = (Rpc - LABEL_44_15);
      goto continuation_8;

    case 9:
      current_block = (Rpc - LABEL_44_10);
      goto lambda_19;

    case 10:
      current_block = (Rpc - LABEL_44_16);
      goto label_31;

    case 11:
      current_block = (Rpc - LABEL_44_17);
      goto label_33;

    case 12:
      current_block = (Rpc - LABEL_44_18);
      goto label_32;

    case 13:
      current_block = (Rpc - LABEL_44_20);
      goto continuation_16;

    case 14:
      current_block = (Rpc - LABEL_44_19);
      goto lambda_18;

    case 15:
      current_block = (Rpc - LABEL_44_21);
      goto label_34;

    case 16:
      current_block = (Rpc - LABEL_44_22);
      goto label_37;

    case 17:
      current_block = (Rpc - LABEL_44_23);
      goto label_35;

    case 18:
      current_block = (Rpc - LABEL_44_24);
      goto label_36;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (load_descriptionP_39)
DEFLABEL (load_descriptionP_24)
  INTERRUPT_CHECK (26, LABEL_44_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 10)
    goto label_43;

DEFLABEL (label_42)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_43)
  if (! ((Wrd6.uLng) == 10))
    goto label_57;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd9.Obj) = (MAKE_OBJECT (26, (Wrd13.uLng)));

DEFLABEL (label_56)
  if (! ((Wrd9.Obj) == (current_block [OBJECT_44_1])))
    goto label_42;
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_6]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd33.Obj) = (Rsp [1]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 10))
    goto label_55;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd32.Lng))))
    goto label_55;
  (Wrd26.Obj) = ((Wrd30.pObj) [1]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_54)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_44_8]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_44_6);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_44;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_44)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_10]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 10))
    goto label_53;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd20.Lng))))
    goto label_53;
  (Wrd14.Obj) = ((Wrd18.pObj) [2]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_52)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_44_12]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_44_9);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_46;
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_51;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd15.Lng))))
    goto label_51;
  (Wrd7.Obj) = ((Wrd13.pObj) [3]);

DEFLABEL (label_50)
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd23.uLng) == 10)
    goto label_47;

DEFLABEL (label_46)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_45)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_47)
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd36.uLng) == 10))
    goto label_49;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [0]);
  (Wrd34.Lng) = (FIXNUM_TO_LONG (Wrd33.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd34.Lng))))
    goto label_49;
  (Wrd26.Obj) = ((Wrd32.pObj) [4]);

DEFLABEL (label_48)
  (Wrd43.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd43.uLng) == 10))
    goto label_46;
  Rvl = (current_block [OBJECT_44_7]);
  goto label_45;

DEFLABEL (label_49)
  (Wrd37.Obj) = (Rsp [0]);
  (Wrd38.Obj) = (current_block [OBJECT_44_6]);
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_14]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44_3]), 2);

DEFLABEL (label_30)
  (Wrd26.Obj) = Rvl;
  goto label_48;

DEFLABEL (label_51)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_44_5]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_13]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44_3]), 2);

DEFLABEL (label_29)
  (Wrd7.Obj) = Rvl;
  goto label_50;

DEFLABEL (label_53)
  (Wrd23.Obj) = (Rsp [2]);
  (Wrd24.Obj) = (current_block [OBJECT_44_4]);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_11]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44_3]), 2);

DEFLABEL (label_28)
  (* (--Rsp)) = Rvl;
  goto label_52;

DEFLABEL (label_55)
  (Wrd35.Obj) = (Rsp [1]);
  (Wrd36.Obj) = (current_block [OBJECT_44_2]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_7]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44_3]), 2);

DEFLABEL (label_27)
  (* (--Rsp)) = Rvl;
  goto label_54;

DEFLABEL (label_57)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_5]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44_0]), 1);

DEFLABEL (label_26)
  (Wrd9.Obj) = Rvl;
  goto label_56;

DEFLABEL (lambda_40)
DEFLABEL (lambda_19)
  INTERRUPT_CHECK (26, LABEL_44_10);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_58;
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_44_14]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_44_12]));

DEFLABEL (label_58)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_15]))));
  (* (--Rsp)) = (Wrd11.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_71;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_70)
  (Wrd51.Obj) = (current_block [OBJECT_44_9]);
  (Wrd54.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 29L) < ((unsigned long) (Wrd54.Lng))))
    goto label_69;
  (Wrd22.uLng) = (OBJECT_DATUM (Wrd51.Obj));
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd22.Obj) == (Wrd24.Obj))
    goto label_68;

DEFLABEL (label_67)
  (Wrd25.Obj) = (current_block [OBJECT_44_11]);
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd35.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 5L) < ((unsigned long) (Wrd35.Lng)))
    goto label_59;
  INVOKE_PRIMITIVE ((current_block [OBJECT_44_10]), 2);

DEFLABEL (label_59)
  (Wrd29.uLng) = (OBJECT_DATUM (Wrd25.Obj));
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd29.Obj) == (Wrd31.Obj))
    goto label_61;
  (Wrd27.Obj) = (current_block [OBJECT_44_12]);
  goto label_60;

DEFLABEL (label_61)
  (Wrd27.Obj) = (current_block [OBJECT_44_7]);

DEFLABEL (label_60)
DEFLABEL (label_66)
  Rsp = (& (Rsp [3]));
  if (! ((Wrd27.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_63;

DEFLABEL (label_62)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_63)
  (Wrd42.Obj) = (Rsp [0]);
  (Wrd43.uLng) = (OBJECT_TYPE (Wrd42.Obj));
  if (! ((Wrd43.uLng) == 1))
    goto label_65;
  (Wrd40.pObj) = (OBJECT_ADDRESS (Wrd42.Obj));
  (Wrd41.Obj) = ((Wrd40.pObj) [1]);
  (* (--Rsp)) = (Wrd41.Obj);

DEFLABEL (label_64)
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_19]))));
  (Rsp [1]) = (Wrd48.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_44_12]));

DEFLABEL (label_65)
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_18]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44_13]), 1);

DEFLABEL (label_32)
  (* (--Rsp)) = Rvl;
  goto label_64;

DEFLABEL (label_68)
  Rsp = (& (Rsp [2]));
  goto label_63;

DEFLABEL (label_69)
  (Wrd56.Obj) = (Rsp [0]);
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_17]))));
  (* (--Rsp)) = (Wrd59.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44_10]), 2);

DEFLABEL (label_33)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_67;
  goto label_68;

DEFLABEL (label_71)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_16]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44_8]), 1);

DEFLABEL (label_31)
  (* (--Rsp)) = Rvl;
  goto label_70;

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_44_15);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_62;
  goto label_63;

DEFLABEL (lambda_41)
DEFLABEL (lambda_18)
  INTERRUPT_CHECK (26, LABEL_44_19);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_73;

DEFLABEL (label_72)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_73)
  if (! ((Wrd6.uLng) == 1))
    goto label_82;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [0]);

DEFLABEL (label_81)
  if ((Wrd9.Obj) == (current_block [OBJECT_44_15]))
    goto label_78;
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_20]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd23.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_44_0]));
  (Wrd26.Obj) = ((Wrd23.pObj) [0]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if ((Wrd27.uLng) == 50)
    goto label_77;
  Wrd22 = Wrd26;

DEFLABEL (label_76)
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd31.Obj) = (Rsp [2]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if (! ((Wrd32.uLng) == 1))
    goto label_75;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_74)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_44_12]));

DEFLABEL (label_75)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_24]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd31.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44_8]), 1);

DEFLABEL (label_36)
  (* (--Rsp)) = Rvl;
  goto label_74;

DEFLABEL (label_77)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_44_23])), (Wrd23.pObj));

DEFLABEL (label_35)
  (Wrd22.Obj) = Rvl;
  goto label_76;

DEFLABEL (label_78)
  (Wrd40.Obj) = (Rsp [0]);
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if (! ((Wrd41.uLng) == 1))
    goto label_80;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [1]);
  (* (--Rsp)) = (Wrd39.Obj);

DEFLABEL (label_79)
  (Wrd46.Obj) = (current_block [OBJECT_44_14]);
  (Rsp [1]) = (Wrd46.Obj);
  goto label_74;

DEFLABEL (label_80)
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_22]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44_13]), 1);

DEFLABEL (label_37)
  (* (--Rsp)) = Rvl;
  goto label_79;

DEFLABEL (label_82)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_21]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44_8]), 1);

DEFLABEL (label_34)
  (Wrd9.Obj) = Rvl;
  goto label_81;

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_44_20);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_72;
  goto label_78;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_45_4 3
#define LABEL_45_5 5
#define LABEL_45_6 7
#define LABEL_45_7 9
#define LABEL_45_9 11
#define LABEL_45_10 13
#define LABEL_45_12 15
#define LABEL_45_14 17
#define LABEL_45_15 19
#define LABEL_45_11 21
#define LABEL_45_8 23
#define LABEL_45_18 25
#define LABEL_45_19 27
#define LABEL_45_20 29
#define LABEL_45_16 31
#define LABEL_45_13 33
#define ENVIRONMENT_LABEL_45_3 49
#define DEBUGGING_LABEL_45_2 48
#define OBJECT_45_8 47
#define OBJECT_45_7 46
#define OBJECT_45_6 45
#define OBJECT_45_5 44
#define OBJECT_45_4 43
#define OBJECT_45_3 42
#define OBJECT_45_2 41
#define OBJECT_45_1 40
#define OBJECT_45_0 39
#define EXECUTE_CACHE_45_21 35
#define EXECUTE_CACHE_45_17 37
#define FREE_REFERENCES_LABEL_45_0 34
#define NUMBER_OF_LINKER_SECTIONS_45_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_45 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd19;
  machine_word Wrd7;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd52;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd39;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd21;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd22;
  machine_word Wrd30;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd27;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_45_4);
      goto construct_packages_from_file_35;

    case 1:
      current_block = (Rpc - LABEL_45_5);
      goto label_37;

    case 2:
      current_block = (Rpc - LABEL_45_6);
      goto label_38;

    case 3:
      current_block = (Rpc - LABEL_45_7);
      goto do_loop_19;

    case 4:
      current_block = (Rpc - LABEL_45_9);
      goto label_39;

    case 5:
      current_block = (Rpc - LABEL_45_10);
      goto label_40;

    case 6:
      current_block = (Rpc - LABEL_45_12);
      goto do_loop_31;

    case 7:
      current_block = (Rpc - LABEL_45_14);
      goto label_41;

    case 8:
      current_block = (Rpc - LABEL_45_15);
      goto label_42;

    case 9:
      current_block = (Rpc - LABEL_45_11);
      goto continuation_14;

    case 10:
      current_block = (Rpc - LABEL_45_8);
      goto continuation_12;

    case 11:
      current_block = (Rpc - LABEL_45_18);
      goto lambda_6;

    case 12:
      current_block = (Rpc - LABEL_45_19);
      goto label_43;

    case 13:
      current_block = (Rpc - LABEL_45_20);
      goto label_44;

    case 14:
      current_block = (Rpc - LABEL_45_16);
      goto continuation_26;

    case 15:
      current_block = (Rpc - LABEL_45_13);
      goto continuation_24;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (construct_packages_from_file_46)
DEFLABEL (construct_packages_from_file_35)
  INTERRUPT_CHECK (26, LABEL_45_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_53;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd13.Lng))))
    goto label_53;
  (Wrd5.Obj) = ((Wrd11.pObj) [3]);

DEFLABEL (label_52)
  (Rsp [0]) = (Wrd5.Obj);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd27.uLng) == 10))
    goto label_51;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [0]);
  (Wrd25.Obj) = (MAKE_OBJECT (26, (Wrd24.uLng)));
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_50)
  (Wrd32.Obj) = (current_block [OBJECT_45_3]);
  (* (--Rsp)) = (Wrd32.Obj);
  goto do_loop_19;

DEFLABEL (label_51)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_6]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_45_2]), 1);

DEFLABEL (label_38)
  (* (--Rsp)) = Rvl;
  goto label_50;

DEFLABEL (label_53)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_45_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_45_1]), 2);

DEFLABEL (label_37)
  (Wrd5.Obj) = Rvl;
  goto label_52;

DEFLABEL (do_loop_47)
DEFLABEL (do_loop_19)
  INTERRUPT_CHECK (26, LABEL_45_7);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_55;
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  goto label_54;

DEFLABEL (label_55)
  (Wrd8.Obj) = (current_block [OBJECT_45_4]);
  (* (--Rsp)) = (Wrd8.Obj);

DEFLABEL (label_54)
DEFLABEL (label_63)
  (Wrd9.Obj) = (Rsp [0]);
  if ((Wrd9.Obj) == ((SCHEME_OBJECT) 0))
    goto label_56;
  Rsp = (& (Rsp [2]));
  (Wrd12.Obj) = (current_block [OBJECT_45_3]);
  (* (--Rsp)) = (Wrd12.Obj);
  goto do_loop_31;

DEFLABEL (label_56)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_8]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd30.Obj) = (Rsp [4]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_62;
  (Wrd22.Obj) = (Rsp [2]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd23.uLng) == 26))
    goto label_62;
  (Wrd25.Lng) = (FIXNUM_TO_LONG (Wrd22.Obj));
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) (Wrd25.Lng)) < ((unsigned long) (Wrd29.Lng))))
    goto label_62;
  (Wrd17.uLng) = (OBJECT_DATUM (Wrd22.Obj));
  (Wrd20.pObj) = (& ((Wrd27.pObj) [(Wrd17.Lng)]));
  (Wrd21.Obj) = ((Wrd20.pObj) [1]);
  (* (--Rsp)) = (Wrd21.Obj);

DEFLABEL (label_61)
  (Wrd46.Obj) = (Rsp [0]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if (! ((Wrd47.uLng) == 10))
    goto label_60;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [0]);
  (Wrd45.Lng) = (FIXNUM_TO_LONG (Wrd44.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd45.Lng))))
    goto label_60;
  (Wrd39.Obj) = ((Wrd43.pObj) [1]);
  (* (--Rsp)) = (Wrd39.Obj);

DEFLABEL (label_59)
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_11]))));
  (* (--Rsp)) = (Wrd55.Obj);
  (Wrd56.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd56.Obj);
  goto lambda_6;

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_45_11);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_57;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_17]));

DEFLABEL (label_57)
  Rsp = (& (Rsp [3]));

DEFLABEL (label_58)
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.Lng) = (FIXNUM_TO_LONG (Wrd6.Obj));
  (Wrd8.Lng) = ((Wrd7.Lng) + 1L);
  (Wrd5.Obj) = (LONG_TO_FIXNUM (Wrd8.Lng));
  (Rsp [1]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  goto do_loop_19;

DEFLABEL (label_60)
  (Wrd48.Obj) = (Rsp [0]);
  (Wrd49.Obj) = (current_block [OBJECT_45_3]);
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_10]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_45_1]), 2);

DEFLABEL (label_40)
  (* (--Rsp)) = Rvl;
  goto label_59;

DEFLABEL (label_62)
  (Wrd32.Obj) = (Rsp [4]);
  (Wrd33.Obj) = (Rsp [2]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_9]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_45_1]), 2);

DEFLABEL (label_39)
  (* (--Rsp)) = Rvl;
  goto label_61;

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_45_8);
  goto label_58;

DEFLABEL (do_loop_48)
DEFLABEL (do_loop_31)
  INTERRUPT_CHECK (26, LABEL_45_12);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_65;
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  goto label_64;

DEFLABEL (label_65)
  (Wrd8.Obj) = (current_block [OBJECT_45_4]);
  (* (--Rsp)) = (Wrd8.Obj);

DEFLABEL (label_64)
DEFLABEL (label_73)
  (Wrd9.Obj) = (Rsp [0]);
  if ((Wrd9.Obj) == ((SCHEME_OBJECT) 0))
    goto label_66;
  Rvl = (Wrd9.Obj);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_66)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_13]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd30.Obj) = (Rsp [4]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_72;
  (Wrd22.Obj) = (Rsp [2]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd23.uLng) == 26))
    goto label_72;
  (Wrd25.Lng) = (FIXNUM_TO_LONG (Wrd22.Obj));
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) (Wrd25.Lng)) < ((unsigned long) (Wrd29.Lng))))
    goto label_72;
  (Wrd17.uLng) = (OBJECT_DATUM (Wrd22.Obj));
  (Wrd20.pObj) = (& ((Wrd27.pObj) [(Wrd17.Lng)]));
  (Wrd21.Obj) = ((Wrd20.pObj) [1]);
  (* (--Rsp)) = (Wrd21.Obj);

DEFLABEL (label_71)
  (Wrd46.Obj) = (Rsp [0]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if (! ((Wrd47.uLng) == 10))
    goto label_70;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [0]);
  (Wrd45.Lng) = (FIXNUM_TO_LONG (Wrd44.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd45.Lng))))
    goto label_70;
  (Wrd39.Obj) = ((Wrd43.pObj) [1]);
  (* (--Rsp)) = (Wrd39.Obj);

DEFLABEL (label_69)
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_16]))));
  (* (--Rsp)) = (Wrd55.Obj);
  (Wrd56.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd56.Obj);
  goto lambda_6;

DEFLABEL (continuation_26)
  INTERRUPT_CHECK (27, LABEL_45_16);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_67;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_21]));

DEFLABEL (label_67)
  Rsp = (& (Rsp [3]));

DEFLABEL (label_68)
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.Lng) = (FIXNUM_TO_LONG (Wrd6.Obj));
  (Wrd8.Lng) = ((Wrd7.Lng) + 1L);
  (Wrd5.Obj) = (LONG_TO_FIXNUM (Wrd8.Lng));
  (Rsp [1]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  goto do_loop_31;

DEFLABEL (label_70)
  (Wrd48.Obj) = (Rsp [0]);
  (Wrd49.Obj) = (current_block [OBJECT_45_3]);
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_15]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_45_1]), 2);

DEFLABEL (label_42)
  (* (--Rsp)) = Rvl;
  goto label_69;

DEFLABEL (label_72)
  (Wrd32.Obj) = (Rsp [4]);
  (Wrd33.Obj) = (Rsp [2]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_14]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_45_1]), 2);

DEFLABEL (label_41)
  (* (--Rsp)) = Rvl;
  goto label_71;

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_45_13);
  goto label_68;

DEFLABEL (lambda_49)
DEFLABEL (lambda_6)
  INTERRUPT_CHECK (26, LABEL_45_18);
  (Wrd5.Obj) = (Rsp [0]);
  if ((Wrd5.Obj) == (current_block [OBJECT_45_5]))
    goto label_77;
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd8.uLng) == 1)
    goto label_76;

DEFLABEL (label_75)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_74)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_76)
  if (! ((Wrd8.uLng) == 1))
    goto label_81;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd11.Obj) = ((Wrd13.pObj) [0]);

DEFLABEL (label_80)
  if (! ((Wrd11.Obj) == (current_block [OBJECT_45_7])))
    goto label_75;
  (Wrd24.Obj) = (Rsp [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd25.uLng) == 1))
    goto label_79;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd21.Obj) = ((Wrd23.pObj) [1]);

DEFLABEL (label_78)
  if (! ((Wrd21.Obj) == (current_block [OBJECT_45_5])))
    goto label_75;

DEFLABEL (label_77)
  Rvl = (current_block [OBJECT_45_4]);
  goto label_74;

DEFLABEL (label_79)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_20]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_45_8]), 1);

DEFLABEL (label_44)
  (Wrd21.Obj) = Rvl;
  goto label_78;

DEFLABEL (label_81)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_19]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_45_6]), 1);

DEFLABEL (label_43)
  (Wrd11.Obj) = Rvl;
  goto label_80;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_46_5 3
#define LABEL_46_6 5
#define LABEL_46_4 7
#define LABEL_46_7 9
#define LABEL_46_8 11
#define LABEL_46_10 13
#define LABEL_46_12 15
#define LABEL_46_14 17
#define LABEL_46_16 19
#define LABEL_46_17 21
#define LABEL_46_19 23
#define LABEL_46_9 25
#define LABEL_46_21 27
#define LABEL_46_11 29
#define LABEL_46_13 31
#define LABEL_46_15 33
#define LABEL_46_22 35
#define LABEL_46_23 37
#define LABEL_46_24 39
#define LABEL_46_27 41
#define LABEL_46_29 43
#define LABEL_46_31 45
#define LABEL_46_26 47
#define LABEL_46_33 49
#define LABEL_46_25 51
#define LABEL_46_35 53
#define LABEL_46_32 55
#define ENVIRONMENT_LABEL_46_3 85
#define DEBUGGING_LABEL_46_2 84
#define OBJECT_46_11 83
#define OBJECT_46_10 82
#define OBJECT_46_9 81
#define OBJECT_46_8 80
#define OBJECT_46_7 79
#define OBJECT_46_6 78
#define OBJECT_46_5 77
#define OBJECT_46_4 76
#define OBJECT_46_3 75
#define OBJECT_46_2 74
#define OBJECT_46_1 73
#define OBJECT_46_0 72
#define EXECUTE_CACHE_46_36 57
#define EXECUTE_CACHE_46_34 59
#define EXECUTE_CACHE_46_30 61
#define EXECUTE_CACHE_46_28 63
#define EXECUTE_CACHE_46_20 65
#define EXECUTE_CACHE_46_18 67
#define FREE_REFERENCE_46_1 70
#define FREE_REFERENCE_46_0 71
#define FREE_REFERENCES_LABEL_46_0 56
#define NUMBER_OF_LINKER_SECTIONS_46_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_46 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd24;
  machine_word Wrd19;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd43;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd18;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd10;
  machine_word Wrd132;
  machine_word Wrd137;
  machine_word Wrd136;
  machine_word Wrd133;
  machine_word Wrd149;
  machine_word Wrd143;
  machine_word Wrd142;
  machine_word Wrd140;
  machine_word Wrd129;
  machine_word Wrd128;
  machine_word Wrd127;
  machine_word Wrd124;
  machine_word Wrd123;
  machine_word Wrd114;
  machine_word Wrd120;
  machine_word Wrd119;
  machine_word Wrd118;
  machine_word Wrd122;
  machine_word Wrd121;
  machine_word Wrd111;
  machine_word Wrd106;
  machine_word Wrd105;
  machine_word Wrd102;
  machine_word Wrd101;
  machine_word Wrd98;
  machine_word Wrd97;
  machine_word Wrd86;
  machine_word Wrd94;
  machine_word Wrd93;
  machine_word Wrd92;
  machine_word Wrd96;
  machine_word Wrd95;
  machine_word Wrd83;
  machine_word Wrd82;
  machine_word Wrd79;
  machine_word Wrd78;
  machine_word Wrd75;
  machine_word Wrd74;
  machine_word Wrd63;
  machine_word Wrd71;
  machine_word Wrd70;
  machine_word Wrd69;
  machine_word Wrd73;
  machine_word Wrd72;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd40;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd23;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd152;
  machine_word Wrd160;
  machine_word Wrd159;
  machine_word Wrd158;
  machine_word Wrd162;
  machine_word Wrd150;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_46_5);
      goto continuation_6;

    case 1:
      current_block = (Rpc - LABEL_46_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_46_4);
      goto construct_normal_package_from_description_34;

    case 3:
      current_block = (Rpc - LABEL_46_7);
      goto label_36;

    case 4:
      current_block = (Rpc - LABEL_46_8);
      goto label_37;

    case 5:
      current_block = (Rpc - LABEL_46_10);
      goto label_38;

    case 6:
      current_block = (Rpc - LABEL_46_12);
      goto label_39;

    case 7:
      current_block = (Rpc - LABEL_46_14);
      goto label_40;

    case 8:
      current_block = (Rpc - LABEL_46_16);
      goto label_41;

    case 9:
      current_block = (Rpc - LABEL_46_17);
      goto label_43;

    case 10:
      current_block = (Rpc - LABEL_46_19);
      goto label_42;

    case 11:
      current_block = (Rpc - LABEL_46_9);
      goto continuation_17;

    case 12:
      current_block = (Rpc - LABEL_46_21);
      goto label_44;

    case 13:
      current_block = (Rpc - LABEL_46_11);
      goto lambda_15;

    case 14:
      current_block = (Rpc - LABEL_46_13);
      goto lambda_12;

    case 15:
      current_block = (Rpc - LABEL_46_15);
      goto lambda_9;

    case 16:
      current_block = (Rpc - LABEL_46_22);
      goto continuation_22;

    case 17:
      current_block = (Rpc - LABEL_46_23);
      goto loop_31;

    case 18:
      current_block = (Rpc - LABEL_46_24);
      goto label_45;

    case 19:
      current_block = (Rpc - LABEL_46_27);
      goto label_48;

    case 20:
      current_block = (Rpc - LABEL_46_29);
      goto label_47;

    case 21:
      current_block = (Rpc - LABEL_46_31);
      goto label_46;

    case 22:
      current_block = (Rpc - LABEL_46_26);
      goto continuation_26;

    case 23:
      current_block = (Rpc - LABEL_46_33);
      goto label_50;

    case 24:
      current_block = (Rpc - LABEL_46_25);
      goto continuation_27;

    case 25:
      current_block = (Rpc - LABEL_46_35);
      goto label_49;

    case 26:
      current_block = (Rpc - LABEL_46_32);
      goto continuation_29;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (construct_normal_package_from_description_52)
DEFLABEL (construct_normal_package_from_description_34)
  INTERRUPT_CHECK (26, LABEL_46_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_78;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd13.Lng))))
    goto label_78;
  (Wrd7.Obj) = ((Wrd11.pObj) [6]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_77)
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_76;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd29.Lng))))
    goto label_76;
  (Wrd23.Obj) = ((Wrd27.pObj) [1]);
  (* (--Rsp)) = (Wrd23.Obj);

DEFLABEL (label_75)
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_9]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd49.Obj) = (Rsp [3]);
  (Wrd50.uLng) = (OBJECT_TYPE (Wrd49.Obj));
  if (! ((Wrd50.uLng) == 10))
    goto label_74;
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd49.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [0]);
  (Wrd48.Lng) = (FIXNUM_TO_LONG (Wrd47.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd48.Lng))))
    goto label_74;
  (Wrd40.Obj) = ((Wrd46.pObj) [5]);

DEFLABEL (label_73)
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_11]))));
  (* (Rhp++)) = (Wrd40.Obj);
  (* (Rhp++)) = (Wrd56.Obj);
  (Wrd59.pObj) = (& (Rhp [-2]));
  (Wrd60.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd59.pObj)));
  (* (--Rsp)) = (Wrd60.Obj);
  (Wrd72.Obj) = (Rsp [4]);
  (Wrd73.uLng) = (OBJECT_TYPE (Wrd72.Obj));
  if (! ((Wrd73.uLng) == 10))
    goto label_72;
  (Wrd69.pObj) = (OBJECT_ADDRESS (Wrd72.Obj));
  (Wrd70.Obj) = ((Wrd69.pObj) [0]);
  (Wrd71.Lng) = (FIXNUM_TO_LONG (Wrd70.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd71.Lng))))
    goto label_72;
  (Wrd63.Obj) = ((Wrd69.pObj) [4]);

DEFLABEL (label_71)
  (Wrd79.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_13]))));
  (* (Rhp++)) = (Wrd63.Obj);
  (* (Rhp++)) = (Wrd79.Obj);
  (Wrd82.pObj) = (& (Rhp [-2]));
  (Wrd83.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd82.pObj)));
  (* (--Rsp)) = (Wrd83.Obj);
  (Wrd95.Obj) = (Rsp [5]);
  (Wrd96.uLng) = (OBJECT_TYPE (Wrd95.Obj));
  if (! ((Wrd96.uLng) == 10))
    goto label_70;
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd95.Obj));
  (Wrd93.Obj) = ((Wrd92.pObj) [0]);
  (Wrd94.Lng) = (FIXNUM_TO_LONG (Wrd93.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd94.Lng))))
    goto label_70;
  (Wrd86.Obj) = ((Wrd92.pObj) [3]);

DEFLABEL (label_69)
  (Wrd102.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_15]))));
  (* (Rhp++)) = (Wrd86.Obj);
  (* (Rhp++)) = (Wrd102.Obj);
  (Wrd105.pObj) = (& (Rhp [-2]));
  (Wrd106.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd105.pObj)));
  (* (--Rsp)) = (Wrd106.Obj);
  (Wrd111.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_6]))));
  (* (--Rsp)) = (Wrd111.Obj);
  (Wrd121.Obj) = (Rsp [7]);
  (Wrd122.uLng) = (OBJECT_TYPE (Wrd121.Obj));
  if (! ((Wrd122.uLng) == 10))
    goto label_68;
  (Wrd118.pObj) = (OBJECT_ADDRESS (Wrd121.Obj));
  (Wrd119.Obj) = ((Wrd118.pObj) [0]);
  (Wrd120.Lng) = (FIXNUM_TO_LONG (Wrd119.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd120.Lng))))
    goto label_68;
  (Wrd114.Obj) = ((Wrd118.pObj) [2]);
  (* (--Rsp)) = (Wrd114.Obj);

DEFLABEL (label_67)
  (Wrd128.Obj) = (Rsp [0]);
  (Wrd129.uLng) = (OBJECT_TYPE (Wrd128.Obj));
  if ((Wrd129.uLng) == 1)
    goto label_62;
  (Wrd133.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_46_0]));
  (Wrd136.Obj) = ((Wrd133.pObj) [0]);
  (Wrd137.uLng) = (OBJECT_TYPE (Wrd136.Obj));
  if ((Wrd137.uLng) == 50)
    goto label_61;
  Wrd132 = Wrd136;

DEFLABEL (label_60)
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd132.Obj);

DEFLABEL (label_59)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_20]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_46_9);
  (Rsp [2]) = Rvl;
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_46_1]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_58;
  Wrd6 = Wrd10;

DEFLABEL (label_57)
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd12.Obj);
  goto loop_31;

DEFLABEL (label_58)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_46_21])), (Wrd7.pObj));

DEFLABEL (label_44)
  (Wrd6.Obj) = Rvl;
  goto label_57;

DEFLABEL (label_61)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_46_19])), (Wrd133.pObj));

DEFLABEL (label_42)
  (Wrd132.Obj) = Rvl;
  goto label_60;

DEFLABEL (label_62)
  (Wrd140.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_5]))));
  (* (--Rsp)) = (Wrd140.Obj);
  if (! ((Wrd129.uLng) == 1))
    goto label_66;
  (Wrd142.pObj) = (OBJECT_ADDRESS (Wrd128.Obj));
  (Wrd143.Obj) = ((Wrd142.pObj) [0]);
  (* (--Rsp)) = (Wrd143.Obj);

DEFLABEL (label_65)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_18]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_46_5);
  (* (--Rsp)) = Rvl;
  (Wrd150.Obj) = (current_block [OBJECT_46_0]);
  (Rsp [1]) = (Wrd150.Obj);
  (Wrd162.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd162.uLng) == 62)
    goto label_64;

DEFLABEL (label_63)
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_1]), 2);

DEFLABEL (label_64)
  (Wrd158.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd159.Obj) = ((Wrd158.pObj) [0]);
  (Wrd160.Lng) = (FIXNUM_TO_LONG (Wrd159.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd160.Lng))))
    goto label_63;
  (Wrd152.Obj) = ((Wrd158.pObj) [5]);
  Rsp = (& (Rsp [3]));
  (* (--Rsp)) = (Wrd152.Obj);
  goto label_59;

DEFLABEL (label_66)
  (Wrd149.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_17]))));
  (* (--Rsp)) = (Wrd149.Obj);
  (* (--Rsp)) = (Wrd128.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_8]), 1);

DEFLABEL (label_43)
  (* (--Rsp)) = Rvl;
  goto label_65;

DEFLABEL (label_68)
  (Wrd123.Obj) = (Rsp [7]);
  (Wrd124.Obj) = (current_block [OBJECT_46_7]);
  (Wrd127.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_16]))));
  (* (--Rsp)) = (Wrd127.Obj);
  (* (--Rsp)) = (Wrd124.Obj);
  (* (--Rsp)) = (Wrd123.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_3]), 2);

DEFLABEL (label_41)
  (* (--Rsp)) = Rvl;
  goto label_67;

DEFLABEL (label_70)
  (Wrd97.Obj) = (Rsp [5]);
  (Wrd98.Obj) = (current_block [OBJECT_46_6]);
  (Wrd101.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_14]))));
  (* (--Rsp)) = (Wrd101.Obj);
  (* (--Rsp)) = (Wrd98.Obj);
  (* (--Rsp)) = (Wrd97.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_3]), 2);

DEFLABEL (label_40)
  (Wrd86.Obj) = Rvl;
  goto label_69;

DEFLABEL (label_72)
  (Wrd74.Obj) = (Rsp [4]);
  (Wrd75.Obj) = (current_block [OBJECT_46_5]);
  (Wrd78.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_12]))));
  (* (--Rsp)) = (Wrd78.Obj);
  (* (--Rsp)) = (Wrd75.Obj);
  (* (--Rsp)) = (Wrd74.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_3]), 2);

DEFLABEL (label_39)
  (Wrd63.Obj) = Rvl;
  goto label_71;

DEFLABEL (label_74)
  (Wrd51.Obj) = (Rsp [3]);
  (Wrd52.Obj) = (current_block [OBJECT_46_0]);
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_10]))));
  (* (--Rsp)) = (Wrd55.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_3]), 2);

DEFLABEL (label_38)
  (Wrd40.Obj) = Rvl;
  goto label_73;

DEFLABEL (label_76)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.Obj) = (current_block [OBJECT_46_4]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_8]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_3]), 2);

DEFLABEL (label_37)
  (* (--Rsp)) = Rvl;
  goto label_75;

DEFLABEL (label_78)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_46_2]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_7]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_3]), 2);

DEFLABEL (label_36)
  (* (--Rsp)) = Rvl;
  goto label_77;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_46_6);
  (* (--Rsp)) = Rvl;
  goto label_59;

DEFLABEL (lambda_53)
DEFLABEL (lambda_15)
  INTERRUPT_CHECK (26, LABEL_46_11);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_46_4]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_80;

DEFLABEL (label_79)
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_3]), 2);

DEFLABEL (label_80)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd16.Lng))))
    goto label_79;
  Rvl = ((Wrd14.pObj) [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (lambda_54)
DEFLABEL (lambda_12)
  INTERRUPT_CHECK (26, LABEL_46_13);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_46_4]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 10)
    goto label_82;

DEFLABEL (label_81)
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_3]), 2);

DEFLABEL (label_82)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd16.Lng))))
    goto label_81;
  Rvl = ((Wrd14.pObj) [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (lambda_55)
DEFLABEL (lambda_9)
  INTERRUPT_CHECK (26, LABEL_46_15);
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (loop_56)
DEFLABEL (loop_31)
  INTERRUPT_CHECK (26, LABEL_46_23);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_98;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_97)
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd14.uLng) == 1)
    goto label_88;
  (Wrd15.Obj) = (Rsp [3]);
  if ((Wrd15.Obj) == ((SCHEME_OBJECT) 0))
    goto label_83;
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_22]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd23.Obj) = (Rsp [1]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 1))
    goto label_87;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [0]);
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_86)
  (Wrd29.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd29.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_28]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_46_22);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_83;
  Rvl = (current_block [OBJECT_46_9]);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_83)
  (Wrd30.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd30.Obj);
  (Wrd34.Obj) = (Rsp [0]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 1))
    goto label_85;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd31.Obj) = ((Wrd33.pObj) [0]);

DEFLABEL (label_84)
  (Rsp [3]) = (Wrd31.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_30]));

DEFLABEL (label_85)
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_29]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_8]), 1);

DEFLABEL (label_47)
  (Wrd31.Obj) = Rvl;
  goto label_84;

DEFLABEL (label_87)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_31]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_8]), 1);

DEFLABEL (label_46)
  (* (--Rsp)) = Rvl;
  goto label_86;

DEFLABEL (label_88)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_25]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_26]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd50.Obj) = (Rsp [2]);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd51.uLng) == 1))
    goto label_96;
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd49.Obj) = ((Wrd48.pObj) [0]);
  (* (--Rsp)) = (Wrd49.Obj);

DEFLABEL (label_95)
  (Wrd56.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd56.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_28]));

DEFLABEL (continuation_26)
  INTERRUPT_CHECK (27, LABEL_46_26);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_92;
  (Wrd5.Obj) = Rvl;
  Rsp = (& (Rsp [2]));

DEFLABEL (label_91)
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd10.uLng) == 1))
    goto label_90;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [1]);

DEFLABEL (label_89)
  (Rsp [0]) = (Wrd6.Obj);
  goto loop_31;

DEFLABEL (label_90)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_35]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_10]), 1);

DEFLABEL (label_49)
  (Wrd6.Obj) = Rvl;
  goto label_89;

DEFLABEL (label_92)
  (Wrd18.Obj) = (current_block [OBJECT_46_11]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_32]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd25.Obj) = (Rsp [4]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 1))
    goto label_94;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [1]);
  (* (--Rsp)) = (Wrd24.Obj);

DEFLABEL (label_93)
  (Wrd31.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd31.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_34]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_46_32);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_36]));

DEFLABEL (label_94)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_33]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_10]), 1);

DEFLABEL (label_50)
  (* (--Rsp)) = Rvl;
  goto label_93;

DEFLABEL (label_96)
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_27]))));
  (* (--Rsp)) = (Wrd55.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_8]), 1);

DEFLABEL (label_48)
  (* (--Rsp)) = Rvl;
  goto label_95;

DEFLABEL (label_98)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_24]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_10]), 1);

DEFLABEL (label_45)
  (Wrd5.Obj) = Rvl;
  goto label_97;

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_46_25);
  (Wrd5.Obj) = Rvl;
  goto label_91;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_47_4 3
#define LABEL_47_6 5
#define LABEL_47_5 7
#define LABEL_47_8 9
#define LABEL_47_9 11
#define LABEL_47_10 13
#define LABEL_47_11 15
#define LABEL_47_13 17
#define LABEL_47_14 19
#define LABEL_47_15 21
#define LABEL_47_16 23
#define LABEL_47_18 25
#define LABEL_47_19 27
#define LABEL_47_20 29
#define LABEL_47_21 31
#define LABEL_47_22 33
#define LABEL_47_24 35
#define LABEL_47_25 37
#define LABEL_47_26 39
#define LABEL_47_27 41
#define LABEL_47_29 43
#define LABEL_47_12 45
#define LABEL_47_17 47
#define LABEL_47_30 49
#define LABEL_47_23 51
#define LABEL_47_28 53
#define LABEL_47_31 55
#define LABEL_47_33 57
#define ENVIRONMENT_LABEL_47_3 73
#define DEBUGGING_LABEL_47_2 72
#define OBJECT_47_8 71
#define OBJECT_47_7 70
#define OBJECT_47_6 69
#define OBJECT_47_5 68
#define OBJECT_47_4 67
#define OBJECT_47_3 66
#define OBJECT_47_2 65
#define OBJECT_47_1 64
#define OBJECT_47_0 63
#define EXECUTE_CACHE_47_32 59
#define EXECUTE_CACHE_47_7 61
#define FREE_REFERENCES_LABEL_47_0 58
#define NUMBER_OF_LINKER_SECTIONS_47_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_47 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd84;
  machine_word Wrd83;
  machine_word Wrd80;
  machine_word Wrd79;
  machine_word Wrd82;
  machine_word Wrd65;
  machine_word Wrd53;
  machine_word Wrd61;
  machine_word Wrd62;
  machine_word Wrd104;
  machine_word Wrd101;
  machine_word Wrd100;
  machine_word Wrd97;
  machine_word Wrd95;
  machine_word Wrd98;
  machine_word Wrd40;
  machine_word Wrd43;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd36;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd30;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd115;
  machine_word Wrd112;
  machine_word Wrd111;
  machine_word Wrd102;
  machine_word Wrd108;
  machine_word Wrd107;
  machine_word Wrd106;
  machine_word Wrd110;
  machine_word Wrd109;
  machine_word Wrd99;
  machine_word Wrd96;
  machine_word Wrd93;
  machine_word Wrd92;
  machine_word Wrd81;
  machine_word Wrd89;
  machine_word Wrd88;
  machine_word Wrd87;
  machine_word Wrd91;
  machine_word Wrd90;
  machine_word Wrd132;
  machine_word Wrd129;
  machine_word Wrd128;
  machine_word Wrd117;
  machine_word Wrd125;
  machine_word Wrd124;
  machine_word Wrd123;
  machine_word Wrd127;
  machine_word Wrd126;
  machine_word Wrd78;
  machine_word Wrd68;
  machine_word Wrd72;
  machine_word Wrd71;
  machine_word Wrd74;
  machine_word Wrd73;
  machine_word Wrd67;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd44;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd52;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd42;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd10;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_47_4);
      goto create_links_from_description_44;

    case 1:
      current_block = (Rpc - LABEL_47_6);
      goto label_46;

    case 2:
      current_block = (Rpc - LABEL_47_5);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_47_8);
      goto label_47;

    case 4:
      current_block = (Rpc - LABEL_47_9);
      goto label_48;

    case 5:
      current_block = (Rpc - LABEL_47_10);
      goto continuation_13;

    case 6:
      current_block = (Rpc - LABEL_47_11);
      goto do_loop_18;

    case 7:
      current_block = (Rpc - LABEL_47_13);
      goto label_51;

    case 8:
      current_block = (Rpc - LABEL_47_14);
      goto label_52;

    case 9:
      current_block = (Rpc - LABEL_47_15);
      goto label_55;

    case 10:
      current_block = (Rpc - LABEL_47_16);
      goto label_53;

    case 11:
      current_block = (Rpc - LABEL_47_18);
      goto label_54;

    case 12:
      current_block = (Rpc - LABEL_47_19);
      goto label_49;

    case 13:
      current_block = (Rpc - LABEL_47_20);
      goto label_50;

    case 14:
      current_block = (Rpc - LABEL_47_21);
      goto continuation_32;

    case 15:
      current_block = (Rpc - LABEL_47_22);
      goto do_loop_39;

    case 16:
      current_block = (Rpc - LABEL_47_24);
      goto label_56;

    case 17:
      current_block = (Rpc - LABEL_47_25);
      goto label_57;

    case 18:
      current_block = (Rpc - LABEL_47_26);
      goto label_60;

    case 19:
      current_block = (Rpc - LABEL_47_27);
      goto label_58;

    case 20:
      current_block = (Rpc - LABEL_47_29);
      goto label_59;

    case 21:
      current_block = (Rpc - LABEL_47_12);
      goto continuation_8;

    case 22:
      current_block = (Rpc - LABEL_47_17);
      goto continuation_10;

    case 23:
      current_block = (Rpc - LABEL_47_30);
      goto label_61;

    case 24:
      current_block = (Rpc - LABEL_47_23);
      goto continuation_27;

    case 25:
      current_block = (Rpc - LABEL_47_28);
      goto continuation_29;

    case 26:
      current_block = (Rpc - LABEL_47_31);
      goto continuation_33;

    case 27:
      current_block = (Rpc - LABEL_47_33);
      goto label_62;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (create_links_from_description_64)
DEFLABEL (create_links_from_description_44)
  INTERRUPT_CHECK (26, LABEL_47_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_72;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd16.Lng))))
    goto label_72;
  (Wrd10.Obj) = ((Wrd14.pObj) [1]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_71)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_47_5);
  (* (--Rsp)) = Rvl;
  (Wrd14.Obj) = (Rsp [1]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_70;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd13.Lng))))
    goto label_70;
  (Wrd7.Obj) = ((Wrd11.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_69)
  (Wrd26.Obj) = (Rsp [0]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd27.uLng) == 10))
    goto label_68;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [0]);
  (Wrd25.Obj) = (MAKE_OBJECT (26, (Wrd24.uLng)));
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_67)
  (Wrd32.Obj) = (current_block [OBJECT_47_0]);
  (* (--Rsp)) = (Wrd32.Obj);
  goto do_loop_18;

DEFLABEL (label_68)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_9]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_3]), 1);

DEFLABEL (label_48)
  (* (--Rsp)) = Rvl;
  goto label_67;

DEFLABEL (label_70)
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.Obj) = (current_block [OBJECT_47_2]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_8]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_1]), 2);

DEFLABEL (label_47)
  (* (--Rsp)) = Rvl;
  goto label_69;

DEFLABEL (label_72)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_47_0]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_6]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_1]), 2);

DEFLABEL (label_46)
  (* (--Rsp)) = Rvl;
  goto label_71;

DEFLABEL (do_loop_65)
DEFLABEL (do_loop_18)
  INTERRUPT_CHECK (26, LABEL_47_11);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_74;
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  goto label_73;

DEFLABEL (label_74)
  (Wrd8.Obj) = (current_block [OBJECT_47_4]);
  (* (--Rsp)) = (Wrd8.Obj);

DEFLABEL (label_73)
DEFLABEL (label_94)
  (Wrd9.Obj) = (Rsp [0]);
  if ((Wrd9.Obj) == ((SCHEME_OBJECT) 0))
    goto label_79;
  Rsp = (& (Rsp [4]));
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 10))
    goto label_78;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd20.Lng))))
    goto label_78;
  (Wrd14.Obj) = ((Wrd18.pObj) [5]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_77)
  (Wrd33.Obj) = (Rsp [0]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 10))
    goto label_76;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Obj) = (MAKE_OBJECT (26, (Wrd31.uLng)));
  (* (--Rsp)) = (Wrd32.Obj);

DEFLABEL (label_75)
  (Wrd39.Obj) = (current_block [OBJECT_47_0]);
  (* (--Rsp)) = (Wrd39.Obj);
  goto do_loop_39;

DEFLABEL (label_76)
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_20]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_3]), 1);

DEFLABEL (label_50)
  (* (--Rsp)) = Rvl;
  goto label_75;

DEFLABEL (label_78)
  (Wrd23.Obj) = (Rsp [1]);
  (Wrd24.Obj) = (current_block [OBJECT_47_7]);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_19]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_1]), 2);

DEFLABEL (label_49)
  (* (--Rsp)) = Rvl;
  goto label_77;

DEFLABEL (label_79)
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_12]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (Wrd57.Obj) = (Rsp [4]);
  (Wrd58.uLng) = (OBJECT_TYPE (Wrd57.Obj));
  if (! ((Wrd58.uLng) == 10))
    goto label_93;
  (Wrd49.Obj) = (Rsp [2]);
  (Wrd50.uLng) = (OBJECT_TYPE (Wrd49.Obj));
  if (! ((Wrd50.uLng) == 26))
    goto label_93;
  (Wrd52.Lng) = (FIXNUM_TO_LONG (Wrd49.Obj));
  (Wrd54.pObj) = (OBJECT_ADDRESS (Wrd57.Obj));
  (Wrd55.Obj) = ((Wrd54.pObj) [0]);
  (Wrd56.Lng) = (FIXNUM_TO_LONG (Wrd55.Obj));
  if (! (((unsigned long) (Wrd52.Lng)) < ((unsigned long) (Wrd56.Lng))))
    goto label_93;
  (Wrd44.uLng) = (OBJECT_DATUM (Wrd49.Obj));
  (Wrd47.pObj) = (& ((Wrd54.pObj) [(Wrd44.Lng)]));
  (Wrd48.Obj) = ((Wrd47.pObj) [1]);
  (* (--Rsp)) = (Wrd48.Obj);

DEFLABEL (label_92)
  (Wrd64.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd64.Obj);
  (Wrd67.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_10]))));
  (* (--Rsp)) = (Wrd67.Obj);
  (Wrd73.Obj) = (Rsp [2]);
  (Wrd74.uLng) = (OBJECT_TYPE (Wrd73.Obj));
  if (! ((Wrd74.uLng) == 10))
    goto label_91;
  (Wrd71.pObj) = (OBJECT_ADDRESS (Wrd73.Obj));
  (Wrd72.Obj) = ((Wrd71.pObj) [0]);
  (Wrd68.Obj) = (MAKE_OBJECT (26, (Wrd72.uLng)));

DEFLABEL (label_90)
  if ((Wrd68.Obj) == (current_block [OBJECT_47_2]))
    goto label_87;
  (Wrd90.Obj) = (Rsp [2]);
  (Wrd91.uLng) = (OBJECT_TYPE (Wrd90.Obj));
  if (! ((Wrd91.uLng) == 10))
    goto label_86;
  (Wrd87.pObj) = (OBJECT_ADDRESS (Wrd90.Obj));
  (Wrd88.Obj) = ((Wrd87.pObj) [0]);
  (Wrd89.Lng) = (FIXNUM_TO_LONG (Wrd88.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd89.Lng))))
    goto label_86;
  (Wrd81.Obj) = ((Wrd87.pObj) [1]);

DEFLABEL (label_85)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd81.Obj);

DEFLABEL (label_84)
  (Wrd99.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_17]))));
  (* (--Rsp)) = (Wrd99.Obj);
  (Wrd109.Obj) = (Rsp [3]);
  (Wrd110.uLng) = (OBJECT_TYPE (Wrd109.Obj));
  if (! ((Wrd110.uLng) == 10))
    goto label_83;
  (Wrd106.pObj) = (OBJECT_ADDRESS (Wrd109.Obj));
  (Wrd107.Obj) = ((Wrd106.pObj) [0]);
  (Wrd108.Lng) = (FIXNUM_TO_LONG (Wrd107.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd108.Lng))))
    goto label_83;
  (Wrd102.Obj) = ((Wrd106.pObj) [2]);
  (* (--Rsp)) = (Wrd102.Obj);

DEFLABEL (label_82)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_7]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_47_17);
  (* (--Rsp)) = Rvl;
  (Wrd14.Obj) = (Rsp [3]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_81;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd13.Lng))))
    goto label_81;
  (Wrd5.Obj) = ((Wrd11.pObj) [1]);

DEFLABEL (label_80)
  (Rsp [3]) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_8]), 4);

DEFLABEL (label_81)
  (Wrd16.Obj) = (Rsp [3]);
  (Wrd17.Obj) = (current_block [OBJECT_47_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_30]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_1]), 2);

DEFLABEL (label_61)
  (Wrd5.Obj) = Rvl;
  goto label_80;

DEFLABEL (label_83)
  (Wrd111.Obj) = (Rsp [3]);
  (Wrd112.Obj) = (current_block [OBJECT_47_6]);
  (Wrd115.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_18]))));
  (* (--Rsp)) = (Wrd115.Obj);
  (* (--Rsp)) = (Wrd112.Obj);
  (* (--Rsp)) = (Wrd111.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_1]), 2);

DEFLABEL (label_54)
  (* (--Rsp)) = Rvl;
  goto label_82;

DEFLABEL (label_86)
  (Wrd92.Obj) = (Rsp [2]);
  (Wrd93.Obj) = (current_block [OBJECT_47_0]);
  (Wrd96.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_16]))));
  (* (--Rsp)) = (Wrd96.Obj);
  (* (--Rsp)) = (Wrd93.Obj);
  (* (--Rsp)) = (Wrd92.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_1]), 2);

DEFLABEL (label_53)
  (Wrd81.Obj) = Rvl;
  goto label_85;

DEFLABEL (label_87)
  (Wrd126.Obj) = (Rsp [2]);
  (Wrd127.uLng) = (OBJECT_TYPE (Wrd126.Obj));
  if (! ((Wrd127.uLng) == 10))
    goto label_89;
  (Wrd123.pObj) = (OBJECT_ADDRESS (Wrd126.Obj));
  (Wrd124.Obj) = ((Wrd123.pObj) [0]);
  (Wrd125.Lng) = (FIXNUM_TO_LONG (Wrd124.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd125.Lng))))
    goto label_89;
  (Wrd117.Obj) = ((Wrd123.pObj) [3]);

DEFLABEL (label_88)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd117.Obj);
  goto label_84;

DEFLABEL (label_89)
  (Wrd128.Obj) = (Rsp [2]);
  (Wrd129.Obj) = (current_block [OBJECT_47_5]);
  (Wrd132.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_15]))));
  (* (--Rsp)) = (Wrd132.Obj);
  (* (--Rsp)) = (Wrd129.Obj);
  (* (--Rsp)) = (Wrd128.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_1]), 2);

DEFLABEL (label_55)
  (Wrd117.Obj) = Rvl;
  goto label_88;

DEFLABEL (label_91)
  (Wrd78.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_14]))));
  (* (--Rsp)) = (Wrd78.Obj);
  (* (--Rsp)) = (Wrd73.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_3]), 1);

DEFLABEL (label_52)
  (Wrd68.Obj) = Rvl;
  goto label_90;

DEFLABEL (label_93)
  (Wrd59.Obj) = (Rsp [4]);
  (Wrd60.Obj) = (Rsp [2]);
  (Wrd63.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_13]))));
  (* (--Rsp)) = (Wrd63.Obj);
  (* (--Rsp)) = (Wrd60.Obj);
  (* (--Rsp)) = (Wrd59.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_1]), 2);

DEFLABEL (label_51)
  (* (--Rsp)) = Rvl;
  goto label_92;

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_47_10);
  (* (--Rsp)) = Rvl;
  goto label_84;

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_47_12);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.Lng) = (FIXNUM_TO_LONG (Wrd6.Obj));
  (Wrd8.Lng) = ((Wrd7.Lng) + 1L);
  (Wrd5.Obj) = (LONG_TO_FIXNUM (Wrd8.Lng));
  (Rsp [1]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  goto do_loop_18;

DEFLABEL (do_loop_66)
DEFLABEL (do_loop_39)
  INTERRUPT_CHECK (26, LABEL_47_22);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_96;
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  goto label_95;

DEFLABEL (label_96)
  (Wrd8.Obj) = (current_block [OBJECT_47_4]);
  (* (--Rsp)) = (Wrd8.Obj);

DEFLABEL (label_95)
DEFLABEL (label_112)
  (Wrd9.Obj) = (Rsp [0]);
  if ((Wrd9.Obj) == ((SCHEME_OBJECT) 0))
    goto label_97;
  Rvl = (Wrd9.Obj);
  Rsp = (& (Rsp [6]));
  goto pop_return;

DEFLABEL (label_97)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_23]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd30.Obj) = (Rsp [4]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_111;
  (Wrd22.Obj) = (Rsp [2]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd23.uLng) == 26))
    goto label_111;
  (Wrd25.Lng) = (FIXNUM_TO_LONG (Wrd22.Obj));
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) (Wrd25.Lng)) < ((unsigned long) (Wrd29.Lng))))
    goto label_111;
  (Wrd17.uLng) = (OBJECT_DATUM (Wrd22.Obj));
  (Wrd20.pObj) = (& ((Wrd27.pObj) [(Wrd17.Lng)]));
  (Wrd21.Obj) = ((Wrd20.pObj) [1]);
  (* (--Rsp)) = (Wrd21.Obj);

DEFLABEL (label_110)
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_21]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd45.Obj) = (Rsp [1]);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd45.Obj));
  if (! ((Wrd46.uLng) == 10))
    goto label_109;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [0]);
  (Wrd40.Obj) = (MAKE_OBJECT (26, (Wrd44.uLng)));

DEFLABEL (label_108)
  if ((Wrd40.Obj) == (current_block [OBJECT_47_2]))
    goto label_105;
  (Wrd62.Obj) = (Rsp [1]);
  (Wrd63.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if (! ((Wrd63.uLng) == 10))
    goto label_104;
  (Wrd59.pObj) = (OBJECT_ADDRESS (Wrd62.Obj));
  (Wrd60.Obj) = ((Wrd59.pObj) [0]);
  (Wrd61.Lng) = (FIXNUM_TO_LONG (Wrd60.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd61.Lng))))
    goto label_104;
  (Wrd53.Obj) = ((Wrd59.pObj) [1]);

DEFLABEL (label_103)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd53.Obj);

DEFLABEL (label_102)
  (Wrd71.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_28]))));
  (* (--Rsp)) = (Wrd71.Obj);
  (Wrd81.Obj) = (Rsp [2]);
  (Wrd82.uLng) = (OBJECT_TYPE (Wrd81.Obj));
  if (! ((Wrd82.uLng) == 10))
    goto label_101;
  (Wrd78.pObj) = (OBJECT_ADDRESS (Wrd81.Obj));
  (Wrd79.Obj) = ((Wrd78.pObj) [0]);
  (Wrd80.Lng) = (FIXNUM_TO_LONG (Wrd79.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd80.Lng))))
    goto label_101;
  (Wrd74.Obj) = ((Wrd78.pObj) [2]);
  (* (--Rsp)) = (Wrd74.Obj);

DEFLABEL (label_100)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_7]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_47_28);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_31]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_32]));

DEFLABEL (continuation_33)
  INTERRUPT_CHECK (27, LABEL_47_31);
  (Wrd5.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 10))
    goto label_99;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd14.Lng))))
    goto label_99;
  (Wrd6.Obj) = ((Wrd12.pObj) [1]);

DEFLABEL (label_98)
  (Wrd22.Obj) = (Rsp [2]);
  (Rsp [3]) = (Wrd22.Obj);
  (Wrd23.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd23.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_8]), 4);

DEFLABEL (label_99)
  (Wrd17.Obj) = (Rsp [3]);
  (Wrd18.Obj) = (current_block [OBJECT_47_0]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_33]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_1]), 2);

DEFLABEL (label_62)
  (Wrd6.Obj) = Rvl;
  goto label_98;

DEFLABEL (label_101)
  (Wrd83.Obj) = (Rsp [2]);
  (Wrd84.Obj) = (current_block [OBJECT_47_6]);
  (Wrd87.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_29]))));
  (* (--Rsp)) = (Wrd87.Obj);
  (* (--Rsp)) = (Wrd84.Obj);
  (* (--Rsp)) = (Wrd83.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_1]), 2);

DEFLABEL (label_59)
  (* (--Rsp)) = Rvl;
  goto label_100;

DEFLABEL (label_104)
  (Wrd64.Obj) = (Rsp [1]);
  (Wrd65.Obj) = (current_block [OBJECT_47_0]);
  (Wrd68.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_27]))));
  (* (--Rsp)) = (Wrd68.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  (* (--Rsp)) = (Wrd64.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_1]), 2);

DEFLABEL (label_58)
  (Wrd53.Obj) = Rvl;
  goto label_103;

DEFLABEL (label_105)
  (Wrd98.Obj) = (Rsp [1]);
  (Wrd99.uLng) = (OBJECT_TYPE (Wrd98.Obj));
  if (! ((Wrd99.uLng) == 10))
    goto label_107;
  (Wrd95.pObj) = (OBJECT_ADDRESS (Wrd98.Obj));
  (Wrd96.Obj) = ((Wrd95.pObj) [0]);
  (Wrd97.Lng) = (FIXNUM_TO_LONG (Wrd96.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd97.Lng))))
    goto label_107;
  (Wrd89.Obj) = ((Wrd95.pObj) [3]);

DEFLABEL (label_106)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd89.Obj);
  goto label_102;

DEFLABEL (label_107)
  (Wrd100.Obj) = (Rsp [1]);
  (Wrd101.Obj) = (current_block [OBJECT_47_5]);
  (Wrd104.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_26]))));
  (* (--Rsp)) = (Wrd104.Obj);
  (* (--Rsp)) = (Wrd101.Obj);
  (* (--Rsp)) = (Wrd100.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_1]), 2);

DEFLABEL (label_60)
  (Wrd89.Obj) = Rvl;
  goto label_106;

DEFLABEL (label_109)
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_25]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_3]), 1);

DEFLABEL (label_57)
  (Wrd40.Obj) = Rvl;
  goto label_108;

DEFLABEL (label_111)
  (Wrd32.Obj) = (Rsp [4]);
  (Wrd33.Obj) = (Rsp [2]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_24]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_1]), 2);

DEFLABEL (label_56)
  (* (--Rsp)) = Rvl;
  goto label_110;

DEFLABEL (continuation_32)
  INTERRUPT_CHECK (27, LABEL_47_21);
  (* (--Rsp)) = Rvl;
  goto label_102;

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_47_23);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.Lng) = (FIXNUM_TO_LONG (Wrd6.Obj));
  (Wrd8.Lng) = ((Wrd7.Lng) + 1L);
  (Wrd5.Obj) = (LONG_TO_FIXNUM (Wrd8.Lng));
  (Rsp [1]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  goto do_loop_39;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_48_4 3
#define LABEL_48_5 5
#define LABEL_48_6 7
#define LABEL_48_7 9
#define LABEL_48_8 11
#define LABEL_48_9 13
#define LABEL_48_10 15
#define LABEL_48_11 17
#define LABEL_48_12 19
#define LABEL_48_13 21
#define LABEL_48_14 23
#define LABEL_48_15 25
#define LABEL_48_16 27
#define LABEL_48_17 29
#define LABEL_48_18 31
#define LABEL_48_19 33
#define LABEL_48_20 35
#define LABEL_48_22 37
#define LABEL_48_21 39
#define LABEL_48_23 41
#define LABEL_48_25 43
#define LABEL_48_26 45
#define LABEL_48_24 47
#define LABEL_48_27 49
#define ENVIRONMENT_LABEL_48_3 67
#define DEBUGGING_LABEL_48_2 66
#define OBJECT_48_15 65
#define OBJECT_48_14 64
#define OBJECT_48_13 63
#define OBJECT_48_12 62
#define OBJECT_48_11 61
#define OBJECT_48_10 60
#define OBJECT_48_9 59
#define OBJECT_48_8 58
#define OBJECT_48_7 57
#define OBJECT_48_6 56
#define OBJECT_48_5 55
#define OBJECT_48_4 54
#define OBJECT_48_3 53
#define OBJECT_48_2 52
#define OBJECT_48_1 51
#define OBJECT_48_0 50
#define FREE_REFERENCES_LABEL_48_0 50
#define NUMBER_OF_LINKER_SECTIONS_48_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_48 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd13;
  machine_word Wrd36;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd15;
  machine_word Wrd31;
  machine_word Wrd20;
  machine_word Wrd26;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd79;
  machine_word Wrd78;
  machine_word Wrd77;
  machine_word Wrd71;
  machine_word Wrd70;
  machine_word Wrd69;
  machine_word Wrd73;
  machine_word Wrd72;
  machine_word Wrd66;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd62;
  machine_word Wrd59;
  machine_word Wrd51;
  machine_word Wrd53;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd50;
  machine_word Wrd45;
  machine_word Wrd35;
  machine_word Wrd37;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd52;
  machine_word Wrd44;
  machine_word Wrd46;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd39;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd38;
  machine_word Wrd30;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd34;
  machine_word Wrd29;
  machine_word Wrd23;
  machine_word Wrd24;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd14;
  machine_word Wrd16;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_48_4);
      goto extend_package_environment_41;

    case 1:
      current_block = (Rpc - LABEL_48_5);
      goto loop_8;

    case 2:
      current_block = (Rpc - LABEL_48_6);
      goto label_43;

    case 3:
      current_block = (Rpc - LABEL_48_7);
      goto label_44;

    case 4:
      current_block = (Rpc - LABEL_48_8);
      goto label_45;

    case 5:
      current_block = (Rpc - LABEL_48_9);
      goto label_46;

    case 6:
      current_block = (Rpc - LABEL_48_10);
      goto continuation_10;

    case 7:
      current_block = (Rpc - LABEL_48_11);
      goto continuation_12;

    case 8:
      current_block = (Rpc - LABEL_48_12);
      goto continuation_11;

    case 9:
      current_block = (Rpc - LABEL_48_13);
      goto loop_33;

    case 10:
      current_block = (Rpc - LABEL_48_14);
      goto label_48;

    case 11:
      current_block = (Rpc - LABEL_48_15);
      goto label_49;

    case 12:
      current_block = (Rpc - LABEL_48_16);
      goto label_50;

    case 13:
      current_block = (Rpc - LABEL_48_17);
      goto label_51;

    case 14:
      current_block = (Rpc - LABEL_48_18);
      goto label_52;

    case 15:
      current_block = (Rpc - LABEL_48_19);
      goto label_47;

    case 16:
      current_block = (Rpc - LABEL_48_20);
      goto continuation_37;

    case 17:
      current_block = (Rpc - LABEL_48_22);
      goto label_53;

    case 18:
      current_block = (Rpc - LABEL_48_21);
      goto continuation_36;

    case 19:
      current_block = (Rpc - LABEL_48_23);
      goto do_source_29;

    case 20:
      current_block = (Rpc - LABEL_48_25);
      goto label_55;

    case 21:
      current_block = (Rpc - LABEL_48_26);
      goto label_54;

    case 22:
      current_block = (Rpc - LABEL_48_24);
      goto continuation_25;

    case 23:
      current_block = (Rpc - LABEL_48_27);
      goto label_56;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (extend_package_environment_58)
DEFLABEL (extend_package_environment_41)
  INTERRUPT_CHECK (26, LABEL_48_4);
  (Wrd5.Obj) = (current_block [OBJECT_48_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd6.Obj);
  goto loop_8;

DEFLABEL (loop_59)
DEFLABEL (loop_8)
  INTERRUPT_CHECK (26, LABEL_48_5);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_62;
  (Wrd8.Obj) = (Rsp [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_10]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_4]), 2);

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_48_10);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_11]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_12]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_48_5]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_48_6]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_7]), 2);

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_48_12);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_4]), 2);

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_48_11);
  (Rsp [1]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_48_0]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd7.Obj);
  goto loop_33;

DEFLABEL (label_62)
  if (! ((Wrd6.uLng) == 1))
    goto label_70;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [0]);

DEFLABEL (label_69)
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd25.uLng) == 1))
    goto label_68;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd23.Obj) = ((Wrd24.pObj) [0]);

DEFLABEL (label_67)
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd34.uLng) == 10))
    goto label_66;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [0]);
  (Wrd30.Obj) = (MAKE_OBJECT (26, (Wrd33.uLng)));

DEFLABEL (label_65)
  (Wrd40.Obj) = (Rsp [1]);
  (Wrd41.Lng) = (FIXNUM_TO_LONG (Wrd40.Obj));
  (Wrd42.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  (Wrd43.Lng) = ((Wrd41.Lng) + (Wrd42.Lng));
  (Wrd39.Obj) = (LONG_TO_FIXNUM (Wrd43.Lng));
  (Rsp [1]) = (Wrd39.Obj);
  (Wrd47.Obj) = (Rsp [0]);
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd47.Obj));
  if (! ((Wrd48.uLng) == 1))
    goto label_64;
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  (Wrd44.Obj) = ((Wrd46.pObj) [1]);

DEFLABEL (label_63)
  (Rsp [0]) = (Wrd44.Obj);
  goto loop_8;

DEFLABEL (label_64)
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_9]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_3]), 1);

DEFLABEL (label_46)
  (Wrd44.Obj) = Rvl;
  goto label_63;

DEFLABEL (label_66)
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_8]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_2]), 1);

DEFLABEL (label_45)
  (Wrd30.Obj) = Rvl;
  goto label_65;

DEFLABEL (label_68)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_7]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_1]), 1);

DEFLABEL (label_44)
  (Wrd23.Obj) = Rvl;
  goto label_67;

DEFLABEL (label_70)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_6]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_1]), 1);

DEFLABEL (label_43)
  (Wrd14.Obj) = Rvl;
  goto label_69;

DEFLABEL (loop_60)
DEFLABEL (loop_33)
  INTERRUPT_CHECK (26, LABEL_48_13);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_75;
  Rsp = (& (Rsp [2]));
  (Wrd27.Obj) = (Rsp [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd28.uLng) == 10))
    goto label_74;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [0]);
  (Wrd26.Lng) = (FIXNUM_TO_LONG (Wrd25.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd26.Lng))))
    goto label_74;
  (Wrd20.Obj) = (current_block [OBJECT_48_8]);
  ((Wrd24.pObj) [1]) = (Wrd20.Obj);

DEFLABEL (label_73)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_20]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_21]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd17.Obj) = (current_block [OBJECT_48_10]);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_11]), 3);

DEFLABEL (continuation_36)
  INTERRUPT_CHECK (27, LABEL_48_21);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_48_14]);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_11]), 3);

DEFLABEL (continuation_37)
  INTERRUPT_CHECK (27, LABEL_48_20);
  (Wrd5.Obj) = Rvl;
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_72;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd16.Lng))))
    goto label_72;
  ((Wrd14.pObj) [1]) = Rvl;

DEFLABEL (label_71)
  (Wrd6.Obj) = (current_block [OBJECT_48_12]);
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [1]);
  (Rsp [3]) = (Wrd7.Obj);
  Rsp = (& (Rsp [2]));
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_13]), 2);

DEFLABEL (label_72)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_48_5]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_22]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_9]), 3);

DEFLABEL (label_53)
  goto label_71;

DEFLABEL (label_74)
  (Wrd29.Obj) = (Rsp [0]);
  (Wrd30.Obj) = (current_block [OBJECT_48_5]);
  (Wrd31.Obj) = (current_block [OBJECT_48_8]);
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_19]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_9]), 3);

DEFLABEL (label_47)
  goto label_73;

DEFLABEL (label_75)
  if (! ((Wrd6.uLng) == 1))
    goto label_85;
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd35.Obj) = ((Wrd37.pObj) [0]);

DEFLABEL (label_84)
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd46.uLng) == 1))
    goto label_83;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd45.Obj) = ((Wrd44.pObj) [1]);
  (* (--Rsp)) = (Wrd45.Obj);

DEFLABEL (label_82)
  (Wrd54.Obj) = (Rsp [1]);
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if (! ((Wrd55.uLng) == 1))
    goto label_81;
  (Wrd53.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd51.Obj) = ((Wrd53.pObj) [0]);

DEFLABEL (label_80)
  (Wrd62.uLng) = (OBJECT_TYPE (Wrd51.Obj));
  if (! ((Wrd62.uLng) == 1))
    goto label_79;
  (Wrd60.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd61.Obj) = ((Wrd60.pObj) [0]);
  (* (--Rsp)) = (Wrd61.Obj);

DEFLABEL (label_78)
  (Wrd72.Obj) = (Rsp [0]);
  (Wrd73.uLng) = (OBJECT_TYPE (Wrd72.Obj));
  if (! ((Wrd73.uLng) == 10))
    goto label_77;
  (Wrd69.pObj) = (OBJECT_ADDRESS (Wrd72.Obj));
  (Wrd70.Obj) = ((Wrd69.pObj) [0]);
  (Wrd71.Obj) = (MAKE_OBJECT (26, (Wrd70.uLng)));
  (* (--Rsp)) = (Wrd71.Obj);

DEFLABEL (label_76)
  (Wrd78.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd78.Obj);
  (Wrd79.Obj) = (current_block [OBJECT_48_5]);
  (* (--Rsp)) = (Wrd79.Obj);
  goto do_source_29;

DEFLABEL (label_77)
  (Wrd77.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_18]))));
  (* (--Rsp)) = (Wrd77.Obj);
  (* (--Rsp)) = (Wrd72.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_2]), 1);

DEFLABEL (label_52)
  (* (--Rsp)) = Rvl;
  goto label_76;

DEFLABEL (label_79)
  (Wrd66.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_17]))));
  (* (--Rsp)) = (Wrd66.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_1]), 1);

DEFLABEL (label_51)
  (* (--Rsp)) = Rvl;
  goto label_78;

DEFLABEL (label_81)
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_16]))));
  (* (--Rsp)) = (Wrd59.Obj);
  (* (--Rsp)) = (Wrd54.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_1]), 1);

DEFLABEL (label_50)
  (Wrd51.Obj) = Rvl;
  goto label_80;

DEFLABEL (label_83)
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_15]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_3]), 1);

DEFLABEL (label_49)
  (* (--Rsp)) = Rvl;
  goto label_82;

DEFLABEL (label_85)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_14]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_1]), 1);

DEFLABEL (label_48)
  (Wrd35.Obj) = Rvl;
  goto label_84;

DEFLABEL (do_source_61)
DEFLABEL (do_source_29)
  INTERRUPT_CHECK (26, LABEL_48_23);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  (Wrd7.Obj) = (Rsp [2]);
  (Wrd8.Lng) = (FIXNUM_TO_LONG (Wrd7.Obj));
  if ((Wrd6.Lng) < (Wrd8.Lng))
    goto label_88;
  (Wrd12.Obj) = (Rsp [5]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_87;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [1]);

DEFLABEL (label_86)
  (Rsp [5]) = (Wrd9.Obj);
  (Wrd18.Obj) = (Rsp [1]);
  (Rsp [6]) = (Wrd18.Obj);
  Rsp = (& (Rsp [5]));
  goto loop_33;

DEFLABEL (label_87)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_26]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_3]), 1);

DEFLABEL (label_54)
  (Wrd9.Obj) = Rvl;
  goto label_86;

DEFLABEL (label_88)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_24]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd37.Obj) = (Rsp [4]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd38.uLng) == 10))
    goto label_92;
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd30.uLng) == 26))
    goto label_92;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [0]);
  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd35.Obj));
  if (! (((unsigned long) (Wrd6.Lng)) < ((unsigned long) (Wrd36.Lng))))
    goto label_92;
  (Wrd24.uLng) = (OBJECT_DATUM (Wrd5.Obj));
  (Wrd27.pObj) = (& ((Wrd34.pObj) [(Wrd24.Lng)]));
  (Wrd28.Obj) = ((Wrd27.pObj) [1]);
  (* (--Rsp)) = (Wrd28.Obj);

DEFLABEL (label_91)
  (Wrd44.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd44.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_48_24);
  (Wrd5.Obj) = Rvl;
  (Wrd27.Obj) = (Rsp [7]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd28.uLng) == 10))
    goto label_90;
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 26))
    goto label_90;
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [0]);
  (Wrd26.Lng) = (FIXNUM_TO_LONG (Wrd25.Obj));
  if (! (((unsigned long) (Wrd22.Lng)) < ((unsigned long) (Wrd26.Lng))))
    goto label_90;
  (Wrd15.uLng) = (OBJECT_DATUM (Wrd19.Obj));
  (Wrd18.pObj) = (& ((Wrd24.pObj) [(Wrd15.Lng)]));
  ((Wrd18.pObj) [1]) = Rvl;

DEFLABEL (label_89)
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.Lng) = (FIXNUM_TO_LONG (Wrd7.Obj));
  (Wrd9.Lng) = ((Wrd8.Lng) + 1L);
  (Wrd6.Obj) = (LONG_TO_FIXNUM (Wrd9.Lng));
  (Rsp [0]) = (Wrd6.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd12.Lng) = (FIXNUM_TO_LONG (Wrd11.Obj));
  (Wrd13.Lng) = ((Wrd12.Lng) + 1L);
  (Wrd10.Obj) = (LONG_TO_FIXNUM (Wrd13.Lng));
  (Rsp [1]) = (Wrd10.Obj);
  goto do_source_29;

DEFLABEL (label_90)
  (Wrd29.Obj) = (Rsp [7]);
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_27]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_9]), 3);

DEFLABEL (label_56)
  goto label_89;

DEFLABEL (label_92)
  (Wrd39.Obj) = (Rsp [4]);
  (Wrd40.Obj) = (Rsp [1]);
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48_25]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_15]), 2);

DEFLABEL (label_55)
  (* (--Rsp)) = Rvl;
  goto label_91;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_49_4 3
#define LABEL_49_5 5
#define ENVIRONMENT_LABEL_49_3 12
#define DEBUGGING_LABEL_49_2 11
#define OBJECT_49_1 10
#define OBJECT_49_0 9
#define EXECUTE_CACHE_49_6 7
#define FREE_REFERENCES_LABEL_49_0 6
#define NUMBER_OF_LINKER_SECTIONS_49_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_49 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_49_4);
      goto find_package_environment_1;

    case 1:
      current_block = (Rpc - LABEL_49_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (find_package_environment_4)
DEFLABEL (find_package_environment_1)
  INTERRUPT_CHECK (26, LABEL_49_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_49_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_49_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_49_0]);
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd17.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd17.uLng) == 62)
    goto label_6;

DEFLABEL (label_5)
  INVOKE_PRIMITIVE ((current_block [OBJECT_49_1]), 2);

DEFLABEL (label_6)
  (Wrd13.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd15.Lng))))
    goto label_5;
  Rvl = ((Wrd13.pObj) [5]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_50_4 3
#define LABEL_50_5 5
#define LABEL_50_6 7
#define ENVIRONMENT_LABEL_50_3 15
#define DEBUGGING_LABEL_50_2 14
#define OBJECT_50_5 13
#define OBJECT_50_4 12
#define OBJECT_50_3 11
#define OBJECT_50_2 10
#define OBJECT_50_1 9
#define OBJECT_50_0 8
#define FREE_REFERENCES_LABEL_50_0 8
#define NUMBER_OF_LINKER_SECTIONS_50_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_50 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_50_4);
      goto guarantee_binding_2;

    case 1:
      current_block = (Rpc - LABEL_50_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_50_6);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_binding_5)
DEFLABEL (guarantee_binding_2)
  INTERRUPT_CHECK (26, LABEL_50_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_50_0]), 2);

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_50_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_6;
  Rvl = (current_block [OBJECT_50_1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_6)
  (Wrd7.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50_6]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_50_2]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_50_3]);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_50_4]), 2);

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_50_6);
  (Rsp [2]) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_50_5]), 3);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_51_4 3
#define ENVIRONMENT_LABEL_51_3 8
#define DEBUGGING_LABEL_51_2 7
#define OBJECT_51_2 6
#define OBJECT_51_1 5
#define OBJECT_51_0 4
#define FREE_REFERENCES_LABEL_51_0 4
#define NUMBER_OF_LINKER_SECTIONS_51_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_51 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_51_4);
      goto make_unmapped_unassigned_reference_trap_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_unmapped_unassigned_reference_trap_3)
DEFLABEL (make_unmapped_unassigned_reference_trap_0)
  INTERRUPT_CHECK (26, LABEL_51_4);
  (Wrd5.Obj) = (current_block [OBJECT_51_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_51_1]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_2]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_52_4 3
#define LABEL_52_5 5
#define LABEL_52_6 7
#define LABEL_52_7 9
#define LABEL_52_9 11
#define LABEL_52_11 13
#define LABEL_52_8 15
#define LABEL_52_10 17
#define ENVIRONMENT_LABEL_52_3 29
#define DEBUGGING_LABEL_52_2 28
#define OBJECT_52_4 27
#define OBJECT_52_3 26
#define OBJECT_52_2 25
#define OBJECT_52_1 24
#define OBJECT_52_0 23
#define EXECUTE_CACHE_52_13 19
#define EXECUTE_CACHE_52_12 21
#define FREE_REFERENCES_LABEL_52_0 18
#define NUMBER_OF_LINKER_SECTIONS_52_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_52 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd57;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd44;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd52;
  machine_word Wrd41;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd21;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd22;
  machine_word Wrd30;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_52_4);
      goto load_packages_from_file_15;

    case 1:
      current_block = (Rpc - LABEL_52_5);
      goto label_17;

    case 2:
      current_block = (Rpc - LABEL_52_6);
      goto label_18;

    case 3:
      current_block = (Rpc - LABEL_52_7);
      goto do_loop_11;

    case 4:
      current_block = (Rpc - LABEL_52_9);
      goto label_19;

    case 5:
      current_block = (Rpc - LABEL_52_11);
      goto label_20;

    case 6:
      current_block = (Rpc - LABEL_52_8);
      goto continuation_5;

    case 7:
      current_block = (Rpc - LABEL_52_10);
      goto continuation_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (load_packages_from_file_22)
DEFLABEL (load_packages_from_file_15)
  INTERRUPT_CHECK (26, LABEL_52_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_27;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd13.Lng))))
    goto label_27;
  (Wrd7.Obj) = ((Wrd11.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_26)
  (Wrd26.Obj) = (Rsp [0]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd27.uLng) == 10))
    goto label_25;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [0]);
  (Wrd25.Obj) = (MAKE_OBJECT (26, (Wrd24.uLng)));
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_24)
  (Wrd32.Obj) = (current_block [OBJECT_52_3]);
  (* (--Rsp)) = (Wrd32.Obj);
  goto do_loop_11;

DEFLABEL (label_25)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_6]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_52_2]), 1);

DEFLABEL (label_18)
  (* (--Rsp)) = Rvl;
  goto label_24;

DEFLABEL (label_27)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_52_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_52_1]), 2);

DEFLABEL (label_17)
  (* (--Rsp)) = Rvl;
  goto label_26;

DEFLABEL (do_loop_23)
DEFLABEL (do_loop_11)
  INTERRUPT_CHECK (26, LABEL_52_7);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_29;
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  goto label_28;

DEFLABEL (label_29)
  (Wrd8.Obj) = (current_block [OBJECT_52_4]);
  (* (--Rsp)) = (Wrd8.Obj);

DEFLABEL (label_28)
DEFLABEL (label_35)
  (Wrd9.Obj) = (Rsp [0]);
  if ((Wrd9.Obj) == ((SCHEME_OBJECT) 0))
    goto label_30;
  Rvl = (Wrd9.Obj);
  Rsp = (& (Rsp [7]));
  goto pop_return;

DEFLABEL (label_30)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_8]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd30.Obj) = (Rsp [4]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_34;
  (Wrd22.Obj) = (Rsp [2]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd23.uLng) == 26))
    goto label_34;
  (Wrd25.Lng) = (FIXNUM_TO_LONG (Wrd22.Obj));
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) (Wrd25.Lng)) < ((unsigned long) (Wrd29.Lng))))
    goto label_34;
  (Wrd17.uLng) = (OBJECT_DATUM (Wrd22.Obj));
  (Wrd20.pObj) = (& ((Wrd27.pObj) [(Wrd17.Lng)]));
  (Wrd21.Obj) = ((Wrd20.pObj) [1]);
  (* (--Rsp)) = (Wrd21.Obj);

DEFLABEL (label_33)
  (Wrd37.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd38.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_10]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (Wrd52.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if (! ((Wrd52.uLng) == 10))
    goto label_32;
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd49.Obj) = ((Wrd48.pObj) [0]);
  (Wrd50.Lng) = (FIXNUM_TO_LONG (Wrd49.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd50.Lng))))
    goto label_32;
  (Wrd44.Obj) = ((Wrd48.pObj) [1]);
  (* (--Rsp)) = (Wrd44.Obj);

DEFLABEL (label_31)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_52_12]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_52_10);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [11]);
  (Rsp [3]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_52_13]));

DEFLABEL (label_32)
  (Wrd53.Obj) = (Rsp [3]);
  (Wrd54.Obj) = (current_block [OBJECT_52_3]);
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_11]))));
  (* (--Rsp)) = (Wrd57.Obj);
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_52_1]), 2);

DEFLABEL (label_20)
  (* (--Rsp)) = Rvl;
  goto label_31;

DEFLABEL (label_34)
  (Wrd32.Obj) = (Rsp [4]);
  (Wrd33.Obj) = (Rsp [2]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_9]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_52_1]), 2);

DEFLABEL (label_19)
  (* (--Rsp)) = Rvl;
  goto label_33;

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_52_8);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.Lng) = (FIXNUM_TO_LONG (Wrd6.Obj));
  (Wrd8.Lng) = ((Wrd7.Lng) + 1L);
  (Wrd5.Obj) = (LONG_TO_FIXNUM (Wrd8.Lng));
  (Rsp [1]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  goto do_loop_11;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_53_4 3
#define LABEL_53_5 5
#define LABEL_53_6 7
#define LABEL_53_7 9
#define LABEL_53_8 11
#define LABEL_53_10 13
#define LABEL_53_12 15
#define LABEL_53_14 17
#define LABEL_53_15 19
#define LABEL_53_16 21
#define LABEL_53_17 23
#define LABEL_53_18 25
#define LABEL_53_19 27
#define LABEL_53_20 29
#define LABEL_53_21 31
#define LABEL_53_9 33
#define LABEL_53_22 35
#define LABEL_53_23 37
#define LABEL_53_24 39
#define LABEL_53_11 41
#define LABEL_53_25 43
#define LABEL_53_27 45
#define LABEL_53_28 47
#define LABEL_53_29 49
#define LABEL_53_31 51
#define LABEL_53_30 53
#define ENVIRONMENT_LABEL_53_3 71
#define DEBUGGING_LABEL_53_2 70
#define OBJECT_53_10 69
#define OBJECT_53_9 68
#define OBJECT_53_8 67
#define OBJECT_53_7 66
#define OBJECT_53_6 65
#define OBJECT_53_5 64
#define OBJECT_53_4 63
#define OBJECT_53_3 62
#define OBJECT_53_2 61
#define OBJECT_53_1 60
#define OBJECT_53_0 59
#define EXECUTE_CACHE_53_26 55
#define EXECUTE_CACHE_53_13 57
#define FREE_REFERENCES_LABEL_53_0 54
#define NUMBER_OF_LINKER_SECTIONS_53_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_53 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd58;
  machine_word Wrd77;
  machine_word Wrd75;
  machine_word Wrd73;
  machine_word Wrd67;
  machine_word Wrd66;
  machine_word Wrd69;
  machine_word Wrd68;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd24;
  machine_word Wrd26;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd19;
  machine_word Wrd10;
  machine_word Wrd78;
  machine_word Wrd81;
  machine_word Wrd80;
  machine_word Wrd79;
  machine_word Wrd111;
  machine_word Wrd114;
  machine_word Wrd113;
  machine_word Wrd112;
  machine_word Wrd110;
  machine_word Wrd109;
  machine_word Wrd106;
  machine_word Wrd105;
  machine_word Wrd89;
  machine_word Wrd94;
  machine_word Wrd91;
  machine_word Wrd102;
  machine_word Wrd101;
  machine_word Wrd100;
  machine_word Wrd96;
  machine_word Wrd104;
  machine_word Wrd103;
  machine_word Wrd86;
  machine_word Wrd85;
  machine_word Wrd84;
  machine_word Wrd83;
  machine_word Wrd56;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd46;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd21;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd23;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_53_4);
      goto load_package_from_description_59;

    case 1:
      current_block = (Rpc - LABEL_53_5);
      goto label_61;

    case 2:
      current_block = (Rpc - LABEL_53_6);
      goto label_62;

    case 3:
      current_block = (Rpc - LABEL_53_7);
      goto label_63;

    case 4:
      current_block = (Rpc - LABEL_53_8);
      goto do_loop_54;

    case 5:
      current_block = (Rpc - LABEL_53_10);
      goto label_64;

    case 6:
      current_block = (Rpc - LABEL_53_12);
      goto label_65;

    case 7:
      current_block = (Rpc - LABEL_53_14);
      goto loop_38;

    case 8:
      current_block = (Rpc - LABEL_53_15);
      goto label_75;

    case 9:
      current_block = (Rpc - LABEL_53_16);
      goto continuation_28;

    case 10:
      current_block = (Rpc - LABEL_53_17);
      goto do_loop_46;

    case 11:
      current_block = (Rpc - LABEL_53_18);
      goto label_71;

    case 12:
      current_block = (Rpc - LABEL_53_19);
      goto label_72;

    case 13:
      current_block = (Rpc - LABEL_53_20);
      goto label_74;

    case 14:
      current_block = (Rpc - LABEL_53_21);
      goto label_73;

    case 15:
      current_block = (Rpc - LABEL_53_9);
      goto continuation_17;

    case 16:
      current_block = (Rpc - LABEL_53_22);
      goto lambda_11;

    case 17:
      current_block = (Rpc - LABEL_53_23);
      goto label_66;

    case 18:
      current_block = (Rpc - LABEL_53_24);
      goto continuation_22;

    case 19:
      current_block = (Rpc - LABEL_53_11);
      goto continuation_20;

    case 20:
      current_block = (Rpc - LABEL_53_25);
      goto label_69;

    case 21:
      current_block = (Rpc - LABEL_53_27);
      goto label_67;

    case 22:
      current_block = (Rpc - LABEL_53_28);
      goto label_68;

    case 23:
      current_block = (Rpc - LABEL_53_29);
      goto do_loop_8;

    case 24:
      current_block = (Rpc - LABEL_53_31);
      goto label_70;

    case 25:
      current_block = (Rpc - LABEL_53_30);
      goto continuation_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (load_package_from_description_77)
DEFLABEL (load_package_from_description_59)
  INTERRUPT_CHECK (26, LABEL_53_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 62))
    goto label_88;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd13.Lng))))
    goto label_88;
  (Wrd7.Obj) = ((Wrd11.pObj) [5]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_87)
  (Wrd30.Obj) = (Rsp [2]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_86;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd29.Lng))))
    goto label_86;
  (Wrd23.Obj) = ((Wrd27.pObj) [2]);
  (* (--Rsp)) = (Wrd23.Obj);

DEFLABEL (label_85)
  (Wrd42.Obj) = (Rsp [0]);
  (Wrd43.uLng) = (OBJECT_TYPE (Wrd42.Obj));
  if (! ((Wrd43.uLng) == 10))
    goto label_84;
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd42.Obj));
  (Wrd40.Obj) = ((Wrd39.pObj) [0]);
  (Wrd41.Obj) = (MAKE_OBJECT (26, (Wrd40.uLng)));
  (* (--Rsp)) = (Wrd41.Obj);

DEFLABEL (label_83)
  (Wrd48.Obj) = (current_block [OBJECT_53_5]);
  (* (--Rsp)) = (Wrd48.Obj);
  goto do_loop_54;

DEFLABEL (label_84)
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_7]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_4]), 1);

DEFLABEL (label_63)
  (* (--Rsp)) = Rvl;
  goto label_83;

DEFLABEL (label_86)
  (Wrd32.Obj) = (Rsp [2]);
  (Wrd33.Obj) = (current_block [OBJECT_53_2]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_6]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_3]), 2);

DEFLABEL (label_62)
  (* (--Rsp)) = Rvl;
  goto label_85;

DEFLABEL (label_88)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_53_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_1]), 2);

DEFLABEL (label_61)
  (* (--Rsp)) = Rvl;
  goto label_87;

DEFLABEL (do_loop_78)
DEFLABEL (do_loop_54)
  INTERRUPT_CHECK (26, LABEL_53_8);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_90;
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  goto label_89;

DEFLABEL (label_90)
  (Wrd8.Obj) = (current_block [OBJECT_53_6]);
  (* (--Rsp)) = (Wrd8.Obj);

DEFLABEL (label_89)
DEFLABEL (label_105)
  (Wrd9.Obj) = (Rsp [0]);
  if ((Wrd9.Obj) == ((SCHEME_OBJECT) 0))
    goto label_91;
  Rvl = (Wrd9.Obj);
  Rsp = (& (Rsp [9]));
  goto pop_return;

DEFLABEL (label_91)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_9]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd30.Obj) = (Rsp [4]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 10))
    goto label_104;
  (Wrd22.Obj) = (Rsp [2]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd23.uLng) == 26))
    goto label_104;
  (Wrd25.Lng) = (FIXNUM_TO_LONG (Wrd22.Obj));
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) (Wrd25.Lng)) < ((unsigned long) (Wrd29.Lng))))
    goto label_104;
  (Wrd17.uLng) = (OBJECT_DATUM (Wrd22.Obj));
  (Wrd20.pObj) = (& ((Wrd27.pObj) [(Wrd17.Lng)]));
  (Wrd21.Obj) = ((Wrd20.pObj) [1]);
  (* (--Rsp)) = (Wrd21.Obj);

DEFLABEL (label_103)
  (Wrd37.Obj) = (Rsp [0]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if ((Wrd38.uLng) == 1)
    goto label_92;
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd41.pObj) = (& (Rsp [7]));
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd41.pObj)));
  (Rsp [1]) = (Wrd43.Obj);
  goto lambda_11;

DEFLABEL (label_92)
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_11]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd47.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd47.Obj);
  if (! ((Wrd38.uLng) == 1))
    goto label_102;
  (Wrd49.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd50.Obj) = ((Wrd49.pObj) [0]);
  (* (--Rsp)) = (Wrd50.Obj);

DEFLABEL (label_101)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_53_13]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_53_11);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_98;

DEFLABEL (label_97)
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_96;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [1]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_95)
  (Wrd21.Obj) = (Rsp [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 10))
    goto label_94;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (Wrd20.Obj) = (MAKE_OBJECT (26, (Wrd19.uLng)));
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_93)
  (Wrd27.Obj) = (current_block [OBJECT_53_5]);
  (* (--Rsp)) = (Wrd27.Obj);
  goto do_loop_46;

DEFLABEL (label_94)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_28]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_4]), 1);

DEFLABEL (label_68)
  (* (--Rsp)) = Rvl;
  goto label_93;

DEFLABEL (label_96)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_27]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_9]), 1);

DEFLABEL (label_67)
  (* (--Rsp)) = Rvl;
  goto label_95;

DEFLABEL (label_98)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_24]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd34.Obj) = (Rsp [2]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 1))
    goto label_100;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [0]);
  (* (--Rsp)) = (Wrd33.Obj);

DEFLABEL (label_99)
  (Wrd40.Obj) = (current_block [OBJECT_53_10]);
  (* (--Rsp)) = (Wrd40.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_53_26]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_53_24);
  goto label_97;

DEFLABEL (label_100)
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_25]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_7]), 1);

DEFLABEL (label_69)
  (* (--Rsp)) = Rvl;
  goto label_99;

DEFLABEL (label_102)
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_12]))));
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_7]), 1);

DEFLABEL (label_65)
  (* (--Rsp)) = Rvl;
  goto label_101;

DEFLABEL (label_104)
  (Wrd32.Obj) = (Rsp [4]);
  (Wrd33.Obj) = (Rsp [2]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_10]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_3]), 2);

DEFLABEL (label_64)
  (* (--Rsp)) = Rvl;
  goto label_103;

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_53_9);

DEFLABEL (label_106)
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.Lng) = (FIXNUM_TO_LONG (Wrd6.Obj));
  (Wrd8.Lng) = ((Wrd7.Lng) + 1L);
  (Wrd5.Obj) = (LONG_TO_FIXNUM (Wrd8.Lng));
  (Rsp [1]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  goto do_loop_54;

DEFLABEL (lambda_81)
DEFLABEL (lambda_11)
  INTERRUPT_CHECK (26, LABEL_53_22);
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 10))
    goto label_108;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [0]);
  (Wrd9.Obj) = (MAKE_OBJECT (26, (Wrd8.uLng)));
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_107)
  (Wrd16.Obj) = (current_block [OBJECT_53_5]);
  (* (--Rsp)) = (Wrd16.Obj);
  goto do_loop_8;

DEFLABEL (label_108)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_23]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_4]), 1);

DEFLABEL (label_66)
  (* (--Rsp)) = Rvl;
  goto label_107;

DEFLABEL (do_loop_82)
DEFLABEL (do_loop_8)
  INTERRUPT_CHECK (26, LABEL_53_29);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == (Wrd6.Obj))
    goto label_110;
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  goto label_109;

DEFLABEL (label_110)
  (Wrd8.Obj) = (current_block [OBJECT_53_6]);
  (* (--Rsp)) = (Wrd8.Obj);

DEFLABEL (label_109)
DEFLABEL (label_114)
  (Wrd9.Obj) = (Rsp [0]);
  if ((Wrd9.Obj) == ((SCHEME_OBJECT) 0))
    goto label_111;
  Rvl = (Wrd9.Obj);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_111)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_30]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [5]);
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd33.Obj) = (Rsp [5]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 10))
    goto label_113;
  (Wrd25.Obj) = (Rsp [3]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 26))
    goto label_113;
  (Wrd28.Lng) = (FIXNUM_TO_LONG (Wrd25.Obj));
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) (Wrd28.Lng)) < ((unsigned long) (Wrd32.Lng))))
    goto label_113;
  (Wrd20.uLng) = (OBJECT_DATUM (Wrd25.Obj));
  (Wrd23.pObj) = (& ((Wrd30.pObj) [(Wrd20.Lng)]));
  (Wrd24.Obj) = ((Wrd23.pObj) [1]);
  (* (--Rsp)) = (Wrd24.Obj);

DEFLABEL (label_112)
  (Wrd40.Obj) = (Rsp [7]);
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  (Wrd42.Obj) = ((Wrd41.pObj) [4]);
  (* (--Rsp)) = (Wrd42.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_53_30);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.Lng) = (FIXNUM_TO_LONG (Wrd6.Obj));
  (Wrd8.Lng) = ((Wrd7.Lng) + 1L);
  (Wrd5.Obj) = (LONG_TO_FIXNUM (Wrd8.Lng));
  (Rsp [1]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  goto do_loop_8;

DEFLABEL (label_113)
  (Wrd35.Obj) = (Rsp [5]);
  (Wrd36.Obj) = (Rsp [3]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_31]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_3]), 2);

DEFLABEL (label_70)
  (* (--Rsp)) = Rvl;
  goto label_112;

DEFLABEL (do_loop_80)
DEFLABEL (do_loop_46)
  INTERRUPT_CHECK (26, LABEL_53_17);
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.Obj) = (Rsp [1]);
  if ((Wrd10.Obj) == (Wrd11.Obj))
    goto label_116;
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  goto label_115;

DEFLABEL (label_116)
  (Wrd13.Obj) = (current_block [OBJECT_53_6]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_115)
DEFLABEL (label_128)
  (Wrd14.Obj) = (Rsp [0]);
  if ((Wrd14.Obj) == ((SCHEME_OBJECT) 0))
    goto label_117;
  Rsp = (& (Rsp [7]));
  goto label_106;

DEFLABEL (label_117)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_16]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd34.Obj) = (Rsp [4]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 10))
    goto label_127;
  (Wrd26.Obj) = (Rsp [2]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd27.uLng) == 26))
    goto label_127;
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [0]);
  (Wrd33.Lng) = (FIXNUM_TO_LONG (Wrd32.Obj));
  if (! (((unsigned long) (Wrd29.Lng)) < ((unsigned long) (Wrd33.Lng))))
    goto label_127;
  (Wrd21.uLng) = (OBJECT_DATUM (Wrd26.Obj));
  (Wrd24.pObj) = (& ((Wrd31.pObj) [(Wrd21.Lng)]));
  (Wrd25.Obj) = ((Wrd24.pObj) [1]);
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_126)
  (Wrd44.Obj) = (Rsp [0]);
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if (! ((Wrd45.uLng) == 1))
    goto label_125;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd43.Obj) = ((Wrd42.pObj) [0]);
  (* (--Rsp)) = (Wrd43.Obj);

DEFLABEL (label_124)
  (Wrd50.Obj) = (Rsp [0]);
  if ((Wrd50.Obj) == (current_block [OBJECT_53_8]))
    goto label_120;
  (Wrd58.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd58.uLng) == 10))
    goto label_119;
  (Wrd54.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd55.Obj) = ((Wrd54.pObj) [0]);
  (Wrd56.Obj) = (MAKE_OBJECT (26, (Wrd55.uLng)));
  (* (--Rsp)) = (Wrd56.Obj);

DEFLABEL (label_118)
  (Wrd63.Obj) = (current_block [OBJECT_53_5]);
  (* (--Rsp)) = (Wrd63.Obj);
  goto loop_38;

DEFLABEL (label_119)
  (Wrd62.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_21]))));
  (* (--Rsp)) = (Wrd62.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_4]), 1);

DEFLABEL (label_73)
  (* (--Rsp)) = Rvl;
  goto label_118;

DEFLABEL (label_120)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_123)
  (Wrd68.Obj) = (Rsp [0]);
  (Wrd69.uLng) = (OBJECT_TYPE (Wrd68.Obj));
  if (! ((Wrd69.uLng) == 1))
    goto label_122;
  (Wrd66.pObj) = (OBJECT_ADDRESS (Wrd68.Obj));
  (Wrd67.Obj) = ((Wrd66.pObj) [1]);
  (* (--Rsp)) = (Wrd67.Obj);

DEFLABEL (label_121)
  (Wrd75.pObj) = (& (Rsp [14]));
  (Wrd77.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd75.pObj)));
  (Rsp [1]) = (Wrd77.Obj);
  goto lambda_11;

DEFLABEL (label_122)
  (Wrd73.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_20]))));
  (* (--Rsp)) = (Wrd73.Obj);
  (* (--Rsp)) = (Wrd68.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_9]), 1);

DEFLABEL (label_74)
  (* (--Rsp)) = Rvl;
  goto label_121;

DEFLABEL (label_125)
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_19]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_7]), 1);

DEFLABEL (label_72)
  (* (--Rsp)) = Rvl;
  goto label_124;

DEFLABEL (label_127)
  (Wrd36.Obj) = (Rsp [4]);
  (Wrd37.Obj) = (Rsp [2]);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_18]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_3]), 2);

DEFLABEL (label_71)
  (* (--Rsp)) = Rvl;
  goto label_126;

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_53_16);

DEFLABEL (label_129)
  (Wrd79.Obj) = (Rsp [1]);
  (Wrd80.Lng) = (FIXNUM_TO_LONG (Wrd79.Obj));
  (Wrd81.Lng) = ((Wrd80.Lng) + 1L);
  (Wrd78.Obj) = (LONG_TO_FIXNUM (Wrd81.Lng));
  (Rsp [1]) = (Wrd78.Obj);
  Rsp = (& (Rsp [1]));
  goto do_loop_46;

DEFLABEL (loop_79)
DEFLABEL (loop_38)
  INTERRUPT_CHECK (26, LABEL_53_14);
  (Wrd83.Obj) = (Rsp [0]);
  (Wrd84.Lng) = (FIXNUM_TO_LONG (Wrd83.Obj));
  (Wrd85.Obj) = (Rsp [1]);
  (Wrd86.Lng) = (FIXNUM_TO_LONG (Wrd85.Obj));
  if ((Wrd84.Lng) < (Wrd86.Lng))
    goto label_130;
  Rsp = (& (Rsp [3]));
  Rsp = (& (Rsp [2]));
  goto label_129;

DEFLABEL (label_130)
  (Wrd103.Obj) = (Rsp [2]);
  (Wrd104.uLng) = (OBJECT_TYPE (Wrd103.Obj));
  if (! ((Wrd104.uLng) == 10))
    goto label_133;
  (Wrd96.uLng) = (OBJECT_TYPE (Wrd83.Obj));
  if (! ((Wrd96.uLng) == 26))
    goto label_133;
  (Wrd100.pObj) = (OBJECT_ADDRESS (Wrd103.Obj));
  (Wrd101.Obj) = ((Wrd100.pObj) [0]);
  (Wrd102.Lng) = (FIXNUM_TO_LONG (Wrd101.Obj));
  if (! (((unsigned long) (Wrd84.Lng)) < ((unsigned long) (Wrd102.Lng))))
    goto label_133;
  (Wrd91.uLng) = (OBJECT_DATUM (Wrd83.Obj));
  (Wrd94.pObj) = (& ((Wrd100.pObj) [(Wrd91.Lng)]));
  (Wrd89.Obj) = ((Wrd94.pObj) [1]);

DEFLABEL (label_132)
  (Wrd110.Obj) = (Rsp [9]);
  if ((Wrd89.Obj) == (Wrd110.Obj))
    goto label_131;
  (Wrd112.Obj) = (Rsp [0]);
  (Wrd113.Lng) = (FIXNUM_TO_LONG (Wrd112.Obj));
  (Wrd114.Lng) = ((Wrd113.Lng) + 1L);
  (Wrd111.Obj) = (LONG_TO_FIXNUM (Wrd114.Lng));
  (Rsp [0]) = (Wrd111.Obj);
  goto loop_38;

DEFLABEL (label_131)
  Rsp = (& (Rsp [3]));
  goto label_123;

DEFLABEL (label_133)
  (Wrd105.Obj) = (Rsp [2]);
  (Wrd106.Obj) = (Rsp [0]);
  (Wrd109.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_15]))));
  (* (--Rsp)) = (Wrd109.Obj);
  (* (--Rsp)) = (Wrd106.Obj);
  (* (--Rsp)) = (Wrd105.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_3]), 2);

DEFLABEL (label_75)
  (Wrd89.Obj) = Rvl;
  goto label_132;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_54_4 3
#define LABEL_54_5 5
#define LABEL_54_6 7
#define LABEL_54_7 9
#define LABEL_54_8 11
#define LABEL_54_9 13
#define ENVIRONMENT_LABEL_54_3 17
#define DEBUGGING_LABEL_54_2 16
#define OBJECT_54_1 15
#define OBJECT_54_0 14
#define FREE_REFERENCES_LABEL_54_0 14
#define NUMBER_OF_LINKER_SECTIONS_54_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_54 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd34;
  machine_word Wrd26;
  machine_word Wrd28;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd46;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd43;
  machine_word Wrd35;
  machine_word Wrd37;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd18;
  machine_word Wrd19;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_54_4);
      goto lookup_option_9;

    case 1:
      current_block = (Rpc - LABEL_54_5);
      goto loop_7;

    case 2:
      current_block = (Rpc - LABEL_54_6);
      goto label_11;

    case 3:
      current_block = (Rpc - LABEL_54_7);
      goto label_12;

    case 4:
      current_block = (Rpc - LABEL_54_8);
      goto label_14;

    case 5:
      current_block = (Rpc - LABEL_54_9);
      goto label_13;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lookup_option_16)
DEFLABEL (lookup_option_9)
  INTERRUPT_CHECK (26, LABEL_54_4);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_7;

DEFLABEL (loop_17)
DEFLABEL (loop_7)
  INTERRUPT_CHECK (26, LABEL_54_5);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_18;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_18)
  if (! ((Wrd6.uLng) == 1))
    goto label_28;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [0]);

DEFLABEL (label_27)
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_26;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd18.Obj) = ((Wrd19.pObj) [0]);

DEFLABEL (label_25)
  (Wrd25.Obj) = (Rsp [1]);
  if ((Wrd18.Obj) == (Wrd25.Obj))
    goto label_21;
  (Wrd29.Obj) = (Rsp [0]);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if (! ((Wrd30.uLng) == 1))
    goto label_20;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd26.Obj) = ((Wrd28.pObj) [1]);

DEFLABEL (label_19)
  (Rsp [0]) = (Wrd26.Obj);
  goto loop_7;

DEFLABEL (label_20)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54_9]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_54_1]), 1);

DEFLABEL (label_13)
  (Wrd26.Obj) = Rvl;
  goto label_19;

DEFLABEL (label_21)
  (Wrd38.Obj) = (Rsp [0]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if (! ((Wrd39.uLng) == 1))
    goto label_24;
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd35.Obj) = ((Wrd37.pObj) [0]);

DEFLABEL (label_23)
  (Rsp [2]) = (Wrd35.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd48.Obj) = (Rsp [0]);
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if (! ((Wrd49.uLng) == 1))
    goto label_22;
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  Rvl = ((Wrd46.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_22)
  INVOKE_PRIMITIVE ((current_block [OBJECT_54_1]), 1);

DEFLABEL (label_24)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54_8]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_54_0]), 1);

DEFLABEL (label_14)
  (Wrd35.Obj) = Rvl;
  goto label_23;

DEFLABEL (label_26)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54_7]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_54_0]), 1);

DEFLABEL (label_12)
  (Wrd18.Obj) = Rvl;
  goto label_25;

DEFLABEL (label_28)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54_6]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_54_0]), 1);

DEFLABEL (label_11)
  (Wrd9.Obj) = Rvl;
  goto label_27;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_55_4 3
#define LABEL_55_5 5
#define ENVIRONMENT_LABEL_55_3 13
#define DEBUGGING_LABEL_55_2 12
#define OBJECT_55_0 11
#define EXECUTE_CACHE_55_6 7
#define FREE_REFERENCE_55_0 10
#define FREE_REFERENCES_LABEL_55_0 6
#define NUMBER_OF_LINKER_SECTIONS_55_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_55 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_55_4);
      goto initialize_packages_from_file_0;

    case 1:
      current_block = (Rpc - LABEL_55_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (initialize_packages_from_file_4)
DEFLABEL (initialize_packages_from_file_0)
  INTERRUPT_CHECK (26, LABEL_55_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_55_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_6;
  Wrd5 = Wrd9;

DEFLABEL (label_5)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_55_0]);
  (Rsp [2]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_55_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_55_5])), (Wrd6.pObj));

DEFLABEL (label_2)
  (Wrd5.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_56_4 3
#define LABEL_56_5 5
#define ENVIRONMENT_LABEL_56_3 13
#define DEBUGGING_LABEL_56_2 12
#define OBJECT_56_0 11
#define EXECUTE_CACHE_56_6 7
#define FREE_REFERENCE_56_0 10
#define FREE_REFERENCES_LABEL_56_0 6
#define NUMBER_OF_LINKER_SECTIONS_56_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_56 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_56_4);
      goto finalize_packages_from_file_0;

    case 1:
      current_block = (Rpc - LABEL_56_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (finalize_packages_from_file_4)
DEFLABEL (finalize_packages_from_file_0)
  INTERRUPT_CHECK (26, LABEL_56_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_56_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_6;
  Wrd5 = Wrd9;

DEFLABEL (label_5)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_56_0]);
  (Rsp [2]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_56_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_56_5])), (Wrd6.pObj));

DEFLABEL (label_2)
  (Wrd5.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_57_4 3
#define LABEL_57_7 5
#define LABEL_57_5 7
#define TAG_57_6 2
#define LABEL_57_9 9
#define LABEL_57_10 11
#define LABEL_57_11 13
#define LABEL_57_12 15
#define TAG_57_13 6
#define LABEL_57_14 17
#define TAG_57_15 7
#define LABEL_57_17 19
#define LABEL_57_19 21
#define LABEL_57_21 23
#define TAG_57_22 10
#define LABEL_57_23 25
#define ENVIRONMENT_LABEL_57_3 46
#define DEBUGGING_LABEL_57_2 45
#define OBJECT_57_5 44
#define OBJECT_57_4 43
#define OBJECT_57_3 42
#define OBJECT_57_2 41
#define OBJECT_57_1 40
#define OBJECT_57_0 39
#define EXECUTE_CACHE_57_25 27
#define EXECUTE_CACHE_57_24 29
#define EXECUTE_CACHE_57_20 31
#define EXECUTE_CACHE_57_18 33
#define EXECUTE_CACHE_57_16 35
#define EXECUTE_CACHE_57_8 37
#define FREE_REFERENCES_LABEL_57_0 26
#define NUMBER_OF_LINKER_SECTIONS_57_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
packag_so_code_57 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd43;
  machine_word Wrd44;
  machine_word Wrd39;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd36;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd27;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd12;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_57_4);
      goto initialize_finalize_16;

    case 1:
      current_block = (Rpc - LABEL_57_7);
      goto label_18;

    case 2:
      current_block = (Rpc - LABEL_57_5);
      goto lambda_23;

    case 3:
      current_block = (Rpc - LABEL_57_9);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_57_10);
      goto label_19;

    case 5:
      current_block = (Rpc - LABEL_57_11);
      goto label_20;

    case 6:
      current_block = (Rpc - LABEL_57_12);
      goto lambda_24;

    case 7:
      current_block = (Rpc - LABEL_57_14);
      goto lambda_25;

    case 8:
      current_block = (Rpc - LABEL_57_17);
      goto continuation_8;

    case 9:
      current_block = (Rpc - LABEL_57_19);
      goto continuation_5;

    case 10:
      current_block = (Rpc - LABEL_57_21);
      goto lambda_26;

    case 11:
      current_block = (Rpc - LABEL_57_23);
      goto continuation_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (initialize_finalize_22)
DEFLABEL (initialize_finalize_16)
  INTERRUPT_CHECK (26, LABEL_57_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_57_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_57_5])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [2]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd21.Obj) = (Rsp [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 10))
    goto label_28;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd20.Lng))))
    goto label_28;
  (Wrd12.Obj) = ((Wrd18.pObj) [4]);

DEFLABEL (label_27)
  (Rsp [1]) = (Wrd12.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_57_8]));

DEFLABEL (label_28)
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.Obj) = (current_block [OBJECT_57_0]);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57_7]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_57_1]), 2);

DEFLABEL (label_18)
  (Wrd12.Obj) = Rvl;
  goto label_27;

DEFLABEL (lambda_23)
  CLOSURE_HEADER (LABEL_57_5);

DEFLABEL (lambda_15)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_57_9);
  (* (--Rsp)) = Rvl;
  (Wrd11.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd11.uLng) == 10))
    goto label_33;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (Wrd5.Obj) = (MAKE_OBJECT (26, (Wrd9.uLng)));

DEFLABEL (label_32)
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  if ((Wrd16.Lng) > 0)
    goto label_29;
  Rvl = (current_block [OBJECT_57_4]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_29)
  (Wrd28.Obj) = (Rsp [2]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if (! ((Wrd29.uLng) == 10))
    goto label_31;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd27.Lng))))
    goto label_31;
  (Wrd21.Obj) = ((Wrd25.pObj) [1]);
  (* (--Rsp)) = (Wrd21.Obj);

DEFLABEL (label_30)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd37.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_57_13);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_57_12])));
  Rhp += 2;
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd37.pObj)));
  Wrd40 = Wrd37;
  (Wrd41.Obj) = (Rsp [1]);
  ((Wrd40.pObj) [2]) = (Wrd41.Obj);
  (Wrd39.Obj) = (Rsp [0]);
  ((Wrd40.pObj) [3]) = (Wrd39.Obj);
  (Rsp [3]) = (Wrd36.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd44.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_57_15);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_57_14])));
  Rhp += 2;
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd44.pObj)));
  Wrd47 = Wrd44;
  (Wrd48.Obj) = (Rsp [2]);
  (Wrd49.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd50.Obj) = ((Wrd49.pObj) [2]);
  ((Wrd47.pObj) [2]) = (Wrd50.Obj);
  ((Wrd47.pObj) [3]) = (Wrd39.Obj);
  (Rsp [2]) = (Wrd43.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_57_16]));

DEFLABEL (label_31)
  (Wrd30.Obj) = (Rsp [2]);
  (Wrd31.Obj) = (current_block [OBJECT_57_3]);
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57_11]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_57_1]), 2);

DEFLABEL (label_20)
  (* (--Rsp)) = Rvl;
  goto label_30;

DEFLABEL (label_33)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57_10]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_57_2]), 1);

DEFLABEL (label_19)
  (Wrd5.Obj) = Rvl;
  goto label_32;

DEFLABEL (lambda_24)
  CLOSURE_HEADER (LABEL_57_12);

DEFLABEL (lambda_12)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57_17]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_57_18]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_57_17);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_57_22);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_57_21])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  ((Wrd7.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_57_8]));

DEFLABEL (lambda_25)
  CLOSURE_HEADER (LABEL_57_14);

DEFLABEL (lambda_7)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57_19]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_57_20]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_57_19);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57_23]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_57_5]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_57_20]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_57_23);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [3]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_57_25]));

DEFLABEL (lambda_26)
  CLOSURE_HEADER (LABEL_57_21);

DEFLABEL (lambda_10)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Wrd8.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd8.Obj);
  (Rsp [1]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_57_24]));

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4 3
#define LABEL_5 5
#define LABEL_6 7
#define LABEL_8 9
#define LABEL_9 11
#define LABEL_10 13
#define ENVIRONMENT_LABEL_3 27
#define DEBUGGING_LABEL_2 26
#define PURIFICATION_ROOT 25
#define OBJECT_7 24
#define OBJECT_6 23
#define OBJECT_5 22
#define OBJECT_4 21
#define OBJECT_3 20
#define OBJECT_2 19
#define OBJECT_1 18
#define OBJECT_0 17
#define GLOBAL_EXECUTE_CACHE_7 15
#define FREE_REFERENCES_LABEL_0 14
#define NUMBER_OF_LINKER_SECTIONS_1 1

#ifndef WANT_ONLY_DATA

SCHEME_OBJECT *
packag_so_86685bc3d3277846 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4);
      goto continuation_3;

    case 1:
      current_block = (Rpc - LABEL_5);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_6);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_8);
      goto label_8;

    case 4:
      current_block = (Rpc - LABEL_9);
      goto label_9;

    case 5:
      current_block = (Rpc - LABEL_10);
      goto expression_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_5)
  (current_block [ENVIRONMENT_LABEL_3]) = (Rrb [REGBLOCK_ENV]);
  INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_9])), current_block, (& (current_block [FREE_REFERENCES_LABEL_0])), NUMBER_OF_LINKER_SECTIONS_1);

DEFLABEL (label_9)
  (* (--Rsp)) = (ULONG_TO_FIXNUM (1UL));

DEFLABEL (label_8)
  {
    static const short sections [] =
      {
	0,
	1,
	2,
	2,
	0,
	1,
	1,
	0,
	0,
	1,
	0,
	1,
	2,
	1,
	2,
	1,
	2,
	2,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	2,
	2,
	2,
	2,
	2,
	0,
	2,
	1,
	1,
	2,
	0,
	0,
	3,
	0,
	2,
	0,
	0,
	0,
	0,
	0,
	0,
	1,
	1
      };
    unsigned long counter = (OBJECT_DATUM (* Rsp));
    SCHEME_OBJECT blocks;
    SCHEME_OBJECT * sub_block;
    short section;
    if (counter > 57)
      goto label_7;
    blocks = (current_block [OBJECT_7]);
    sub_block = (OBJECT_ADDRESS (MEMORY_REF (blocks, counter)));
    (sub_block [(OBJECT_DATUM (sub_block [0]))]) = (Rrb [REGBLOCK_ENV]);
    section = (sections [counter]);
    (* Rsp) = (ULONG_TO_FIXNUM (counter + 1));
    INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_8])), sub_block, (sub_block + (2 + (OBJECT_DATUM (sub_block [1])))), section);
  }

DEFLABEL (label_7)
  Rsp += 1;
  (Wrd5.Obj) = (Rrb [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  INVOKE_PRIMITIVE ((current_block [OBJECT_0]), 1);

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_6);
  (Wrd6.Lng) = (FIXNUM_TO_LONG (Rvl));
  (Wrd9.Lng) = ((Wrd6.Lng) ^ 1L);
  (Wrd10.Obj) = (LONG_TO_FIXNUM (Wrd9.Lng));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_5]);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_4);
  (Wrd5.Obj) = (current_block [OBJECT_1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_2]);
  (Rsp [2]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_7]));

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

static const struct liarc_code_S arr_decl_packag_so_86685bc3d3277846 [57] =
  {
    { "packag_so_code_1", 2, packag_so_code_1 },
    { "packag_so_code_2", 3, packag_so_code_2 },
    { "packag_so_code_3", 1, packag_so_code_3 },
    { "packag_so_code_4", 1, packag_so_code_4 },
    { "packag_so_code_5", 1, packag_so_code_5 },
    { "packag_so_code_6", 1, packag_so_code_6 },
    { "packag_so_code_7", 1, packag_so_code_7 },
    { "packag_so_code_8", 1, packag_so_code_8 },
    { "packag_so_code_9", 2, packag_so_code_9 },
    { "packag_so_code_10", 2, packag_so_code_10 },
    { "packag_so_code_11", 13, packag_so_code_11 },
    { "packag_so_code_12", 6, packag_so_code_12 },
    { "packag_so_code_13", 5, packag_so_code_13 },
    { "packag_so_code_14", 6, packag_so_code_14 },
    { "packag_so_code_15", 2, packag_so_code_15 },
    { "packag_so_code_16", 5, packag_so_code_16 },
    { "packag_so_code_17", 9, packag_so_code_17 },
    { "packag_so_code_18", 5, packag_so_code_18 },
    { "packag_so_code_19", 12, packag_so_code_19 },
    { "packag_so_code_20", 4, packag_so_code_20 },
    { "packag_so_code_21", 17, packag_so_code_21 },
    { "packag_so_code_22", 5, packag_so_code_22 },
    { "packag_so_code_23", 8, packag_so_code_23 },
    { "packag_so_code_24", 1, packag_so_code_24 },
    { "packag_so_code_25", 1, packag_so_code_25 },
    { "packag_so_code_26", 1, packag_so_code_26 },
    { "packag_so_code_27", 1, packag_so_code_27 },
    { "packag_so_code_28", 1, packag_so_code_28 },
    { "packag_so_code_29", 1, packag_so_code_29 },
    { "packag_so_code_30", 1, packag_so_code_30 },
    { "packag_so_code_31", 1, packag_so_code_31 },
    { "packag_so_code_32", 1, packag_so_code_32 },
    { "packag_so_code_33", 1, packag_so_code_33 },
    { "packag_so_code_34", 1, packag_so_code_34 },
    { "packag_so_code_35", 1, packag_so_code_35 },
    { "packag_so_code_36", 1, packag_so_code_36 },
    { "packag_so_code_37", 1, packag_so_code_37 },
    { "packag_so_code_38", 1, packag_so_code_38 },
    { "packag_so_code_39", 1, packag_so_code_39 },
    { "packag_so_code_40", 1, packag_so_code_40 },
    { "packag_so_code_41", 10, packag_so_code_41 },
    { "packag_so_code_42", 17, packag_so_code_42 },
    { "packag_so_code_43", 14, packag_so_code_43 },
    { "packag_so_code_44", 19, packag_so_code_44 },
    { "packag_so_code_45", 16, packag_so_code_45 },
    { "packag_so_code_46", 27, packag_so_code_46 },
    { "packag_so_code_47", 28, packag_so_code_47 },
    { "packag_so_code_48", 24, packag_so_code_48 },
    { "packag_so_code_49", 2, packag_so_code_49 },
    { "packag_so_code_50", 3, packag_so_code_50 },
    { "packag_so_code_51", 1, packag_so_code_51 },
    { "packag_so_code_52", 8, packag_so_code_52 },
    { "packag_so_code_53", 26, packag_so_code_53 },
    { "packag_so_code_54", 6, packag_so_code_54 },
    { "packag_so_code_55", 2, packag_so_code_55 },
    { "packag_so_code_56", 2, packag_so_code_56 },
    { "packag_so_code_57", 12, packag_so_code_57 }
  };

int
decl_packag_so_86685bc3d3277846 (void)
{
  DECLARE_SUBCODE_MULTIPLE (arr_decl_packag_so_86685bc3d3277846);
  return (0);
}

DECLARE_COMPILED_CODE ("packag.so", 6, decl_packag_so_86685bc3d3277846, packag_so_86685bc3d3277846)

#endif /* !WANT_ONLY_DATA */

#ifndef WANT_ONLY_CODE

static const unsigned char prog_packag_so_data_86685bc3d3277846 [7396] =
  "\x86\x01\x63\xdf\x0e\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x08\x0d\xb9"
  "\x24\x22\x29\x22\x29\x21\x17\x2b\xba\x1d\xb0\x82\x88\x07\xc2\xbb"
  "\x80\xb1\x24\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbc\x1d\xb0\x83"
  "\x88\xb3\x81\x22\x29\x21\x9e\x2b\xbd\x1d\xb0\x84\x88\xb3\x82\x22"
  "\x29\x21\x9e\x2b\xbe\x1d\xb0\x85\x88\xc3\xbf\x1d\x82\x22\x29\x21"
  "\x9f\x2b\x1c\x1d\xb0\x86\x88\xb3\x83\x22\x29\x21\x9e\x2b\x1c\x1d"
  "\xb0\x02\x88\xb3\x84\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\xb7"
  "\x1d\x84\x22\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x24\x28"
  "\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xc2"
  "\x1c\xb3\x84\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb3"
  "\x82\xb7\x80\x0f\x0d\x1c\x0c\x0d\x0d\x0d\x0d\x08\x8b\xb1\x25\x0d"
  "\x1c\x24\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d"
  "\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\xc1\x1c\x83\xc1\x1c\xb3\x82\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x83\xb3\x81\x08\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x1b\x24\x28\x0d\x1c\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x28\x0d\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\xb3\x84\x1b\xc2\x0d\x1c\x28\x0d\x1c\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x1b\x0c\x1b\x1b\x24\x28\x1b\x28\x0d\x1c\x28\x0d\x1c\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x08\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xc3"
  "\x1c\x1b\x84\x0c\x1d\xb7\xb3\x82\x08\xb1\x0d\xbf\x24\x28\x1b\x28"
  "\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x1b\x1b\x08\x1b\x25\xb1\x1b\x24\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x07\x0d\x0d\x0c"
  "\x08\x1d\x0d\x0d\x1c\x24\x28\x0d\x1c\x28\x0d\x28\x0d\x28\x0d\x1c"
  "\x28\x0d\x28\x0d\x28\x0d\x1c\x28\x1b\x28\x0d\x1c\x28\x0d\x1c\x28"
  "\x0d\x1c\x28\x0d\x1c\x28\x0d\x28\x0d\x28\x0d\x1c\x28\x0d\x28\x0d"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x0c\x0c\x0c\x0d"
  "\x0c\x0d\x0c\x0d\x1d\x1b\x24\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x0c\x0d\x24\x28\x1b\x28\x0d\x28\x0d\x28\x0d\x1c\x28\x0d"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b"
  "\x1c\x1d\xb0\x02\x88\xc2\x1c\x80\x22\x29\x21\x9e\x2b\x1c\x1d\xb0"
  "\x02\x88\x1b\x81\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x82"
  "\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x83\x22\x29\x21\x9e"
  "\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88"
  "\x1b\x80\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x22\x29"
  "\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x82\x22\x29\x21\x9e\x2b\x1c"
  "\x1d\xb0\x02\x88\x1b\x83\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88"
  "\x1b\x84\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x85\x22\x29"
  "\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0"
  "\x02\x88\x1b\x80\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x81"
  "\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x82\x22\x29\x21\x9e"
  "\x2b\x1c\x1d\xb0\x02\x88\x1b\x83\x22\x29\x21\x9e\x2b\x1c\x1d\xb0"
  "\x02\x88\x83\x82\x81\x0d\x1b\x80\x84\xc1\x1c\x0d\x1c\x0d\x1c\x24"
  "\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x85\x84\x83\x82\x81\x1b\x80\x86\x1b\x0d\x1c\x1b\x0d\x1c\x24\x28"
  "\x1b\x28\x1b\x28\x1b\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x83\x81\x06\x07\x85\xc2\x1c\x02\x1b\x80\x82\x1b\x28\x1b"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x0d\x1c\xc1\x1b\x06\x85\x1b\x02\x1b\x07\x83"
  "\x82\x81\x1b\x80\x84\x1b\x1b\x24\x28\x1b\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x1b\x08\x07"
  "\x80\x1b\x1b\x82\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x0c\x1b\x1d\x1b\x81\x82\x83\x80\x1b\x85\xb3\x84\x0d"
  "\x1c\x1b\x24\x28\x0d\x1c\x28\x0d\x1c\x28\x1b\x28\x0d\x1c\x28\x1b"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\xc4\x1c\x84\x81\x82\x07\x1b\x83\x1b\x80\x28\x0d\x1c\x28\x0d"
  "\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x1b\x02\xc2\x1c\x02\xc3\x02\xc3\x0d\xc2\x1c\x02\x80\xc2"
  "\x1b\x1b\x1b\x81\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb3\x84\x28\x1b"
  "\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x02"
  "\x80\x1d\xc2\x1c\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x1b\x02\x80\x22\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88\x07"
  "\x80\x1b\x1b\x83\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x0c\x1b\x1b\x1b\x07\x80\x1b\x1b\x81\xb3\x84\x28\x1b\x28"
  "\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x0c\x0d\x1c\x24\x28\x0d\x1c\x23\x22\x29\x22\x29"
  "\x21\x17\x2b\xbb\x1d\xb0\x02\x88\x0c\x0d\x1c\x24\x28\x1b\x23\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x1d\x80\x1b\x1b"
  "\x83\x28\x0d\x28\x0d\x28\x1b\x28\x1b\x28\x0d\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x17\x1c\x88\x1b\x1b\x80"
  "\x1b\x1b\x1b\x2a\x1b\x2a\xb3\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x1b"
  "\x1b\x1b\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x06\x1b"
  "\x2a\x1b\x2a\x06\x1e\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\xb6\x2a\xb5\x2a\xb4\x2a\xb2\x2a\x06\x17\x1b\x0d"
  "\x1b\x1b\x1b\x1b\x0d\x0d\x0d\x0d\x0d\x1b\x1b\x1b\x1b\x1b\x1b\x1b"
  "\x1b\x1b\x1b\x1b\x1b\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x1b\x1b\x0d\x0d\x0d\xb7\x1b\x1b\x1b\x1b\x0d\x1b"
  "\x0d\x0d\x1b\x1b\x0d\x0d\x1b\x0d\x0d\x0d\x0d\x0d\x0d\x1b\x0d\xb1"
  "\x17\xc1\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x02\x78\x2f\x61\x66\x73\x2f\x63\x73\x61\x69\x6c\x2e"
  "\x6d\x69\x74\x2e\x65\x64\x75\x2f\x67\x72\x6f\x75\x70\x2f\x6d\x61"
  "\x63\x2f\x70\x72\x6f\x6a\x65\x63\x74\x73\x2f\x73\x63\x68\x65\x6d"
  "\x65\x2f\x76\x37\x2f\x64\x69\x73\x74\x2f\x73\x6e\x61\x70\x73\x68"
  "\x6f\x74\x2e\x70\x6b\x67\x2f\x32\x30\x30\x37\x30\x39\x30\x39\x2f"
  "\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x32\x30\x30"
  "\x37\x30\x39\x30\x39\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d"
  "\x65\x2f\x70\x61\x63\x6b\x61\x67\x2e\x69\x6e\x66\x15\x23\x5b\x70"
  "\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74"
  "\x5d\x02\x0c\x70\x61\x63\x6b\x61\x67\x65\x2d\x74\x61\x67\x02\x08"
  "\x06\x81\x87\x02\x07\x04\x85\x08\x05\x0b\x02\x0c\x25\x72\x65\x63"
  "\x6f\x72\x64\x2d\x72\x65\x66\x02\x0b\x08\x81\x85\x02\x0a\x06\x81"
  "\x83\x02\x09\x04\x83\x04\x07\x0f\x02\x0c\x04\x83\x04\x03\x02\x0d"
  "\x04\x83\x04\x03\x02\x0d\x25\x72\x65\x63\x6f\x72\x64\x2d\x73\x65"
  "\x74\x21\x02\x0e\x04\x84\x06\x03\x09\x02\x0f\x04\x83\x04\x03\x0a"
  "\x02\x08\x10\x04\x83\x04\x03\x0b\x02\x09\x02\x11\x04\x84\x06\x03"
  "\x0c\x02\x0a\x08\x73\x79\x6d\x62\x6f\x6c\x3f\x0d\x02\x04\x0e\x6c"
  "\x69\x73\x74\x2d\x6f\x66\x2d\x74\x79\x70\x65\x3f\x0e\x02\x13\x06"
  "\x81\x85\x02\x12\x04\x83\x04\x05\x0d\x0f\x02\x0b\x12\x6c\x65\x78"
  "\x69\x63\x61\x6c\x2d\x72\x65\x66\x65\x72\x65\x6e\x63\x65\x10\x15"
  "\x06\x81\x85\x02\x14\x04\x84\x06\x05\x0b\x11\x02\x0c\x01\x21\x08"
  "\x70\x61\x63\x6b\x61\x67\x65\x12\x08\x70\x61\x63\x6b\x61\x67\x65"
  "\x07\x70\x61\x72\x65\x6e\x74\x09\x63\x68\x69\x6c\x64\x72\x65\x6e"
  "\x06\x25\x6e\x61\x6d\x65\x0c\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65"
  "\x6e\x74\x02\x16\x73\x79\x73\x74\x65\x6d\x2d\x67\x6c\x6f\x62\x61"
  "\x6c\x2d\x70\x61\x63\x6b\x61\x67\x65\x13\x02\x04\x11\x6d\x61\x6b"
  "\x65\x2d\x72\x65\x63\x6f\x72\x64\x2d\x74\x79\x70\x65\x03\x19\x72"
  "\x65\x63\x6f\x72\x64\x2d\x74\x79\x70\x65\x2d\x64\x69\x73\x70\x61"
  "\x74\x63\x68\x2d\x74\x61\x67\x04\x19\x73\x74\x61\x6e\x64\x61\x72"
  "\x64\x2d\x75\x6e\x70\x61\x72\x73\x65\x72\x2d\x6d\x65\x74\x68\x6f"
  "\x64\x04\x21\x73\x65\x74\x2d\x72\x65\x63\x6f\x72\x64\x2d\x74\x79"
  "\x70\x65\x2d\x75\x6e\x70\x61\x72\x73\x65\x72\x2d\x6d\x65\x74\x68"
  "\x6f\x64\x21\x04\x0b\x77\x72\x69\x74\x65\x2d\x63\x68\x61\x72\x04"
  "\x09\x66\x6f\x72\x2d\x65\x61\x63\x68\x03\x0d\x70\x61\x63\x6b\x61"
  "\x67\x65\x2f\x6e\x61\x6d\x65\x14\x04\x06\x77\x72\x69\x74\x65\x15"
  "\x09\x22\x1c\x81\x85\x02\x21\x1a\x81\x85\x02\x20\x18\x81\x85\x02"
  "\x1f\x16\x81\x85\x02\x1e\x14\x81\x85\x02\x1d\x12\x84\x06\x1c\x10"
  "\x81\x85\x02\x1b\x0e\x81\x85\x02\x1a\x0c\x81\x83\x02\x19\x0a\x81"
  "\x85\x02\x18\x08\x81\x83\x02\x17\x06\x81\x81\x02\x16\x04\x82\x02"
  "\x1b\x3b\x16\x02\x0d\x04\x63\x64\x72\x17\x04\x63\x61\x72\x18\x28"
  "\x0e\x81\x87\x02\x27\x0c\x81\x87\x02\x26\x0a\x81\x87\x02\x25\x08"
  "\x81\x87\x02\x24\x06\x81\x85\x02\x23\x04\x84\x06\x0d\x15\x19\x02"
  "\x0e\x2d\x0c\x81\x85\x02\x2c\x0a\x81\x85\x02\x2b\x08\x81\x85\x02"
  "\x2a\x06\x81\x85\x02\x29\x04\x83\x04\x0b\x12\x1a\x02\x0f\x17\x18"
  "\x13\x02\x04\x0e\x70\x61\x63\x6b\x61\x67\x65\x2f\x63\x68\x69\x6c"
  "\x64\x1b\x02\x33\x0e\x81\x87\x02\x32\x0c\x81\x85\x02\x31\x0a\x81"
  "\x87\x02\x30\x08\x81\x85\x02\x2f\x06\x81\x85\x02\x2e\x04\x83\x04"
  "\x0d\x17\x1c\x02\x10\x03\x19\x69\x6e\x74\x65\x72\x70\x72\x65\x74"
  "\x65\x72\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x3f\x03"
  "\x21\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72\x2d\x65\x6e\x76"
  "\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x2d\x3e\x70\x61\x63\x6b\x61\x67"
  "\x65\x1d\x03\x35\x06\x81\x83\x02\x34\x04\x83\x04\x05\x0d\x1e\x02"
  "\x11\x10\x19\x6c\x65\x78\x69\x63\x61\x6c\x2d\x75\x6e\x72\x65\x66"
  "\x65\x72\x65\x6e\x63\x65\x61\x62\x6c\x65\x3f\x1d\x23\x5b\x28\x70"
  "\x61\x63\x6b\x61\x67\x65\x29\x70\x61\x63\x6b\x61\x67\x65\x2d\x6e"
  "\x61\x6d\x65\x2d\x74\x61\x67\x5d\x10\x03\x09\x70\x61\x63\x6b\x61"
  "\x67\x65\x3f\x1f\x02\x3a\x0c\x81\x85\x02\x39\x0a\x81\x85\x02\x38"
  "\x08\x81\x83\x02\x37\x06\x81\x83\x02\x36\x04\x83\x04\x0b\x16\x20"
  "\x02\x12\x17\x18\x55\x6e\x61\x62\x6c\x65\x20\x74\x6f\x20\x66\x69"
  "\x6e\x64\x20\x70\x61\x63\x6b\x61\x67\x65\x3a\x18\x13\x02\x04\x1b"
  "\x04\x10\x6c\x69\x73\x74\x2d\x64\x69\x66\x66\x65\x72\x65\x6e\x63"
  "\x65\x21\x04\x06\x65\x72\x72\x6f\x72\x22\x04\x43\x14\x81\x85\x02"
  "\x42\x12\x81\x87\x02\x41\x10\x81\x87\x02\x40\x0e\x81\x87\x02\x3f"
  "\x0c\x81\x89\x02\x3e\x0a\x81\x8b\x02\x3d\x08\x81\x87\x02\x3c\x06"
  "\x81\x83\x02\x3b\x04\x83\x04\x13\x22\x23\x02\x13\x18\x17\x48\x0c"
  "\xfd\xff\x03\x47\x0a\xfd\xff\x03\x46\x08\xfd\xff\x03\x45\x06\xff"
  "\xff\x03\x44\x04\x84\x06\x0b\x11\x24\x02\x14\x11\x6c\x6f\x63\x61"
  "\x6c\x2d\x61\x73\x73\x69\x67\x6e\x6d\x65\x6e\x74\x25\x10\x29\x50"
  "\x61\x63\x6b\x61\x67\x65\x20\x61\x6c\x72\x65\x61\x64\x79\x20\x68"
  "\x61\x73\x20\x63\x68\x69\x6c\x64\x20\x6f\x66\x20\x67\x69\x76\x65"
  "\x6e\x20\x6e\x61\x6d\x65\x3a\x08\x1e\x2a\x61\x6c\x6c\x6f\x77\x2d"
  "\x70\x61\x63\x6b\x61\x67\x65\x2d\x72\x65\x64\x65\x66\x69\x6e\x69"
  "\x74\x69\x6f\x6e\x3f\x2a\x03\x04\x1b\x05\x22\x03\x1d\x04\x54\x1a"
  "\x81\x8b\x02\x53\x18\x81\x8b\x02\x52\x16\x81\x8b\x02\x51\x14\x81"
  "\x8b\x02\x50\x12\x81\x8b\x02\x4f\x10\x81\x8b\x02\x4e\x0e\x81\x8b"
  "\x02\x4d\x0c\x81\x8b\x02\x4c\x0a\x81\x8b\x02\x4b\x08\x81\x89\x02"
  "\x4a\x06\x81\x8b\x02\x49\x04\x86\x08\x19\x2f\x26\x02\x15\x25\x10"
  "\x13\x02\x13\x03\x58\x0a\x81\x81\x02\x57\x08\x81\x81\x02\x56\x06"
  "\x81\x81\x02\x55\x04\x82\x02\x09\x14\x27\x02\x16\x08\x64\x65\x66"
  "\x61\x75\x6c\x74\x19\x61\x6c\x74\x65\x72\x6e\x61\x74\x65\x2d\x70"
  "\x61\x63\x6b\x61\x67\x65\x2d\x6c\x6f\x61\x64\x65\x72\x24\x4d\x61"
  "\x6c\x66\x6f\x72\x6d\x65\x64\x20\x70\x61\x63\x6b\x61\x67\x65\x2d"
  "\x64\x65\x73\x63\x72\x69\x70\x74\x69\x6f\x6e\x20\x66\x69\x6c\x65"
  "\x3a\x08\x08\x6f\x73\x2d\x74\x79\x70\x65\x1e\x6d\x69\x63\x72\x6f"
  "\x63\x6f\x64\x65\x2d\x69\x64\x2f\x6f\x70\x65\x72\x61\x74\x69\x6e"
  "\x67\x2d\x73\x79\x73\x74\x65\x6d\x28\x02\x03\x10\x6d\x65\x72\x67"
  "\x65\x2d\x70\x61\x74\x68\x6e\x61\x6d\x65\x73\x29\x02\x1a\x66\x6c"
  "\x75\x73\x68\x2d\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e"
  "\x2d\x71\x75\x65\x75\x65\x21\x03\x13\x64\x69\x72\x65\x63\x74\x6f"
  "\x72\x79\x2d\x70\x61\x74\x68\x6e\x61\x6d\x65\x04\x15\x70\x61\x63"
  "\x6b\x61\x67\x65\x2d\x73\x65\x74\x2d\x70\x61\x74\x68\x6e\x61\x6d"
  "\x65\x2a\x04\x20\x77\x69\x74\x68\x2d\x77\x6f\x72\x6b\x69\x6e\x67"
  "\x2d\x64\x69\x72\x65\x63\x74\x6f\x72\x79\x2d\x70\x61\x74\x68\x6e"
  "\x61\x6d\x65\x03\x08\x66\x61\x73\x6c\x6f\x61\x64\x03\x0e\x70\x61"
  "\x63\x6b\x61\x67\x65\x2d\x66\x69\x6c\x65\x3f\x2b\x04\x22\x03\x1d"
  "\x63\x6f\x6e\x73\x74\x72\x75\x63\x74\x2d\x70\x61\x63\x6b\x61\x67"
  "\x65\x73\x2d\x66\x72\x6f\x6d\x2d\x66\x69\x6c\x65\x2c\x04\x0e\x6c"
  "\x6f\x6f\x6b\x75\x70\x2d\x6f\x70\x74\x69\x6f\x6e\x2d\x04\x1a\x66"
  "\x69\x6c\x65\x6e\x61\x6d\x65\x2d\x3e\x63\x6f\x6d\x70\x69\x6c\x65"
  "\x64\x2d\x6f\x62\x6a\x65\x63\x74\x2e\x05\x18\x6c\x6f\x61\x64\x2d"
  "\x70\x61\x63\x6b\x61\x67\x65\x73\x2d\x66\x72\x6f\x6d\x2d\x66\x69"
  "\x6c\x65\x2f\x06\x05\x6c\x6f\x61\x64\x03\x17\x6c\x6f\x61\x64\x2f"
  "\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f"
  "\x74\x03\x1e\x69\x6e\x69\x74\x69\x61\x6c\x69\x7a\x65\x2d\x70\x61"
  "\x63\x6b\x61\x67\x65\x73\x2d\x66\x72\x6f\x6d\x2d\x66\x69\x6c\x65"
  "\x30\x04\x0b\x73\x63\x6f\x64\x65\x2d\x65\x76\x61\x6c\x03\x07\x70"
  "\x75\x72\x69\x66\x79\x12\x69\x24\x81\x8b\x02\x68\x22\x81\x89\x02"
  "\x67\x20\x81\x89\x02\x66\x1e\x81\x87\x02\x65\x1c\x81\x87\x02\x64"
  "\x1a\x81\x87\x02\x63\x18\x81\x85\x02\x62\x16\x81\x85\x02\x61\x14"
  "\x81\x85\x02\x60\x12\x81\x83\x02\x5f\x10\x81\x83\x02\x5e\x0e\x81"
  "\x87\x02\x5d\x0c\x81\x85\x02\x5c\x0a\x81\x89\x02\x5b\x08\x81\x85"
  "\x02\x5a\x06\x81\x87\x02\x59\x04\x84\x04\x23\x52\x31\x02\x17\x04"
  "\x70\x6b\x64\x02\x2d\x04\x75\x6e\x6b\x04\x75\x6e\x78\x05\x75\x6e"
  "\x69\x78\x04\x6f\x73\x32\x05\x6f\x73\x2f\x32\x04\x77\x33\x32\x03"
  "\x6e\x74\x08\x28\x02\x03\x0e\x70\x61\x74\x68\x6e\x61\x6d\x65\x2d"
  "\x6e\x61\x6d\x65\x04\x12\x70\x61\x74\x68\x6e\x61\x6d\x65\x2d\x6e"
  "\x65\x77\x2d\x74\x79\x70\x65\x04\x12\x70\x61\x74\x68\x6e\x61\x6d"
  "\x65\x2d\x6e\x65\x77\x2d\x6e\x61\x6d\x65\x05\x0e\x73\x74\x72\x69"
  "\x6e\x67\x2d\x61\x70\x70\x65\x6e\x64\x05\x6e\x0c\x81\x8d\x02\x6d"
  "\x0a\x81\x87\x02\x6c\x08\x81\x85\x02\x6b\x06\x81\x89\x02\x6a\x04"
  "\x84\x04\x0b\x23\x28\x02\x18\x0d\x49\x6e\x69\x74\x69\x61\x6c\x69"
  "\x7a\x65\x64\x20\x1f\x6c\x6f\x61\x64\x2f\x73\x75\x70\x70\x72\x65"
  "\x73\x73\x2d\x6c\x6f\x61\x64\x69\x6e\x67\x2d\x6d\x65\x73\x73\x61"
  "\x67\x65\x3f\x02\x04\x29\x03\x15\x62\x75\x69\x6c\x74\x2d\x69\x6e"
  "\x2d\x6f\x62\x6a\x65\x63\x74\x2d\x66\x69\x6c\x65\x03\x18\x77\x72"
  "\x69\x74\x65\x2d\x6e\x6f\x74\x69\x66\x69\x63\x61\x74\x69\x6f\x6e"
  "\x2d\x6c\x69\x6e\x65\x04\x0d\x77\x72\x69\x74\x65\x2d\x73\x74\x72"
  "\x69\x6e\x67\x29\x03\x12\x65\x6e\x6f\x75\x67\x68\x2d\x6e\x61\x6d"
  "\x65\x73\x74\x72\x69\x6e\x67\x04\x15\x07\x76\x12\x81\x85\x02\x75"
  "\x10\x81\x85\x02\x74\x0e\x81\x85\x02\x73\x0c\x81\x85\x02\x72\x0a"
  "\x81\x83\x02\x71\x08\x81\x85\x02\x70\x06\x81\x85\x02\x6f\x04\x84"
  "\x06\x11\x24\x32\x02\x19\x77\x04\x86\x0a\x03\x33\x02\x1a\x0b\x76"
  "\x65\x63\x74\x6f\x72\x2d\x72\x65\x66\x34\x78\x04\x83\x04\x03\x35"
  "\x02\x1b\x34\x79\x04\x83\x04\x03\x36\x02\x1c\x34\x7a\x04\x83\x04"
  "\x03\x37\x02\x1d\x34\x7b\x04\x83\x04\x03\x38\x02\x1e\x7c\x04\x88"
  "\x0e\x03\x39\x02\x1f\x34\x7d\x04\x83\x04\x03\x3a\x02\x20\x34\x7e"
  "\x04\x83\x04\x03\x3b\x02\x21\x34\x7f\x04\x83\x04\x03\x3c\x02\x22"
  "\x34\x80\x01\x04\x83\x04\x03\x3d\x02\x23\x34\x81\x01\x04\x83\x04"
  "\x03\x3e\x02\x24\x34\x82\x01\x04\x83\x04\x03\x3f\x02\x25\x83\x01"
  "\x04\x86\x0a\x03\x40\x02\x26\x34\x84\x01\x04\x83\x04\x03\x41\x02"
  "\x27\x34\x85\x01\x04\x83\x04\x03\x42\x02\x28\x34\x86\x01\x04\x83"
  "\x04\x03\x43\x02\x29\x34\x87\x01\x04\x83\x04\x03\x44\x02\x2a\x15"
  "\x70\x61\x63\x6b\x61\x67\x65\x2d\x64\x65\x73\x63\x72\x69\x70\x74"
  "\x69\x6f\x6e\x73\x34\x0e\x76\x65\x63\x74\x6f\x72\x2d\x6c\x65\x6e"
  "\x67\x74\x68\x45\x15\x70\x61\x63\x6b\x61\x67\x65\x2d\x64\x65\x73"
  "\x63\x72\x69\x70\x74\x69\x6f\x6e\x3f\x46\x12\x6c\x6f\x61\x64\x2d"
  "\x64\x65\x73\x63\x72\x69\x70\x74\x69\x6f\x6e\x3f\x47\x03\x04\x10"
  "\x76\x65\x63\x74\x6f\x72\x2d\x6f\x66\x2d\x74\x79\x70\x65\x3f\x48"
  "\x02\x91\x01\x16\x81\x85\x02\x90\x01\x14\x81\x83\x02\x8f\x01\x12"
  "\x81\x83\x02\x8e\x01\x10\x81\x87\x02\x8d\x01\x0e\x81\x85\x02\x8c"
  "\x01\x0c\x81\x83\x02\x8b\x01\x0a\x81\x83\x02\x8a\x01\x08\x81\x83"
  "\x02\x89\x01\x06\x81\x83\x02\x88\x01\x04\x83\x04\x15\x26\x49\x02"
  "\x2b\x34\x45\x0e\x70\x61\x63\x6b\x61\x67\x65\x2d\x6e\x61\x6d\x65"
  "\x3f\x4a\x0d\x12\x6c\x69\x6e\x6b\x2d\x64\x65\x73\x63\x72\x69\x70"
  "\x74\x69\x6f\x6e\x3f\x4b\x04\x03\x4a\x04\x0e\x04\x48\x03\x09\x62"
  "\x6f\x6f\x6c\x65\x61\x6e\x3f\x05\xa2\x01\x24\x81\x83\x02\xa1\x01"
  "\x22\x81\x83\x02\xa0\x01\x20\x81\x87\x02\x9f\x01\x1e\x81\x85\x02"
  "\x9e\x01\x1c\x81\x83\x02\x9d\x01\x1a\x81\x87\x02\x9c\x01\x18\x81"
  "\x85\x02\x9b\x01\x16\x81\x83\x02\x9a\x01\x14\x81\x87\x02\x99\x01"
  "\x12\x81\x85\x02\x98\x01\x10\x81\x83\x02\x97\x01\x0e\x81\x87\x02"
  "\x96\x01\x0c\x81\x85\x02\x95\x01\x0a\x81\x83\x02\x94\x01\x08\x81"
  "\x85\x02\x93\x01\x06\x81\x83\x02\x92\x01\x04\x83\x04\x23\x3c\x0e"
  "\x02\x2c\x0d\x6f\x62\x6a\x65\x63\x74\x2d\x74\x79\x70\x65\x3f\x4c"
  "\x1e\x34\x45\x03\x4a\x02\xb0\x01\x1e\x81\x83\x02\xaf\x01\x1c\x81"
  "\x83\x02\xae\x01\x1a\x81\x83\x02\xad\x01\x18\x81\x85\x02\xac\x01"
  "\x16\x81\x83\x02\xab\x01\x14\x81\x85\x02\xaa\x01\x12\x81\x83\x02"
  "\xa9\x01\x10\x81\x83\x02\xa8\x01\x0e\x81\x83\x02\xa7\x01\x0c\x81"
  "\x85\x02\xa6\x01\x0a\x81\x83\x02\xa5\x01\x08\x83\x04\xa4\x01\x06"
  "\x81\x83\x02\xa3\x01\x04\x81\x83\x02\x1d\x2e\x4d\x02\x2d\x05\x65"
  "\x6c\x73\x65\x4e\x08\x73\x74\x72\x69\x6e\x67\x3f\x17\x4c\x1e\x18"
  "\x34\x45\x0d\x02\x03\x4a\x04\x48\x03\xc3\x01\x28\x81\x87\x02\xc2"
  "\x01\x26\x81\x85\x02\xc1\x01\x24\x81\x83\x02\xc0\x01\x22\x81\x83"
  "\x02\xbf\x01\x20\x83\x04\xbe\x01\x1e\x81\x83\x02\xbd\x01\x1c\x81"
  "\x83\x02\xbc\x01\x1a\x81\x83\x02\xbb\x01\x18\x81\x85\x02\xba\x01"
  "\x16\x83\x04\xb9\x01\x14\x81\x83\x02\xb8\x01\x12\x81\x83\x02\xb7"
  "\x01\x10\x81\x83\x02\xb6\x01\x0e\x81\x83\x02\xb5\x01\x0c\x81\x87"
  "\x02\xb4\x01\x0a\x81\x83\x02\xb3\x01\x08\x81\x85\x02\xb2\x01\x06"
  "\x81\x83\x02\xb1\x01\x04\x83\x04\x27\x41\x4c\x02\x2e\x17\x12\x18"
  "\x45\x34\x03\x2a\x63\x6f\x6e\x73\x74\x72\x75\x63\x74\x2d\x6e\x6f"
  "\x72\x6d\x61\x6c\x2d\x70\x61\x63\x6b\x61\x67\x65\x2d\x66\x72\x6f"
  "\x6d\x2d\x64\x65\x73\x63\x72\x69\x70\x74\x69\x6f\x6e\x48\x03\x1e"
  "\x63\x72\x65\x61\x74\x65\x2d\x6c\x69\x6e\x6b\x73\x2d\x66\x72\x6f"
  "\x6d\x2d\x64\x65\x73\x63\x72\x69\x70\x74\x69\x6f\x6e\x12\x03\xd3"
  "\x01\x22\x81\x89\x02\xd2\x01\x20\x81\x85\x02\xd1\x01\x1e\x81\x83"
  "\x02\xd0\x01\x1c\x81\x83\x02\xcf\x01\x1a\x81\x83\x02\xce\x01\x18"
  "\x81\x89\x02\xcd\x01\x16\x81\x85\x02\xcc\x01\x14\x81\x83\x02\xcb"
  "\x01\x12\x81\x8b\x02\xca\x01\x10\x81\x87\x02\xc9\x01\x0e\x81\x83"
  "\x02\xc8\x01\x0c\x81\x8b\x02\xc7\x01\x0a\x81\x87\x02\xc6\x01\x08"
  "\x81\x83\x02\xc5\x01\x06\x81\x83\x02\xc4\x01\x04\x83\x04\x21\x32"
  "\x0d\x02\x2f\x18\x55\x6e\x61\x62\x6c\x65\x20\x74\x6f\x20\x66\x69"
  "\x6e\x64\x20\x70\x61\x63\x6b\x61\x67\x65\x3a\x17\x02\x18\x34\x11"
  "\x6e\x75\x6c\x6c\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74"
  "\x4f\x13\x03\x03\x0d\x66\x69\x6e\x64\x2d\x70\x61\x63\x6b\x61\x67"
  "\x65\x50\x06\x1b\x65\x78\x74\x65\x6e\x64\x2d\x70\x61\x63\x6b\x61"
  "\x67\x65\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x51\x04"
  "\x1b\x05\x13\x70\x61\x63\x6b\x61\x67\x65\x2f\x61\x64\x64\x2d\x63"
  "\x68\x69\x6c\x64\x21\x52\x04\x21\x04\x22\x07\xee\x01\x38\x81\x85"
  "\x02\xed\x01\x36\x81\x8b\x02\xec\x01\x34\x81\x8b\x02\xeb\x01\x32"
  "\x81\x87\x02\xea\x01\x30\x81\x8d\x02\xe9\x01\x2e\x81\x8d\x02\xe8"
  "\x01\x2c\x81\x8b\x02\xe7\x01\x2a\x81\x8f\x02\xe6\x01\x28\x81\x8b"
  "\x02\xe5\x01\x26\x81\x8b\x02\xe4\x01\x24\x81\x8b\x02\xe3\x01\x22"
  "\x83\x04\xe2\x01\x20\x83\x04\xe1\x01\x1e\x83\x04\xe0\x01\x1c\x81"
  "\x87\x02\xdf\x01\x1a\x81\x87\x02\xde\x01\x18\x81\x83\x02\xdd\x01"
  "\x16\x81\x85\x02\xdc\x01\x14\x81\x91\x02\xdb\x01\x12\x81\x8d\x02"
  "\xda\x01\x10\x81\x8b\x02\xd9\x01\x0e\x81\x89\x02\xd8\x01\x0c\x81"
  "\x85\x02\xd7\x01\x0a\x81\x83\x02\xd6\x01\x08\x83\x04\xd5\x01\x06"
  "\x81\x8f\x02\xd4\x01\x04\x81\x83\x02\x37\x56\x53\x02\x30\x0f\x6c"
  "\x69\x6e\x6b\x2d\x76\x61\x72\x69\x61\x62\x6c\x65\x73\x54\x45\x34"
  "\x03\x19\x66\x69\x6e\x64\x2d\x70\x61\x63\x6b\x61\x67\x65\x2d\x65"
  "\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x55\x04\x12\x67\x75\x61"
  "\x72\x61\x6e\x74\x65\x65\x2d\x62\x69\x6e\x64\x69\x6e\x67\x56\x03"
  "\x8a\x02\x3a\x81\x89\x02\x89\x02\x38\x81\x87\x02\x88\x02\x36\x81"
  "\x85\x02\x87\x02\x34\x81\x8d\x02\x86\x02\x32\x81\x89\x02\x85\x02"
  "\x30\x81\x87\x02\x84\x02\x2e\x81\x8d\x02\x83\x02\x2c\x81\x87\x02"
  "\x82\x02\x2a\x81\x85\x02\x81\x02\x28\x81\x85\x02\x80\x02\x26\x81"
  "\x85\x02\xff\x01\x24\x81\x8f\x02\xfe\x01\x22\x81\x8b\x02\xfd\x01"
  "\x20\x81\x83\x02\xfc\x01\x1e\x81\x87\x02\xfb\x01\x1c\x81\x85\x02"
  "\xfa\x01\x1a\x81\x89\x02\xf9\x01\x18\x81\x87\x02\xf8\x01\x16\x81"
  "\x87\x02\xf7\x01\x14\x81\x87\x02\xf6\x01\x12\x81\x8f\x02\xf5\x01"
  "\x10\x81\x8b\x02\xf4\x01\x0e\x81\x85\x02\xf3\x01\x0c\x81\x87\x02"
  "\xf2\x01\x0a\x81\x85\x02\xf1\x01\x08\x81\x83\x02\xf0\x01\x06\x81"
  "\x85\x02\xef\x01\x04\x83\x04\x39\x4a\x57\x02\x31\x34\x10\x10\x6f"
  "\x62\x6a\x65\x63\x74\x2d\x73\x65\x74\x2d\x74\x79\x70\x65\x58\x13"
  "\x11\x73\x79\x73\x74\x65\x6d\x2d\x70\x61\x69\x72\x2d\x63\x6f\x6e"
  "\x73\x18\x0c\x76\x65\x63\x74\x6f\x72\x2d\x73\x65\x74\x21\x10\x64"
  "\x75\x6d\x6d\x79\x2d\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x1a\x70"
  "\x72\x69\x6d\x69\x74\x69\x76\x65\x2d\x6f\x62\x6a\x65\x63\x74\x2d"
  "\x73\x65\x74\x2d\x74\x79\x70\x65\x59\x33\x0c\x76\x65\x63\x74\x6f"
  "\x72\x2d\x63\x6f\x6e\x73\x17\x45\x18\xa2\x02\x32\x81\x97\x02\xa1"
  "\x02\x30\x81\x97\x02\xa0\x02\x2e\x81\x97\x02\x9f\x02\x2c\x81\x99"
  "\x02\x9e\x02\x2a\x81\x97\x02\x9d\x02\x28\x81\x8d\x02\x9c\x02\x26"
  "\x81\x89\x02\x9b\x02\x24\x81\x89\x02\x9a\x02\x22\x81\x89\x02\x99"
  "\x02\x20\x81\x91\x02\x98\x02\x1e\x81\x8f\x02\x97\x02\x1c\x81\x8f"
  "\x02\x96\x02\x1a\x81\x8d\x02\x95\x02\x18\x81\x8d\x02\x94\x02\x16"
  "\x81\x8d\x02\x93\x02\x14\x81\x8b\x02\x92\x02\x12\x81\x89\x02\x91"
  "\x02\x10\x81\x87\x02\x90\x02\x0e\x81\x89\x02\x8f\x02\x0c\x81\x89"
  "\x02\x8e\x02\x0a\x81\x89\x02\x8d\x02\x08\x81\x89\x02\x8c\x02\x06"
  "\x81\x89\x02\x8b\x02\x04\xfe\x05\x31\x44\x5a\x02\x32\x03\x50\x02"
  "\xa4\x02\x06\x81\x83\x02\xa3\x02\x04\x83\x04\x05\x0d\x5b\x02\x33"
  "\x25\x59\x33\x02\x11\x6c\x65\x78\x69\x63\x61\x6c\x2d\x75\x6e\x62"
  "\x6f\x75\x6e\x64\x3f\x5c\xa7\x02\x08\x81\x87\x02\xa6\x02\x06\x81"
  "\x85\x02\xa5\x02\x04\x84\x06\x07\x10\x5d\x02\x34\x59\x33\xa8\x02"
  "\x04\x82\x02\x03\x5e\x02\x35\x45\x34\x03\x50\x06\x1e\x6c\x6f\x61"
  "\x64\x2d\x70\x61\x63\x6b\x61\x67\x65\x2d\x66\x72\x6f\x6d\x2d\x64"
  "\x65\x73\x63\x72\x69\x70\x74\x69\x6f\x6e\x5f\x03\xb0\x02\x12\x81"
  "\x87\x02\xaf\x02\x10\x81\x8f\x02\xae\x02\x0e\x81\x89\x02\xad\x02"
  "\x0c\x81\x91\x02\xac\x02\x0a\x81\x8d\x02\xab\x02\x08\x81\x89\x02"
  "\xaa\x02\x06\x81\x87\x02\xa9\x02\x04\x85\x08\x11\x1e\x60\x02\x36"
  "\x0d\x4d\x69\x73\x73\x69\x6e\x67\x20\x6b\x65\x79\x3a\x17\x4e\x18"
  "\x45\x34\x04\x2d\x04\x22\x03\xca\x02\x36\x81\x8b\x02\xc9\x02\x34"
  "\x81\x8f\x02\xc8\x02\x32\x81\x89\x02\xc7\x02\x30\x81\x87\x02\xc6"
  "\x02\x2e\x81\x85\x02\xc5\x02\x2c\x81\x87\x02\xc4\x02\x2a\x81\x83"
  "\x02\xc3\x02\x28\x81\x85\x02\xc2\x02\x26\x81\x85\x02\xc1\x02\x24"
  "\x81\x85\x02\xc0\x02\x22\x81\x93\x02\xbf\x02\x20\x81\x85\x02\xbe"
  "\x02\x1e\x81\x83\x02\xbd\x02\x1c\x81\x83\x02\xbc\x02\x1a\x81\x8f"
  "\x02\xbb\x02\x18\x81\x8b\x02\xba\x02\x16\x81\x8d\x02\xb9\x02\x14"
  "\x81\x89\x02\xb8\x02\x12\x81\x89\x02\xb7\x02\x10\x81\x87\x02\xb6"
  "\x02\x0e\x81\x95\x02\xb5\x02\x0c\x81\x91\x02\xb4\x02\x0a\x81\x8d"
  "\x02\xb3\x02\x08\x81\x8b\x02\xb2\x02\x06\x81\x89\x02\xb1\x02\x04"
  "\x86\x0a\x35\x48\x4e\x02\x37\x17\x18\xd0\x02\x0e\x81\x87\x02\xcf"
  "\x02\x0c\x81\x87\x02\xce\x02\x0a\x81\x87\x02\xcd\x02\x08\x81\x87"
  "\x02\xcc\x02\x06\x81\x87\x02\xcb\x02\x04\x84\x06\x0d\x12\x22\x02"
  "\x38\x0d\x49\x6e\x69\x74\x69\x61\x6c\x69\x7a\x69\x6e\x67\x21\x6c"
  "\x6f\x61\x64\x2d\x64\x65\x73\x63\x72\x69\x70\x74\x69\x6f\x6e\x2f"
  "\x69\x6e\x69\x74\x69\x61\x6c\x69\x7a\x61\x74\x69\x6f\x6e\x73\x18"
  "\x02\x05\x14\x69\x6e\x69\x74\x69\x61\x6c\x69\x7a\x65\x2f\x66\x69"
  "\x6e\x61\x6c\x69\x7a\x65\x17\x02\xd2\x02\x06\x81\x83\x02\xd1\x02"
  "\x04\x83\x04\x05\x0e\x02\x39\x0b\x46\x69\x6e\x61\x6c\x69\x7a\x69"
  "\x6e\x67\x1f\x6c\x6f\x61\x64\x2d\x64\x65\x73\x63\x72\x69\x70\x74"
  "\x69\x6f\x6e\x2f\x66\x69\x6e\x61\x6c\x69\x7a\x61\x74\x69\x6f\x6e"
  "\x73\x61\x02\x05\x17\x02\xd4\x02\x06\x81\x83\x02\xd3\x02\x04\x83"
  "\x04\x05\x0e\x62\x02\x3a\x0a\x20\x70\x61\x63\x6b\x61\x67\x65\x20"
  "\x02\x45\x34\x04\x18\x66\x6f\x72\x2d\x65\x61\x63\x68\x2d\x76\x65"
  "\x63\x74\x6f\x72\x2d\x65\x6c\x65\x6d\x65\x6e\x74\x04\x12\x77\x69"
  "\x74\x68\x2d\x6e\x6f\x74\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x03"
  "\x55\x04\x29\x04\x05\x65\x76\x61\x6c\x04\x15\x07\xe0\x02\x1a\x81"
  "\x85\x02\xdf\x02\x18\x81\x85\x02\xde\x02\x16\x81\x85\x02\xdd\x02"
  "\x14\x81\x85\x02\xdc\x02\x12\x81\x85\x02\xdb\x02\x10\x81\x83\x02"
  "\xda\x02\x0e\x81\x87\x02\xd9\x02\x0c\x81\x87\x02\xd8\x02\x0a\x81"
  "\x85\x02\xd7\x02\x08\x81\x85\x02\xd6\x02\x06\x81\x87\x02\xd5\x02"
  "\x04\x85\x08\x19\x2f\x45\x3a\x34\x34\x58\x25\x4f\x45\x04\x62\x04"
  "\x04\x22\x04\x4e\x04\x60\x04\x59\x25\x54\x5c\x5e\x04\x5d\x04\x5b"
  "\x04\x5a\x04\x57\x04\x53\x08\x0d\x04\x4c\x04\x4d\x08\x0e\x04\x49"
  "\x04\x44\x04\x43\x04\x42\x04\x41\x04\x40\x04\x3f\x04\x3e\x04\x3d"
  "\x04\x3c\x04\x3b\x04\x3a\x04\x39\x04\x38\x04\x37\x04\x36\x04\x35"
  "\x04\x33\x04\x32\x04\x28\x04\x31\x04\x27\x04\x26\x04\x24\x04\x23"
  "\x04\x10\x20\x04\x1e\x04\x1c\x04\x1a\x04\x19\x04\x16\x04\x11\x04"
  "\x0f\x04\x0c\x04\x0b\x04\x0a\x04\x09\x04\x04\x04\x04\x04\x43\x17"
  "\x1c\x66\x69\x6e\x61\x6c\x69\x7a\x65\x2d\x70\x61\x63\x6b\x61\x67"
  "\x65\x73\x2d\x66\x72\x6f\x6d\x2d\x66\x69\x6c\x65\x30\x2d\x5f\x2f"
  "\x1a\x70\x72\x69\x6d\x69\x74\x69\x76\x65\x2d\x6f\x62\x6a\x65\x63"
  "\x74\x2d\x73\x65\x74\x2d\x74\x79\x70\x65\x11\x6c\x6f\x63\x61\x6c"
  "\x2d\x61\x73\x73\x69\x67\x6e\x6d\x65\x6e\x74\x0f\x6c\x69\x6e\x6b"
  "\x2d\x76\x61\x72\x69\x61\x62\x6c\x65\x73\x11\x6c\x65\x78\x69\x63"
  "\x61\x6c\x2d\x75\x6e\x62\x6f\x75\x6e\x64\x3f\x28\x6d\x61\x6b\x65"
  "\x2d\x75\x6e\x6d\x61\x70\x70\x65\x64\x2d\x75\x6e\x61\x73\x73\x69"
  "\x67\x6e\x65\x64\x2d\x72\x65\x66\x65\x72\x65\x6e\x63\x65\x2d\x74"
  "\x72\x61\x70\x56\x55\x51\x12\x48\x2c\x47\x4b\x46\x2b\x61\x18\x1c"
  "\x6c\x6f\x61\x64\x2d\x64\x65\x73\x63\x72\x69\x70\x74\x69\x6f\x6e"
  "\x2f\x66\x69\x6c\x65\x2d\x63\x61\x73\x65\x73\x16\x6c\x6f\x61\x64"
  "\x2d\x64\x65\x73\x63\x72\x69\x70\x74\x69\x6f\x6e\x2f\x6e\x61\x6d"
  "\x65\x16\x6d\x61\x6b\x65\x2d\x6c\x6f\x61\x64\x2d\x64\x65\x73\x63"
  "\x72\x69\x70\x74\x69\x6f\x6e\x1f\x70\x61\x63\x6b\x61\x67\x65\x2d"
  "\x64\x65\x73\x63\x72\x69\x70\x74\x69\x6f\x6e\x2f\x65\x78\x74\x65"
  "\x6e\x73\x69\x6f\x6e\x3f\x1c\x70\x61\x63\x6b\x61\x67\x65\x2d\x64"
  "\x65\x73\x63\x72\x69\x70\x74\x69\x6f\x6e\x2f\x69\x6d\x70\x6f\x72"
  "\x74\x73\x1c\x70\x61\x63\x6b\x61\x67\x65\x2d\x64\x65\x73\x63\x72"
  "\x69\x70\x74\x69\x6f\x6e\x2f\x65\x78\x70\x6f\x72\x74\x73\x23\x70"
  "\x61\x63\x6b\x61\x67\x65\x2d\x64\x65\x73\x63\x72\x69\x70\x74\x69"
  "\x6f\x6e\x2f\x69\x6e\x74\x65\x72\x6e\x61\x6c\x2d\x6e\x61\x6d\x65"
  "\x73\x1e\x70\x61\x63\x6b\x61\x67\x65\x2d\x64\x65\x73\x63\x72\x69"
  "\x70\x74\x69\x6f\x6e\x2f\x61\x6e\x63\x65\x73\x74\x6f\x72\x73\x19"
  "\x70\x61\x63\x6b\x61\x67\x65\x2d\x64\x65\x73\x63\x72\x69\x70\x74"
  "\x69\x6f\x6e\x2f\x6e\x61\x6d\x65\x19\x6d\x61\x6b\x65\x2d\x70\x61"
  "\x63\x6b\x61\x67\x65\x2d\x64\x65\x73\x63\x72\x69\x70\x74\x69\x6f"
  "\x6e\x13\x70\x61\x63\x6b\x61\x67\x65\x2d\x66\x69\x6c\x65\x2f\x6c"
  "\x6f\x61\x64\x73\x1a\x70\x61\x63\x6b\x61\x67\x65\x2d\x66\x69\x6c"
  "\x65\x2f\x64\x65\x73\x63\x72\x69\x70\x74\x69\x6f\x6e\x73\x15\x70"
  "\x61\x63\x6b\x61\x67\x65\x2d\x66\x69\x6c\x65\x2f\x76\x65\x72\x73"
  "\x69\x6f\x6e\x11\x70\x61\x63\x6b\x61\x67\x65\x2d\x66\x69\x6c\x65"
  "\x2f\x74\x61\x67\x12\x6d\x61\x6b\x65\x2d\x70\x61\x63\x6b\x61\x67"
  "\x65\x2d\x66\x69\x6c\x65\x2e\x2a\x1c\x73\x79\x73\x74\x65\x6d\x2d"
  "\x6c\x6f\x61\x64\x65\x72\x2f\x65\x6e\x61\x62\x6c\x65\x2d\x71\x75"
  "\x65\x72\x79\x3f\x11\x6c\x6f\x61\x64\x2d\x70\x61\x63\x6b\x61\x67"
  "\x65\x2d\x73\x65\x74\x14\x69\x6e\x69\x74\x69\x61\x6c\x69\x7a\x65"
  "\x2d\x70\x61\x63\x6b\x61\x67\x65\x21\x13\x52\x21\x50\x11\x70\x61"
  "\x63\x6b\x61\x67\x65\x2d\x6e\x61\x6d\x65\x2d\x74\x61\x67\x1d\x15"
  "\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x2d\x3e\x70\x61\x63"
  "\x6b\x61\x67\x65\x0e\x6e\x61\x6d\x65\x2d\x3e\x70\x61\x63\x6b\x61"
  "\x67\x65\x14\x1b\x1e\x66\x69\x6e\x61\x6c\x69\x7a\x65\x2d\x70\x61"
  "\x63\x6b\x61\x67\x65\x2d\x72\x65\x63\x6f\x72\x64\x2d\x74\x79\x70"
  "\x65\x21\x12\x70\x61\x63\x6b\x61\x67\x65\x2f\x72\x65\x66\x65\x72"
  "\x65\x6e\x63\x65\x4a\x19\x73\x65\x74\x2d\x70\x61\x63\x6b\x61\x67"
  "\x65\x2f\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x21\x14\x70"
  "\x61\x63\x6b\x61\x67\x65\x2f\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65"
  "\x6e\x74\x0e\x70\x61\x63\x6b\x61\x67\x65\x2f\x25\x6e\x61\x6d\x65"
  "\x16\x73\x65\x74\x2d\x70\x61\x63\x6b\x61\x67\x65\x2f\x63\x68\x69"
  "\x6c\x64\x72\x65\x6e\x21\x11\x70\x61\x63\x6b\x61\x67\x65\x2f\x63"
  "\x68\x69\x6c\x64\x72\x65\x6e\x0f\x70\x61\x63\x6b\x61\x67\x65\x2f"
  "\x70\x61\x72\x65\x6e\x74\x1f\x0d\x6d\x61\x6b\x65\x2d\x70\x61\x63"
  "\x6b\x61\x67\x65\x43\x0d\x6f\x62\x6a\x65\x63\x74\x2d\x64\x61\x74"
  "\x75\x6d\x05\x10\x64\x65\x66\x69\x6e\x65\x2d\x6d\x75\x6c\x74\x69"
  "\x70\x6c\x65\x02\x06\x0e\x80\x80\x04\x05\x0c\x81\x81\x02\x04\x0a"
  "\x81\x81\x02\x03\x08\x81\x87\x02\x02\x06\x81\x85\x02\x01\x04\x81"
  "\x83\x02\x0d\x1c";

SCHEME_OBJECT *
packag_so_data_86685bc3d3277846 (entry_count_t dispatch_base)
{
  SCHEME_OBJECT ccb;
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES_FOR_DATA ();

  ccb = (unstackify (((unsigned char *) (& (prog_packag_so_data_86685bc3d3277846 [0]))), (sizeof (prog_packag_so_data_86685bc3d3277846)), dispatch_base));
  current_block = (OBJECT_ADDRESS (ccb));
  return (& (current_block [LABEL_10]));
}

DECLARE_COMPILED_DATA_NS ("packag.so", packag_so_data_86685bc3d3277846)

#endif /* !WANT_ONLY_CODE */

DECLARE_DYNAMIC_INITIALIZATION ("packag.so", "fa6a0c524e0213a9")
