/* Emacs: this is -*- C -*- code, */
/* generated 2007-09-09T13:50:16-0400 by Liar version UNKNOWN. */

#include "liarc.h"

#define LABEL_1_4 3
#define LABEL_1_5 5
#define TAG_1_6 1
#define LABEL_1_8 7
#define ENVIRONMENT_LABEL_1_3 16
#define DEBUGGING_LABEL_1_2 15
#define EXECUTE_CACHE_1_9 9
#define EXECUTE_CACHE_1_7 11
#define FREE_REFERENCE_1_0 14
#define FREE_REFERENCES_LABEL_1_0 8
#define NUMBER_OF_LINKER_SECTIONS_1_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rinvex_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_1_4);
      goto invertible_expression_elimination_1;

    case 1:
      current_block = (Rpc - LABEL_1_5);
      goto lambda_6;

    case 2:
      current_block = (Rpc - LABEL_1_8);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (invertible_expression_elimination_5)
DEFLABEL (invertible_expression_elimination_1)
  INTERRUPT_CHECK (26, LABEL_1_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_7]));

DEFLABEL (lambda_6)
  CLOSURE_HEADER (LABEL_1_5);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_8;
  Wrd5 = Wrd9;

DEFLABEL (label_7)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd11.Obj) = ((Wrd13.pObj) [2]);
  (Rsp [1]) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_9]));

DEFLABEL (label_8)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_8])), (Wrd6.pObj));

DEFLABEL (label_3)
  (Wrd5.Obj) = Rvl;
  goto label_7;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_2_4 3
#define LABEL_2_6 5
#define LABEL_2_5 7
#define LABEL_2_8 9
#define LABEL_2_10 11
#define TAG_2_11 4
#define LABEL_2_17 13
#define LABEL_2_18 15
#define LABEL_2_19 17
#define LABEL_2_20 19
#define LABEL_2_21 21
#define LABEL_2_22 23
#define LABEL_2_23 25
#define LABEL_2_24 27
#define LABEL_2_12 29
#define TAG_2_13 13
#define LABEL_2_14 31
#define TAG_2_15 14
#define LABEL_2_28 33
#define LABEL_2_29 35
#define LABEL_2_30 37
#define LABEL_2_31 39
#define LABEL_2_32 41
#define LABEL_2_33 43
#define LABEL_2_34 45
#define LABEL_2_35 47
#define LABEL_2_25 49
#define LABEL_2_26 51
#define LABEL_2_37 53
#define LABEL_2_39 55
#define LABEL_2_40 57
#define ENVIRONMENT_LABEL_2_3 90
#define DEBUGGING_LABEL_2_2 89
#define OBJECT_2_3 88
#define OBJECT_2_2 87
#define OBJECT_2_1 86
#define OBJECT_2_0 85
#define EXECUTE_CACHE_2_42 59
#define EXECUTE_CACHE_2_41 61
#define EXECUTE_CACHE_2_38 63
#define EXECUTE_CACHE_2_36 65
#define EXECUTE_CACHE_2_27 67
#define EXECUTE_CACHE_2_16 69
#define EXECUTE_CACHE_2_9 71
#define EXECUTE_CACHE_2_7 73
#define FREE_REFERENCE_2_3 76
#define FREE_REFERENCE_2_2 77
#define FREE_REFERENCE_2_1 78
#define FREE_REFERENCE_2_0 79
#define FREE_ASSIGNMENT_2_3 81
#define FREE_ASSIGNMENT_2_2 82
#define FREE_ASSIGNMENT_2_1 83
#define FREE_ASSIGNMENT_2_0 84
#define FREE_REFERENCES_LABEL_2_0 58
#define NUMBER_OF_LINKER_SECTIONS_2_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rinvex_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd180;
  machine_word Wrd179;
  machine_word Wrd178;
  machine_word Wrd177;
  machine_word Wrd176;
  machine_word Wrd172;
  machine_word Wrd171;
  machine_word Wrd164;
  machine_word Wrd163;
  machine_word Wrd151;
  machine_word Wrd156;
  machine_word Wrd155;
  machine_word Wrd152;
  machine_word Wrd148;
  machine_word Wrd141;
  machine_word Wrd140;
  machine_word Wrd139;
  machine_word Wrd136;
  machine_word Wrd135;
  machine_word Wrd134;
  machine_word Wrd133;
  machine_word Wrd132;
  machine_word Wrd128;
  machine_word Wrd127;
  machine_word Wrd120;
  machine_word Wrd119;
  machine_word Wrd107;
  machine_word Wrd112;
  machine_word Wrd111;
  machine_word Wrd108;
  machine_word Wrd104;
  machine_word Wrd97;
  machine_word Wrd96;
  machine_word Wrd95;
  machine_word Wrd92;
  machine_word Wrd91;
  machine_word Wrd90;
  machine_word Wrd89;
  machine_word Wrd88;
  machine_word Wrd84;
  machine_word Wrd83;
  machine_word Wrd76;
  machine_word Wrd75;
  machine_word Wrd63;
  machine_word Wrd68;
  machine_word Wrd67;
  machine_word Wrd64;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd32;
  machine_word Wrd20;
  machine_word Wrd16;
  machine_word Wrd9;
  machine_word Wrd5;
  machine_word Wrd50;
  machine_word Wrd34;
  machine_word Wrd29;
  machine_word Wrd30;
  machine_word Wrd17;
  machine_word Wrd21;
  machine_word Wrd23;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd59;
  machine_word Wrd58;
  machine_word Wrd60;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd48;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd35;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd31;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd10;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_2_4);
      goto walk_rgraph_59;

    case 1:
      current_block = (Rpc - LABEL_2_6);
      goto label_61;

    case 2:
      current_block = (Rpc - LABEL_2_5);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_2_8);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_2_10);
      goto lambda_81;

    case 5:
      current_block = (Rpc - LABEL_2_17);
      goto label_62;

    case 6:
      current_block = (Rpc - LABEL_2_18);
      goto label_63;

    case 7:
      current_block = (Rpc - LABEL_2_19);
      goto label_64;

    case 8:
      current_block = (Rpc - LABEL_2_20);
      goto label_65;

    case 9:
      current_block = (Rpc - LABEL_2_21);
      goto label_66;

    case 10:
      current_block = (Rpc - LABEL_2_22);
      goto label_67;

    case 11:
      current_block = (Rpc - LABEL_2_23);
      goto label_68;

    case 12:
      current_block = (Rpc - LABEL_2_24);
      goto label_69;

    case 13:
      current_block = (Rpc - LABEL_2_12);
      goto lambda_82;

    case 14:
      current_block = (Rpc - LABEL_2_14);
      goto lambda_83;

    case 15:
      current_block = (Rpc - LABEL_2_28);
      goto label_70;

    case 16:
      current_block = (Rpc - LABEL_2_29);
      goto label_71;

    case 17:
      current_block = (Rpc - LABEL_2_30);
      goto label_72;

    case 18:
      current_block = (Rpc - LABEL_2_31);
      goto label_73;

    case 19:
      current_block = (Rpc - LABEL_2_32);
      goto label_74;

    case 20:
      current_block = (Rpc - LABEL_2_33);
      goto label_75;

    case 21:
      current_block = (Rpc - LABEL_2_34);
      goto label_76;

    case 22:
      current_block = (Rpc - LABEL_2_35);
      goto label_77;

    case 23:
      current_block = (Rpc - LABEL_2_25);
      goto continuation_31;

    case 24:
      current_block = (Rpc - LABEL_2_26);
      goto continuation_30;

    case 25:
      current_block = (Rpc - LABEL_2_37);
      goto lambda_29;

    case 26:
      current_block = (Rpc - LABEL_2_39);
      goto label_78;

    case 27:
      current_block = (Rpc - LABEL_2_40);
      goto continuation_28;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (walk_rgraph_80)
DEFLABEL (walk_rgraph_59)
  INTERRUPT_CHECK (26, LABEL_2_4);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd12.pObj) = (& (Rhp [-1]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd18.pObj) = (& (Rhp [-1]));
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd18.pObj)));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd24.pObj) = (& (Rhp [-1]));
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd24.pObj)));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_5]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd42.Obj) = (Rsp [6]);
  (Wrd43.uLng) = (OBJECT_TYPE (Wrd42.Obj));
  if (! ((Wrd43.uLng) == 10))
    goto label_86;
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd42.Obj));
  (Wrd40.Obj) = ((Wrd39.pObj) [0]);
  (Wrd41.Lng) = (FIXNUM_TO_LONG (Wrd40.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd41.Lng))))
    goto label_86;
  (Wrd35.Obj) = ((Wrd39.pObj) [1]);
  (* (--Rsp)) = (Wrd35.Obj);

DEFLABEL (label_85)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_7]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_2_5);
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (current_block [OBJECT_2_2]);
  (* (Rhp++)) = (Wrd8.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_8]))));
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_9]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_2_8);
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (Rsp [7]);
  (* (Rhp++)) = (Wrd8.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd54.pObj) = (& (Rhp [-1]));
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd54.pObj)));
  (Rsp [1]) = (Wrd55.Obj);
  (Wrd60.Obj) = (Rsp [3]);
  (* (Rhp++)) = (Wrd60.Obj);
  (Wrd58.pObj) = (& (Rhp [-1]));
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd58.pObj)));
  (Rsp [3]) = (Wrd59.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 11));
  (Wrd11.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_2_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_2_10])));
  Rhp += 8;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd11.pObj)));
  Wrd26 = Wrd11;
  (Wrd27.Obj) = (Rsp [7]);
  ((Wrd26.pObj) [2]) = (Wrd27.Obj);
  (Wrd25.Obj) = (Rsp [6]);
  ((Wrd26.pObj) [3]) = (Wrd25.Obj);
  (Wrd23.Obj) = (Rsp [5]);
  ((Wrd26.pObj) [4]) = (Wrd23.Obj);
  (Wrd21.Obj) = (Rsp [4]);
  ((Wrd26.pObj) [5]) = (Wrd21.Obj);
  ((Wrd26.pObj) [6]) = (Wrd59.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  ((Wrd26.pObj) [7]) = (Wrd17.Obj);
  ((Wrd26.pObj) [8]) = (Wrd55.Obj);
  ((Wrd26.pObj) [9]) = (Wrd7.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd30.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_2_13);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_2_12])));
  Rhp += 1;
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd30.pObj)));
  ((Wrd30.pObj) [2]) = (Wrd8.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 11));
  (Wrd35.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_2_15);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_2_14])));
  Rhp += 8;
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd35.pObj)));
  Wrd50 = Wrd35;
  ((Wrd50.pObj) [2]) = (Wrd27.Obj);
  ((Wrd50.pObj) [3]) = (Wrd25.Obj);
  ((Wrd50.pObj) [4]) = (Wrd23.Obj);
  ((Wrd50.pObj) [5]) = (Wrd21.Obj);
  ((Wrd50.pObj) [6]) = (Wrd59.Obj);
  ((Wrd50.pObj) [7]) = (Wrd17.Obj);
  ((Wrd50.pObj) [8]) = (Wrd55.Obj);
  ((Wrd50.pObj) [9]) = (Wrd7.Obj);
  (Rsp [8]) = (Wrd34.Obj);
  (Rsp [7]) = (Wrd29.Obj);
  (Rsp [6]) = (Wrd10.Obj);
  Rsp = (& (Rsp [6]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_16]));

DEFLABEL (label_86)
  (Wrd44.Obj) = (Rsp [6]);
  (Wrd45.Obj) = (current_block [OBJECT_2_0]);
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_6]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_1]), 2);

DEFLABEL (label_61)
  (* (--Rsp)) = Rvl;
  goto label_85;

DEFLABEL (lambda_81)
  CLOSURE_HEADER (LABEL_2_10);

DEFLABEL (lambda_27)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [9]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_110;

DEFLABEL (label_109)
  Wrd19 = Wrd23;

DEFLABEL (label_108)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_2_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_107;

DEFLABEL (label_106)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_105)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [5]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  (Wrd51.Obj) = ((Wrd46.pObj) [8]);
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [0]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd60.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd52.pObj) [0]) = (Wrd60.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd64.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_1]));
  (Wrd67.Obj) = ((Wrd64.pObj) [0]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if ((Wrd68.uLng) == 50)
    goto label_104;

DEFLABEL (label_103)
  Wrd63 = Wrd67;

DEFLABEL (label_102)
  (* (--Rsp)) = (Wrd63.Obj);
  (Wrd75.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_2_1]));
  (Wrd76.Obj) = (Rsp [1]);
  (Wrd83.Obj) = ((Wrd75.pObj) [0]);
  (Wrd84.uLng) = (OBJECT_TYPE (Wrd83.Obj));
  if ((Wrd84.uLng) == 50)
    goto label_101;

DEFLABEL (label_100)
  ((Wrd75.pObj) [0]) = (Wrd76.Obj);

DEFLABEL (label_99)
  (Wrd88.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd89.Obj) = (Rsp [0]);
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd89.Obj));
  (Wrd91.Obj) = ((Wrd90.pObj) [4]);
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  ((Wrd92.pObj) [0]) = (Wrd88.Obj);
  (Wrd95.Obj) = ((Wrd90.pObj) [7]);
  (Wrd96.pObj) = (OBJECT_ADDRESS (Wrd95.Obj));
  (Wrd97.Obj) = ((Wrd96.pObj) [0]);
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd104.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd96.pObj) [0]) = (Wrd104.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd108.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_2]));
  (Wrd111.Obj) = ((Wrd108.pObj) [0]);
  (Wrd112.uLng) = (OBJECT_TYPE (Wrd111.Obj));
  if ((Wrd112.uLng) == 50)
    goto label_98;

DEFLABEL (label_97)
  Wrd107 = Wrd111;

DEFLABEL (label_96)
  (* (--Rsp)) = (Wrd107.Obj);
  (Wrd119.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_2_2]));
  (Wrd120.Obj) = (Rsp [1]);
  (Wrd127.Obj) = ((Wrd119.pObj) [0]);
  (Wrd128.uLng) = (OBJECT_TYPE (Wrd127.Obj));
  if ((Wrd128.uLng) == 50)
    goto label_95;

DEFLABEL (label_94)
  ((Wrd119.pObj) [0]) = (Wrd120.Obj);

DEFLABEL (label_93)
  (Wrd132.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd133.Obj) = (Rsp [0]);
  (Wrd134.pObj) = (OBJECT_ADDRESS (Wrd133.Obj));
  (Wrd135.Obj) = ((Wrd134.pObj) [3]);
  (Wrd136.pObj) = (OBJECT_ADDRESS (Wrd135.Obj));
  ((Wrd136.pObj) [0]) = (Wrd132.Obj);
  (Wrd139.Obj) = ((Wrd134.pObj) [6]);
  (Wrd140.pObj) = (OBJECT_ADDRESS (Wrd139.Obj));
  (Wrd141.Obj) = ((Wrd140.pObj) [0]);
  (* (--Rsp)) = (Wrd141.Obj);
  (Wrd148.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd140.pObj) [0]) = (Wrd148.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd141.Obj);
  (Wrd152.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_3]));
  (Wrd155.Obj) = ((Wrd152.pObj) [0]);
  (Wrd156.uLng) = (OBJECT_TYPE (Wrd155.Obj));
  if ((Wrd156.uLng) == 50)
    goto label_92;

DEFLABEL (label_91)
  Wrd151 = Wrd155;

DEFLABEL (label_90)
  (* (--Rsp)) = (Wrd151.Obj);
  (Wrd163.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_2_3]));
  (Wrd164.Obj) = (Rsp [1]);
  (Wrd171.Obj) = ((Wrd163.pObj) [0]);
  (Wrd172.uLng) = (OBJECT_TYPE (Wrd171.Obj));
  if ((Wrd172.uLng) == 50)
    goto label_89;

DEFLABEL (label_88)
  ((Wrd163.pObj) [0]) = (Wrd164.Obj);

DEFLABEL (label_87)
  (Wrd176.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd177.Obj) = (Rsp [0]);
  (Wrd178.pObj) = (OBJECT_ADDRESS (Wrd177.Obj));
  (Wrd179.Obj) = ((Wrd178.pObj) [2]);
  (Wrd180.pObj) = (OBJECT_ADDRESS (Wrd179.Obj));
  ((Wrd180.pObj) [0]) = (Wrd176.Obj);
  Rvl = (current_block [OBJECT_2_3]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_89)
  if ((Wrd171.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_88;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_2_24])), (Wrd163.pObj), (Wrd164.Obj));

DEFLABEL (label_69)
  goto label_87;

DEFLABEL (label_92)
  if ((Wrd155.Obj) == (Wrd148.Obj))
    goto label_91;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_2_23])), (Wrd152.pObj));

DEFLABEL (label_68)
  (Wrd151.Obj) = Rvl;
  goto label_90;

DEFLABEL (label_95)
  if ((Wrd127.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_94;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_2_22])), (Wrd119.pObj), (Wrd120.Obj));

DEFLABEL (label_67)
  goto label_93;

DEFLABEL (label_98)
  if ((Wrd111.Obj) == (Wrd104.Obj))
    goto label_97;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_2_21])), (Wrd108.pObj));

DEFLABEL (label_66)
  (Wrd107.Obj) = Rvl;
  goto label_96;

DEFLABEL (label_101)
  if ((Wrd83.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_100;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_2_20])), (Wrd75.pObj), (Wrd76.Obj));

DEFLABEL (label_65)
  goto label_99;

DEFLABEL (label_104)
  if ((Wrd67.Obj) == (Wrd60.Obj))
    goto label_103;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_2_19])), (Wrd64.pObj));

DEFLABEL (label_64)
  (Wrd63.Obj) = Rvl;
  goto label_102;

DEFLABEL (label_107)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_106;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_2_18])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_63)
  goto label_105;

DEFLABEL (label_110)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_109;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_2_17])), (Wrd20.pObj));

DEFLABEL (label_62)
  (Wrd19.Obj) = Rvl;
  goto label_108;

DEFLABEL (lambda_82)
  CLOSURE_HEADER (LABEL_2_12);

DEFLABEL (lambda_32)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_25]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_26]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_27]));

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_2_26);
  (* (--Rsp)) = Rvl;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_37]))));
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_38]));

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_2_25);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_36]));

DEFLABEL (lambda_83)
  CLOSURE_HEADER (LABEL_2_14);

DEFLABEL (lambda_57)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [5]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd8.pObj) [0]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_134;

DEFLABEL (label_133)
  Wrd19 = Wrd23;

DEFLABEL (label_132)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_2_0]));
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd39.Obj) = ((Wrd31.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_131;

DEFLABEL (label_130)
  ((Wrd31.pObj) [0]) = (Wrd32.Obj);

DEFLABEL (label_129)
  (Wrd44.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd47.Obj) = ((Wrd46.pObj) [9]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  ((Wrd48.pObj) [0]) = (Wrd44.Obj);
  (Wrd51.Obj) = ((Wrd46.pObj) [4]);
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [0]);
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd60.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd52.pObj) [0]) = (Wrd60.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd64.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_1]));
  (Wrd67.Obj) = ((Wrd64.pObj) [0]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if ((Wrd68.uLng) == 50)
    goto label_128;

DEFLABEL (label_127)
  Wrd63 = Wrd67;

DEFLABEL (label_126)
  (* (--Rsp)) = (Wrd63.Obj);
  (Wrd75.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_2_1]));
  (Wrd76.Obj) = (Rsp [1]);
  (Wrd83.Obj) = ((Wrd75.pObj) [0]);
  (Wrd84.uLng) = (OBJECT_TYPE (Wrd83.Obj));
  if ((Wrd84.uLng) == 50)
    goto label_125;

DEFLABEL (label_124)
  ((Wrd75.pObj) [0]) = (Wrd76.Obj);

DEFLABEL (label_123)
  (Wrd88.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd89.Obj) = (Rsp [0]);
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd89.Obj));
  (Wrd91.Obj) = ((Wrd90.pObj) [8]);
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  ((Wrd92.pObj) [0]) = (Wrd88.Obj);
  (Wrd95.Obj) = ((Wrd90.pObj) [3]);
  (Wrd96.pObj) = (OBJECT_ADDRESS (Wrd95.Obj));
  (Wrd97.Obj) = ((Wrd96.pObj) [0]);
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd104.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd96.pObj) [0]) = (Wrd104.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd108.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_2]));
  (Wrd111.Obj) = ((Wrd108.pObj) [0]);
  (Wrd112.uLng) = (OBJECT_TYPE (Wrd111.Obj));
  if ((Wrd112.uLng) == 50)
    goto label_122;

DEFLABEL (label_121)
  Wrd107 = Wrd111;

DEFLABEL (label_120)
  (* (--Rsp)) = (Wrd107.Obj);
  (Wrd119.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_2_2]));
  (Wrd120.Obj) = (Rsp [1]);
  (Wrd127.Obj) = ((Wrd119.pObj) [0]);
  (Wrd128.uLng) = (OBJECT_TYPE (Wrd127.Obj));
  if ((Wrd128.uLng) == 50)
    goto label_119;

DEFLABEL (label_118)
  ((Wrd119.pObj) [0]) = (Wrd120.Obj);

DEFLABEL (label_117)
  (Wrd132.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd133.Obj) = (Rsp [0]);
  (Wrd134.pObj) = (OBJECT_ADDRESS (Wrd133.Obj));
  (Wrd135.Obj) = ((Wrd134.pObj) [7]);
  (Wrd136.pObj) = (OBJECT_ADDRESS (Wrd135.Obj));
  ((Wrd136.pObj) [0]) = (Wrd132.Obj);
  (Wrd139.Obj) = ((Wrd134.pObj) [2]);
  (Wrd140.pObj) = (OBJECT_ADDRESS (Wrd139.Obj));
  (Wrd141.Obj) = ((Wrd140.pObj) [0]);
  (* (--Rsp)) = (Wrd141.Obj);
  (Wrd148.Obj) = (MAKE_OBJECT (50, 0));
  ((Wrd140.pObj) [0]) = (Wrd148.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd141.Obj);
  (Wrd152.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_3]));
  (Wrd155.Obj) = ((Wrd152.pObj) [0]);
  (Wrd156.uLng) = (OBJECT_TYPE (Wrd155.Obj));
  if ((Wrd156.uLng) == 50)
    goto label_116;

DEFLABEL (label_115)
  Wrd151 = Wrd155;

DEFLABEL (label_114)
  (* (--Rsp)) = (Wrd151.Obj);
  (Wrd163.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_2_3]));
  (Wrd164.Obj) = (Rsp [1]);
  (Wrd171.Obj) = ((Wrd163.pObj) [0]);
  (Wrd172.uLng) = (OBJECT_TYPE (Wrd171.Obj));
  if ((Wrd172.uLng) == 50)
    goto label_113;

DEFLABEL (label_112)
  ((Wrd163.pObj) [0]) = (Wrd164.Obj);

DEFLABEL (label_111)
  (Wrd176.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  (Wrd177.Obj) = (Rsp [0]);
  (Wrd178.pObj) = (OBJECT_ADDRESS (Wrd177.Obj));
  (Wrd179.Obj) = ((Wrd178.pObj) [6]);
  (Wrd180.pObj) = (OBJECT_ADDRESS (Wrd179.Obj));
  ((Wrd180.pObj) [0]) = (Wrd176.Obj);
  Rvl = (current_block [OBJECT_2_3]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_113)
  if ((Wrd171.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_112;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_2_35])), (Wrd163.pObj), (Wrd164.Obj));

DEFLABEL (label_77)
  goto label_111;

DEFLABEL (label_116)
  if ((Wrd155.Obj) == (Wrd148.Obj))
    goto label_115;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_2_34])), (Wrd152.pObj));

DEFLABEL (label_76)
  (Wrd151.Obj) = Rvl;
  goto label_114;

DEFLABEL (label_119)
  if ((Wrd127.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_118;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_2_33])), (Wrd119.pObj), (Wrd120.Obj));

DEFLABEL (label_75)
  goto label_117;

DEFLABEL (label_122)
  if ((Wrd111.Obj) == (Wrd104.Obj))
    goto label_121;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_2_32])), (Wrd108.pObj));

DEFLABEL (label_74)
  (Wrd107.Obj) = Rvl;
  goto label_120;

DEFLABEL (label_125)
  if ((Wrd83.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_124;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_2_31])), (Wrd75.pObj), (Wrd76.Obj));

DEFLABEL (label_73)
  goto label_123;

DEFLABEL (label_128)
  if ((Wrd67.Obj) == (Wrd60.Obj))
    goto label_127;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_2_30])), (Wrd64.pObj));

DEFLABEL (label_72)
  (Wrd63.Obj) = Rvl;
  goto label_126;

DEFLABEL (label_131)
  if ((Wrd39.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_130;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_2_29])), (Wrd31.pObj), (Wrd32.Obj));

DEFLABEL (label_71)
  goto label_129;

DEFLABEL (label_134)
  if ((Wrd23.Obj) == (Wrd16.Obj))
    goto label_133;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_2_28])), (Wrd20.pObj));

DEFLABEL (label_70)
  (Wrd19.Obj) = Rvl;
  goto label_132;

DEFLABEL (lambda_84)
DEFLABEL (lambda_29)
  INTERRUPT_CHECK (26, LABEL_2_37);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_1]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_136;
  Wrd5 = Wrd9;

DEFLABEL (label_135)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_40]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_41]));

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_2_40);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_42]));

DEFLABEL (label_136)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_39])), (Wrd6.pObj));

DEFLABEL (label_78)
  (Wrd5.Obj) = Rvl;
  goto label_135;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_3_4 3
#define LABEL_3_5 5
#define LABEL_3_7 7
#define LABEL_3_9 9
#define LABEL_3_10 11
#define LABEL_3_11 13
#define LABEL_3_12 15
#define LABEL_3_13 17
#define LABEL_3_14 19
#define LABEL_3_15 21
#define LABEL_3_16 23
#define LABEL_3_6 25
#define LABEL_3_19 27
#define LABEL_3_18 29
#define LABEL_3_22 31
#define LABEL_3_21 33
#define ENVIRONMENT_LABEL_3_3 55
#define DEBUGGING_LABEL_3_2 54
#define OBJECT_3_3 53
#define OBJECT_3_2 52
#define OBJECT_3_1 51
#define OBJECT_3_0 50
#define EXECUTE_CACHE_3_23 35
#define EXECUTE_CACHE_3_20 37
#define EXECUTE_CACHE_3_17 39
#define EXECUTE_CACHE_3_8 41
#define FREE_REFERENCE_3_2 44
#define FREE_REFERENCE_3_1 45
#define FREE_REFERENCE_3_0 46
#define FREE_ASSIGNMENT_3_1 48
#define FREE_ASSIGNMENT_3_0 49
#define FREE_REFERENCES_LABEL_3_0 34
#define NUMBER_OF_LINKER_SECTIONS_3_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rinvex_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd12;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd82;
  machine_word Wrd74;
  machine_word Wrd76;
  machine_word Wrd78;
  machine_word Wrd77;
  machine_word Wrd71;
  machine_word Wrd70;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd53;
  machine_word Wrd55;
  machine_word Wrd57;
  machine_word Wrd56;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd34;
  machine_word Wrd35;
  machine_word Wrd36;
  machine_word Wrd28;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd14;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd86;
  machine_word Wrd91;
  machine_word Wrd90;
  machine_word Wrd87;
  machine_word Wrd85;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_3_4);
      goto continue_walk_9;

    case 1:
      current_block = (Rpc - LABEL_3_5);
      goto label_11;

    case 2:
      current_block = (Rpc - LABEL_3_7);
      goto label_20;

    case 3:
      current_block = (Rpc - LABEL_3_9);
      goto label_12;

    case 4:
      current_block = (Rpc - LABEL_3_10);
      goto label_13;

    case 5:
      current_block = (Rpc - LABEL_3_11);
      goto label_14;

    case 6:
      current_block = (Rpc - LABEL_3_12);
      goto label_15;

    case 7:
      current_block = (Rpc - LABEL_3_13);
      goto label_16;

    case 8:
      current_block = (Rpc - LABEL_3_14);
      goto label_17;

    case 9:
      current_block = (Rpc - LABEL_3_15);
      goto label_18;

    case 10:
      current_block = (Rpc - LABEL_3_16);
      goto label_19;

    case 11:
      current_block = (Rpc - LABEL_3_6);
      goto continuation_6;

    case 12:
      current_block = (Rpc - LABEL_3_19);
      goto label_21;

    case 13:
      current_block = (Rpc - LABEL_3_18);
      goto continuation_7;

    case 14:
      current_block = (Rpc - LABEL_3_22);
      goto label_22;

    case 15:
      current_block = (Rpc - LABEL_3_21);
      goto continuation_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (continue_walk_24)
DEFLABEL (continue_walk_9)
  INTERRUPT_CHECK (26, LABEL_3_4);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3_0]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_52;
  Wrd6 = Wrd10;

DEFLABEL (label_51)
  if ((Wrd6.Obj) == (current_block [OBJECT_3_0]))
    goto label_43;
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3_0]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_42;
  Wrd14 = Wrd18;

DEFLABEL (label_41)
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_40;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (* (--Rsp)) = (Wrd21.Obj);

DEFLABEL (label_39)
  (Wrd29.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3_0]));
  (Wrd32.Obj) = ((Wrd29.pObj) [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd33.uLng) == 50)
    goto label_38;
  Wrd28 = Wrd32;

DEFLABEL (label_37)
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if (! ((Wrd36.uLng) == 1))
    goto label_36;
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd34.Obj) = ((Wrd35.pObj) [1]);

DEFLABEL (label_35)
  (Wrd41.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_3_0]));
  (Wrd49.Obj) = ((Wrd41.pObj) [0]);
  (Wrd50.uLng) = (OBJECT_TYPE (Wrd49.Obj));
  if ((Wrd50.uLng) == 50)
    goto label_34;

DEFLABEL (label_33)
  ((Wrd41.pObj) [0]) = (Wrd34.Obj);

DEFLABEL (label_32)
  (Wrd56.Obj) = (Rsp [0]);
  (Wrd57.uLng) = (OBJECT_TYPE (Wrd56.Obj));
  if (! ((Wrd57.uLng) == 1))
    goto label_31;
  (Wrd55.pObj) = (OBJECT_ADDRESS (Wrd56.Obj));
  (Wrd53.Obj) = ((Wrd55.pObj) [0]);

DEFLABEL (label_30)
  (Wrd62.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_3_1]));
  (Wrd70.Obj) = ((Wrd62.pObj) [0]);
  (Wrd71.uLng) = (OBJECT_TYPE (Wrd70.Obj));
  if ((Wrd71.uLng) == 50)
    goto label_29;

DEFLABEL (label_28)
  ((Wrd62.pObj) [0]) = (Wrd53.Obj);

DEFLABEL (label_27)
  (Wrd77.Obj) = (Rsp [0]);
  (Wrd78.uLng) = (OBJECT_TYPE (Wrd77.Obj));
  if (! ((Wrd78.uLng) == 1))
    goto label_26;
  (Wrd76.pObj) = (OBJECT_ADDRESS (Wrd77.Obj));
  (Wrd74.Obj) = ((Wrd76.pObj) [1]);

DEFLABEL (label_25)
  (Rsp [0]) = (Wrd74.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_17]));

DEFLABEL (label_26)
  (Wrd82.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_16]))));
  (* (--Rsp)) = (Wrd82.Obj);
  (* (--Rsp)) = (Wrd77.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_2]), 1);

DEFLABEL (label_19)
  (Wrd74.Obj) = Rvl;
  goto label_25;

DEFLABEL (label_29)
  if ((Wrd70.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_28;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_3_15])), (Wrd62.pObj), (Wrd53.Obj));

DEFLABEL (label_18)
  goto label_27;

DEFLABEL (label_31)
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_14]))));
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_1]), 1);

DEFLABEL (label_17)
  (Wrd53.Obj) = Rvl;
  goto label_30;

DEFLABEL (label_34)
  if ((Wrd49.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_33;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_3_13])), (Wrd41.pObj), (Wrd34.Obj));

DEFLABEL (label_16)
  goto label_32;

DEFLABEL (label_36)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_12]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_2]), 1);

DEFLABEL (label_15)
  (Wrd34.Obj) = Rvl;
  goto label_35;

DEFLABEL (label_38)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_3_11])), (Wrd29.pObj));

DEFLABEL (label_14)
  (Wrd28.Obj) = Rvl;
  goto label_37;

DEFLABEL (label_40)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_10]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_1]), 1);

DEFLABEL (label_13)
  (* (--Rsp)) = Rvl;
  goto label_39;

DEFLABEL (label_42)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_3_9])), (Wrd15.pObj));

DEFLABEL (label_12)
  (Wrd14.Obj) = Rvl;
  goto label_41;

DEFLABEL (label_43)
  (Wrd85.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_6]))));
  (* (--Rsp)) = (Wrd85.Obj);
  (Wrd87.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3_1]));
  (Wrd90.Obj) = ((Wrd87.pObj) [0]);
  (Wrd91.uLng) = (OBJECT_TYPE (Wrd90.Obj));
  if ((Wrd91.uLng) == 50)
    goto label_50;
  Wrd86 = Wrd90;

DEFLABEL (label_49)
  (* (--Rsp)) = (Wrd86.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_8]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_3_6);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_44;
  Rvl = (current_block [OBJECT_3_3]);
  goto pop_return;

DEFLABEL (label_44)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_18]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3_2]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_48;
  Wrd12 = Wrd16;

DEFLABEL (label_47)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_20]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_3_18);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_21]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3_1]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_46;
  Wrd8 = Wrd12;

DEFLABEL (label_45)
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_23]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_3_21);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_17]));

DEFLABEL (label_46)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_3_22])), (Wrd9.pObj));

DEFLABEL (label_22)
  (Wrd8.Obj) = Rvl;
  goto label_45;

DEFLABEL (label_48)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_3_19])), (Wrd13.pObj));

DEFLABEL (label_21)
  (Wrd12.Obj) = Rvl;
  goto label_47;

DEFLABEL (label_50)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_3_7])), (Wrd87.pObj));

DEFLABEL (label_20)
  (Wrd86.Obj) = Rvl;
  goto label_49;

DEFLABEL (label_52)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_3_5])), (Wrd7.pObj));

DEFLABEL (label_11)
  (Wrd6.Obj) = Rvl;
  goto label_51;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4_4 3
#define LABEL_4_5 5
#define LABEL_4_6 7
#define LABEL_4_8 9
#define LABEL_4_10 11
#define LABEL_4_7 13
#define LABEL_4_12 15
#define LABEL_4_15 17
#define LABEL_4_9 19
#define LABEL_4_13 21
#define LABEL_4_16 23
#define LABEL_4_22 25
#define LABEL_4_20 27
#define LABEL_4_18 29
#define LABEL_4_29 31
#define LABEL_4_31 33
#define LABEL_4_33 35
#define LABEL_4_27 37
#define LABEL_4_35 39
#define LABEL_4_23 41
#define LABEL_4_37 43
#define LABEL_4_39 45
#define LABEL_4_34 47
#define LABEL_4_40 49
#define LABEL_4_41 51
#define LABEL_4_32 53
#define LABEL_4_42 55
#define LABEL_4_30 57
#define LABEL_4_45 59
#define LABEL_4_44 61
#define LABEL_4_43 63
#define LABEL_4_48 65
#define LABEL_4_50 67
#define LABEL_4_53 69
#define LABEL_4_54 71
#define LABEL_4_47 73
#define LABEL_4_55 75
#define LABEL_4_49 77
#define LABEL_4_56 79
#define LABEL_4_52 81
#define ENVIRONMENT_LABEL_4_3 121
#define DEBUGGING_LABEL_4_2 120
#define OBJECT_4_4 119
#define OBJECT_4_3 118
#define OBJECT_4_2 117
#define OBJECT_4_1 116
#define OBJECT_4_0 115
#define EXECUTE_CACHE_4_51 83
#define EXECUTE_CACHE_4_46 85
#define EXECUTE_CACHE_4_38 87
#define EXECUTE_CACHE_4_36 89
#define EXECUTE_CACHE_4_28 91
#define EXECUTE_CACHE_4_26 93
#define EXECUTE_CACHE_4_25 95
#define EXECUTE_CACHE_4_24 97
#define EXECUTE_CACHE_4_21 99
#define EXECUTE_CACHE_4_19 101
#define EXECUTE_CACHE_4_17 103
#define EXECUTE_CACHE_4_14 105
#define EXECUTE_CACHE_4_11 107
#define FREE_REFERENCE_4_2 110
#define FREE_REFERENCE_4_1 111
#define FREE_REFERENCE_4_0 112
#define FREE_ASSIGNMENT_4_0 114
#define FREE_REFERENCES_LABEL_4_0 82
#define NUMBER_OF_LINKER_SECTIONS_4_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rinvex_so_code_4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd27;
  machine_word Wrd6;
  machine_word Wrd41;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd24;
  machine_word Wrd42;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd19;
  machine_word Wrd10;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4_4);
      goto walk_bblock_38;

    case 1:
      current_block = (Rpc - LABEL_4_5);
      goto label_40;

    case 2:
      current_block = (Rpc - LABEL_4_6);
      goto loop_10;

    case 3:
      current_block = (Rpc - LABEL_4_8);
      goto label_41;

    case 4:
      current_block = (Rpc - LABEL_4_10);
      goto label_42;

    case 5:
      current_block = (Rpc - LABEL_4_7);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_4_12);
      goto label_44;

    case 7:
      current_block = (Rpc - LABEL_4_15);
      goto label_43;

    case 8:
      current_block = (Rpc - LABEL_4_9);
      goto continuation_6;

    case 9:
      current_block = (Rpc - LABEL_4_13);
      goto continuation_12;

    case 10:
      current_block = (Rpc - LABEL_4_16);
      goto continuation_13;

    case 11:
      current_block = (Rpc - LABEL_4_22);
      goto continuation_34;

    case 12:
      current_block = (Rpc - LABEL_4_20);
      goto continuation_33;

    case 13:
      current_block = (Rpc - LABEL_4_18);
      goto continuation_14;

    case 14:
      current_block = (Rpc - LABEL_4_29);
      goto continuation_20;

    case 15:
      current_block = (Rpc - LABEL_4_31);
      goto continuation_17;

    case 16:
      current_block = (Rpc - LABEL_4_33);
      goto continuation_16;

    case 17:
      current_block = (Rpc - LABEL_4_27);
      goto continuation_15;

    case 18:
      current_block = (Rpc - LABEL_4_35);
      goto continuation_36;

    case 19:
      current_block = (Rpc - LABEL_4_23);
      goto continuation_35;

    case 20:
      current_block = (Rpc - LABEL_4_37);
      goto label_45;

    case 21:
      current_block = (Rpc - LABEL_4_39);
      goto continuation_22;

    case 22:
      current_block = (Rpc - LABEL_4_34);
      goto continuation_21;

    case 23:
      current_block = (Rpc - LABEL_4_40);
      goto label_46;

    case 24:
      current_block = (Rpc - LABEL_4_41);
      goto continuation_19;

    case 25:
      current_block = (Rpc - LABEL_4_32);
      goto continuation_18;

    case 26:
      current_block = (Rpc - LABEL_4_42);
      goto label_47;

    case 27:
      current_block = (Rpc - LABEL_4_30);
      goto continuation_23;

    case 28:
      current_block = (Rpc - LABEL_4_45);
      goto label_48;

    case 29:
      current_block = (Rpc - LABEL_4_44);
      goto continuation_29;

    case 30:
      current_block = (Rpc - LABEL_4_43);
      goto continuation_24;

    case 31:
      current_block = (Rpc - LABEL_4_48);
      goto label_50;

    case 32:
      current_block = (Rpc - LABEL_4_50);
      goto label_51;

    case 33:
      current_block = (Rpc - LABEL_4_53);
      goto label_49;

    case 34:
      current_block = (Rpc - LABEL_4_54);
      goto continuation_31;

    case 35:
      current_block = (Rpc - LABEL_4_47);
      goto continuation_30;

    case 36:
      current_block = (Rpc - LABEL_4_55);
      goto label_52;

    case 37:
      current_block = (Rpc - LABEL_4_49);
      goto continuation_25;

    case 38:
      current_block = (Rpc - LABEL_4_56);
      goto label_53;

    case 39:
      current_block = (Rpc - LABEL_4_52);
      goto continuation_28;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (walk_bblock_55)
DEFLABEL (walk_bblock_38)
  INTERRUPT_CHECK (26, LABEL_4_4);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_58;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd13.Lng))))
    goto label_58;
  (Wrd7.Obj) = ((Wrd11.pObj) [7]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_57)
  goto loop_10;

DEFLABEL (label_58)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_4_0]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_5]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 2);

DEFLABEL (label_40)
  (* (--Rsp)) = Rvl;
  goto label_57;

DEFLABEL (loop_56)
DEFLABEL (loop_10)
  INTERRUPT_CHECK (26, LABEL_4_6);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_62;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd16.Lng))))
    goto label_62;
  (Wrd10.Obj) = ((Wrd14.pObj) [1]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_61)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_9]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 1))
    goto label_60;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [0]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_59)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_11]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_4_9);
  (* (--Rsp)) = Rvl;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_60)
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_10]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_3]), 1);

DEFLABEL (label_42)
  (* (--Rsp)) = Rvl;
  goto label_59;

DEFLABEL (label_62)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_4_2]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_8]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 2);

DEFLABEL (label_41)
  (* (--Rsp)) = Rvl;
  goto label_61;

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_4_7);
  (Wrd36.Obj) = (Rsp [0]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 10))
    goto label_86;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd35.Lng))))
    goto label_86;
  (Wrd7.Obj) = ((Wrd33.pObj) [3]);
  if (! ((Wrd7.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_83;

DEFLABEL (label_82)
  Rsp = (& (Rsp [1]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_13]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_14]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_4_13);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_17]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_4_16);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_69;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_20]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_21]));

DEFLABEL (continuation_33)
  INTERRUPT_CHECK (27, LABEL_4_20);
  (Rsp [0]) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_64;

DEFLABEL (label_63)
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_25]));

DEFLABEL (label_64)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_22]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_26]));

DEFLABEL (continuation_34)
  INTERRUPT_CHECK (27, LABEL_4_22);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_63;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_23]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_24]));

DEFLABEL (continuation_35)
  INTERRUPT_CHECK (27, LABEL_4_23);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_66;

DEFLABEL (label_65)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_36]));

DEFLABEL (label_66)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_35]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_68;
  Wrd11 = Wrd15;

DEFLABEL (label_67)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_38]));

DEFLABEL (continuation_36)
  INTERRUPT_CHECK (27, LABEL_4_35);
  goto label_65;

DEFLABEL (label_68)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_37])), (Wrd12.pObj));

DEFLABEL (label_45)
  (Wrd11.Obj) = Rvl;
  goto label_67;

DEFLABEL (label_69)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_18]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_19]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_4_18);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_27]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_28]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_4_27);
  (Rsp [1]) = Rvl;
  (Wrd6.Obj) = (Rsp [0]);
  if ((Wrd6.Obj) == ((SCHEME_OBJECT) 0))
    goto label_76;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_33]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_26]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_4_33);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_77;

DEFLABEL (label_76)
  (Wrd12.Obj) = (Rsp [1]);
  if (! ((Wrd12.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_71;

DEFLABEL (label_70)
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_25]));

DEFLABEL (label_71)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_31]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_26]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_4_31);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_70;
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_32]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd36.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd36.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_24]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_4_32);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_73;

DEFLABEL (label_72)
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_36]));

DEFLABEL (label_73)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_41]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_75;
  Wrd11 = Wrd15;

DEFLABEL (label_74)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_38]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_4_41);
  goto label_72;

DEFLABEL (label_75)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_42])), (Wrd12.pObj));

DEFLABEL (label_47)
  (Wrd11.Obj) = Rvl;
  goto label_74;

DEFLABEL (label_77)
  (Wrd21.Obj) = (Rsp [1]);
  if ((Wrd21.Obj) == ((SCHEME_OBJECT) 0))
    goto label_80;
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_29]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_26]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_4_29);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_79;

DEFLABEL (label_80)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_34]))));
  (* (--Rsp)) = (Wrd29.Obj);
  goto label_78;

DEFLABEL (label_79)
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_30]))));
  (* (--Rsp)) = (Wrd41.Obj);

DEFLABEL (label_78)
DEFLABEL (label_81)
  (Wrd42.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd42.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_24]));

DEFLABEL (label_83)
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 10))
    goto label_85;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd22.Lng))))
    goto label_85;
  (Wrd14.Obj) = ((Wrd20.pObj) [3]);

DEFLABEL (label_84)
  (Rsp [0]) = (Wrd14.Obj);
  goto loop_10;

DEFLABEL (label_85)
  (Wrd25.Obj) = (Rsp [0]);
  (Wrd26.Obj) = (current_block [OBJECT_4_4]);
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_15]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 2);

DEFLABEL (label_43)
  (Wrd14.Obj) = Rvl;
  goto label_84;

DEFLABEL (label_86)
  (Wrd38.Obj) = (Rsp [0]);
  (Wrd39.Obj) = (current_block [OBJECT_4_4]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_12]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 2);

DEFLABEL (label_44)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_82;
  goto label_83;

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_4_34);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_88;

DEFLABEL (label_87)
  (Wrd17.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd17.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_36]));

DEFLABEL (label_88)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_39]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_90;
  Wrd11 = Wrd15;

DEFLABEL (label_89)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_38]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_4_39);
  goto label_87;

DEFLABEL (label_90)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_40])), (Wrd12.pObj));

DEFLABEL (label_46)
  (Wrd11.Obj) = Rvl;
  goto label_89;

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_4_30);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_101;
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_43]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_24]));

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_4_43);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_94;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_52]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_1]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_93;
  Wrd11 = Wrd15;

DEFLABEL (label_92)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_46]));

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_4_52);

DEFLABEL (label_91)
  (Wrd5.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_36]));

DEFLABEL (label_93)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_53])), (Wrd12.pObj));

DEFLABEL (label_49)
  (Wrd11.Obj) = Rvl;
  goto label_92;

DEFLABEL (label_94)
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_2]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_100;
  Wrd17 = Wrd21;

DEFLABEL (label_99)
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_49]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd27.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_0]));
  (Wrd30.Obj) = ((Wrd27.pObj) [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd31.uLng) == 50)
    goto label_98;
  Wrd26 = Wrd30;

DEFLABEL (label_97)
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_51]));

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_4_49);
  (Wrd11.Obj) = (Rsp [2]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd10.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd10.pObj)));
  (Wrd12.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = (Wrd12.Obj);
  (Wrd15.pObj) = (& (Rhp [-2]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd15.pObj)));
  (Wrd16.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_4_0]));
  (Wrd24.Obj) = ((Wrd16.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_96;

DEFLABEL (label_95)
  ((Wrd16.pObj) [0]) = (Wrd13.Obj);
  goto label_91;

DEFLABEL (label_96)
  if ((Wrd24.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_95;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_4_56])), (Wrd16.pObj), (Wrd13.Obj));

DEFLABEL (label_53)
  goto label_91;

DEFLABEL (label_98)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_50])), (Wrd27.pObj));

DEFLABEL (label_51)
  (Wrd26.Obj) = Rvl;
  goto label_97;

DEFLABEL (label_100)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_48])), (Wrd18.pObj));

DEFLABEL (label_50)
  (Wrd17.Obj) = Rvl;
  goto label_99;

DEFLABEL (label_101)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_44]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_1]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_107;
  Wrd11 = Wrd15;

DEFLABEL (label_106)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_46]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_4_44);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_47]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_24]));

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_4_47);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_103;

DEFLABEL (label_102)
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_36]));

DEFLABEL (label_103)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_54]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_105;
  Wrd11 = Wrd15;

DEFLABEL (label_104)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_38]));

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_4_54);
  goto label_102;

DEFLABEL (label_105)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_55])), (Wrd12.pObj));

DEFLABEL (label_52)
  (Wrd11.Obj) = Rvl;
  goto label_104;

DEFLABEL (label_107)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_4_45])), (Wrd12.pObj));

DEFLABEL (label_48)
  (Wrd11.Obj) = Rvl;
  goto label_106;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_5_4 3
#define LABEL_5_5 5
#define ENVIRONMENT_LABEL_5_3 11
#define DEBUGGING_LABEL_5_2 10
#define OBJECT_5_0 9
#define EXECUTE_CACHE_5_6 7
#define FREE_REFERENCES_LABEL_5_0 6
#define NUMBER_OF_LINKER_SECTIONS_5_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rinvex_so_code_5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_5_4);
      goto walk_nextP_1;

    case 1:
      current_block = (Rpc - LABEL_5_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (walk_nextP_4)
DEFLABEL (walk_nextP_1)
  INTERRUPT_CHECK (26, LABEL_5_4);
  (Wrd5.Obj) = (Rsp [0]);
  if (! ((Wrd5.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_5;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_5)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5_5]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_5_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_7;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_6;

DEFLABEL (label_7)
  Rvl = (current_block [OBJECT_5_0]);

DEFLABEL (label_6)
DEFLABEL (label_8)
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_6_4 3
#define LABEL_6_7 5
#define LABEL_6_5 7
#define LABEL_6_9 9
#define ENVIRONMENT_LABEL_6_3 20
#define DEBUGGING_LABEL_6_2 19
#define EXECUTE_CACHE_6_10 11
#define EXECUTE_CACHE_6_8 13
#define EXECUTE_CACHE_6_6 15
#define FREE_REFERENCE_6_0 18
#define FREE_REFERENCES_LABEL_6_0 10
#define NUMBER_OF_LINKER_SECTIONS_6_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rinvex_so_code_6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_6_4);
      goto walk_next_2;

    case 1:
      current_block = (Rpc - LABEL_6_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_6_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_6_9);
      goto label_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (walk_next_6)
DEFLABEL (walk_next_2)
  INTERRUPT_CHECK (26, LABEL_6_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_6_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_8;

DEFLABEL (label_7)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_8]));

DEFLABEL (label_8)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_10;
  Wrd11 = Wrd15;

DEFLABEL (label_9)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_10]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_6_7);
  goto label_7;

DEFLABEL (label_10)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_6_9])), (Wrd12.pObj));

DEFLABEL (label_4)
  (Wrd11.Obj) = Rvl;
  goto label_9;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_7_4 3
#define LABEL_7_5 5
#define ENVIRONMENT_LABEL_7_3 10
#define DEBUGGING_LABEL_7_2 9
#define OBJECT_7_0 8
#define FREE_REFERENCE_7_0 7
#define FREE_REFERENCES_LABEL_7_0 6
#define NUMBER_OF_LINKER_SECTIONS_7_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rinvex_so_code_7 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd27;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_7_4);
      goto register_value_0;

    case 1:
      current_block = (Rpc - LABEL_7_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (register_value_4)
DEFLABEL (register_value_0)
  INTERRUPT_CHECK (26, LABEL_7_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_8;
  Wrd5 = Wrd9;

DEFLABEL (label_7)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd27.uLng) == 10)
    goto label_6;

DEFLABEL (label_5)
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_0]), 2);

DEFLABEL (label_6)
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 26))
    goto label_5;
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [0]);
  (Wrd25.Lng) = (FIXNUM_TO_LONG (Wrd24.Obj));
  if (! (((unsigned long) (Wrd21.Lng)) < ((unsigned long) (Wrd25.Lng))))
    goto label_5;
  (Wrd13.uLng) = (OBJECT_DATUM (Wrd18.Obj));
  (Wrd16.pObj) = (& ((Wrd23.pObj) [(Wrd13.Lng)]));
  Rvl = ((Wrd16.pObj) [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_8)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_7_5])), (Wrd6.pObj));

DEFLABEL (label_2)
  (Wrd5.Obj) = Rvl;
  goto label_7;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_8_4 3
#define LABEL_8_5 5
#define LABEL_8_6 7
#define ENVIRONMENT_LABEL_8_3 13
#define DEBUGGING_LABEL_8_2 12
#define OBJECT_8_1 11
#define OBJECT_8_0 10
#define FREE_REFERENCE_8_0 9
#define FREE_REFERENCES_LABEL_8_0 8
#define NUMBER_OF_LINKER_SECTIONS_8_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rinvex_so_code_8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd32;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd15;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd26;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_8_4);
      goto set_register_valueB_1;

    case 1:
      current_block = (Rpc - LABEL_8_5);
      goto label_3;

    case 2:
      current_block = (Rpc - LABEL_8_6);
      goto label_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (set_register_valueB_6)
DEFLABEL (set_register_valueB_1)
  INTERRUPT_CHECK (26, LABEL_8_4);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_8_0]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_10;
  Wrd6 = Wrd10;

DEFLABEL (label_9)
  Wrd5 = Wrd6;
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if (! ((Wrd26.uLng) == 10))
    goto label_8;
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 26))
    goto label_8;
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [0]);
  (Wrd25.Lng) = (FIXNUM_TO_LONG (Wrd24.Obj));
  if (! (((unsigned long) (Wrd22.Lng)) < ((unsigned long) (Wrd25.Lng))))
    goto label_8;
  (Wrd15.uLng) = (OBJECT_DATUM (Wrd19.Obj));
  (Wrd17.pObj) = (& ((Wrd23.pObj) [(Wrd15.Lng)]));
  (Wrd18.Obj) = (Rsp [1]);
  ((Wrd17.pObj) [1]) = (Wrd18.Obj);

DEFLABEL (label_7)
  Rvl = (current_block [OBJECT_8_1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_8)
  (Wrd28.Obj) = (Rsp [0]);
  (Wrd29.Obj) = (Rsp [1]);
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_6]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_8_0]), 3);

DEFLABEL (label_4)
  goto label_7;

DEFLABEL (label_10)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_8_5])), (Wrd7.pObj));

DEFLABEL (label_3)
  (Wrd6.Obj) = Rvl;
  goto label_9;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_9_4 3
#define LABEL_9_5 5
#define LABEL_9_6 7
#define LABEL_9_7 9
#define LABEL_9_8 11
#define LABEL_9_9 13
#define ENVIRONMENT_LABEL_9_3 22
#define DEBUGGING_LABEL_9_2 21
#define OBJECT_9_1 20
#define OBJECT_9_0 19
#define EXECUTE_CACHE_9_11 15
#define EXECUTE_CACHE_9_10 17
#define FREE_REFERENCES_LABEL_9_0 14
#define NUMBER_OF_LINKER_SECTIONS_9_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rinvex_so_code_9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd17;
  machine_word Wrd13;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_9_4);
      goto expression_updateB_8;

    case 1:
      current_block = (Rpc - LABEL_9_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_9_6);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_9_7);
      goto loop_6;

    case 4:
      current_block = (Rpc - LABEL_9_8);
      goto label_10;

    case 5:
      current_block = (Rpc - LABEL_9_9);
      goto continuation_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_updateB_12)
DEFLABEL (expression_updateB_8)
  INTERRUPT_CHECK (26, LABEL_9_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_9_6);
  (* (--Rsp)) = Rvl;
  goto loop_6;

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_9_5);
  (Wrd5.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd6.Obj);
  (Rsp [2]) = Rvl;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (loop_13)
DEFLABEL (loop_6)
  INTERRUPT_CHECK (26, LABEL_9_7);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_16;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [0]);

DEFLABEL (label_15)
  if (! ((Wrd5.Obj) == (current_block [OBJECT_9_1])))
    goto label_14;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_14)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_9]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_7]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_10]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_9_9);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_11]));

DEFLABEL (label_16)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_8]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9_0]), 1);

DEFLABEL (label_10)
  (Wrd5.Obj) = Rvl;
  goto label_15;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_10_4 3
#define LABEL_10_6 5
#define LABEL_10_9 7
#define LABEL_10_5 9
#define LABEL_10_7 11
#define TAG_10_8 4
#define LABEL_10_11 13
#define LABEL_10_12 15
#define LABEL_10_13 17
#define LABEL_10_14 19
#define LABEL_10_15 21
#define LABEL_10_16 23
#define LABEL_10_17 25
#define LABEL_10_18 27
#define LABEL_10_20 29
#define LABEL_10_21 31
#define LABEL_10_19 33
#define LABEL_10_22 35
#define LABEL_10_23 37
#define LABEL_10_24 39
#define LABEL_10_29 41
#define LABEL_10_25 43
#define LABEL_10_27 45
#define LABEL_10_32 47
#define LABEL_10_33 49
#define LABEL_10_34 51
#define LABEL_10_36 53
#define LABEL_10_37 55
#define LABEL_10_38 57
#define LABEL_10_39 59
#define LABEL_10_35 61
#define LABEL_10_41 63
#define LABEL_10_30 65
#define ENVIRONMENT_LABEL_10_3 84
#define DEBUGGING_LABEL_10_2 83
#define OBJECT_10_3 82
#define OBJECT_10_2 81
#define OBJECT_10_1 80
#define OBJECT_10_0 79
#define EXECUTE_CACHE_10_40 67
#define EXECUTE_CACHE_10_31 69
#define EXECUTE_CACHE_10_28 71
#define EXECUTE_CACHE_10_26 73
#define EXECUTE_CACHE_10_10 75
#define FREE_REFERENCE_10_0 78
#define FREE_REFERENCES_LABEL_10_0 66
#define NUMBER_OF_LINKER_SECTIONS_10_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rinvex_so_code_10 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd37;
  machine_word Wrd39;
  machine_word Wrd41;
  machine_word Wrd73;
  machine_word Wrd68;
  machine_word Wrd67;
  machine_word Wrd69;
  machine_word Wrd66;
  machine_word Wrd61;
  machine_word Wrd62;
  machine_word Wrd59;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd17;
  machine_word Wrd6;
  machine_word Wrd82;
  machine_word Wrd81;
  machine_word Wrd78;
  machine_word Wrd88;
  machine_word Wrd60;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd56;
  machine_word Wrd53;
  machine_word Wrd45;
  machine_word Wrd47;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd40;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd18;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd14;
  machine_word Wrd15;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd23;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd24;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd20;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_10_4);
      goto optimize_expression_44;

    case 1:
      current_block = (Rpc - LABEL_10_6);
      goto label_46;

    case 2:
      current_block = (Rpc - LABEL_10_9);
      goto label_47;

    case 3:
      current_block = (Rpc - LABEL_10_5);
      goto continuation_7;

    case 4:
      current_block = (Rpc - LABEL_10_7);
      goto lambda_69;

    case 5:
      current_block = (Rpc - LABEL_10_11);
      goto label_48;

    case 6:
      current_block = (Rpc - LABEL_10_12);
      goto label_49;

    case 7:
      current_block = (Rpc - LABEL_10_13);
      goto label_50;

    case 8:
      current_block = (Rpc - LABEL_10_14);
      goto loop_42;

    case 9:
      current_block = (Rpc - LABEL_10_15);
      goto label_51;

    case 10:
      current_block = (Rpc - LABEL_10_16);
      goto label_52;

    case 11:
      current_block = (Rpc - LABEL_10_17);
      goto label_53;

    case 12:
      current_block = (Rpc - LABEL_10_18);
      goto label_54;

    case 13:
      current_block = (Rpc - LABEL_10_20);
      goto label_55;

    case 14:
      current_block = (Rpc - LABEL_10_21);
      goto label_56;

    case 15:
      current_block = (Rpc - LABEL_10_19);
      goto continuation_17;

    case 16:
      current_block = (Rpc - LABEL_10_22);
      goto label_57;

    case 17:
      current_block = (Rpc - LABEL_10_23);
      goto label_58;

    case 18:
      current_block = (Rpc - LABEL_10_24);
      goto loop_36;

    case 19:
      current_block = (Rpc - LABEL_10_29);
      goto continuation_35;

    case 20:
      current_block = (Rpc - LABEL_10_25);
      goto continuation_33;

    case 21:
      current_block = (Rpc - LABEL_10_27);
      goto continuation_22;

    case 22:
      current_block = (Rpc - LABEL_10_32);
      goto label_59;

    case 23:
      current_block = (Rpc - LABEL_10_33);
      goto label_60;

    case 24:
      current_block = (Rpc - LABEL_10_34);
      goto label_61;

    case 25:
      current_block = (Rpc - LABEL_10_36);
      goto label_63;

    case 26:
      current_block = (Rpc - LABEL_10_37);
      goto label_64;

    case 27:
      current_block = (Rpc - LABEL_10_38);
      goto label_65;

    case 28:
      current_block = (Rpc - LABEL_10_39);
      goto label_62;

    case 29:
      current_block = (Rpc - LABEL_10_35);
      goto continuation_28;

    case 30:
      current_block = (Rpc - LABEL_10_41);
      goto label_66;

    case 31:
      current_block = (Rpc - LABEL_10_30);
      goto continuation_34;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (optimize_expression_68)
DEFLABEL (optimize_expression_44)
  INTERRUPT_CHECK (26, LABEL_10_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_75;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [0]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_74)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd20.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_10_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_10_7])));
  Rhp += 1;
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd20.pObj)));
  Wrd21 = Wrd20;
  (Wrd22.Obj) = (Rsp [0]);
  ((Wrd21.pObj) [2]) = (Wrd22.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_10_0]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_73;
  Wrd23 = Wrd27;

DEFLABEL (label_72)
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_10_10]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_10_5);
  (* (--Rsp)) = Rvl;
  goto loop_42;

DEFLABEL (label_73)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_10_9])), (Wrd24.pObj));

DEFLABEL (label_47)
  (Wrd23.Obj) = Rvl;
  goto label_72;

DEFLABEL (label_75)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_6]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_0]), 1);

DEFLABEL (label_46)
  (* (--Rsp)) = Rvl;
  goto label_74;

DEFLABEL (lambda_69)
  CLOSURE_HEADER (LABEL_10_7);

DEFLABEL (lambda_5)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_84;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_83)
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_82;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd15.pObj) [0]);

DEFLABEL (label_81)
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd23.uLng) == 1))
    goto label_80;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd21.Obj) = ((Wrd22.pObj) [0]);

DEFLABEL (label_79)
  (Wrd29.Obj) = (Rsp [0]);
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [2]);
  if ((Wrd31.Obj) == (Wrd21.Obj))
    goto label_77;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_76;

DEFLABEL (label_77)
  Rvl = (current_block [OBJECT_10_2]);

DEFLABEL (label_76)
DEFLABEL (label_78)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_80)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_13]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_0]), 1);

DEFLABEL (label_50)
  (Wrd21.Obj) = Rvl;
  goto label_79;

DEFLABEL (label_82)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_12]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_0]), 1);

DEFLABEL (label_49)
  (Wrd14.Obj) = Rvl;
  goto label_81;

DEFLABEL (label_84)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_11]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_1]), 1);

DEFLABEL (label_48)
  (Wrd5.Obj) = Rvl;
  goto label_83;

DEFLABEL (loop_70)
DEFLABEL (loop_42)
  INTERRUPT_CHECK (26, LABEL_10_14);
  (Wrd5.Obj) = (Rsp [0]);
  if (! ((Wrd5.Obj) == (current_block [OBJECT_10_3])))
    goto label_85;
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_85)
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_101;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_100)
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_99;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [1]);

DEFLABEL (label_98)
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd27.uLng) == 1))
    goto label_97;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_96)
  (Wrd35.Obj) = (Rsp [1]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd36.uLng) == 1))
    goto label_95;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (* (--Rsp)) = (Wrd34.Obj);

DEFLABEL (label_94)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_19]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd44.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd48.Obj) = (Rsp [3]);
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if (! ((Wrd49.uLng) == 1))
    goto label_93;
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd45.Obj) = ((Wrd47.pObj) [1]);

DEFLABEL (label_92)
  (Wrd56.uLng) = (OBJECT_TYPE (Wrd45.Obj));
  if (! ((Wrd56.uLng) == 1))
    goto label_91;
  (Wrd54.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd55.Obj) = ((Wrd54.pObj) [0]);
  (* (--Rsp)) = (Wrd55.Obj);

DEFLABEL (label_90)
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_10_19);
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (Rsp [3]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_89;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_88)
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_87;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [1]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_86)
  goto loop_36;

DEFLABEL (label_87)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_23]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_1]), 1);

DEFLABEL (label_58)
  (* (--Rsp)) = Rvl;
  goto label_86;

DEFLABEL (label_89)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_22]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_1]), 1);

DEFLABEL (label_57)
  (Wrd5.Obj) = Rvl;
  goto label_88;

DEFLABEL (label_91)
  (Wrd60.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_21]))));
  (* (--Rsp)) = (Wrd60.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_0]), 1);

DEFLABEL (label_56)
  (* (--Rsp)) = Rvl;
  goto label_90;

DEFLABEL (label_93)
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_20]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_1]), 1);

DEFLABEL (label_55)
  (Wrd45.Obj) = Rvl;
  goto label_92;

DEFLABEL (label_95)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_18]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_0]), 1);

DEFLABEL (label_54)
  (* (--Rsp)) = Rvl;
  goto label_94;

DEFLABEL (label_97)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_17]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_0]), 1);

DEFLABEL (label_53)
  (* (--Rsp)) = Rvl;
  goto label_96;

DEFLABEL (label_99)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_16]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_1]), 1);

DEFLABEL (label_52)
  (Wrd16.Obj) = Rvl;
  goto label_98;

DEFLABEL (label_101)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_15]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_0]), 1);

DEFLABEL (label_51)
  (* (--Rsp)) = Rvl;
  goto label_100;

DEFLABEL (loop_71)
DEFLABEL (loop_36)
  INTERRUPT_CHECK (26, LABEL_10_24);
  (Wrd5.Obj) = (Rsp [0]);
  if ((Wrd5.Obj) == (current_block [OBJECT_10_3]))
    goto label_122;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_27]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_10_28]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_10_27);
  (* (--Rsp)) = Rvl;
  (Wrd9.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd9.uLng) == 1))
    goto label_121;
  (Wrd6.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd7.Obj) = ((Wrd6.pObj) [0]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_120)
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_119;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [0]);

DEFLABEL (label_118)
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd25.uLng) == 1))
    goto label_117;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd23.Obj) = ((Wrd24.pObj) [0]);

DEFLABEL (label_116)
  (Wrd30.Obj) = (* (Rsp++));
  if ((Wrd23.Obj) == (Wrd30.Obj))
    goto label_107;
  Rsp = (& (Rsp [6]));

DEFLABEL (label_106)
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_105)
  (Wrd33.Obj) = (Rsp [0]);
  if ((Wrd33.Obj) == ((SCHEME_OBJECT) 0))
    goto label_102;
  (Rsp [2]) = (Wrd33.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_10_40]));

DEFLABEL (label_102)
  (Wrd40.Obj) = (Rsp [1]);
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if (! ((Wrd41.uLng) == 1))
    goto label_104;
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  (Wrd37.Obj) = ((Wrd39.pObj) [1]);

DEFLABEL (label_103)
  (Rsp [1]) = (Wrd37.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_42;

DEFLABEL (label_104)
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_39]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_1]), 1);

DEFLABEL (label_62)
  (Wrd37.Obj) = Rvl;
  goto label_103;

DEFLABEL (label_107)
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_35]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (Wrd50.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd50.Obj);
  (Wrd54.Obj) = (Rsp [3]);
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if (! ((Wrd55.uLng) == 1))
    goto label_115;
  (Wrd53.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd51.Obj) = ((Wrd53.pObj) [0]);

DEFLABEL (label_114)
  (Wrd62.uLng) = (OBJECT_TYPE (Wrd51.Obj));
  if (! ((Wrd62.uLng) == 1))
    goto label_113;
  (Wrd61.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd60.Obj) = ((Wrd61.pObj) [1]);

DEFLABEL (label_112)
  (Wrd69.uLng) = (OBJECT_TYPE (Wrd60.Obj));
  if (! ((Wrd69.uLng) == 1))
    goto label_111;
  (Wrd67.pObj) = (OBJECT_ADDRESS (Wrd60.Obj));
  (Wrd68.Obj) = ((Wrd67.pObj) [0]);
  (* (--Rsp)) = (Wrd68.Obj);

DEFLABEL (label_110)
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_10_35);
  (Rsp [2]) = Rvl;
  (Wrd9.Obj) = (Rsp [1]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd10.uLng) == 1))
    goto label_109;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [1]);

DEFLABEL (label_108)
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_36;

DEFLABEL (label_109)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_41]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_1]), 1);

DEFLABEL (label_66)
  (Wrd6.Obj) = Rvl;
  goto label_108;

DEFLABEL (label_111)
  (Wrd73.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_38]))));
  (* (--Rsp)) = (Wrd73.Obj);
  (* (--Rsp)) = (Wrd60.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_0]), 1);

DEFLABEL (label_65)
  (* (--Rsp)) = Rvl;
  goto label_110;

DEFLABEL (label_113)
  (Wrd66.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_37]))));
  (* (--Rsp)) = (Wrd66.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_1]), 1);

DEFLABEL (label_64)
  (Wrd60.Obj) = Rvl;
  goto label_112;

DEFLABEL (label_115)
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_36]))));
  (* (--Rsp)) = (Wrd59.Obj);
  (* (--Rsp)) = (Wrd54.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_0]), 1);

DEFLABEL (label_63)
  (Wrd51.Obj) = Rvl;
  goto label_114;

DEFLABEL (label_117)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_34]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_0]), 1);

DEFLABEL (label_61)
  (Wrd23.Obj) = Rvl;
  goto label_116;

DEFLABEL (label_119)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_33]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_0]), 1);

DEFLABEL (label_60)
  (Wrd14.Obj) = Rvl;
  goto label_118;

DEFLABEL (label_121)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_32]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_0]), 1);

DEFLABEL (label_59)
  (* (--Rsp)) = Rvl;
  goto label_120;

DEFLABEL (label_122)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_25]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_10_26]));

DEFLABEL (continuation_33)
  INTERRUPT_CHECK (27, LABEL_10_25);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_123;
  (Wrd78.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_29]))));
  (* (--Rsp)) = (Wrd78.Obj);
  (Wrd81.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_30]))));
  (* (--Rsp)) = (Wrd81.Obj);
  (Wrd82.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd82.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_10_31]));

DEFLABEL (continuation_34)
  INTERRUPT_CHECK (27, LABEL_10_30);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_35)
  INTERRUPT_CHECK (27, LABEL_10_29);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_123;
  (Wrd88.Obj) = (Rsp [1]);
  Rsp = (& (Rsp [5]));
  (* (--Rsp)) = (Wrd88.Obj);
  goto label_105;

DEFLABEL (label_123)
  Rsp = (& (Rsp [5]));
  goto label_106;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_11_4 3
#define LABEL_11_5 5
#define ENVIRONMENT_LABEL_11_3 13
#define DEBUGGING_LABEL_11_2 12
#define OBJECT_11_2 11
#define OBJECT_11_1 10
#define OBJECT_11_0 9
#define EXECUTE_CACHE_11_6 7
#define FREE_REFERENCES_LABEL_11_0 6
#define NUMBER_OF_LINKER_SECTIONS_11_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rinvex_so_code_11 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd7;
  machine_word Wrd9;
  machine_word Wrd8;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_11_4);
      goto valid_subexpressionP_2;

    case 1:
      current_block = (Rpc - LABEL_11_5);
      goto label_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (valid_subexpressionP_6)
DEFLABEL (valid_subexpressionP_2)
  INTERRUPT_CHECK (26, LABEL_11_4);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_9;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [0]);

DEFLABEL (label_8)
  if ((Wrd5.Obj) == (current_block [OBJECT_11_1]))
    goto label_7;
  Rvl = (current_block [OBJECT_11_2]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_7)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_6]));

DEFLABEL (label_9)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_11_0]), 1);

DEFLABEL (label_4)
  (Wrd5.Obj) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_12_4 3
#define LABEL_12_6 5
#define LABEL_12_8 7
#define LABEL_12_9 9
#define LABEL_12_10 11
#define LABEL_12_11 13
#define LABEL_12_5 15
#define ENVIRONMENT_LABEL_12_3 25
#define DEBUGGING_LABEL_12_2 24
#define OBJECT_12_2 23
#define OBJECT_12_1 22
#define OBJECT_12_0 21
#define EXECUTE_CACHE_12_7 17
#define FREE_REFERENCE_12_0 20
#define FREE_REFERENCES_LABEL_12_0 16
#define NUMBER_OF_LINKER_SECTIONS_12_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rinvex_so_code_12 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd52;
  machine_word Wrd38;
  machine_word Wrd41;
  machine_word Wrd39;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd47;
  machine_word Wrd36;
  machine_word Wrd29;
  machine_word Wrd30;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd31;
  machine_word Wrd28;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd13;
  machine_word Wrd15;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_12_4);
      goto canonicalize_subexpression_5;

    case 1:
      current_block = (Rpc - LABEL_12_6);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_12_8);
      goto label_7;

    case 3:
      current_block = (Rpc - LABEL_12_9);
      goto label_8;

    case 4:
      current_block = (Rpc - LABEL_12_10);
      goto label_9;

    case 5:
      current_block = (Rpc - LABEL_12_11);
      goto label_10;

    case 6:
      current_block = (Rpc - LABEL_12_5);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (canonicalize_subexpression_12)
DEFLABEL (canonicalize_subexpression_5)
  INTERRUPT_CHECK (26, LABEL_12_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_12_6);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_25;
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 1))
    goto label_24;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd13.Obj) = ((Wrd15.pObj) [1]);

DEFLABEL (label_23)
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd24.uLng) == 1))
    goto label_22;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [0]);
  (* (--Rsp)) = (Wrd23.Obj);

DEFLABEL (label_21)
  (Wrd31.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_12_0]));
  (Wrd34.Obj) = ((Wrd31.pObj) [0]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if ((Wrd35.uLng) == 50)
    goto label_20;
  Wrd30 = Wrd34;

DEFLABEL (label_19)
  Wrd29 = Wrd30;
  (Wrd36.Obj) = (* (Rsp++));
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd47.uLng) == 10))
    goto label_18;
  (Wrd42.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd42.uLng) == 26))
    goto label_18;
  (Wrd43.Lng) = (FIXNUM_TO_LONG (Wrd36.Obj));
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd45.Obj) = ((Wrd44.pObj) [0]);
  (Wrd46.Lng) = (FIXNUM_TO_LONG (Wrd45.Obj));
  if (! (((unsigned long) (Wrd43.Lng)) < ((unsigned long) (Wrd46.Lng))))
    goto label_18;
  (Wrd39.uLng) = (OBJECT_DATUM (Wrd36.Obj));
  (Wrd41.pObj) = (& ((Wrd44.pObj) [(Wrd39.Lng)]));
  (Wrd38.Obj) = ((Wrd41.pObj) [1]);

DEFLABEL (label_17)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd38.Obj);

DEFLABEL (label_16)
  (Wrd5.Obj) = (Rsp [0]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_14;
  Rvl = (Wrd5.Obj);
  goto label_13;

DEFLABEL (label_14)
  Rvl = (Rsp [1]);

DEFLABEL (label_13)
DEFLABEL (label_15)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_18)
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_11]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_2]), 2);

DEFLABEL (label_10)
  (Wrd38.Obj) = Rvl;
  goto label_17;

DEFLABEL (label_20)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_12_10])), (Wrd31.pObj));

DEFLABEL (label_9)
  (Wrd30.Obj) = Rvl;
  goto label_19;

DEFLABEL (label_22)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_9]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_1]), 1);

DEFLABEL (label_8)
  (* (--Rsp)) = Rvl;
  goto label_21;

DEFLABEL (label_24)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_8]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_0]), 1);

DEFLABEL (label_7)
  (Wrd13.Obj) = Rvl;
  goto label_23;

DEFLABEL (label_25)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  goto label_16;

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_12_5);
  (* (--Rsp)) = Rvl;
  goto label_16;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_13_4 3
#define LABEL_13_7 5
#define LABEL_13_6 7
#define LABEL_13_9 9
#define LABEL_13_10 11
#define LABEL_13_5 13
#define ENVIRONMENT_LABEL_13_3 23
#define DEBUGGING_LABEL_13_2 22
#define OBJECT_13_0 21
#define EXECUTE_CACHE_13_8 15
#define FREE_REFERENCE_13_0 18
#define FREE_ASSIGNMENT_13_0 20
#define FREE_REFERENCES_LABEL_13_0 14
#define NUMBER_OF_LINKER_SECTIONS_13_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rinvex_so_code_13 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd32;
  machine_word Wrd29;
  machine_word Wrd31;
  machine_word Wrd24;
  machine_word Wrd26;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd18;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd17;
  machine_word Wrd11;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_13_4);
      goto define_general_method_5;

    case 1:
      current_block = (Rpc - LABEL_13_7);
      goto label_7;

    case 2:
      current_block = (Rpc - LABEL_13_6);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_13_9);
      goto label_8;

    case 4:
      current_block = (Rpc - LABEL_13_10);
      goto label_9;

    case 5:
      current_block = (Rpc - LABEL_13_5);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (define_general_method_11)
DEFLABEL (define_general_method_5)
  INTERRUPT_CHECK (26, LABEL_13_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_21;
  Wrd11 = Wrd15;

DEFLABEL (label_20)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_13_6);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_14;
  (* (--Rsp)) = Rvl;
  (Wrd10.Obj) = (Rsp [4]);
  (Rsp [1]) = (Wrd10.Obj);
  (Wrd16.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd16.uLng) == 1)
    goto label_12;
  INVOKE_PRIMITIVE ((current_block [OBJECT_13_0]), 2);

DEFLABEL (label_12)
  (Wrd13.pObj) = (OBJECT_ADDRESS (Rvl));
  ((Wrd13.pObj) [1]) = (Wrd10.Obj);
  Rsp = (& (Rsp [3]));

DEFLABEL (label_13)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_14)
  (Wrd19.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13_0]));
  (Wrd22.Obj) = ((Wrd19.pObj) [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd23.uLng) == 50)
    goto label_19;
  Wrd18 = Wrd22;

DEFLABEL (label_18)
  (Wrd27.Obj) = (Rsp [2]);
  (Wrd28.Obj) = (Rsp [3]);
  (* (Rhp++)) = (Wrd27.Obj);
  (* (Rhp++)) = (Wrd28.Obj);
  (Wrd26.pObj) = (& (Rhp [-2]));
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd26.pObj)));
  (* (Rhp++)) = (Wrd24.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (Wrd31.pObj) = (& (Rhp [-2]));
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd31.pObj)));
  (Wrd32.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_13_0]));
  (Wrd40.Obj) = ((Wrd32.pObj) [0]);
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if ((Wrd41.uLng) == 50)
    goto label_17;

DEFLABEL (label_16)
  ((Wrd32.pObj) [0]) = (Wrd29.Obj);

DEFLABEL (label_15)
  Rsp = (& (Rsp [2]));
  goto label_13;

DEFLABEL (label_17)
  if ((Wrd40.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_16;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_13_10])), (Wrd32.pObj), (Wrd29.Obj));

DEFLABEL (label_9)
  goto label_15;

DEFLABEL (label_19)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_13_9])), (Wrd19.pObj));

DEFLABEL (label_8)
  (Wrd18.Obj) = Rvl;
  goto label_18;

DEFLABEL (label_21)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_13_7])), (Wrd12.pObj));

DEFLABEL (label_7)
  (Wrd11.Obj) = Rvl;
  goto label_20;

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_13_5);
  goto label_13;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_14_4 3
#define LABEL_14_5 5
#define LABEL_14_7 7
#define LABEL_14_9 9
#define LABEL_14_6 11
#define ENVIRONMENT_LABEL_14_3 24
#define DEBUGGING_LABEL_14_2 23
#define OBJECT_14_2 22
#define OBJECT_14_1 21
#define OBJECT_14_0 20
#define EXECUTE_CACHE_14_10 13
#define EXECUTE_CACHE_14_8 15
#define FREE_REFERENCE_14_1 18
#define FREE_REFERENCE_14_0 19
#define FREE_REFERENCES_LABEL_14_0 12
#define NUMBER_OF_LINKER_SECTIONS_14_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rinvex_so_code_14 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd7;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd18;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_14_4);
      goto lookup_method_4;

    case 1:
      current_block = (Rpc - LABEL_14_5);
      goto label_7;

    case 2:
      current_block = (Rpc - LABEL_14_7);
      goto label_6;

    case 3:
      current_block = (Rpc - LABEL_14_9);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_14_6);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lookup_method_9)
DEFLABEL (lookup_method_4)
  INTERRUPT_CHECK (26, LABEL_14_4);
  (Wrd5.Obj) = (Rsp [0]);
  if ((Wrd5.Obj) == (current_block [OBJECT_14_0]))
    goto label_14;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_6]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14_1]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_13;
  Wrd10 = Wrd14;

DEFLABEL (label_12)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd16.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_14_6);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_11;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_9]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (current_block [OBJECT_14_1]);
  (* (--Rsp)) = (Wrd19.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_14_9);

DEFLABEL (label_11)
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd7.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_10;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  Rvl = ((Wrd10.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_10)
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_2]), 1);

DEFLABEL (label_13)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_14_7])), (Wrd11.pObj));

DEFLABEL (label_6)
  (Wrd10.Obj) = Rvl;
  goto label_12;

DEFLABEL (label_14)
  (Wrd19.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14_0]));
  (Wrd22.Obj) = ((Wrd19.pObj) [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd23.uLng) == 50)
    goto label_16;
  Wrd18 = Wrd22;

DEFLABEL (label_15)
  Rvl = (Wrd18.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_16)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_14_5])), (Wrd19.pObj));

DEFLABEL (label_7)
  (Wrd18.Obj) = Rvl;
  goto label_15;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_15_4 3
#define LABEL_15_6 5
#define LABEL_15_7 7
#define LABEL_15_5 9
#define LABEL_15_9 11
#define LABEL_15_10 13
#define LABEL_15_11 15
#define LABEL_15_13 17
#define LABEL_15_14 19
#define LABEL_15_15 21
#define LABEL_15_16 23
#define LABEL_15_17 25
#define LABEL_15_18 27
#define LABEL_15_19 29
#define ENVIRONMENT_LABEL_15_3 44
#define DEBUGGING_LABEL_15_2 43
#define OBJECT_15_3 42
#define OBJECT_15_2 41
#define OBJECT_15_1 40
#define OBJECT_15_0 39
#define EXECUTE_CACHE_15_12 31
#define EXECUTE_CACHE_15_8 33
#define FREE_REFERENCE_15_2 36
#define FREE_REFERENCE_15_1 37
#define FREE_REFERENCE_15_0 38
#define FREE_REFERENCES_LABEL_15_0 30
#define NUMBER_OF_LINKER_SECTIONS_15_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rinvex_so_code_15 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd71;
  machine_word Wrd59;
  machine_word Wrd57;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd65;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd46;
  machine_word Wrd47;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd48;
  machine_word Wrd45;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd41;
  machine_word Wrd38;
  machine_word Wrd32;
  machine_word Wrd33;
  machine_word Wrd34;
  machine_word Wrd31;
  machine_word Wrd25;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd22;
  machine_word Wrd17;
  machine_word Wrd18;
  machine_word Wrd11;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd5;
  machine_word Wrd15;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_15_4);
      goto walk_assign_11;

    case 1:
      current_block = (Rpc - LABEL_15_6);
      goto label_13;

    case 2:
      current_block = (Rpc - LABEL_15_7);
      goto label_14;

    case 3:
      current_block = (Rpc - LABEL_15_5);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_15_9);
      goto label_15;

    case 5:
      current_block = (Rpc - LABEL_15_10);
      goto label_16;

    case 6:
      current_block = (Rpc - LABEL_15_11);
      goto continuation_3;

    case 7:
      current_block = (Rpc - LABEL_15_13);
      goto label_17;

    case 8:
      current_block = (Rpc - LABEL_15_14);
      goto label_18;

    case 9:
      current_block = (Rpc - LABEL_15_15);
      goto label_19;

    case 10:
      current_block = (Rpc - LABEL_15_16);
      goto label_20;

    case 11:
      current_block = (Rpc - LABEL_15_17);
      goto label_21;

    case 12:
      current_block = (Rpc - LABEL_15_18);
      goto label_22;

    case 13:
      current_block = (Rpc - LABEL_15_19);
      goto label_23;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (walk_assign_25)
DEFLABEL (walk_assign_11)
  INTERRUPT_CHECK (26, LABEL_15_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_48;
  Wrd9 = Wrd13;

DEFLABEL (label_47)
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15_1]));
  (Wrd19.Obj) = ((Wrd16.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 50)
    goto label_46;
  Wrd15 = Wrd19;

DEFLABEL (label_45)
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_15_5);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_44;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_43)
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_42;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_41)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_11]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_12]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_15_11);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_27;

DEFLABEL (label_26)
  Rvl = (current_block [OBJECT_15_3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_27)
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_40;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_39)
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_38;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_37)
  (Wrd26.Obj) = (Rsp [2]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd27.uLng) == 1))
    goto label_36;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd23.Obj) = ((Wrd25.pObj) [1]);

DEFLABEL (label_35)
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd34.uLng) == 1))
    goto label_34;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd32.Obj) = ((Wrd33.pObj) [1]);

DEFLABEL (label_33)
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd41.uLng) == 1))
    goto label_32;
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd40.Obj) = ((Wrd39.pObj) [0]);
  (* (--Rsp)) = (Wrd40.Obj);

DEFLABEL (label_31)
  (Wrd48.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15_2]));
  (Wrd51.Obj) = ((Wrd48.pObj) [0]);
  (Wrd52.uLng) = (OBJECT_TYPE (Wrd51.Obj));
  if ((Wrd52.uLng) == 50)
    goto label_30;
  Wrd47 = Wrd51;

DEFLABEL (label_29)
  Wrd46 = Wrd47;
  (Wrd53.Obj) = (* (Rsp++));
  (Wrd54.Obj) = (* (Rsp++));
  (Wrd65.uLng) = (OBJECT_TYPE (Wrd47.Obj));
  if (! ((Wrd65.uLng) == 10))
    goto label_28;
  (Wrd60.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if (! ((Wrd60.uLng) == 26))
    goto label_28;
  (Wrd61.Lng) = (FIXNUM_TO_LONG (Wrd54.Obj));
  (Wrd62.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  (Wrd63.Obj) = ((Wrd62.pObj) [0]);
  (Wrd64.Lng) = (FIXNUM_TO_LONG (Wrd63.Obj));
  if (! (((unsigned long) (Wrd61.Lng)) < ((unsigned long) (Wrd64.Lng))))
    goto label_28;
  (Wrd57.uLng) = (OBJECT_DATUM (Wrd54.Obj));
  (Wrd59.pObj) = (& ((Wrd62.pObj) [(Wrd57.Lng)]));
  ((Wrd59.pObj) [1]) = (Wrd53.Obj);
  goto label_26;

DEFLABEL (label_28)
  (Wrd71.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_19]))));
  (* (--Rsp)) = (Wrd71.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd46.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_15_2]), 3);

DEFLABEL (label_23)
  goto label_26;

DEFLABEL (label_30)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_15_18])), (Wrd48.pObj));

DEFLABEL (label_22)
  (Wrd47.Obj) = Rvl;
  goto label_29;

DEFLABEL (label_32)
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_17]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_15_1]), 1);

DEFLABEL (label_21)
  (* (--Rsp)) = Rvl;
  goto label_31;

DEFLABEL (label_34)
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_16]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_15_0]), 1);

DEFLABEL (label_20)
  (Wrd32.Obj) = Rvl;
  goto label_33;

DEFLABEL (label_36)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_15]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_15_0]), 1);

DEFLABEL (label_19)
  (Wrd23.Obj) = Rvl;
  goto label_35;

DEFLABEL (label_38)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_14]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_15_1]), 1);

DEFLABEL (label_18)
  (* (--Rsp)) = Rvl;
  goto label_37;

DEFLABEL (label_40)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_13]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_15_0]), 1);

DEFLABEL (label_17)
  (Wrd7.Obj) = Rvl;
  goto label_39;

DEFLABEL (label_42)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_10]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_15_1]), 1);

DEFLABEL (label_16)
  (* (--Rsp)) = Rvl;
  goto label_41;

DEFLABEL (label_44)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_9]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_15_0]), 1);

DEFLABEL (label_15)
  (Wrd5.Obj) = Rvl;
  goto label_43;

DEFLABEL (label_46)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_15_7])), (Wrd16.pObj));

DEFLABEL (label_14)
  (Wrd15.Obj) = Rvl;
  goto label_45;

DEFLABEL (label_48)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_15_6])), (Wrd10.pObj));

DEFLABEL (label_13)
  (Wrd9.Obj) = Rvl;
  goto label_47;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_16_4 3
#define LABEL_16_5 5
#define LABEL_16_7 7
#define LABEL_16_8 9
#define ENVIRONMENT_LABEL_16_3 18
#define DEBUGGING_LABEL_16_2 17
#define OBJECT_16_1 16
#define OBJECT_16_0 15
#define EXECUTE_CACHE_16_6 11
#define FREE_REFERENCE_16_0 14
#define FREE_REFERENCES_LABEL_16_0 10
#define NUMBER_OF_LINKER_SECTIONS_16_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rinvex_so_code_16 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd32;
  machine_word Wrd28;
  machine_word Wrd17;
  machine_word Wrd15;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd26;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_16_4);
      goto lambda_2;

    case 1:
      current_block = (Rpc - LABEL_16_5);
      goto lambda_1;

    case 2:
      current_block = (Rpc - LABEL_16_7);
      goto label_4;

    case 3:
      current_block = (Rpc - LABEL_16_8);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_7)
DEFLABEL (lambda_2)
  INTERRUPT_CHECK (26, LABEL_16_4);
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_5]))));
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_6]));

DEFLABEL (lambda_8)
DEFLABEL (lambda_1)
  INTERRUPT_CHECK (26, LABEL_16_5);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_16_0]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_12;
  Wrd6 = Wrd10;

DEFLABEL (label_11)
  Wrd5 = Wrd6;
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if (! ((Wrd26.uLng) == 10))
    goto label_10;
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 26))
    goto label_10;
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [0]);
  (Wrd25.Lng) = (FIXNUM_TO_LONG (Wrd24.Obj));
  if (! (((unsigned long) (Wrd22.Lng)) < ((unsigned long) (Wrd25.Lng))))
    goto label_10;
  (Wrd15.uLng) = (OBJECT_DATUM (Wrd19.Obj));
  (Wrd17.pObj) = (& ((Wrd23.pObj) [(Wrd15.Lng)]));
  ((Wrd17.pObj) [1]) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_9)
  Rvl = (current_block [OBJECT_16_1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_10)
  (Wrd28.Obj) = (Rsp [0]);
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_8]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_16_0]), 3);

DEFLABEL (label_5)
  goto label_9;

DEFLABEL (label_12)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_16_7])), (Wrd7.pObj));

DEFLABEL (label_4)
  (Wrd6.Obj) = Rvl;
  goto label_11;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_17_4 3
#define LABEL_17_5 5
#define ENVIRONMENT_LABEL_17_3 11
#define DEBUGGING_LABEL_17_2 10
#define OBJECT_17_0 9
#define EXECUTE_CACHE_17_6 7
#define FREE_REFERENCES_LABEL_17_0 6
#define NUMBER_OF_LINKER_SECTIONS_17_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rinvex_so_code_17 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_17_4);
      goto lambda_1;

    case 1:
      current_block = (Rpc - LABEL_17_5);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_4)
DEFLABEL (lambda_1)
  INTERRUPT_CHECK (26, LABEL_17_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_5]))));
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_6]));

DEFLABEL (lambda_5)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_17_5);
  Rvl = (current_block [OBJECT_17_0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_18_4 3
#define LABEL_18_5 5
#define TAG_18_6 1
#define ENVIRONMENT_LABEL_18_3 12
#define DEBUGGING_LABEL_18_2 11
#define EXECUTE_CACHE_18_8 7
#define EXECUTE_CACHE_18_7 9
#define FREE_REFERENCES_LABEL_18_0 6
#define NUMBER_OF_LINKER_SECTIONS_18_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rinvex_so_code_18 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd5;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_18_4);
      goto define_one_arg_method_1;

    case 1:
      current_block = (Rpc - LABEL_18_5);
      goto lambda_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (define_one_arg_method_4)
DEFLABEL (define_one_arg_method_1)
  INTERRUPT_CHECK (26, LABEL_18_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_18_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_18_5])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [2]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd12.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd12.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_7]));

DEFLABEL (lambda_5)
  CLOSURE_HEADER (LABEL_18_5);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = ((Wrd6.pObj) [2]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_8]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_19_4 3
#define LABEL_19_5 5
#define TAG_19_6 1
#define LABEL_19_8 7
#define ENVIRONMENT_LABEL_19_3 14
#define DEBUGGING_LABEL_19_2 13
#define EXECUTE_CACHE_19_9 9
#define EXECUTE_CACHE_19_7 11
#define FREE_REFERENCES_LABEL_19_0 8
#define NUMBER_OF_LINKER_SECTIONS_19_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
rinvex_so_code_19 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd16;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_19_4);
      goto define_two_arg_method_2;

    case 1:
      current_block = (Rpc - LABEL_19_5);
      goto lambda_6;

    case 2:
      current_block = (Rpc - LABEL_19_8);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (define_two_arg_method_5)
DEFLABEL (define_two_arg_method_2)
  INTERRUPT_CHECK (26, LABEL_19_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_19_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_19_5])));
  Rhp += 4;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [4]);
  ((Wrd14.pObj) [2]) = (Wrd15.Obj);
  (Wrd13.Obj) = (Rsp [3]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [4]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd14.pObj) [5]) = (Wrd9.Obj);
  (Rsp [4]) = (Wrd6.Obj);
  (Wrd16.Obj) = (Rsp [0]);
  (Rsp [3]) = (Wrd16.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_7]));

DEFLABEL (lambda_6)
  CLOSURE_HEADER (LABEL_19_5);

DEFLABEL (lambda_1)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = ((Wrd10.pObj) [5]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_9]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_19_8);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = ((Wrd6.pObj) [2]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_9]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4 3
#define LABEL_8 5
#define LABEL_9 7
#define LABEL_10 9
#define LABEL_11 11
#define LABEL_12 13
#define LABEL_13 15
#define LABEL_14 17
#define LABEL_15 19
#define LABEL_16 21
#define LABEL_17 23
#define LABEL_18 25
#define LABEL_19 27
#define LABEL_20 29
#define LABEL_21 31
#define LABEL_22 33
#define LABEL_23 35
#define LABEL_24 37
#define LABEL_25 39
#define LABEL_26 41
#define LABEL_27 43
#define LABEL_28 45
#define LABEL_29 47
#define LABEL_30 49
#define LABEL_31 51
#define LABEL_32 53
#define LABEL_33 55
#define LABEL_34 57
#define LABEL_35 59
#define LABEL_36 61
#define LABEL_37 63
#define LABEL_38 65
#define LABEL_39 67
#define LABEL_40 69
#define LABEL_41 71
#define LABEL_42 73
#define LABEL_43 75
#define LABEL_6 77
#define LABEL_7 79
#define LABEL_45 81
#define LABEL_46 83
#define LABEL_48 85
#define LABEL_50 87
#define LABEL_52 89
#define LABEL_53 91
#define LABEL_51 93
#define LABEL_56 95
#define LABEL_57 97
#define LABEL_55 99
#define LABEL_59 101
#define LABEL_60 103
#define LABEL_58 105
#define LABEL_62 107
#define LABEL_63 109
#define LABEL_61 111
#define LABEL_65 113
#define LABEL_66 115
#define LABEL_64 117
#define LABEL_68 119
#define LABEL_69 121
#define LABEL_67 123
#define LABEL_71 125
#define LABEL_72 127
#define LABEL_70 129
#define LABEL_74 131
#define LABEL_75 133
#define LABEL_73 135
#define LABEL_77 137
#define LABEL_78 139
#define LABEL_76 141
#define LABEL_80 143
#define LABEL_81 145
#define LABEL_79 147
#define LABEL_83 149
#define LABEL_84 151
#define LABEL_82 153
#define LABEL_86 155
#define LABEL_87 157
#define LABEL_85 159
#define LABEL_89 161
#define LABEL_90 163
#define LABEL_88 165
#define LABEL_91 167
#define LABEL_93 169
#define LABEL_94 171
#define LABEL_95 173
#define LABEL_96 175
#define LABEL_92 177
#define LABEL_99 179
#define LABEL_100 181
#define LABEL_101 183
#define LABEL_102 185
#define LABEL_98 187
#define LABEL_104 189
#define LABEL_105 191
#define LABEL_106 193
#define LABEL_107 195
#define LABEL_103 197
#define LABEL_109 199
#define LABEL_110 201
#define LABEL_111 203
#define LABEL_112 205
#define LABEL_108 207
#define LABEL_114 209
#define LABEL_115 211
#define LABEL_116 213
#define LABEL_117 215
#define LABEL_113 217
#define LABEL_119 219
#define LABEL_120 221
#define LABEL_121 223
#define LABEL_122 225
#define LABEL_118 227
#define LABEL_124 229
#define LABEL_125 231
#define LABEL_126 233
#define LABEL_127 235
#define LABEL_123 237
#define LABEL_128 239
#define LABEL_129 241
#define LABEL_130 243
#define LABEL_131 245
#define LABEL_132 247
#define LABEL_133 249
#define LABEL_134 251
#define ENVIRONMENT_LABEL_3 393
#define DEBUGGING_LABEL_2 392
#define PURIFICATION_ROOT 391
#define OBJECT_48 390
#define OBJECT_47 389
#define OBJECT_46 388
#define OBJECT_45 387
#define OBJECT_44 386
#define OBJECT_43 385
#define OBJECT_42 384
#define OBJECT_41 383
#define OBJECT_40 382
#define OBJECT_39 381
#define OBJECT_38 380
#define OBJECT_37 379
#define OBJECT_36 378
#define OBJECT_35 377
#define OBJECT_34 376
#define OBJECT_33 375
#define OBJECT_32 374
#define OBJECT_31 373
#define OBJECT_30 372
#define OBJECT_29 371
#define OBJECT_28 370
#define OBJECT_27 369
#define OBJECT_26 368
#define OBJECT_25 367
#define OBJECT_24 366
#define OBJECT_23 365
#define OBJECT_22 364
#define OBJECT_21 363
#define OBJECT_20 362
#define OBJECT_19 361
#define OBJECT_18 360
#define OBJECT_17 359
#define OBJECT_16 358
#define OBJECT_15 357
#define OBJECT_14 356
#define OBJECT_13 355
#define OBJECT_12 354
#define OBJECT_11 353
#define OBJECT_10 352
#define OBJECT_9 351
#define OBJECT_8 350
#define OBJECT_7 349
#define OBJECT_6 348
#define OBJECT_5 347
#define OBJECT_4 346
#define OBJECT_3 345
#define OBJECT_2 344
#define OBJECT_1 343
#define OBJECT_0 342
#define EXECUTE_CACHE_97 253
#define EXECUTE_CACHE_54 255
#define EXECUTE_CACHE_49 257
#define EXECUTE_CACHE_47 259
#define EXECUTE_CACHE_44 261
#define FREE_REFERENCE_74 264
#define FREE_REFERENCE_73 265
#define FREE_REFERENCE_72 266
#define FREE_REFERENCE_71 267
#define FREE_REFERENCE_70 268
#define FREE_REFERENCE_69 269
#define FREE_REFERENCE_68 270
#define FREE_REFERENCE_67 271
#define FREE_REFERENCE_66 272
#define FREE_REFERENCE_65 273
#define FREE_REFERENCE_64 274
#define FREE_REFERENCE_63 275
#define FREE_REFERENCE_62 276
#define FREE_REFERENCE_61 277
#define FREE_REFERENCE_60 278
#define FREE_REFERENCE_59 279
#define FREE_REFERENCE_58 280
#define FREE_REFERENCE_57 281
#define FREE_REFERENCE_56 282
#define FREE_REFERENCE_55 283
#define FREE_REFERENCE_54 284
#define FREE_REFERENCE_53 285
#define FREE_REFERENCE_52 286
#define FREE_REFERENCE_51 287
#define FREE_REFERENCE_50 288
#define FREE_REFERENCE_49 289
#define FREE_REFERENCE_48 290
#define FREE_REFERENCE_47 291
#define FREE_REFERENCE_46 292
#define FREE_REFERENCE_45 293
#define FREE_REFERENCE_44 294
#define FREE_REFERENCE_43 295
#define FREE_REFERENCE_42 296
#define FREE_REFERENCE_41 297
#define FREE_REFERENCE_40 298
#define FREE_REFERENCE_39 299
#define FREE_REFERENCE_38 300
#define FREE_REFERENCE_37 301
#define FREE_REFERENCE_36 302
#define FREE_REFERENCE_35 303
#define FREE_REFERENCE_34 304
#define FREE_REFERENCE_33 305
#define FREE_REFERENCE_32 306
#define FREE_REFERENCE_31 307
#define FREE_REFERENCE_30 308
#define FREE_REFERENCE_29 309
#define FREE_REFERENCE_28 310
#define FREE_REFERENCE_27 311
#define FREE_REFERENCE_26 312
#define FREE_REFERENCE_25 313
#define FREE_REFERENCE_24 314
#define FREE_REFERENCE_23 315
#define FREE_REFERENCE_22 316
#define FREE_REFERENCE_21 317
#define FREE_REFERENCE_20 318
#define FREE_REFERENCE_19 319
#define FREE_REFERENCE_18 320
#define FREE_REFERENCE_17 321
#define FREE_REFERENCE_16 322
#define FREE_REFERENCE_15 323
#define FREE_REFERENCE_14 324
#define FREE_REFERENCE_13 325
#define FREE_REFERENCE_12 326
#define FREE_REFERENCE_11 327
#define FREE_REFERENCE_10 328
#define FREE_REFERENCE_9 329
#define FREE_REFERENCE_8 330
#define FREE_REFERENCE_7 331
#define FREE_REFERENCE_6 332
#define FREE_REFERENCE_5 333
#define FREE_REFERENCE_4 334
#define FREE_REFERENCE_3 335
#define FREE_REFERENCE_2 336
#define FREE_REFERENCE_1 337
#define FREE_REFERENCE_0 338
#define GLOBAL_EXECUTE_CACHE_5 340
#define FREE_REFERENCES_LABEL_0 252
#define NUMBER_OF_LINKER_SECTIONS_1 3

#ifndef WANT_ONLY_DATA

SCHEME_OBJECT *
rinvex_so_a18b0e3a6ee30bb4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd29;
  machine_word Wrd23;
  machine_word Wrd11;
  machine_word Wrd26;
  machine_word Wrd30;
  machine_word Wrd14;
  machine_word Wrd19;
  machine_word Wrd15;
  machine_word Wrd6;
  machine_word Wrd598;
  machine_word Wrd597;
  machine_word Wrd595;
  machine_word Wrd589;
  machine_word Wrd594;
  machine_word Wrd593;
  machine_word Wrd590;
  machine_word Wrd587;
  machine_word Wrd586;
  machine_word Wrd584;
  machine_word Wrd580;
  machine_word Wrd582;
  machine_word Wrd583;
  machine_word Wrd576;
  machine_word Wrd578;
  machine_word Wrd579;
  machine_word Wrd570;
  machine_word Wrd575;
  machine_word Wrd574;
  machine_word Wrd571;
  machine_word Wrd567;
  machine_word Wrd566;
  machine_word Wrd561;
  machine_word Wrd563;
  machine_word Wrd564;
  machine_word Wrd557;
  machine_word Wrd559;
  machine_word Wrd560;
  machine_word Wrd551;
  machine_word Wrd556;
  machine_word Wrd555;
  machine_word Wrd552;
  machine_word Wrd549;
  machine_word Wrd548;
  machine_word Wrd546;
  machine_word Wrd540;
  machine_word Wrd545;
  machine_word Wrd544;
  machine_word Wrd541;
  machine_word Wrd538;
  machine_word Wrd537;
  machine_word Wrd535;
  machine_word Wrd531;
  machine_word Wrd533;
  machine_word Wrd534;
  machine_word Wrd527;
  machine_word Wrd529;
  machine_word Wrd530;
  machine_word Wrd521;
  machine_word Wrd526;
  machine_word Wrd525;
  machine_word Wrd522;
  machine_word Wrd518;
  machine_word Wrd517;
  machine_word Wrd512;
  machine_word Wrd514;
  machine_word Wrd515;
  machine_word Wrd508;
  machine_word Wrd510;
  machine_word Wrd511;
  machine_word Wrd502;
  machine_word Wrd507;
  machine_word Wrd506;
  machine_word Wrd503;
  machine_word Wrd500;
  machine_word Wrd499;
  machine_word Wrd497;
  machine_word Wrd491;
  machine_word Wrd496;
  machine_word Wrd495;
  machine_word Wrd492;
  machine_word Wrd489;
  machine_word Wrd488;
  machine_word Wrd486;
  machine_word Wrd482;
  machine_word Wrd484;
  machine_word Wrd485;
  machine_word Wrd478;
  machine_word Wrd480;
  machine_word Wrd481;
  machine_word Wrd472;
  machine_word Wrd477;
  machine_word Wrd476;
  machine_word Wrd473;
  machine_word Wrd469;
  machine_word Wrd468;
  machine_word Wrd463;
  machine_word Wrd465;
  machine_word Wrd466;
  machine_word Wrd459;
  machine_word Wrd461;
  machine_word Wrd462;
  machine_word Wrd453;
  machine_word Wrd458;
  machine_word Wrd457;
  machine_word Wrd454;
  machine_word Wrd451;
  machine_word Wrd450;
  machine_word Wrd448;
  machine_word Wrd442;
  machine_word Wrd447;
  machine_word Wrd446;
  machine_word Wrd443;
  machine_word Wrd440;
  machine_word Wrd439;
  machine_word Wrd437;
  machine_word Wrd433;
  machine_word Wrd435;
  machine_word Wrd436;
  machine_word Wrd429;
  machine_word Wrd431;
  machine_word Wrd432;
  machine_word Wrd423;
  machine_word Wrd428;
  machine_word Wrd427;
  machine_word Wrd424;
  machine_word Wrd420;
  machine_word Wrd419;
  machine_word Wrd414;
  machine_word Wrd416;
  machine_word Wrd417;
  machine_word Wrd410;
  machine_word Wrd412;
  machine_word Wrd413;
  machine_word Wrd404;
  machine_word Wrd409;
  machine_word Wrd408;
  machine_word Wrd405;
  machine_word Wrd402;
  machine_word Wrd401;
  machine_word Wrd399;
  machine_word Wrd393;
  machine_word Wrd398;
  machine_word Wrd397;
  machine_word Wrd394;
  machine_word Wrd391;
  machine_word Wrd390;
  machine_word Wrd388;
  machine_word Wrd384;
  machine_word Wrd386;
  machine_word Wrd387;
  machine_word Wrd380;
  machine_word Wrd382;
  machine_word Wrd383;
  machine_word Wrd374;
  machine_word Wrd379;
  machine_word Wrd378;
  machine_word Wrd375;
  machine_word Wrd371;
  machine_word Wrd370;
  machine_word Wrd365;
  machine_word Wrd367;
  machine_word Wrd368;
  machine_word Wrd361;
  machine_word Wrd363;
  machine_word Wrd364;
  machine_word Wrd355;
  machine_word Wrd360;
  machine_word Wrd359;
  machine_word Wrd356;
  machine_word Wrd353;
  machine_word Wrd352;
  machine_word Wrd350;
  machine_word Wrd344;
  machine_word Wrd349;
  machine_word Wrd348;
  machine_word Wrd345;
  machine_word Wrd342;
  machine_word Wrd341;
  machine_word Wrd339;
  machine_word Wrd335;
  machine_word Wrd337;
  machine_word Wrd338;
  machine_word Wrd331;
  machine_word Wrd333;
  machine_word Wrd334;
  machine_word Wrd325;
  machine_word Wrd330;
  machine_word Wrd329;
  machine_word Wrd326;
  machine_word Wrd322;
  machine_word Wrd321;
  machine_word Wrd316;
  machine_word Wrd318;
  machine_word Wrd319;
  machine_word Wrd312;
  machine_word Wrd314;
  machine_word Wrd315;
  machine_word Wrd306;
  machine_word Wrd311;
  machine_word Wrd310;
  machine_word Wrd307;
  machine_word Wrd304;
  machine_word Wrd303;
  machine_word Wrd301;
  machine_word Wrd295;
  machine_word Wrd300;
  machine_word Wrd299;
  machine_word Wrd296;
  machine_word Wrd293;
  machine_word Wrd292;
  machine_word Wrd290;
  machine_word Wrd286;
  machine_word Wrd288;
  machine_word Wrd289;
  machine_word Wrd282;
  machine_word Wrd284;
  machine_word Wrd285;
  machine_word Wrd276;
  machine_word Wrd281;
  machine_word Wrd280;
  machine_word Wrd277;
  machine_word Wrd273;
  machine_word Wrd272;
  machine_word Wrd267;
  machine_word Wrd269;
  machine_word Wrd270;
  machine_word Wrd263;
  machine_word Wrd265;
  machine_word Wrd266;
  machine_word Wrd257;
  machine_word Wrd262;
  machine_word Wrd261;
  machine_word Wrd258;
  machine_word Wrd255;
  machine_word Wrd254;
  machine_word Wrd252;
  machine_word Wrd246;
  machine_word Wrd251;
  machine_word Wrd250;
  machine_word Wrd247;
  machine_word Wrd244;
  machine_word Wrd243;
  machine_word Wrd241;
  machine_word Wrd237;
  machine_word Wrd239;
  machine_word Wrd240;
  machine_word Wrd233;
  machine_word Wrd235;
  machine_word Wrd236;
  machine_word Wrd227;
  machine_word Wrd232;
  machine_word Wrd231;
  machine_word Wrd228;
  machine_word Wrd224;
  machine_word Wrd223;
  machine_word Wrd218;
  machine_word Wrd220;
  machine_word Wrd221;
  machine_word Wrd214;
  machine_word Wrd216;
  machine_word Wrd217;
  machine_word Wrd208;
  machine_word Wrd213;
  machine_word Wrd212;
  machine_word Wrd209;
  machine_word Wrd206;
  machine_word Wrd205;
  machine_word Wrd203;
  machine_word Wrd197;
  machine_word Wrd202;
  machine_word Wrd201;
  machine_word Wrd198;
  machine_word Wrd195;
  machine_word Wrd194;
  machine_word Wrd192;
  machine_word Wrd188;
  machine_word Wrd190;
  machine_word Wrd191;
  machine_word Wrd184;
  machine_word Wrd186;
  machine_word Wrd187;
  machine_word Wrd178;
  machine_word Wrd183;
  machine_word Wrd182;
  machine_word Wrd179;
  machine_word Wrd175;
  machine_word Wrd174;
  machine_word Wrd169;
  machine_word Wrd171;
  machine_word Wrd172;
  machine_word Wrd165;
  machine_word Wrd167;
  machine_word Wrd168;
  machine_word Wrd159;
  machine_word Wrd164;
  machine_word Wrd163;
  machine_word Wrd160;
  machine_word Wrd157;
  machine_word Wrd156;
  machine_word Wrd154;
  machine_word Wrd148;
  machine_word Wrd153;
  machine_word Wrd152;
  machine_word Wrd149;
  machine_word Wrd146;
  machine_word Wrd145;
  machine_word Wrd143;
  machine_word Wrd139;
  machine_word Wrd141;
  machine_word Wrd142;
  machine_word Wrd135;
  machine_word Wrd137;
  machine_word Wrd138;
  machine_word Wrd129;
  machine_word Wrd134;
  machine_word Wrd133;
  machine_word Wrd130;
  machine_word Wrd126;
  machine_word Wrd125;
  machine_word Wrd120;
  machine_word Wrd122;
  machine_word Wrd123;
  machine_word Wrd116;
  machine_word Wrd118;
  machine_word Wrd119;
  machine_word Wrd110;
  machine_word Wrd115;
  machine_word Wrd114;
  machine_word Wrd111;
  machine_word Wrd108;
  machine_word Wrd107;
  machine_word Wrd105;
  machine_word Wrd99;
  machine_word Wrd104;
  machine_word Wrd103;
  machine_word Wrd100;
  machine_word Wrd97;
  machine_word Wrd96;
  machine_word Wrd94;
  machine_word Wrd90;
  machine_word Wrd92;
  machine_word Wrd93;
  machine_word Wrd86;
  machine_word Wrd88;
  machine_word Wrd89;
  machine_word Wrd80;
  machine_word Wrd85;
  machine_word Wrd84;
  machine_word Wrd81;
  machine_word Wrd77;
  machine_word Wrd76;
  machine_word Wrd71;
  machine_word Wrd73;
  machine_word Wrd74;
  machine_word Wrd67;
  machine_word Wrd69;
  machine_word Wrd70;
  machine_word Wrd61;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd62;
  machine_word Wrd59;
  machine_word Wrd58;
  machine_word Wrd56;
  machine_word Wrd50;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd51;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd45;
  machine_word Wrd41;
  machine_word Wrd43;
  machine_word Wrd44;
  machine_word Wrd37;
  machine_word Wrd39;
  machine_word Wrd40;
  machine_word Wrd31;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd22;
  machine_word Wrd24;
  machine_word Wrd25;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd21;
  machine_word Wrd12;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_8);
      goto label_114;

    case 2:
      current_block = (Rpc - LABEL_9);
      goto label_115;

    case 3:
      current_block = (Rpc - LABEL_10);
      goto label_116;

    case 4:
      current_block = (Rpc - LABEL_11);
      goto label_117;

    case 5:
      current_block = (Rpc - LABEL_12);
      goto label_118;

    case 6:
      current_block = (Rpc - LABEL_13);
      goto label_119;

    case 7:
      current_block = (Rpc - LABEL_14);
      goto label_120;

    case 8:
      current_block = (Rpc - LABEL_15);
      goto label_121;

    case 9:
      current_block = (Rpc - LABEL_16);
      goto label_122;

    case 10:
      current_block = (Rpc - LABEL_17);
      goto label_123;

    case 11:
      current_block = (Rpc - LABEL_18);
      goto label_124;

    case 12:
      current_block = (Rpc - LABEL_19);
      goto label_125;

    case 13:
      current_block = (Rpc - LABEL_20);
      goto label_126;

    case 14:
      current_block = (Rpc - LABEL_21);
      goto label_127;

    case 15:
      current_block = (Rpc - LABEL_22);
      goto label_128;

    case 16:
      current_block = (Rpc - LABEL_23);
      goto label_129;

    case 17:
      current_block = (Rpc - LABEL_24);
      goto label_130;

    case 18:
      current_block = (Rpc - LABEL_25);
      goto label_131;

    case 19:
      current_block = (Rpc - LABEL_26);
      goto label_132;

    case 20:
      current_block = (Rpc - LABEL_27);
      goto label_133;

    case 21:
      current_block = (Rpc - LABEL_28);
      goto label_134;

    case 22:
      current_block = (Rpc - LABEL_29);
      goto label_135;

    case 23:
      current_block = (Rpc - LABEL_30);
      goto label_136;

    case 24:
      current_block = (Rpc - LABEL_31);
      goto label_137;

    case 25:
      current_block = (Rpc - LABEL_32);
      goto label_138;

    case 26:
      current_block = (Rpc - LABEL_33);
      goto label_139;

    case 27:
      current_block = (Rpc - LABEL_34);
      goto label_140;

    case 28:
      current_block = (Rpc - LABEL_35);
      goto label_141;

    case 29:
      current_block = (Rpc - LABEL_36);
      goto label_142;

    case 30:
      current_block = (Rpc - LABEL_37);
      goto label_143;

    case 31:
      current_block = (Rpc - LABEL_38);
      goto label_144;

    case 32:
      current_block = (Rpc - LABEL_39);
      goto label_145;

    case 33:
      current_block = (Rpc - LABEL_40);
      goto label_146;

    case 34:
      current_block = (Rpc - LABEL_41);
      goto label_147;

    case 35:
      current_block = (Rpc - LABEL_42);
      goto label_148;

    case 36:
      current_block = (Rpc - LABEL_43);
      goto label_149;

    case 37:
      current_block = (Rpc - LABEL_6);
      goto continuation_86;

    case 38:
      current_block = (Rpc - LABEL_7);
      goto continuation_85;

    case 39:
      current_block = (Rpc - LABEL_45);
      goto continuation_87;

    case 40:
      current_block = (Rpc - LABEL_46);
      goto continuation_88;

    case 41:
      current_block = (Rpc - LABEL_48);
      goto continuation_89;

    case 42:
      current_block = (Rpc - LABEL_50);
      goto continuation_90;

    case 43:
      current_block = (Rpc - LABEL_52);
      goto label_150;

    case 44:
      current_block = (Rpc - LABEL_53);
      goto label_151;

    case 45:
      current_block = (Rpc - LABEL_51);
      goto continuation_91;

    case 46:
      current_block = (Rpc - LABEL_56);
      goto label_152;

    case 47:
      current_block = (Rpc - LABEL_57);
      goto label_153;

    case 48:
      current_block = (Rpc - LABEL_55);
      goto continuation_92;

    case 49:
      current_block = (Rpc - LABEL_59);
      goto label_154;

    case 50:
      current_block = (Rpc - LABEL_60);
      goto label_155;

    case 51:
      current_block = (Rpc - LABEL_58);
      goto continuation_93;

    case 52:
      current_block = (Rpc - LABEL_62);
      goto label_156;

    case 53:
      current_block = (Rpc - LABEL_63);
      goto label_157;

    case 54:
      current_block = (Rpc - LABEL_61);
      goto continuation_94;

    case 55:
      current_block = (Rpc - LABEL_65);
      goto label_158;

    case 56:
      current_block = (Rpc - LABEL_66);
      goto label_159;

    case 57:
      current_block = (Rpc - LABEL_64);
      goto continuation_95;

    case 58:
      current_block = (Rpc - LABEL_68);
      goto label_160;

    case 59:
      current_block = (Rpc - LABEL_69);
      goto label_161;

    case 60:
      current_block = (Rpc - LABEL_67);
      goto continuation_96;

    case 61:
      current_block = (Rpc - LABEL_71);
      goto label_162;

    case 62:
      current_block = (Rpc - LABEL_72);
      goto label_163;

    case 63:
      current_block = (Rpc - LABEL_70);
      goto continuation_97;

    case 64:
      current_block = (Rpc - LABEL_74);
      goto label_164;

    case 65:
      current_block = (Rpc - LABEL_75);
      goto label_165;

    case 66:
      current_block = (Rpc - LABEL_73);
      goto continuation_98;

    case 67:
      current_block = (Rpc - LABEL_77);
      goto label_166;

    case 68:
      current_block = (Rpc - LABEL_78);
      goto label_167;

    case 69:
      current_block = (Rpc - LABEL_76);
      goto continuation_99;

    case 70:
      current_block = (Rpc - LABEL_80);
      goto label_168;

    case 71:
      current_block = (Rpc - LABEL_81);
      goto label_169;

    case 72:
      current_block = (Rpc - LABEL_79);
      goto continuation_100;

    case 73:
      current_block = (Rpc - LABEL_83);
      goto label_170;

    case 74:
      current_block = (Rpc - LABEL_84);
      goto label_171;

    case 75:
      current_block = (Rpc - LABEL_82);
      goto continuation_101;

    case 76:
      current_block = (Rpc - LABEL_86);
      goto label_172;

    case 77:
      current_block = (Rpc - LABEL_87);
      goto label_173;

    case 78:
      current_block = (Rpc - LABEL_85);
      goto continuation_102;

    case 79:
      current_block = (Rpc - LABEL_89);
      goto label_174;

    case 80:
      current_block = (Rpc - LABEL_90);
      goto label_175;

    case 81:
      current_block = (Rpc - LABEL_88);
      goto continuation_103;

    case 82:
      current_block = (Rpc - LABEL_91);
      goto continuation_104;

    case 83:
      current_block = (Rpc - LABEL_93);
      goto label_176;

    case 84:
      current_block = (Rpc - LABEL_94);
      goto label_177;

    case 85:
      current_block = (Rpc - LABEL_95);
      goto label_178;

    case 86:
      current_block = (Rpc - LABEL_96);
      goto label_179;

    case 87:
      current_block = (Rpc - LABEL_92);
      goto continuation_105;

    case 88:
      current_block = (Rpc - LABEL_99);
      goto label_180;

    case 89:
      current_block = (Rpc - LABEL_100);
      goto label_181;

    case 90:
      current_block = (Rpc - LABEL_101);
      goto label_182;

    case 91:
      current_block = (Rpc - LABEL_102);
      goto label_183;

    case 92:
      current_block = (Rpc - LABEL_98);
      goto continuation_106;

    case 93:
      current_block = (Rpc - LABEL_104);
      goto label_184;

    case 94:
      current_block = (Rpc - LABEL_105);
      goto label_185;

    case 95:
      current_block = (Rpc - LABEL_106);
      goto label_186;

    case 96:
      current_block = (Rpc - LABEL_107);
      goto label_187;

    case 97:
      current_block = (Rpc - LABEL_103);
      goto continuation_107;

    case 98:
      current_block = (Rpc - LABEL_109);
      goto label_188;

    case 99:
      current_block = (Rpc - LABEL_110);
      goto label_189;

    case 100:
      current_block = (Rpc - LABEL_111);
      goto label_190;

    case 101:
      current_block = (Rpc - LABEL_112);
      goto label_191;

    case 102:
      current_block = (Rpc - LABEL_108);
      goto continuation_108;

    case 103:
      current_block = (Rpc - LABEL_114);
      goto label_192;

    case 104:
      current_block = (Rpc - LABEL_115);
      goto label_193;

    case 105:
      current_block = (Rpc - LABEL_116);
      goto label_194;

    case 106:
      current_block = (Rpc - LABEL_117);
      goto label_195;

    case 107:
      current_block = (Rpc - LABEL_113);
      goto continuation_109;

    case 108:
      current_block = (Rpc - LABEL_119);
      goto label_196;

    case 109:
      current_block = (Rpc - LABEL_120);
      goto label_197;

    case 110:
      current_block = (Rpc - LABEL_121);
      goto label_198;

    case 111:
      current_block = (Rpc - LABEL_122);
      goto label_199;

    case 112:
      current_block = (Rpc - LABEL_118);
      goto continuation_110;

    case 113:
      current_block = (Rpc - LABEL_124);
      goto label_200;

    case 114:
      current_block = (Rpc - LABEL_125);
      goto label_201;

    case 115:
      current_block = (Rpc - LABEL_126);
      goto label_202;

    case 116:
      current_block = (Rpc - LABEL_127);
      goto label_203;

    case 117:
      current_block = (Rpc - LABEL_123);
      goto continuation_111;

    case 118:
      current_block = (Rpc - LABEL_128);
      goto label_204;

    case 119:
      current_block = (Rpc - LABEL_129);
      goto label_205;

    case 120:
      current_block = (Rpc - LABEL_130);
      goto label_206;

    case 121:
      current_block = (Rpc - LABEL_131);
      goto label_207;

    case 122:
      current_block = (Rpc - LABEL_132);
      goto label_210;

    case 123:
      current_block = (Rpc - LABEL_133);
      goto label_211;

    case 124:
      current_block = (Rpc - LABEL_134);
      goto expression_113;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_113)
  (current_block [ENVIRONMENT_LABEL_3]) = (Rrb [REGBLOCK_ENV]);
  INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_133])), current_block, (& (current_block [FREE_REFERENCES_LABEL_0])), NUMBER_OF_LINKER_SECTIONS_1);

DEFLABEL (label_211)
  (* (--Rsp)) = (ULONG_TO_FIXNUM (1UL));

DEFLABEL (label_210)
  {
    static const short sections [] =
      {
	0,
	1,
	1,
	1,
	2,
	2,
	2,
	3,
	2,
	1,
	2,
	1,
	1,
	1,
	2,
	1,
	3,
	3,
	3,
	2
      };
    unsigned long counter = (OBJECT_DATUM (* Rsp));
    SCHEME_OBJECT blocks;
    SCHEME_OBJECT * sub_block;
    short section;
    if (counter > 19)
      goto label_209;
    blocks = (current_block [OBJECT_48]);
    sub_block = (OBJECT_ADDRESS (MEMORY_REF (blocks, counter)));
    (sub_block [(OBJECT_DATUM (sub_block [0]))]) = (Rrb [REGBLOCK_ENV]);
    section = (sections [counter]);
    (* Rsp) = (ULONG_TO_FIXNUM (counter + 1));
    INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_132])), sub_block, (sub_block + (2 + (OBJECT_DATUM (sub_block [1])))), section);
  }

DEFLABEL (label_209)
  Rsp += 1;
  (Wrd5.Obj) = (Rrb [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_1]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_399;
  Wrd12 = Wrd16;

DEFLABEL (label_398)
  (Wrd21.Obj) = (current_block [OBJECT_2]);
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = (Wrd21.Obj);
  (Wrd20.pObj) = (& (Rhp [-2]));
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));
  (Wrd25.Obj) = (current_block [OBJECT_3]);
  (* (Rhp++)) = (Wrd25.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (Wrd24.pObj) = (& (Rhp [-2]));
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd24.pObj)));
  (* (Rhp++)) = (Wrd22.Obj);
  (* (Rhp++)) = (Wrd21.Obj);
  (Wrd27.pObj) = (& (Rhp [-2]));
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd27.pObj)));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd32.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1]));
  (Wrd35.Obj) = ((Wrd32.pObj) [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if ((Wrd36.uLng) == 50)
    goto label_397;
  Wrd31 = Wrd35;

DEFLABEL (label_396)
  (Wrd40.Obj) = (current_block [OBJECT_2]);
  (* (Rhp++)) = (Wrd31.Obj);
  (* (Rhp++)) = (Wrd40.Obj);
  (Wrd39.pObj) = (& (Rhp [-2]));
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd39.pObj)));
  (Wrd44.Obj) = (current_block [OBJECT_4]);
  (* (Rhp++)) = (Wrd44.Obj);
  (* (Rhp++)) = (Wrd37.Obj);
  (Wrd43.pObj) = (& (Rhp [-2]));
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd43.pObj)));
  (Wrd45.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd41.Obj);
  (* (Rhp++)) = (Wrd45.Obj);
  (Wrd47.pObj) = (& (Rhp [-2]));
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd47.pObj)));
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd51.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2]));
  (Wrd54.Obj) = ((Wrd51.pObj) [0]);
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if ((Wrd55.uLng) == 50)
    goto label_395;
  Wrd50 = Wrd54;

DEFLABEL (label_394)
  (Wrd56.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd50.Obj);
  (* (Rhp++)) = (Wrd56.Obj);
  (Wrd58.pObj) = (& (Rhp [-2]));
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd58.pObj)));
  (* (--Rsp)) = (Wrd59.Obj);
  (Wrd62.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3]));
  (Wrd65.Obj) = ((Wrd62.pObj) [0]);
  (Wrd66.uLng) = (OBJECT_TYPE (Wrd65.Obj));
  if ((Wrd66.uLng) == 50)
    goto label_393;
  Wrd61 = Wrd65;

DEFLABEL (label_392)
  (Wrd70.Obj) = (current_block [OBJECT_2]);
  (* (Rhp++)) = (Wrd61.Obj);
  (* (Rhp++)) = (Wrd70.Obj);
  (Wrd69.pObj) = (& (Rhp [-2]));
  (Wrd67.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd69.pObj)));
  (Wrd74.Obj) = (current_block [OBJECT_5]);
  (* (Rhp++)) = (Wrd74.Obj);
  (* (Rhp++)) = (Wrd67.Obj);
  (Wrd73.pObj) = (& (Rhp [-2]));
  (Wrd71.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd73.pObj)));
  (* (Rhp++)) = (Wrd71.Obj);
  (* (Rhp++)) = (Wrd70.Obj);
  (Wrd76.pObj) = (& (Rhp [-2]));
  (Wrd77.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd76.pObj)));
  (* (--Rsp)) = (Wrd77.Obj);
  (Wrd81.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1]));
  (Wrd84.Obj) = ((Wrd81.pObj) [0]);
  (Wrd85.uLng) = (OBJECT_TYPE (Wrd84.Obj));
  if ((Wrd85.uLng) == 50)
    goto label_391;
  Wrd80 = Wrd84;

DEFLABEL (label_390)
  (Wrd89.Obj) = (current_block [OBJECT_2]);
  (* (Rhp++)) = (Wrd80.Obj);
  (* (Rhp++)) = (Wrd89.Obj);
  (Wrd88.pObj) = (& (Rhp [-2]));
  (Wrd86.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd88.pObj)));
  (Wrd93.Obj) = (current_block [OBJECT_4]);
  (* (Rhp++)) = (Wrd93.Obj);
  (* (Rhp++)) = (Wrd86.Obj);
  (Wrd92.pObj) = (& (Rhp [-2]));
  (Wrd90.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd92.pObj)));
  (Wrd94.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd90.Obj);
  (* (Rhp++)) = (Wrd94.Obj);
  (Wrd96.pObj) = (& (Rhp [-2]));
  (Wrd97.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd96.pObj)));
  (* (--Rsp)) = (Wrd97.Obj);
  (Wrd100.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2]));
  (Wrd103.Obj) = ((Wrd100.pObj) [0]);
  (Wrd104.uLng) = (OBJECT_TYPE (Wrd103.Obj));
  if ((Wrd104.uLng) == 50)
    goto label_389;
  Wrd99 = Wrd103;

DEFLABEL (label_388)
  (Wrd105.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd99.Obj);
  (* (Rhp++)) = (Wrd105.Obj);
  (Wrd107.pObj) = (& (Rhp [-2]));
  (Wrd108.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd107.pObj)));
  (* (--Rsp)) = (Wrd108.Obj);
  (Wrd111.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4]));
  (Wrd114.Obj) = ((Wrd111.pObj) [0]);
  (Wrd115.uLng) = (OBJECT_TYPE (Wrd114.Obj));
  if ((Wrd115.uLng) == 50)
    goto label_387;
  Wrd110 = Wrd114;

DEFLABEL (label_386)
  (Wrd119.Obj) = (current_block [OBJECT_2]);
  (* (Rhp++)) = (Wrd110.Obj);
  (* (Rhp++)) = (Wrd119.Obj);
  (Wrd118.pObj) = (& (Rhp [-2]));
  (Wrd116.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd118.pObj)));
  (Wrd123.Obj) = (current_block [OBJECT_3]);
  (* (Rhp++)) = (Wrd123.Obj);
  (* (Rhp++)) = (Wrd116.Obj);
  (Wrd122.pObj) = (& (Rhp [-2]));
  (Wrd120.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd122.pObj)));
  (* (Rhp++)) = (Wrd120.Obj);
  (* (Rhp++)) = (Wrd119.Obj);
  (Wrd125.pObj) = (& (Rhp [-2]));
  (Wrd126.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd125.pObj)));
  (* (--Rsp)) = (Wrd126.Obj);
  (Wrd130.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_5]));
  (Wrd133.Obj) = ((Wrd130.pObj) [0]);
  (Wrd134.uLng) = (OBJECT_TYPE (Wrd133.Obj));
  if ((Wrd134.uLng) == 50)
    goto label_385;
  Wrd129 = Wrd133;

DEFLABEL (label_384)
  (Wrd138.Obj) = (current_block [OBJECT_2]);
  (* (Rhp++)) = (Wrd129.Obj);
  (* (Rhp++)) = (Wrd138.Obj);
  (Wrd137.pObj) = (& (Rhp [-2]));
  (Wrd135.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd137.pObj)));
  (Wrd142.Obj) = (current_block [OBJECT_6]);
  (* (Rhp++)) = (Wrd142.Obj);
  (* (Rhp++)) = (Wrd135.Obj);
  (Wrd141.pObj) = (& (Rhp [-2]));
  (Wrd139.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd141.pObj)));
  (Wrd143.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd139.Obj);
  (* (Rhp++)) = (Wrd143.Obj);
  (Wrd145.pObj) = (& (Rhp [-2]));
  (Wrd146.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd145.pObj)));
  (* (--Rsp)) = (Wrd146.Obj);
  (Wrd149.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2]));
  (Wrd152.Obj) = ((Wrd149.pObj) [0]);
  (Wrd153.uLng) = (OBJECT_TYPE (Wrd152.Obj));
  if ((Wrd153.uLng) == 50)
    goto label_383;
  Wrd148 = Wrd152;

DEFLABEL (label_382)
  (Wrd154.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd148.Obj);
  (* (Rhp++)) = (Wrd154.Obj);
  (Wrd156.pObj) = (& (Rhp [-2]));
  (Wrd157.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd156.pObj)));
  (* (--Rsp)) = (Wrd157.Obj);
  (Wrd160.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6]));
  (Wrd163.Obj) = ((Wrd160.pObj) [0]);
  (Wrd164.uLng) = (OBJECT_TYPE (Wrd163.Obj));
  if ((Wrd164.uLng) == 50)
    goto label_381;
  Wrd159 = Wrd163;

DEFLABEL (label_380)
  (Wrd168.Obj) = (current_block [OBJECT_2]);
  (* (Rhp++)) = (Wrd159.Obj);
  (* (Rhp++)) = (Wrd168.Obj);
  (Wrd167.pObj) = (& (Rhp [-2]));
  (Wrd165.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd167.pObj)));
  (Wrd172.Obj) = (current_block [OBJECT_5]);
  (* (Rhp++)) = (Wrd172.Obj);
  (* (Rhp++)) = (Wrd165.Obj);
  (Wrd171.pObj) = (& (Rhp [-2]));
  (Wrd169.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd171.pObj)));
  (* (Rhp++)) = (Wrd169.Obj);
  (* (Rhp++)) = (Wrd168.Obj);
  (Wrd174.pObj) = (& (Rhp [-2]));
  (Wrd175.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd174.pObj)));
  (* (--Rsp)) = (Wrd175.Obj);
  (Wrd179.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7]));
  (Wrd182.Obj) = ((Wrd179.pObj) [0]);
  (Wrd183.uLng) = (OBJECT_TYPE (Wrd182.Obj));
  if ((Wrd183.uLng) == 50)
    goto label_379;
  Wrd178 = Wrd182;

DEFLABEL (label_378)
  (Wrd187.Obj) = (current_block [OBJECT_2]);
  (* (Rhp++)) = (Wrd178.Obj);
  (* (Rhp++)) = (Wrd187.Obj);
  (Wrd186.pObj) = (& (Rhp [-2]));
  (Wrd184.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd186.pObj)));
  (Wrd191.Obj) = (current_block [OBJECT_7]);
  (* (Rhp++)) = (Wrd191.Obj);
  (* (Rhp++)) = (Wrd184.Obj);
  (Wrd190.pObj) = (& (Rhp [-2]));
  (Wrd188.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd190.pObj)));
  (Wrd192.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd188.Obj);
  (* (Rhp++)) = (Wrd192.Obj);
  (Wrd194.pObj) = (& (Rhp [-2]));
  (Wrd195.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd194.pObj)));
  (* (--Rsp)) = (Wrd195.Obj);
  (Wrd198.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_8]));
  (Wrd201.Obj) = ((Wrd198.pObj) [0]);
  (Wrd202.uLng) = (OBJECT_TYPE (Wrd201.Obj));
  if ((Wrd202.uLng) == 50)
    goto label_377;
  Wrd197 = Wrd201;

DEFLABEL (label_376)
  (Wrd203.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd197.Obj);
  (* (Rhp++)) = (Wrd203.Obj);
  (Wrd205.pObj) = (& (Rhp [-2]));
  (Wrd206.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd205.pObj)));
  (* (--Rsp)) = (Wrd206.Obj);
  (Wrd209.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9]));
  (Wrd212.Obj) = ((Wrd209.pObj) [0]);
  (Wrd213.uLng) = (OBJECT_TYPE (Wrd212.Obj));
  if ((Wrd213.uLng) == 50)
    goto label_375;
  Wrd208 = Wrd212;

DEFLABEL (label_374)
  (Wrd217.Obj) = (current_block [OBJECT_2]);
  (* (Rhp++)) = (Wrd208.Obj);
  (* (Rhp++)) = (Wrd217.Obj);
  (Wrd216.pObj) = (& (Rhp [-2]));
  (Wrd214.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd216.pObj)));
  (Wrd221.Obj) = (current_block [OBJECT_8]);
  (* (Rhp++)) = (Wrd221.Obj);
  (* (Rhp++)) = (Wrd214.Obj);
  (Wrd220.pObj) = (& (Rhp [-2]));
  (Wrd218.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd220.pObj)));
  (* (Rhp++)) = (Wrd218.Obj);
  (* (Rhp++)) = (Wrd217.Obj);
  (Wrd223.pObj) = (& (Rhp [-2]));
  (Wrd224.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd223.pObj)));
  (* (--Rsp)) = (Wrd224.Obj);
  (Wrd228.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_10]));
  (Wrd231.Obj) = ((Wrd228.pObj) [0]);
  (Wrd232.uLng) = (OBJECT_TYPE (Wrd231.Obj));
  if ((Wrd232.uLng) == 50)
    goto label_373;
  Wrd227 = Wrd231;

DEFLABEL (label_372)
  (Wrd236.Obj) = (current_block [OBJECT_2]);
  (* (Rhp++)) = (Wrd227.Obj);
  (* (Rhp++)) = (Wrd236.Obj);
  (Wrd235.pObj) = (& (Rhp [-2]));
  (Wrd233.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd235.pObj)));
  (Wrd240.Obj) = (current_block [OBJECT_9]);
  (* (Rhp++)) = (Wrd240.Obj);
  (* (Rhp++)) = (Wrd233.Obj);
  (Wrd239.pObj) = (& (Rhp [-2]));
  (Wrd237.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd239.pObj)));
  (Wrd241.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd237.Obj);
  (* (Rhp++)) = (Wrd241.Obj);
  (Wrd243.pObj) = (& (Rhp [-2]));
  (Wrd244.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd243.pObj)));
  (* (--Rsp)) = (Wrd244.Obj);
  (Wrd247.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11]));
  (Wrd250.Obj) = ((Wrd247.pObj) [0]);
  (Wrd251.uLng) = (OBJECT_TYPE (Wrd250.Obj));
  if ((Wrd251.uLng) == 50)
    goto label_371;
  Wrd246 = Wrd250;

DEFLABEL (label_370)
  (Wrd252.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd246.Obj);
  (* (Rhp++)) = (Wrd252.Obj);
  (Wrd254.pObj) = (& (Rhp [-2]));
  (Wrd255.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd254.pObj)));
  (* (--Rsp)) = (Wrd255.Obj);
  (Wrd258.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_10]));
  (Wrd261.Obj) = ((Wrd258.pObj) [0]);
  (Wrd262.uLng) = (OBJECT_TYPE (Wrd261.Obj));
  if ((Wrd262.uLng) == 50)
    goto label_369;
  Wrd257 = Wrd261;

DEFLABEL (label_368)
  (Wrd266.Obj) = (current_block [OBJECT_2]);
  (* (Rhp++)) = (Wrd257.Obj);
  (* (Rhp++)) = (Wrd266.Obj);
  (Wrd265.pObj) = (& (Rhp [-2]));
  (Wrd263.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd265.pObj)));
  (Wrd270.Obj) = (current_block [OBJECT_9]);
  (* (Rhp++)) = (Wrd270.Obj);
  (* (Rhp++)) = (Wrd263.Obj);
  (Wrd269.pObj) = (& (Rhp [-2]));
  (Wrd267.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd269.pObj)));
  (* (Rhp++)) = (Wrd267.Obj);
  (* (Rhp++)) = (Wrd266.Obj);
  (Wrd272.pObj) = (& (Rhp [-2]));
  (Wrd273.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd272.pObj)));
  (* (--Rsp)) = (Wrd273.Obj);
  (Wrd277.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9]));
  (Wrd280.Obj) = ((Wrd277.pObj) [0]);
  (Wrd281.uLng) = (OBJECT_TYPE (Wrd280.Obj));
  if ((Wrd281.uLng) == 50)
    goto label_367;
  Wrd276 = Wrd280;

DEFLABEL (label_366)
  (Wrd285.Obj) = (current_block [OBJECT_2]);
  (* (Rhp++)) = (Wrd276.Obj);
  (* (Rhp++)) = (Wrd285.Obj);
  (Wrd284.pObj) = (& (Rhp [-2]));
  (Wrd282.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd284.pObj)));
  (Wrd289.Obj) = (current_block [OBJECT_8]);
  (* (Rhp++)) = (Wrd289.Obj);
  (* (Rhp++)) = (Wrd282.Obj);
  (Wrd288.pObj) = (& (Rhp [-2]));
  (Wrd286.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd288.pObj)));
  (Wrd290.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd286.Obj);
  (* (Rhp++)) = (Wrd290.Obj);
  (Wrd292.pObj) = (& (Rhp [-2]));
  (Wrd293.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd292.pObj)));
  (* (--Rsp)) = (Wrd293.Obj);
  (Wrd296.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11]));
  (Wrd299.Obj) = ((Wrd296.pObj) [0]);
  (Wrd300.uLng) = (OBJECT_TYPE (Wrd299.Obj));
  if ((Wrd300.uLng) == 50)
    goto label_365;
  Wrd295 = Wrd299;

DEFLABEL (label_364)
  (Wrd301.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd295.Obj);
  (* (Rhp++)) = (Wrd301.Obj);
  (Wrd303.pObj) = (& (Rhp [-2]));
  (Wrd304.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd303.pObj)));
  (* (--Rsp)) = (Wrd304.Obj);
  (Wrd307.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_12]));
  (Wrd310.Obj) = ((Wrd307.pObj) [0]);
  (Wrd311.uLng) = (OBJECT_TYPE (Wrd310.Obj));
  if ((Wrd311.uLng) == 50)
    goto label_363;
  Wrd306 = Wrd310;

DEFLABEL (label_362)
  (Wrd315.Obj) = (current_block [OBJECT_2]);
  (* (Rhp++)) = (Wrd306.Obj);
  (* (Rhp++)) = (Wrd315.Obj);
  (Wrd314.pObj) = (& (Rhp [-2]));
  (Wrd312.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd314.pObj)));
  (Wrd319.Obj) = (current_block [OBJECT_10]);
  (* (Rhp++)) = (Wrd319.Obj);
  (* (Rhp++)) = (Wrd312.Obj);
  (Wrd318.pObj) = (& (Rhp [-2]));
  (Wrd316.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd318.pObj)));
  (* (Rhp++)) = (Wrd316.Obj);
  (* (Rhp++)) = (Wrd315.Obj);
  (Wrd321.pObj) = (& (Rhp [-2]));
  (Wrd322.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd321.pObj)));
  (* (--Rsp)) = (Wrd322.Obj);
  (Wrd326.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13]));
  (Wrd329.Obj) = ((Wrd326.pObj) [0]);
  (Wrd330.uLng) = (OBJECT_TYPE (Wrd329.Obj));
  if ((Wrd330.uLng) == 50)
    goto label_361;
  Wrd325 = Wrd329;

DEFLABEL (label_360)
  (Wrd334.Obj) = (current_block [OBJECT_2]);
  (* (Rhp++)) = (Wrd325.Obj);
  (* (Rhp++)) = (Wrd334.Obj);
  (Wrd333.pObj) = (& (Rhp [-2]));
  (Wrd331.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd333.pObj)));
  (Wrd338.Obj) = (current_block [OBJECT_11]);
  (* (Rhp++)) = (Wrd338.Obj);
  (* (Rhp++)) = (Wrd331.Obj);
  (Wrd337.pObj) = (& (Rhp [-2]));
  (Wrd335.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd337.pObj)));
  (Wrd339.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd335.Obj);
  (* (Rhp++)) = (Wrd339.Obj);
  (Wrd341.pObj) = (& (Rhp [-2]));
  (Wrd342.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd341.pObj)));
  (* (--Rsp)) = (Wrd342.Obj);
  (Wrd345.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11]));
  (Wrd348.Obj) = ((Wrd345.pObj) [0]);
  (Wrd349.uLng) = (OBJECT_TYPE (Wrd348.Obj));
  if ((Wrd349.uLng) == 50)
    goto label_359;
  Wrd344 = Wrd348;

DEFLABEL (label_358)
  (Wrd350.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd344.Obj);
  (* (Rhp++)) = (Wrd350.Obj);
  (Wrd352.pObj) = (& (Rhp [-2]));
  (Wrd353.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd352.pObj)));
  (* (--Rsp)) = (Wrd353.Obj);
  (Wrd356.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13]));
  (Wrd359.Obj) = ((Wrd356.pObj) [0]);
  (Wrd360.uLng) = (OBJECT_TYPE (Wrd359.Obj));
  if ((Wrd360.uLng) == 50)
    goto label_357;
  Wrd355 = Wrd359;

DEFLABEL (label_356)
  (Wrd364.Obj) = (current_block [OBJECT_2]);
  (* (Rhp++)) = (Wrd355.Obj);
  (* (Rhp++)) = (Wrd364.Obj);
  (Wrd363.pObj) = (& (Rhp [-2]));
  (Wrd361.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd363.pObj)));
  (Wrd368.Obj) = (current_block [OBJECT_11]);
  (* (Rhp++)) = (Wrd368.Obj);
  (* (Rhp++)) = (Wrd361.Obj);
  (Wrd367.pObj) = (& (Rhp [-2]));
  (Wrd365.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd367.pObj)));
  (* (Rhp++)) = (Wrd365.Obj);
  (* (Rhp++)) = (Wrd364.Obj);
  (Wrd370.pObj) = (& (Rhp [-2]));
  (Wrd371.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd370.pObj)));
  (* (--Rsp)) = (Wrd371.Obj);
  (Wrd375.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_12]));
  (Wrd378.Obj) = ((Wrd375.pObj) [0]);
  (Wrd379.uLng) = (OBJECT_TYPE (Wrd378.Obj));
  if ((Wrd379.uLng) == 50)
    goto label_355;
  Wrd374 = Wrd378;

DEFLABEL (label_354)
  (Wrd383.Obj) = (current_block [OBJECT_2]);
  (* (Rhp++)) = (Wrd374.Obj);
  (* (Rhp++)) = (Wrd383.Obj);
  (Wrd382.pObj) = (& (Rhp [-2]));
  (Wrd380.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd382.pObj)));
  (Wrd387.Obj) = (current_block [OBJECT_10]);
  (* (Rhp++)) = (Wrd387.Obj);
  (* (Rhp++)) = (Wrd380.Obj);
  (Wrd386.pObj) = (& (Rhp [-2]));
  (Wrd384.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd386.pObj)));
  (Wrd388.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd384.Obj);
  (* (Rhp++)) = (Wrd388.Obj);
  (Wrd390.pObj) = (& (Rhp [-2]));
  (Wrd391.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd390.pObj)));
  (* (--Rsp)) = (Wrd391.Obj);
  (Wrd394.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11]));
  (Wrd397.Obj) = ((Wrd394.pObj) [0]);
  (Wrd398.uLng) = (OBJECT_TYPE (Wrd397.Obj));
  if ((Wrd398.uLng) == 50)
    goto label_353;
  Wrd393 = Wrd397;

DEFLABEL (label_352)
  (Wrd399.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd393.Obj);
  (* (Rhp++)) = (Wrd399.Obj);
  (Wrd401.pObj) = (& (Rhp [-2]));
  (Wrd402.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd401.pObj)));
  (* (--Rsp)) = (Wrd402.Obj);
  (Wrd405.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14]));
  (Wrd408.Obj) = ((Wrd405.pObj) [0]);
  (Wrd409.uLng) = (OBJECT_TYPE (Wrd408.Obj));
  if ((Wrd409.uLng) == 50)
    goto label_351;
  Wrd404 = Wrd408;

DEFLABEL (label_350)
  (Wrd413.Obj) = (current_block [OBJECT_2]);
  (* (Rhp++)) = (Wrd404.Obj);
  (* (Rhp++)) = (Wrd413.Obj);
  (Wrd412.pObj) = (& (Rhp [-2]));
  (Wrd410.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd412.pObj)));
  (Wrd417.Obj) = (current_block [OBJECT_12]);
  (* (Rhp++)) = (Wrd417.Obj);
  (* (Rhp++)) = (Wrd410.Obj);
  (Wrd416.pObj) = (& (Rhp [-2]));
  (Wrd414.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd416.pObj)));
  (* (Rhp++)) = (Wrd414.Obj);
  (* (Rhp++)) = (Wrd413.Obj);
  (Wrd419.pObj) = (& (Rhp [-2]));
  (Wrd420.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd419.pObj)));
  (* (--Rsp)) = (Wrd420.Obj);
  (Wrd424.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15]));
  (Wrd427.Obj) = ((Wrd424.pObj) [0]);
  (Wrd428.uLng) = (OBJECT_TYPE (Wrd427.Obj));
  if ((Wrd428.uLng) == 50)
    goto label_349;
  Wrd423 = Wrd427;

DEFLABEL (label_348)
  (Wrd432.Obj) = (current_block [OBJECT_2]);
  (* (Rhp++)) = (Wrd423.Obj);
  (* (Rhp++)) = (Wrd432.Obj);
  (Wrd431.pObj) = (& (Rhp [-2]));
  (Wrd429.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd431.pObj)));
  (Wrd436.Obj) = (current_block [OBJECT_13]);
  (* (Rhp++)) = (Wrd436.Obj);
  (* (Rhp++)) = (Wrd429.Obj);
  (Wrd435.pObj) = (& (Rhp [-2]));
  (Wrd433.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd435.pObj)));
  (Wrd437.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd433.Obj);
  (* (Rhp++)) = (Wrd437.Obj);
  (Wrd439.pObj) = (& (Rhp [-2]));
  (Wrd440.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd439.pObj)));
  (* (--Rsp)) = (Wrd440.Obj);
  (Wrd443.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11]));
  (Wrd446.Obj) = ((Wrd443.pObj) [0]);
  (Wrd447.uLng) = (OBJECT_TYPE (Wrd446.Obj));
  if ((Wrd447.uLng) == 50)
    goto label_347;
  Wrd442 = Wrd446;

DEFLABEL (label_346)
  (Wrd448.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd442.Obj);
  (* (Rhp++)) = (Wrd448.Obj);
  (Wrd450.pObj) = (& (Rhp [-2]));
  (Wrd451.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd450.pObj)));
  (* (--Rsp)) = (Wrd451.Obj);
  (Wrd454.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15]));
  (Wrd457.Obj) = ((Wrd454.pObj) [0]);
  (Wrd458.uLng) = (OBJECT_TYPE (Wrd457.Obj));
  if ((Wrd458.uLng) == 50)
    goto label_345;
  Wrd453 = Wrd457;

DEFLABEL (label_344)
  (Wrd462.Obj) = (current_block [OBJECT_2]);
  (* (Rhp++)) = (Wrd453.Obj);
  (* (Rhp++)) = (Wrd462.Obj);
  (Wrd461.pObj) = (& (Rhp [-2]));
  (Wrd459.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd461.pObj)));
  (Wrd466.Obj) = (current_block [OBJECT_13]);
  (* (Rhp++)) = (Wrd466.Obj);
  (* (Rhp++)) = (Wrd459.Obj);
  (Wrd465.pObj) = (& (Rhp [-2]));
  (Wrd463.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd465.pObj)));
  (* (Rhp++)) = (Wrd463.Obj);
  (* (Rhp++)) = (Wrd462.Obj);
  (Wrd468.pObj) = (& (Rhp [-2]));
  (Wrd469.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd468.pObj)));
  (* (--Rsp)) = (Wrd469.Obj);
  (Wrd473.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14]));
  (Wrd476.Obj) = ((Wrd473.pObj) [0]);
  (Wrd477.uLng) = (OBJECT_TYPE (Wrd476.Obj));
  if ((Wrd477.uLng) == 50)
    goto label_343;
  Wrd472 = Wrd476;

DEFLABEL (label_342)
  (Wrd481.Obj) = (current_block [OBJECT_2]);
  (* (Rhp++)) = (Wrd472.Obj);
  (* (Rhp++)) = (Wrd481.Obj);
  (Wrd480.pObj) = (& (Rhp [-2]));
  (Wrd478.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd480.pObj)));
  (Wrd485.Obj) = (current_block [OBJECT_12]);
  (* (Rhp++)) = (Wrd485.Obj);
  (* (Rhp++)) = (Wrd478.Obj);
  (Wrd484.pObj) = (& (Rhp [-2]));
  (Wrd482.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd484.pObj)));
  (Wrd486.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd482.Obj);
  (* (Rhp++)) = (Wrd486.Obj);
  (Wrd488.pObj) = (& (Rhp [-2]));
  (Wrd489.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd488.pObj)));
  (* (--Rsp)) = (Wrd489.Obj);
  (Wrd492.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11]));
  (Wrd495.Obj) = ((Wrd492.pObj) [0]);
  (Wrd496.uLng) = (OBJECT_TYPE (Wrd495.Obj));
  if ((Wrd496.uLng) == 50)
    goto label_341;
  Wrd491 = Wrd495;

DEFLABEL (label_340)
  (Wrd497.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd491.Obj);
  (* (Rhp++)) = (Wrd497.Obj);
  (Wrd499.pObj) = (& (Rhp [-2]));
  (Wrd500.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd499.pObj)));
  (* (--Rsp)) = (Wrd500.Obj);
  (Wrd503.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_16]));
  (Wrd506.Obj) = ((Wrd503.pObj) [0]);
  (Wrd507.uLng) = (OBJECT_TYPE (Wrd506.Obj));
  if ((Wrd507.uLng) == 50)
    goto label_339;
  Wrd502 = Wrd506;

DEFLABEL (label_338)
  (Wrd511.Obj) = (current_block [OBJECT_2]);
  (* (Rhp++)) = (Wrd502.Obj);
  (* (Rhp++)) = (Wrd511.Obj);
  (Wrd510.pObj) = (& (Rhp [-2]));
  (Wrd508.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd510.pObj)));
  (Wrd515.Obj) = (current_block [OBJECT_14]);
  (* (Rhp++)) = (Wrd515.Obj);
  (* (Rhp++)) = (Wrd508.Obj);
  (Wrd514.pObj) = (& (Rhp [-2]));
  (Wrd512.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd514.pObj)));
  (* (Rhp++)) = (Wrd512.Obj);
  (* (Rhp++)) = (Wrd511.Obj);
  (Wrd517.pObj) = (& (Rhp [-2]));
  (Wrd518.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd517.pObj)));
  (* (--Rsp)) = (Wrd518.Obj);
  (Wrd522.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15]));
  (Wrd525.Obj) = ((Wrd522.pObj) [0]);
  (Wrd526.uLng) = (OBJECT_TYPE (Wrd525.Obj));
  if ((Wrd526.uLng) == 50)
    goto label_337;
  Wrd521 = Wrd525;

DEFLABEL (label_336)
  (Wrd530.Obj) = (current_block [OBJECT_2]);
  (* (Rhp++)) = (Wrd521.Obj);
  (* (Rhp++)) = (Wrd530.Obj);
  (Wrd529.pObj) = (& (Rhp [-2]));
  (Wrd527.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd529.pObj)));
  (Wrd534.Obj) = (current_block [OBJECT_13]);
  (* (Rhp++)) = (Wrd534.Obj);
  (* (Rhp++)) = (Wrd527.Obj);
  (Wrd533.pObj) = (& (Rhp [-2]));
  (Wrd531.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd533.pObj)));
  (Wrd535.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd531.Obj);
  (* (Rhp++)) = (Wrd535.Obj);
  (Wrd537.pObj) = (& (Rhp [-2]));
  (Wrd538.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd537.pObj)));
  (* (--Rsp)) = (Wrd538.Obj);
  (Wrd541.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11]));
  (Wrd544.Obj) = ((Wrd541.pObj) [0]);
  (Wrd545.uLng) = (OBJECT_TYPE (Wrd544.Obj));
  if ((Wrd545.uLng) == 50)
    goto label_335;
  Wrd540 = Wrd544;

DEFLABEL (label_334)
  (Wrd546.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd540.Obj);
  (* (Rhp++)) = (Wrd546.Obj);
  (Wrd548.pObj) = (& (Rhp [-2]));
  (Wrd549.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd548.pObj)));
  (* (--Rsp)) = (Wrd549.Obj);
  (Wrd552.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15]));
  (Wrd555.Obj) = ((Wrd552.pObj) [0]);
  (Wrd556.uLng) = (OBJECT_TYPE (Wrd555.Obj));
  if ((Wrd556.uLng) == 50)
    goto label_333;
  Wrd551 = Wrd555;

DEFLABEL (label_332)
  (Wrd560.Obj) = (current_block [OBJECT_2]);
  (* (Rhp++)) = (Wrd551.Obj);
  (* (Rhp++)) = (Wrd560.Obj);
  (Wrd559.pObj) = (& (Rhp [-2]));
  (Wrd557.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd559.pObj)));
  (Wrd564.Obj) = (current_block [OBJECT_13]);
  (* (Rhp++)) = (Wrd564.Obj);
  (* (Rhp++)) = (Wrd557.Obj);
  (Wrd563.pObj) = (& (Rhp [-2]));
  (Wrd561.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd563.pObj)));
  (* (Rhp++)) = (Wrd561.Obj);
  (* (Rhp++)) = (Wrd560.Obj);
  (Wrd566.pObj) = (& (Rhp [-2]));
  (Wrd567.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd566.pObj)));
  (* (--Rsp)) = (Wrd567.Obj);
  (Wrd571.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_16]));
  (Wrd574.Obj) = ((Wrd571.pObj) [0]);
  (Wrd575.uLng) = (OBJECT_TYPE (Wrd574.Obj));
  if ((Wrd575.uLng) == 50)
    goto label_331;
  Wrd570 = Wrd574;

DEFLABEL (label_330)
  (Wrd579.Obj) = (current_block [OBJECT_2]);
  (* (Rhp++)) = (Wrd570.Obj);
  (* (Rhp++)) = (Wrd579.Obj);
  (Wrd578.pObj) = (& (Rhp [-2]));
  (Wrd576.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd578.pObj)));
  (Wrd583.Obj) = (current_block [OBJECT_14]);
  (* (Rhp++)) = (Wrd583.Obj);
  (* (Rhp++)) = (Wrd576.Obj);
  (Wrd582.pObj) = (& (Rhp [-2]));
  (Wrd580.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd582.pObj)));
  (Wrd584.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd580.Obj);
  (* (Rhp++)) = (Wrd584.Obj);
  (Wrd586.pObj) = (& (Rhp [-2]));
  (Wrd587.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd586.pObj)));
  (* (--Rsp)) = (Wrd587.Obj);
  (Wrd590.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11]));
  (Wrd593.Obj) = ((Wrd590.pObj) [0]);
  (Wrd594.uLng) = (OBJECT_TYPE (Wrd593.Obj));
  if ((Wrd594.uLng) == 50)
    goto label_329;
  Wrd589 = Wrd593;

DEFLABEL (label_328)
  (Wrd595.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd589.Obj);
  (* (Rhp++)) = (Wrd595.Obj);
  (Wrd597.pObj) = (& (Rhp [-2]));
  (Wrd598.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd597.pObj)));
  (* (--Rsp)) = (Wrd598.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_44]));

DEFLABEL (continuation_85)
  INTERRUPT_CHECK (27, LABEL_7);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_17]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_18]), 3);

DEFLABEL (continuation_86)
  INTERRUPT_CHECK (27, LABEL_6);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_15]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_16]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_87)
  INTERRUPT_CHECK (27, LABEL_45);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_19]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_20]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47]));

DEFLABEL (continuation_88)
  INTERRUPT_CHECK (27, LABEL_46);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_21]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_22]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_49]));

DEFLABEL (continuation_89)
  INTERRUPT_CHECK (27, LABEL_48);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_23]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_24]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_18]), 3);

DEFLABEL (continuation_90)
  INTERRUPT_CHECK (27, LABEL_50);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_17]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_327;
  Wrd8 = Wrd12;

DEFLABEL (label_326)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_18]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_325;
  Wrd14 = Wrd18;

DEFLABEL (label_324)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_25]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54]));

DEFLABEL (continuation_91)
  INTERRUPT_CHECK (27, LABEL_51);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_19]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_323;
  Wrd8 = Wrd12;

DEFLABEL (label_322)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_20]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_321;
  Wrd14 = Wrd18;

DEFLABEL (label_320)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_26]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54]));

DEFLABEL (continuation_92)
  INTERRUPT_CHECK (27, LABEL_55);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_21]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_319;
  Wrd8 = Wrd12;

DEFLABEL (label_318)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_22]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_317;
  Wrd14 = Wrd18;

DEFLABEL (label_316)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_27]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54]));

DEFLABEL (continuation_93)
  INTERRUPT_CHECK (27, LABEL_58);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_61]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_23]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_315;
  Wrd8 = Wrd12;

DEFLABEL (label_314)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_24]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_313;
  Wrd14 = Wrd18;

DEFLABEL (label_312)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_28]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54]));

DEFLABEL (continuation_94)
  INTERRUPT_CHECK (27, LABEL_61);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_25]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_311;
  Wrd8 = Wrd12;

DEFLABEL (label_310)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_26]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_309;
  Wrd14 = Wrd18;

DEFLABEL (label_308)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_29]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54]));

DEFLABEL (continuation_95)
  INTERRUPT_CHECK (27, LABEL_64);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_27]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_307;
  Wrd8 = Wrd12;

DEFLABEL (label_306)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_28]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_305;
  Wrd14 = Wrd18;

DEFLABEL (label_304)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_30]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54]));

DEFLABEL (continuation_96)
  INTERRUPT_CHECK (27, LABEL_67);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_29]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_303;
  Wrd8 = Wrd12;

DEFLABEL (label_302)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_30]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_301;
  Wrd14 = Wrd18;

DEFLABEL (label_300)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_31]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54]));

DEFLABEL (continuation_97)
  INTERRUPT_CHECK (27, LABEL_70);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_73]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_31]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_299;
  Wrd8 = Wrd12;

DEFLABEL (label_298)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_32]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_297;
  Wrd14 = Wrd18;

DEFLABEL (label_296)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_32]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54]));

DEFLABEL (continuation_98)
  INTERRUPT_CHECK (27, LABEL_73);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_76]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_33]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_295;
  Wrd8 = Wrd12;

DEFLABEL (label_294)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_34]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_293;
  Wrd14 = Wrd18;

DEFLABEL (label_292)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_33]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54]));

DEFLABEL (continuation_99)
  INTERRUPT_CHECK (27, LABEL_76);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_79]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_35]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_291;
  Wrd8 = Wrd12;

DEFLABEL (label_290)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_36]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_289;
  Wrd14 = Wrd18;

DEFLABEL (label_288)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_34]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54]));

DEFLABEL (continuation_100)
  INTERRUPT_CHECK (27, LABEL_79);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_37]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_287;
  Wrd8 = Wrd12;

DEFLABEL (label_286)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_38]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_285;
  Wrd14 = Wrd18;

DEFLABEL (label_284)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_35]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54]));

DEFLABEL (continuation_101)
  INTERRUPT_CHECK (27, LABEL_82);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_39]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_283;
  Wrd8 = Wrd12;

DEFLABEL (label_282)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_40]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_281;
  Wrd14 = Wrd18;

DEFLABEL (label_280)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_36]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54]));

DEFLABEL (continuation_102)
  INTERRUPT_CHECK (27, LABEL_85);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_88]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_41]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_279;
  Wrd8 = Wrd12;

DEFLABEL (label_278)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_42]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_277;
  Wrd14 = Wrd18;

DEFLABEL (label_276)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_37]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54]));

DEFLABEL (continuation_103)
  INTERRUPT_CHECK (27, LABEL_88);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_91]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_38]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_39]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_18]), 3);

DEFLABEL (continuation_104)
  INTERRUPT_CHECK (27, LABEL_91);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_92]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_43]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_275;
  Wrd8 = Wrd12;

DEFLABEL (label_274)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_44]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_273;
  Wrd14 = Wrd18;

DEFLABEL (label_272)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_45]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_271;
  Wrd20 = Wrd24;

DEFLABEL (label_270)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd27.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_46]));
  (Wrd30.Obj) = ((Wrd27.pObj) [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd31.uLng) == 50)
    goto label_269;
  Wrd26 = Wrd30;

DEFLABEL (label_268)
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd32.Obj) = (current_block [OBJECT_40]);
  (* (--Rsp)) = (Wrd32.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_97]));

DEFLABEL (continuation_105)
  INTERRUPT_CHECK (27, LABEL_92);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_98]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_47]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_267;
  Wrd8 = Wrd12;

DEFLABEL (label_266)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_48]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_265;
  Wrd14 = Wrd18;

DEFLABEL (label_264)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_49]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_263;
  Wrd20 = Wrd24;

DEFLABEL (label_262)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd27.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_50]));
  (Wrd30.Obj) = ((Wrd27.pObj) [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd31.uLng) == 50)
    goto label_261;
  Wrd26 = Wrd30;

DEFLABEL (label_260)
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd32.Obj) = (current_block [OBJECT_41]);
  (* (--Rsp)) = (Wrd32.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_97]));

DEFLABEL (continuation_106)
  INTERRUPT_CHECK (27, LABEL_98);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_51]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_259;
  Wrd8 = Wrd12;

DEFLABEL (label_258)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_52]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_257;
  Wrd14 = Wrd18;

DEFLABEL (label_256)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_53]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_255;
  Wrd20 = Wrd24;

DEFLABEL (label_254)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd27.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_54]));
  (Wrd30.Obj) = ((Wrd27.pObj) [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd31.uLng) == 50)
    goto label_253;
  Wrd26 = Wrd30;

DEFLABEL (label_252)
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd32.Obj) = (current_block [OBJECT_42]);
  (* (--Rsp)) = (Wrd32.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_97]));

DEFLABEL (continuation_107)
  INTERRUPT_CHECK (27, LABEL_103);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_108]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_55]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_251;
  Wrd8 = Wrd12;

DEFLABEL (label_250)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_56]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_249;
  Wrd14 = Wrd18;

DEFLABEL (label_248)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_57]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_247;
  Wrd20 = Wrd24;

DEFLABEL (label_246)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd27.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_58]));
  (Wrd30.Obj) = ((Wrd27.pObj) [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd31.uLng) == 50)
    goto label_245;
  Wrd26 = Wrd30;

DEFLABEL (label_244)
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd32.Obj) = (current_block [OBJECT_43]);
  (* (--Rsp)) = (Wrd32.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_97]));

DEFLABEL (continuation_108)
  INTERRUPT_CHECK (27, LABEL_108);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_59]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_243;
  Wrd8 = Wrd12;

DEFLABEL (label_242)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_60]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_241;
  Wrd14 = Wrd18;

DEFLABEL (label_240)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_61]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_239;
  Wrd20 = Wrd24;

DEFLABEL (label_238)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd27.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_62]));
  (Wrd30.Obj) = ((Wrd27.pObj) [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd31.uLng) == 50)
    goto label_237;
  Wrd26 = Wrd30;

DEFLABEL (label_236)
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd32.Obj) = (current_block [OBJECT_44]);
  (* (--Rsp)) = (Wrd32.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_97]));

DEFLABEL (continuation_109)
  INTERRUPT_CHECK (27, LABEL_113);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_63]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_235;
  Wrd8 = Wrd12;

DEFLABEL (label_234)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_64]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_233;
  Wrd14 = Wrd18;

DEFLABEL (label_232)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_65]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_231;
  Wrd20 = Wrd24;

DEFLABEL (label_230)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd27.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_66]));
  (Wrd30.Obj) = ((Wrd27.pObj) [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd31.uLng) == 50)
    goto label_229;
  Wrd26 = Wrd30;

DEFLABEL (label_228)
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd32.Obj) = (current_block [OBJECT_45]);
  (* (--Rsp)) = (Wrd32.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_97]));

DEFLABEL (continuation_110)
  INTERRUPT_CHECK (27, LABEL_118);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_123]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_67]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_227;
  Wrd8 = Wrd12;

DEFLABEL (label_226)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_68]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_225;
  Wrd14 = Wrd18;

DEFLABEL (label_224)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_69]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_223;
  Wrd20 = Wrd24;

DEFLABEL (label_222)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd27.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_70]));
  (Wrd30.Obj) = ((Wrd27.pObj) [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd31.uLng) == 50)
    goto label_221;
  Wrd26 = Wrd30;

DEFLABEL (label_220)
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd32.Obj) = (current_block [OBJECT_46]);
  (* (--Rsp)) = (Wrd32.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_97]));

DEFLABEL (continuation_111)
  INTERRUPT_CHECK (27, LABEL_123);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_71]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_219;
  Wrd5 = Wrd9;

DEFLABEL (label_218)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_72]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_217;
  Wrd11 = Wrd15;

DEFLABEL (label_216)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_73]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_215;
  Wrd17 = Wrd21;

DEFLABEL (label_214)
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_47]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd26.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_74]));
  (Wrd29.Obj) = ((Wrd26.pObj) [0]);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if ((Wrd30.uLng) == 50)
    goto label_213;
  Wrd25 = Wrd29;

DEFLABEL (label_212)
  (Rsp [4]) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_97]));

DEFLABEL (label_213)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_131])), (Wrd26.pObj));

DEFLABEL (label_207)
  (Wrd25.Obj) = Rvl;
  goto label_212;

DEFLABEL (label_215)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_130])), (Wrd18.pObj));

DEFLABEL (label_206)
  (Wrd17.Obj) = Rvl;
  goto label_214;

DEFLABEL (label_217)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_129])), (Wrd12.pObj));

DEFLABEL (label_205)
  (Wrd11.Obj) = Rvl;
  goto label_216;

DEFLABEL (label_219)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_128])), (Wrd6.pObj));

DEFLABEL (label_204)
  (Wrd5.Obj) = Rvl;
  goto label_218;

DEFLABEL (label_221)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_127])), (Wrd27.pObj));

DEFLABEL (label_203)
  (Wrd26.Obj) = Rvl;
  goto label_220;

DEFLABEL (label_223)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_126])), (Wrd21.pObj));

DEFLABEL (label_202)
  (Wrd20.Obj) = Rvl;
  goto label_222;

DEFLABEL (label_225)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_125])), (Wrd15.pObj));

DEFLABEL (label_201)
  (Wrd14.Obj) = Rvl;
  goto label_224;

DEFLABEL (label_227)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_124])), (Wrd9.pObj));

DEFLABEL (label_200)
  (Wrd8.Obj) = Rvl;
  goto label_226;

DEFLABEL (label_229)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_122])), (Wrd27.pObj));

DEFLABEL (label_199)
  (Wrd26.Obj) = Rvl;
  goto label_228;

DEFLABEL (label_231)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_121])), (Wrd21.pObj));

DEFLABEL (label_198)
  (Wrd20.Obj) = Rvl;
  goto label_230;

DEFLABEL (label_233)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_120])), (Wrd15.pObj));

DEFLABEL (label_197)
  (Wrd14.Obj) = Rvl;
  goto label_232;

DEFLABEL (label_235)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_119])), (Wrd9.pObj));

DEFLABEL (label_196)
  (Wrd8.Obj) = Rvl;
  goto label_234;

DEFLABEL (label_237)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_117])), (Wrd27.pObj));

DEFLABEL (label_195)
  (Wrd26.Obj) = Rvl;
  goto label_236;

DEFLABEL (label_239)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_116])), (Wrd21.pObj));

DEFLABEL (label_194)
  (Wrd20.Obj) = Rvl;
  goto label_238;

DEFLABEL (label_241)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_115])), (Wrd15.pObj));

DEFLABEL (label_193)
  (Wrd14.Obj) = Rvl;
  goto label_240;

DEFLABEL (label_243)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_114])), (Wrd9.pObj));

DEFLABEL (label_192)
  (Wrd8.Obj) = Rvl;
  goto label_242;

DEFLABEL (label_245)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_112])), (Wrd27.pObj));

DEFLABEL (label_191)
  (Wrd26.Obj) = Rvl;
  goto label_244;

DEFLABEL (label_247)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_111])), (Wrd21.pObj));

DEFLABEL (label_190)
  (Wrd20.Obj) = Rvl;
  goto label_246;

DEFLABEL (label_249)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_110])), (Wrd15.pObj));

DEFLABEL (label_189)
  (Wrd14.Obj) = Rvl;
  goto label_248;

DEFLABEL (label_251)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_109])), (Wrd9.pObj));

DEFLABEL (label_188)
  (Wrd8.Obj) = Rvl;
  goto label_250;

DEFLABEL (label_253)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_107])), (Wrd27.pObj));

DEFLABEL (label_187)
  (Wrd26.Obj) = Rvl;
  goto label_252;

DEFLABEL (label_255)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_106])), (Wrd21.pObj));

DEFLABEL (label_186)
  (Wrd20.Obj) = Rvl;
  goto label_254;

DEFLABEL (label_257)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_105])), (Wrd15.pObj));

DEFLABEL (label_185)
  (Wrd14.Obj) = Rvl;
  goto label_256;

DEFLABEL (label_259)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_104])), (Wrd9.pObj));

DEFLABEL (label_184)
  (Wrd8.Obj) = Rvl;
  goto label_258;

DEFLABEL (label_261)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_102])), (Wrd27.pObj));

DEFLABEL (label_183)
  (Wrd26.Obj) = Rvl;
  goto label_260;

DEFLABEL (label_263)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_101])), (Wrd21.pObj));

DEFLABEL (label_182)
  (Wrd20.Obj) = Rvl;
  goto label_262;

DEFLABEL (label_265)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_100])), (Wrd15.pObj));

DEFLABEL (label_181)
  (Wrd14.Obj) = Rvl;
  goto label_264;

DEFLABEL (label_267)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_99])), (Wrd9.pObj));

DEFLABEL (label_180)
  (Wrd8.Obj) = Rvl;
  goto label_266;

DEFLABEL (label_269)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_96])), (Wrd27.pObj));

DEFLABEL (label_179)
  (Wrd26.Obj) = Rvl;
  goto label_268;

DEFLABEL (label_271)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_95])), (Wrd21.pObj));

DEFLABEL (label_178)
  (Wrd20.Obj) = Rvl;
  goto label_270;

DEFLABEL (label_273)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_94])), (Wrd15.pObj));

DEFLABEL (label_177)
  (Wrd14.Obj) = Rvl;
  goto label_272;

DEFLABEL (label_275)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_93])), (Wrd9.pObj));

DEFLABEL (label_176)
  (Wrd8.Obj) = Rvl;
  goto label_274;

DEFLABEL (label_277)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_90])), (Wrd15.pObj));

DEFLABEL (label_175)
  (Wrd14.Obj) = Rvl;
  goto label_276;

DEFLABEL (label_279)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_89])), (Wrd9.pObj));

DEFLABEL (label_174)
  (Wrd8.Obj) = Rvl;
  goto label_278;

DEFLABEL (label_281)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_87])), (Wrd15.pObj));

DEFLABEL (label_173)
  (Wrd14.Obj) = Rvl;
  goto label_280;

DEFLABEL (label_283)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_86])), (Wrd9.pObj));

DEFLABEL (label_172)
  (Wrd8.Obj) = Rvl;
  goto label_282;

DEFLABEL (label_285)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_84])), (Wrd15.pObj));

DEFLABEL (label_171)
  (Wrd14.Obj) = Rvl;
  goto label_284;

DEFLABEL (label_287)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_83])), (Wrd9.pObj));

DEFLABEL (label_170)
  (Wrd8.Obj) = Rvl;
  goto label_286;

DEFLABEL (label_289)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_81])), (Wrd15.pObj));

DEFLABEL (label_169)
  (Wrd14.Obj) = Rvl;
  goto label_288;

DEFLABEL (label_291)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_80])), (Wrd9.pObj));

DEFLABEL (label_168)
  (Wrd8.Obj) = Rvl;
  goto label_290;

DEFLABEL (label_293)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_78])), (Wrd15.pObj));

DEFLABEL (label_167)
  (Wrd14.Obj) = Rvl;
  goto label_292;

DEFLABEL (label_295)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_77])), (Wrd9.pObj));

DEFLABEL (label_166)
  (Wrd8.Obj) = Rvl;
  goto label_294;

DEFLABEL (label_297)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_75])), (Wrd15.pObj));

DEFLABEL (label_165)
  (Wrd14.Obj) = Rvl;
  goto label_296;

DEFLABEL (label_299)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_74])), (Wrd9.pObj));

DEFLABEL (label_164)
  (Wrd8.Obj) = Rvl;
  goto label_298;

DEFLABEL (label_301)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_72])), (Wrd15.pObj));

DEFLABEL (label_163)
  (Wrd14.Obj) = Rvl;
  goto label_300;

DEFLABEL (label_303)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_71])), (Wrd9.pObj));

DEFLABEL (label_162)
  (Wrd8.Obj) = Rvl;
  goto label_302;

DEFLABEL (label_305)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_69])), (Wrd15.pObj));

DEFLABEL (label_161)
  (Wrd14.Obj) = Rvl;
  goto label_304;

DEFLABEL (label_307)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_68])), (Wrd9.pObj));

DEFLABEL (label_160)
  (Wrd8.Obj) = Rvl;
  goto label_306;

DEFLABEL (label_309)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_66])), (Wrd15.pObj));

DEFLABEL (label_159)
  (Wrd14.Obj) = Rvl;
  goto label_308;

DEFLABEL (label_311)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_65])), (Wrd9.pObj));

DEFLABEL (label_158)
  (Wrd8.Obj) = Rvl;
  goto label_310;

DEFLABEL (label_313)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_63])), (Wrd15.pObj));

DEFLABEL (label_157)
  (Wrd14.Obj) = Rvl;
  goto label_312;

DEFLABEL (label_315)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_62])), (Wrd9.pObj));

DEFLABEL (label_156)
  (Wrd8.Obj) = Rvl;
  goto label_314;

DEFLABEL (label_317)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_60])), (Wrd15.pObj));

DEFLABEL (label_155)
  (Wrd14.Obj) = Rvl;
  goto label_316;

DEFLABEL (label_319)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_59])), (Wrd9.pObj));

DEFLABEL (label_154)
  (Wrd8.Obj) = Rvl;
  goto label_318;

DEFLABEL (label_321)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_57])), (Wrd15.pObj));

DEFLABEL (label_153)
  (Wrd14.Obj) = Rvl;
  goto label_320;

DEFLABEL (label_323)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_56])), (Wrd9.pObj));

DEFLABEL (label_152)
  (Wrd8.Obj) = Rvl;
  goto label_322;

DEFLABEL (label_325)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_53])), (Wrd15.pObj));

DEFLABEL (label_151)
  (Wrd14.Obj) = Rvl;
  goto label_324;

DEFLABEL (label_327)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_52])), (Wrd9.pObj));

DEFLABEL (label_150)
  (Wrd8.Obj) = Rvl;
  goto label_326;

DEFLABEL (label_329)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_43])), (Wrd590.pObj));

DEFLABEL (label_149)
  (Wrd589.Obj) = Rvl;
  goto label_328;

DEFLABEL (label_331)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_42])), (Wrd571.pObj));

DEFLABEL (label_148)
  (Wrd570.Obj) = Rvl;
  goto label_330;

DEFLABEL (label_333)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_41])), (Wrd552.pObj));

DEFLABEL (label_147)
  (Wrd551.Obj) = Rvl;
  goto label_332;

DEFLABEL (label_335)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_40])), (Wrd541.pObj));

DEFLABEL (label_146)
  (Wrd540.Obj) = Rvl;
  goto label_334;

DEFLABEL (label_337)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_39])), (Wrd522.pObj));

DEFLABEL (label_145)
  (Wrd521.Obj) = Rvl;
  goto label_336;

DEFLABEL (label_339)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_38])), (Wrd503.pObj));

DEFLABEL (label_144)
  (Wrd502.Obj) = Rvl;
  goto label_338;

DEFLABEL (label_341)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_37])), (Wrd492.pObj));

DEFLABEL (label_143)
  (Wrd491.Obj) = Rvl;
  goto label_340;

DEFLABEL (label_343)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_36])), (Wrd473.pObj));

DEFLABEL (label_142)
  (Wrd472.Obj) = Rvl;
  goto label_342;

DEFLABEL (label_345)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_35])), (Wrd454.pObj));

DEFLABEL (label_141)
  (Wrd453.Obj) = Rvl;
  goto label_344;

DEFLABEL (label_347)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_34])), (Wrd443.pObj));

DEFLABEL (label_140)
  (Wrd442.Obj) = Rvl;
  goto label_346;

DEFLABEL (label_349)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_33])), (Wrd424.pObj));

DEFLABEL (label_139)
  (Wrd423.Obj) = Rvl;
  goto label_348;

DEFLABEL (label_351)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_32])), (Wrd405.pObj));

DEFLABEL (label_138)
  (Wrd404.Obj) = Rvl;
  goto label_350;

DEFLABEL (label_353)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_31])), (Wrd394.pObj));

DEFLABEL (label_137)
  (Wrd393.Obj) = Rvl;
  goto label_352;

DEFLABEL (label_355)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_30])), (Wrd375.pObj));

DEFLABEL (label_136)
  (Wrd374.Obj) = Rvl;
  goto label_354;

DEFLABEL (label_357)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_29])), (Wrd356.pObj));

DEFLABEL (label_135)
  (Wrd355.Obj) = Rvl;
  goto label_356;

DEFLABEL (label_359)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_28])), (Wrd345.pObj));

DEFLABEL (label_134)
  (Wrd344.Obj) = Rvl;
  goto label_358;

DEFLABEL (label_361)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_27])), (Wrd326.pObj));

DEFLABEL (label_133)
  (Wrd325.Obj) = Rvl;
  goto label_360;

DEFLABEL (label_363)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_26])), (Wrd307.pObj));

DEFLABEL (label_132)
  (Wrd306.Obj) = Rvl;
  goto label_362;

DEFLABEL (label_365)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_25])), (Wrd296.pObj));

DEFLABEL (label_131)
  (Wrd295.Obj) = Rvl;
  goto label_364;

DEFLABEL (label_367)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_24])), (Wrd277.pObj));

DEFLABEL (label_130)
  (Wrd276.Obj) = Rvl;
  goto label_366;

DEFLABEL (label_369)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_23])), (Wrd258.pObj));

DEFLABEL (label_129)
  (Wrd257.Obj) = Rvl;
  goto label_368;

DEFLABEL (label_371)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_22])), (Wrd247.pObj));

DEFLABEL (label_128)
  (Wrd246.Obj) = Rvl;
  goto label_370;

DEFLABEL (label_373)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_21])), (Wrd228.pObj));

DEFLABEL (label_127)
  (Wrd227.Obj) = Rvl;
  goto label_372;

DEFLABEL (label_375)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_20])), (Wrd209.pObj));

DEFLABEL (label_126)
  (Wrd208.Obj) = Rvl;
  goto label_374;

DEFLABEL (label_377)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_19])), (Wrd198.pObj));

DEFLABEL (label_125)
  (Wrd197.Obj) = Rvl;
  goto label_376;

DEFLABEL (label_379)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_18])), (Wrd179.pObj));

DEFLABEL (label_124)
  (Wrd178.Obj) = Rvl;
  goto label_378;

DEFLABEL (label_381)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_17])), (Wrd160.pObj));

DEFLABEL (label_123)
  (Wrd159.Obj) = Rvl;
  goto label_380;

DEFLABEL (label_383)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_16])), (Wrd149.pObj));

DEFLABEL (label_122)
  (Wrd148.Obj) = Rvl;
  goto label_382;

DEFLABEL (label_385)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_15])), (Wrd130.pObj));

DEFLABEL (label_121)
  (Wrd129.Obj) = Rvl;
  goto label_384;

DEFLABEL (label_387)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_14])), (Wrd111.pObj));

DEFLABEL (label_120)
  (Wrd110.Obj) = Rvl;
  goto label_386;

DEFLABEL (label_389)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_13])), (Wrd100.pObj));

DEFLABEL (label_119)
  (Wrd99.Obj) = Rvl;
  goto label_388;

DEFLABEL (label_391)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_12])), (Wrd81.pObj));

DEFLABEL (label_118)
  (Wrd80.Obj) = Rvl;
  goto label_390;

DEFLABEL (label_393)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_11])), (Wrd62.pObj));

DEFLABEL (label_117)
  (Wrd61.Obj) = Rvl;
  goto label_392;

DEFLABEL (label_395)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_10])), (Wrd51.pObj));

DEFLABEL (label_116)
  (Wrd50.Obj) = Rvl;
  goto label_394;

DEFLABEL (label_397)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_9])), (Wrd32.pObj));

DEFLABEL (label_115)
  (Wrd31.Obj) = Rvl;
  goto label_396;

DEFLABEL (label_399)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_8])), (Wrd13.pObj));

DEFLABEL (label_114)
  (Wrd12.Obj) = Rvl;
  goto label_398;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

static const struct liarc_code_S arr_decl_rinvex_so_a18b0e3a6ee30bb4 [19] =
  {
    { "rinvex_so_code_1", 3, rinvex_so_code_1 },
    { "rinvex_so_code_2", 28, rinvex_so_code_2 },
    { "rinvex_so_code_3", 16, rinvex_so_code_3 },
    { "rinvex_so_code_4", 40, rinvex_so_code_4 },
    { "rinvex_so_code_5", 2, rinvex_so_code_5 },
    { "rinvex_so_code_6", 4, rinvex_so_code_6 },
    { "rinvex_so_code_7", 2, rinvex_so_code_7 },
    { "rinvex_so_code_8", 3, rinvex_so_code_8 },
    { "rinvex_so_code_9", 6, rinvex_so_code_9 },
    { "rinvex_so_code_10", 32, rinvex_so_code_10 },
    { "rinvex_so_code_11", 2, rinvex_so_code_11 },
    { "rinvex_so_code_12", 7, rinvex_so_code_12 },
    { "rinvex_so_code_13", 6, rinvex_so_code_13 },
    { "rinvex_so_code_14", 5, rinvex_so_code_14 },
    { "rinvex_so_code_15", 14, rinvex_so_code_15 },
    { "rinvex_so_code_16", 4, rinvex_so_code_16 },
    { "rinvex_so_code_17", 2, rinvex_so_code_17 },
    { "rinvex_so_code_18", 2, rinvex_so_code_18 },
    { "rinvex_so_code_19", 3, rinvex_so_code_19 }
  };

int
decl_rinvex_so_a18b0e3a6ee30bb4 (void)
{
  DECLARE_SUBCODE_MULTIPLE (arr_decl_rinvex_so_a18b0e3a6ee30bb4);
  return (0);
}

DECLARE_COMPILED_CODE ("rinvex.so", 125, decl_rinvex_so_a18b0e3a6ee30bb4, rinvex_so_a18b0e3a6ee30bb4)

#endif /* !WANT_ONLY_DATA */

#ifndef WANT_ONLY_CODE

static const unsigned char prog_rinvex_so_data_a18b0e3a6ee30bb4 [8063] =
  "\x8a\x03\x25\xc8\x09\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0d\xb9\x24"
  "\x28\x0d\x28\x0d\xba\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbb"
  "\x1d\xb0\x82\x88\x1d\x08\xc2\xbc\x80\x0d\xbd\x0d\xbe\x0d\xbf\x0d"
  "\x1c\x25\xb5\xb6\xb7\x1b\x24\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28"
  "\x0d\xbd\x28\xb2\x28\x0d\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x83\x88\x1d\xc1\x1c\xc1\x1c\x08"
  "\xb7\x1b\x25\xb7\xb6\x1b\x24\x28\x0d\x28\x0d\x1c\x28\x0d\x1c\x28"
  "\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x84\x88\x82\x1b\x80\xb4\x86\xb7"
  "\x25\x1b\xb6\xb7\x24\x28\x0d\x1c\x28\x0d\x28\x0d\x28\x0d\x28\x0d"
  "\x28\x0d\x1c\x28\xb5\x28\x0d\x1c\x28\x0d\x28\x1b\x28\x1b\x28\x1b"
  "\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x85\x88\x07\x28\x1b\x23\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x86\x88\x1b\x24\x28\x1b\x28"
  "\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\xb4\x1b\x24\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x1d\xc3\x1c\x1b\x24\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x1b\x28\x0d\x28\x0d\x1c\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x08\x07\x1b\x1b\x0d\x1c\x24\x28\x0d\x28\x0d\x1c\x28"
  "\x0d\x1c\x28\x0d\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x07"
  "\x1b\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\xb4\x1b\x1b\x1b\x24\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbc\x1d\xb0\x02\x88"
  "\xc2\x0d\x1c\x25\x1b\x24\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x0c"
  "\x0d\x0d\x1c\x1b\x24\x28\x1b\x28\x0d\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\x1b\x1b\x1b"
  "\x0d\x0d\x1b\x24\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\x1b"
  "\x1b\x24\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x1d\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\xb8\x17\x1c\x88\x1b\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x1c\xb0\x2a\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\xb8\x1b\x2a\x1b\x2a\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x08\x14\x0d\x1b\x2a\xc3\x1b"
  "\x1b\x1b\x1b\x1b\x1b\x1b\x9d\x1b\x2a\x08\x1b\x2a\x1b\x2a\xb4\x2a"
  "\x1b\x2a\x9d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x08"
  "\x1b\x1b\x0d\x0d\x0d\x0d\x1b\xb5\xb1\x0d\x1b\xb7\xb6\x17\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\xb3\x2a\x1e\x1e\x1e\x17\x28\x0d\x26\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x24\x28\x0d\x28\x1b\x28\xb2\x28\xb0\x28\x1b\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x02\x80\x01\x2f"
  "\x61\x66\x73\x2f\x63\x73\x61\x69\x6c\x2e\x6d\x69\x74\x2e\x65\x64"
  "\x75\x2f\x67\x72\x6f\x75\x70\x2f\x6d\x61\x63\x2f\x70\x72\x6f\x6a"
  "\x65\x63\x74\x73\x2f\x73\x63\x68\x65\x6d\x65\x2f\x76\x37\x2f\x64"
  "\x69\x73\x74\x2f\x73\x6e\x61\x70\x73\x68\x6f\x74\x2e\x70\x6b\x67"
  "\x2f\x32\x30\x30\x37\x30\x39\x30\x39\x2f\x6d\x69\x74\x2d\x73\x63"
  "\x68\x65\x6d\x65\x2d\x63\x2d\x32\x30\x30\x37\x30\x39\x30\x39\x2f"
  "\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2f\x72\x74\x6c"
  "\x6f\x70\x74\x2f\x72\x69\x6e\x76\x65\x78\x2e\x69\x6e\x66\x15\x23"
  "\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f"
  "\x6f\x74\x5d\x02\x0c\x77\x61\x6c\x6b\x2d\x72\x67\x72\x61\x70\x68"
  "\x02\x03\x14\x77\x69\x74\x68\x2d\x6e\x65\x77\x2d\x6e\x6f\x64\x65"
  "\x2d\x6d\x61\x72\x6b\x73\x04\x09\x66\x6f\x72\x2d\x65\x61\x63\x68"
  "\x03\x80\x01\x08\x81\x83\x02\x7f\x06\x81\x83\x02\x7e\x04\x83\x04"
  "\x07\x11\x02\x02\x0b\x76\x65\x63\x74\x6f\x72\x2d\x72\x65\x66\x11"
  "\x2a\x63\x75\x72\x72\x65\x6e\x74\x2d\x72\x67\x72\x61\x70\x68\x2a"
  "\x10\x2a\x69\x6e\x69\x74\x69\x61\x6c\x2d\x71\x75\x65\x75\x65\x2a"
  "\x0f\x2a\x62\x72\x61\x6e\x63\x68\x2d\x71\x75\x65\x75\x65\x2a\x12"
  "\x2a\x72\x65\x67\x69\x73\x74\x65\x72\x2d\x76\x61\x6c\x75\x65\x73"
  "\x2a\x09\x05\x09\x05\x04\x0c\x6d\x61\x6b\x65\x2d\x76\x65\x63\x74"
  "\x6f\x72\x02\x0b\x6d\x61\x6b\x65\x2d\x71\x75\x65\x75\x65\x05\x13"
  "\x73\x68\x61\x6c\x6c\x6f\x77\x2d\x66\x6c\x75\x69\x64\x2d\x62\x69"
  "\x6e\x64\x03\x15\x72\x67\x72\x61\x70\x68\x2d\x69\x6e\x69\x74\x69"
  "\x61\x6c\x2d\x65\x64\x67\x65\x73\x02\x0e\x63\x6f\x6e\x74\x69\x6e"
  "\x75\x65\x2d\x77\x61\x6c\x6b\x04\x03\x10\x65\x64\x67\x65\x2d\x72"
  "\x69\x67\x68\x74\x2d\x6e\x6f\x64\x65\x04\x10\x65\x6e\x71\x75\x65"
  "\x75\x65\x21\x2f\x75\x6e\x73\x61\x66\x65\x0a\x09\x9c\x01\x3a\x81"
  "\x85\x02\x9b\x01\x38\x81\x83\x02\x9a\x01\x36\x83\x04\x99\x01\x34"
  "\x81\x85\x02\x98\x01\x32\x81\x83\x02\x97\x01\x30\x81\x87\x02\x96"
  "\x01\x2e\x81\x85\x02\x95\x01\x2c\x81\x87\x02\x94\x01\x2a\x81\x85"
  "\x02\x93\x01\x28\x81\x87\x02\x92\x01\x26\x81\x85\x02\x91\x01\x24"
  "\x81\x87\x02\x90\x01\x22\x81\x85\x02\x8f\x01\x20\x81\x83\x02\x8e"
  "\x01\x1e\x81\x83\x02\x8d\x01\x1c\x81\x87\x02\x8c\x01\x1a\x81\x85"
  "\x02\x8b\x01\x18\x81\x87\x02\x8a\x01\x16\x81\x85\x02\x89\x01\x14"
  "\x81\x87\x02\x88\x01\x12\x81\x85\x02\x87\x01\x10\x81\x87\x02\x86"
  "\x01\x0e\x81\x85\x02\x85\x01\x0c\x81\x83\x02\x84\x01\x0a\x81\x8f"
  "\x02\x83\x01\x08\x81\x8b\x02\x82\x01\x06\x81\x8f\x02\x81\x01\x04"
  "\x83\x04\x39\x5b\x0b\x02\x02\x04\x63\x64\x72\x0c\x04\x63\x61\x72"
  "\x0d\x09\x03\x09\x04\x03\x0d\x71\x75\x65\x75\x65\x2d\x65\x6d\x70"
  "\x74\x79\x3f\x03\x0c\x77\x61\x6c\x6b\x2d\x62\x62\x6c\x6f\x63\x6b"
  "\x0e\x04\x0d\x76\x65\x63\x74\x6f\x72\x2d\x66\x69\x6c\x6c\x21\x0f"
  "\x03\x10\x64\x65\x71\x75\x65\x75\x65\x21\x2f\x75\x6e\x73\x61\x66"
  "\x65\x05\xac\x01\x22\x81\x81\x02\xab\x01\x20\x81\x83\x02\xaa\x01"
  "\x1e\x81\x81\x02\xa9\x01\x1c\x81\x85\x02\xa8\x01\x1a\x81\x81\x02"
  "\xa7\x01\x18\x81\x83\x02\xa6\x01\x16\x81\x83\x02\xa5\x01\x14\x81"
  "\x83\x02\xa4\x01\x12\x81\x83\x02\xa3\x01\x10\x81\x83\x02\xa2\x01"
  "\x0e\x81\x83\x02\xa1\x01\x0c\x81\x81\x02\xa0\x01\x0a\x81\x81\x02"
  "\x9f\x01\x08\x81\x83\x02\x9e\x01\x06\x81\x81\x02\x9d\x01\x04\x82"
  "\x02\x21\x38\x10\x02\x0d\x02\x09\x04\x03\x0e\x6c\x6f\x6f\x6b\x75"
  "\x70\x2d\x6d\x65\x74\x68\x6f\x64\x11\x03\x0b\x6e\x6f\x64\x65\x2d"
  "\x6d\x61\x72\x6b\x21\x03\x08\x73\x62\x6c\x6f\x63\x6b\x3f\x03\x11"
  "\x70\x6e\x6f\x64\x65\x2d\x63\x6f\x6e\x73\x65\x71\x75\x65\x6e\x74"
  "\x03\x0b\x73\x6e\x6f\x64\x65\x2d\x6e\x65\x78\x74\x03\x11\x6e\x6f"
  "\x64\x65\x2d\x70\x72\x65\x76\x69\x6f\x75\x73\x3e\x31\x3f\x12\x02"
  "\x03\x0d\x6e\x6f\x64\x65\x2d\x6d\x61\x72\x6b\x65\x64\x3f\x13\x03"
  "\x12\x70\x6e\x6f\x64\x65\x2d\x61\x6c\x74\x65\x72\x6e\x61\x74\x69"
  "\x76\x65\x03\x0e\x04\x0f\x04\x0a\x03\x0c\x76\x65\x63\x74\x6f\x72"
  "\x2d\x63\x6f\x70\x79\x0e\xd4\x01\x52\x81\x85\x02\xd3\x01\x50\x81"
  "\x85\x02\xd2\x01\x4e\x81\x87\x02\xd1\x01\x4c\x81\x89\x02\xd0\x01"
  "\x4a\x81\x85\x02\xcf\x01\x48\x81\x85\x02\xce\x01\x46\x81\x89\x02"
  "\xcd\x01\x44\x81\x89\x02\xcc\x01\x42\x81\x85\x02\xcb\x01\x40\x81"
  "\x85\x02\xca\x01\x3e\x81\x85\x02\xc9\x01\x3c\x81\x89\x02\xc8\x01"
  "\x3a\x81\x85\x02\xc7\x01\x38\x81\x89\x02\xc6\x01\x36\x81\x85\x02"
  "\xc5\x01\x34\x81\x85\x02\xc4\x01\x32\x81\x89\x02\xc3\x01\x30\x81"
  "\x85\x02\xc2\x01\x2e\x81\x85\x02\xc1\x01\x2c\x81\x87\x02\xc0\x01"
  "\x2a\x81\x83\x02\xbf\x01\x28\x81\x83\x02\xbe\x01\x26\x81\x85\x02"
  "\xbd\x01\x24\x81\x85\x02\xbc\x01\x22\x81\x85\x02\xbb\x01\x20\x81"
  "\x85\x02\xba\x01\x1e\x81\x83\x02\xb9\x01\x1c\x81\x83\x02\xb8\x01"
  "\x1a\x81\x83\x02\xb7\x01\x18\x81\x83\x02\xb6\x01\x16\x81\x83\x02"
  "\xb5\x01\x14\x81\x83\x02\xb4\x01\x12\x81\x85\x02\xb3\x01\x10\x81"
  "\x85\x02\xb2\x01\x0e\x81\x85\x02\xb1\x01\x0c\x81\x85\x02\xb0\x01"
  "\x0a\x81\x87\x02\xaf\x01\x08\x81\x85\x02\xae\x01\x06\x81\x83\x02"
  "\xad\x01\x04\x83\x04\x51\x7a\x0a\x02\x03\x13\x02\xd6\x01\x06\x81"
  "\x83\x02\xd5\x01\x04\x83\x04\x05\x0c\x13\x02\x09\x02\x03\x12\x03"
  "\x0e\x04\x0f\x04\xda\x01\x0a\x81\x87\x02\xd9\x01\x08\x81\x83\x02"
  "\xd8\x01\x06\x81\x83\x02\xd7\x01\x04\x83\x04\x09\x15\x12\x02\x08"
  "\x09\x02\xdc\x01\x06\x81\x83\x02\xdb\x01\x04\x83\x04\x05\x0b\x0f"
  "\x02\x09\x02\x0c\x76\x65\x63\x74\x6f\x72\x2d\x73\x65\x74\x21\x14"
  "\x09\x02\xdf\x01\x08\x81\x85\x02\xde\x01\x06\x81\x85\x02\xdd\x01"
  "\x04\x84\x06\x07\x0e\x15\x02\x0a\x09\x72\x65\x67\x69\x73\x74\x65"
  "\x72\x16\x0d\x04\x17\x72\x74\x6c\x3a\x6d\x61\x70\x2d\x73\x75\x62"
  "\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x73\x03\x14\x6f\x70\x74"
  "\x69\x6d\x69\x7a\x65\x2d\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e"
  "\x17\x03\xe5\x01\x0e\x81\x83\x02\xe4\x01\x0c\x81\x83\x02\xe3\x01"
  "\x0a\x83\x04\xe2\x01\x08\x81\x89\x02\xe1\x01\x06\x81\x87\x02\xe0"
  "\x01\x04\x85\x08\x0d\x17\x18\x02\x0b\x0c\x0d\x0b\x69\x64\x65\x6e"
  "\x74\x69\x74\x69\x65\x73\x19\x02\x04\x18\x6c\x69\x73\x74\x2d\x74"
  "\x72\x61\x6e\x73\x66\x6f\x72\x6d\x2d\x70\x6f\x73\x69\x74\x69\x76"
  "\x65\x03\x15\x76\x61\x6c\x69\x64\x2d\x73\x75\x62\x65\x78\x70\x72"
  "\x65\x73\x73\x69\x6f\x6e\x3f\x1a\x03\x1b\x63\x61\x6e\x6f\x6e\x69"
  "\x63\x61\x6c\x69\x7a\x65\x2d\x73\x75\x62\x65\x78\x70\x72\x65\x73"
  "\x73\x69\x6f\x6e\x1b\x03\x1b\x72\x74\x6c\x3a\x65\x78\x70\x72\x65"
  "\x73\x73\x69\x6f\x6e\x2d\x76\x61\x6c\x75\x65\x2d\x63\x6c\x61\x73"
  "\x73\x03\x17\x06\x85\x02\x42\x81\x91\x02\x84\x02\x40\x81\x91\x02"
  "\x83\x02\x3e\x81\x91\x02\x82\x02\x3c\x81\x87\x02\x81\x02\x3a\x81"
  "\x95\x02\x80\x02\x38\x81\x95\x02\xff\x01\x36\x81\x95\x02\xfe\x01"
  "\x34\x81\x93\x02\xfd\x01\x32\x81\x93\x02\xfc\x01\x30\x81\x91\x02"
  "\xfb\x01\x2e\x81\x8f\x02\xfa\x01\x2c\x81\x8f\x02\xf9\x01\x2a\x81"
  "\x8f\x02\xf8\x01\x28\x81\x8f\x02\xf7\x01\x26\x81\x8d\x02\xf6\x01"
  "\x24\x81\x8d\x02\xf5\x01\x22\x81\x8b\x02\xf4\x01\x20\x81\x8f\x02"
  "\xf3\x01\x1e\x81\x8f\x02\xf2\x01\x1c\x81\x89\x02\xf1\x01\x1a\x81"
  "\x87\x02\xf0\x01\x18\x81\x87\x02\xef\x01\x16\x81\x85\x02\xee\x01"
  "\x14\x81\x85\x02\xed\x01\x12\x81\x85\x02\xec\x01\x10\x81\x85\x02"
  "\xeb\x01\x0e\x81\x85\x02\xea\x01\x0c\x81\x85\x02\xe9\x01\x0a\x81"
  "\x83\x02\xe8\x01\x08\x81\x87\x02\xe7\x01\x06\x81\x85\x02\xe6\x01"
  "\x04\x83\x04\x41\x55\x1c\x02\x0c\x16\x0d\x03\x20\x72\x74\x6c\x3a"
  "\x70\x73\x65\x75\x64\x6f\x2d\x72\x65\x67\x69\x73\x74\x65\x72\x2d"
  "\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x3f\x16\x02\x87\x02\x06"
  "\x81\x83\x02\x86\x02\x04\x83\x04\x05\x0e\x1d\x02\x0d\x0d\x0c\x09"
  "\x02\x03\x16\x02\x8e\x02\x10\x81\x83\x02\x8d\x02\x0e\x81\x85\x02"
  "\x8c\x02\x0c\x81\x87\x02\x8b\x02\x0a\x81\x85\x02\x8a\x02\x08\x81"
  "\x85\x02\x89\x02\x06\x81\x85\x02\x88\x02\x04\x83\x04\x0f\x1a\x02"
  "\x0e\x09\x73\x65\x74\x2d\x63\x64\x72\x21\x08\x6d\x65\x74\x68\x6f"
  "\x64\x73\x1e\x02\x1e\x02\x04\x05\x61\x73\x73\x71\x1f\x02\x94\x02"
  "\x0e\x81\x85\x02\x93\x02\x0c\x81\x83\x02\x92\x02\x0a\x81\x83\x02"
  "\x91\x02\x08\x81\x87\x02\x90\x02\x06\x81\x89\x02\x8f\x02\x04\x84"
  "\x06\x0d\x18\x20\x02\x0f\x0c\x0f\x4d\x69\x73\x73\x69\x6e\x67\x20"
  "\x6d\x65\x74\x68\x6f\x64\x07\x61\x73\x73\x69\x67\x6e\x0c\x77\x61"
  "\x6c\x6b\x2f\x61\x73\x73\x69\x67\x6e\x21\x1e\x03\x04\x1f\x04\x06"
  "\x65\x72\x72\x6f\x72\x03\x99\x02\x0c\x81\x83\x02\x98\x02\x0a\x81"
  "\x85\x02\x97\x02\x08\x81\x85\x02\x96\x02\x06\x81\x83\x02\x95\x02"
  "\x04\x83\x04\x0b\x19\x1f\x02\x10\x02\x14\x0d\x0c\x1b\x72\x74\x6c"
  "\x3a\x73\x65\x74\x2d\x61\x73\x73\x69\x67\x6e\x2d\x65\x78\x70\x72"
  "\x65\x73\x73\x69\x6f\x6e\x21\x16\x72\x74\x6c\x3a\x61\x73\x73\x69"
  "\x67\x6e\x2d\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x09\x04\x05"
  "\x13\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x2d\x75\x70\x64\x61"
  "\x74\x65\x21\x0d\x03\x16\x03\xa7\x02\x1e\x81\x85\x02\xa6\x02\x1c"
  "\x81\x89\x02\xa5\x02\x1a\x81\x87\x02\xa4\x02\x18\x81\x87\x02\xa3"
  "\x02\x16\x81\x87\x02\xa2\x02\x14\x81\x85\x02\xa1\x02\x12\x81\x85"
  "\x02\xa0\x02\x10\x81\x85\x02\x9f\x02\x0e\x81\x83\x02\x9e\x02\x0c"
  "\x81\x83\x02\x9d\x02\x0a\x81\x83\x02\x9c\x02\x08\x81\x89\x02\x9b"
  "\x02\x06\x81\x87\x02\x9a\x02\x04\x83\x04\x1d\x2d\x16\x02\x11\x02"
  "\x14\x09\x02\x03\x19\x66\x6f\x72\x2d\x65\x61\x63\x68\x2d\x70\x73"
  "\x65\x75\x64\x6f\x2d\x72\x65\x67\x69\x73\x74\x65\x72\x02\xab\x02"
  "\x0a\x81\x83\x02\xaa\x02\x08\x81\x83\x02\xa9\x02\x06\x83\x04\xa8"
  "\x02\x04\x83\x04\x09\x13\x14\x02\x12\x02\x04\x16\x64\x65\x66\x69"
  "\x6e\x65\x2d\x67\x65\x6e\x65\x72\x61\x6c\x2d\x6d\x65\x74\x68\x6f"
  "\x64\x0c\x02\xad\x02\x06\x83\x04\xac\x02\x04\x83\x04\x05\x0c\x22"
  "\x02\x13\x04\x0c\x05\x0d\x03\xaf\x02\x06\x81\x85\x02\xae\x02\x04"
  "\x85\x08\x05\x0d\x23\x02\x14\x04\x0c\x05\x0d\x03\xb2\x02\x08\x81"
  "\x85\x02\xb1\x02\x06\x81\x85\x02\xb0\x02\x04\x87\x0c\x07\x0f\x14"
  "\x24\x24\x16\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72\x2d\x63"
  "\x61\x6c\x6c\x3a\x73\x65\x74\x21\x18\x69\x6e\x74\x65\x72\x70\x72"
  "\x65\x74\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x64\x65\x66\x69\x6e\x65"
  "\x22\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72\x2d\x63\x61\x6c"
  "\x6c\x3a\x63\x61\x63\x68\x65\x2d\x61\x73\x73\x69\x67\x6e\x6d\x65"
  "\x6e\x74\x1f\x69\x6e\x76\x6f\x63\x61\x74\x69\x6f\x6e\x2d\x70\x72"
  "\x65\x66\x69\x78\x3a\x64\x79\x6e\x61\x6d\x69\x63\x2d\x6c\x69\x6e"
  "\x6b\x13\x66\x6c\x6f\x6e\x75\x6d\x2d\x70\x72\x65\x64\x2d\x32\x2d"
  "\x61\x72\x67\x73\x13\x66\x69\x78\x6e\x75\x6d\x2d\x70\x72\x65\x64"
  "\x2d\x32\x2d\x61\x72\x67\x73\x0c\x70\x72\x65\x64\x2d\x32\x2d\x61"
  "\x72\x67\x73\x08\x65\x71\x2d\x74\x65\x73\x74\x16\x64\x65\x66\x69"
  "\x6e\x65\x2d\x74\x77\x6f\x2d\x61\x72\x67\x2d\x6d\x65\x74\x68\x6f"
  "\x64\x24\x04\x1a\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72\x2d"
  "\x63\x61\x6c\x6c\x3a\x75\x6e\x62\x6f\x75\x6e\x64\x3f\x1d\x69\x6e"
  "\x74\x65\x72\x70\x72\x65\x74\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x75"
  "\x6e\x61\x73\x73\x69\x67\x6e\x65\x64\x3f\x18\x69\x6e\x74\x65\x72"
  "\x70\x72\x65\x74\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x6c\x6f\x6f\x6b"
  "\x75\x70\x23\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72\x2d\x63"
  "\x61\x6c\x6c\x3a\x63\x61\x63\x68\x65\x2d\x75\x6e\x61\x73\x73\x69"
  "\x67\x6e\x65\x64\x3f\x21\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65"
  "\x72\x2d\x63\x61\x6c\x6c\x3a\x63\x61\x63\x68\x65\x2d\x72\x65\x66"
  "\x65\x72\x65\x6e\x63\x65\x18\x69\x6e\x74\x65\x72\x70\x72\x65\x74"
  "\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x61\x63\x63\x65\x73\x73\x20\x69"
  "\x6e\x76\x6f\x63\x61\x74\x69\x6f\x6e\x2d\x70\x72\x65\x66\x69\x78"
  "\x3a\x6d\x6f\x76\x65\x2d\x66\x72\x61\x6d\x65\x2d\x75\x70\x12\x69"
  "\x6e\x76\x6f\x63\x61\x74\x69\x6f\x6e\x3a\x6c\x6f\x6f\x6b\x75\x70"
  "\x1b\x69\x6e\x76\x6f\x63\x61\x74\x69\x6f\x6e\x3a\x63\x61\x63\x68"
  "\x65\x2d\x72\x65\x66\x65\x72\x65\x6e\x63\x65\x0b\x70\x72\x65\x64"
  "\x2d\x31\x2d\x61\x72\x67\x0a\x74\x79\x70\x65\x2d\x74\x65\x73\x74"
  "\x12\x66\x6c\x6f\x6e\x75\x6d\x2d\x70\x72\x65\x64\x2d\x31\x2d\x61"
  "\x72\x67\x12\x66\x69\x78\x6e\x75\x6d\x2d\x70\x72\x65\x64\x2d\x31"
  "\x2d\x61\x72\x67\x16\x64\x65\x66\x69\x6e\x65\x2d\x6f\x6e\x65\x2d"
  "\x61\x72\x67\x2d\x6d\x65\x74\x68\x6f\x64\x23\x04\x22\x04\x0f\x63"
  "\x6c\x6f\x73\x75\x72\x65\x2d\x68\x65\x61\x64\x65\x72\x13\x63\x6f"
  "\x6e\x74\x69\x6e\x75\x61\x74\x69\x6f\x6e\x2d\x65\x6e\x74\x72\x79"
  "\x14\x63\x6f\x6e\x74\x69\x6e\x75\x61\x74\x69\x6f\x6e\x2d\x68\x65"
  "\x61\x64\x65\x72\x14\x69\x63\x2d\x70\x72\x6f\x63\x65\x64\x75\x72"
  "\x65\x2d\x68\x65\x61\x64\x65\x72\x11\x69\x6e\x76\x6f\x63\x61\x74"
  "\x69\x6f\x6e\x3a\x61\x70\x70\x6c\x79\x19\x69\x6e\x76\x6f\x63\x61"
  "\x74\x69\x6f\x6e\x3a\x63\x6f\x6d\x70\x75\x74\x65\x64\x2d\x6a\x75"
  "\x6d\x70\x1a\x69\x6e\x76\x6f\x63\x61\x74\x69\x6f\x6e\x3a\x63\x6f"
  "\x6d\x70\x75\x74\x65\x64\x2d\x6c\x65\x78\x70\x72\x10\x69\x6e\x76"
  "\x6f\x63\x61\x74\x69\x6f\x6e\x3a\x6a\x75\x6d\x70\x11\x69\x6e\x76"
  "\x6f\x63\x61\x74\x69\x6f\x6e\x3a\x6c\x65\x78\x70\x72\x15\x69\x6e"
  "\x76\x6f\x63\x61\x74\x69\x6f\x6e\x3a\x70\x72\x69\x6d\x69\x74\x69"
  "\x76\x65\x14\x69\x6e\x76\x6f\x63\x61\x74\x69\x6f\x6e\x3a\x75\x75"
  "\x6f\x2d\x6c\x69\x6e\x6b\x17\x69\x6e\x76\x6f\x63\x61\x74\x69\x6f"
  "\x6e\x3a\x67\x6c\x6f\x62\x61\x6c\x2d\x6c\x69\x6e\x6b\x16\x6f\x70"
  "\x65\x6e\x2d\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x2d\x68\x65\x61"
  "\x64\x65\x72\x0e\x6f\x76\x65\x72\x66\x6c\x6f\x77\x2d\x74\x65\x73"
  "\x74\x0b\x70\x6f\x70\x2d\x72\x65\x74\x75\x72\x6e\x11\x70\x72\x6f"
  "\x63\x65\x64\x75\x72\x65\x2d\x68\x65\x61\x64\x65\x72\x10\x1d\x69"
  "\x6e\x76\x6f\x63\x61\x74\x69\x6f\x6e\x3a\x73\x70\x65\x63\x69\x61"
  "\x6c\x2d\x70\x72\x69\x6d\x69\x74\x69\x76\x65\x14\x04\x11\x6c\x6f"
  "\x63\x61\x6c\x2d\x61\x73\x73\x69\x67\x6e\x6d\x65\x6e\x74\x19\x21"
  "\x1e\x11\x0c\x1b\x1a\x16\x04\x1f\x04\x20\x04\x04\x1d\x04\x0f\x6f"
  "\x62\x6a\x65\x63\x74\x2d\x3e\x66\x69\x78\x6e\x75\x6d\x0f\x66\x69"
  "\x78\x6e\x75\x6d\x2d\x3e\x6f\x62\x6a\x65\x63\x74\x18\x6f\x62\x6a"
  "\x65\x63\x74\x2d\x3e\x75\x6e\x73\x69\x67\x6e\x65\x64\x2d\x66\x69"
  "\x78\x6e\x75\x6d\x10\x61\x64\x64\x72\x65\x73\x73\x2d\x3e\x66\x69"
  "\x78\x6e\x75\x6d\x10\x66\x69\x78\x6e\x75\x6d\x2d\x3e\x61\x64\x64"
  "\x72\x65\x73\x73\x0e\x66\x6c\x6f\x61\x74\x2d\x3e\x6f\x62\x6a\x65"
  "\x63\x74\x0e\x6f\x62\x6a\x65\x63\x74\x2d\x3e\x66\x6c\x6f\x61\x74"
  "\x10\x6f\x62\x6a\x65\x63\x74\x2d\x3e\x61\x64\x64\x72\x65\x73\x73"
  "\x0e\x6f\x62\x6a\x65\x63\x74\x2d\x3e\x64\x61\x74\x75\x6d\x0d\x63"
  "\x6f\x6e\x73\x2d\x70\x6f\x69\x6e\x74\x65\x72\x0d\x6f\x62\x6a\x65"
  "\x63\x74\x2d\x3e\x74\x79\x70\x65\x11\x63\x6f\x6e\x73\x2d\x6e\x6f"
  "\x6e\x2d\x70\x6f\x69\x6e\x74\x65\x72\x17\x0d\x14\x73\x65\x74\x2d"
  "\x72\x65\x67\x69\x73\x74\x65\x72\x2d\x76\x61\x6c\x75\x65\x21\x0f"
  "\x72\x65\x67\x69\x73\x74\x65\x72\x2d\x76\x61\x6c\x75\x65\x0a\x77"
  "\x61\x6c\x6b\x2d\x6e\x65\x78\x74\x0b\x77\x61\x6c\x6b\x2d\x6e\x65"
  "\x78\x74\x3f\x0e\x22\x69\x6e\x76\x65\x72\x74\x69\x62\x6c\x65\x2d"
  "\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x2d\x65\x6c\x69\x6d\x69"
  "\x6e\x61\x74\x69\x6f\x6e\x09\x0e\x1c\x04\x18\x04\x15\x04\x0f\x04"
  "\x12\x04\x13\x04\x0a\x04\x10\x04\x0b\x04\x04\x0e\x05\x10\x64\x65"
  "\x66\x69\x6e\x65\x2d\x6d\x75\x6c\x74\x69\x70\x6c\x65\x02\x1a\x72"
  "\x74\x6c\x3a\x63\x6f\x6e\x73\x2d\x6e\x6f\x6e\x2d\x70\x6f\x69\x6e"
  "\x74\x65\x72\x2d\x74\x79\x70\x65\x1c\x72\x74\x6c\x3a\x6f\x62\x6a"
  "\x65\x63\x74\x2d\x3e\x74\x79\x70\x65\x2d\x65\x78\x70\x72\x65\x73"
  "\x73\x69\x6f\x6e\x17\x76\x61\x6c\x75\x65\x2d\x63\x6c\x61\x73\x73"
  "\x3d\x69\x6d\x6d\x65\x64\x69\x61\x74\x65\x3f\x16\x72\x74\x6c\x3a"
  "\x63\x6f\x6e\x73\x2d\x70\x6f\x69\x6e\x74\x65\x72\x2d\x74\x79\x70"
  "\x65\x1b\x72\x74\x6c\x3a\x63\x6f\x6e\x73\x2d\x6e\x6f\x6e\x2d\x70"
  "\x6f\x69\x6e\x74\x65\x72\x2d\x64\x61\x74\x75\x6d\x1d\x72\x74\x6c"
  "\x3a\x6f\x62\x6a\x65\x63\x74\x2d\x3e\x64\x61\x74\x75\x6d\x2d\x65"
  "\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x17\x72\x74\x6c\x3a\x63\x6f"
  "\x6e\x73\x2d\x70\x6f\x69\x6e\x74\x65\x72\x2d\x64\x61\x74\x75\x6d"
  "\x1f\x72\x74\x6c\x3a\x6f\x62\x6a\x65\x63\x74\x2d\x3e\x61\x64\x64"
  "\x72\x65\x73\x73\x2d\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x15"
  "\x76\x61\x6c\x75\x65\x2d\x63\x6c\x61\x73\x73\x3d\x61\x64\x64\x72"
  "\x65\x73\x73\x3f\x1d\x72\x74\x6c\x3a\x6f\x62\x6a\x65\x63\x74\x2d"
  "\x3e\x66\x6c\x6f\x61\x74\x2d\x65\x78\x70\x72\x65\x73\x73\x69\x6f"
  "\x6e\x1d\x72\x74\x6c\x3a\x66\x6c\x6f\x61\x74\x2d\x3e\x6f\x62\x6a"
  "\x65\x63\x74\x2d\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x13\x76"
  "\x61\x6c\x75\x65\x2d\x63\x6c\x61\x73\x73\x3d\x76\x61\x6c\x75\x65"
  "\x3f\x1f\x72\x74\x6c\x3a\x66\x69\x78\x6e\x75\x6d\x2d\x3e\x61\x64"
  "\x64\x72\x65\x73\x73\x2d\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e"
  "\x1f\x72\x74\x6c\x3a\x61\x64\x64\x72\x65\x73\x73\x2d\x3e\x66\x69"
  "\x78\x6e\x75\x6d\x2d\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x27"
  "\x72\x74\x6c\x3a\x6f\x62\x6a\x65\x63\x74\x2d\x3e\x75\x6e\x73\x69"
  "\x67\x6e\x65\x64\x2d\x66\x69\x78\x6e\x75\x6d\x2d\x65\x78\x70\x72"
  "\x65\x73\x73\x69\x6f\x6e\x1e\x72\x74\x6c\x3a\x66\x69\x78\x6e\x75"
  "\x6d\x2d\x3e\x6f\x62\x6a\x65\x63\x74\x2d\x65\x78\x70\x72\x65\x73"
  "\x73\x69\x6f\x6e\x1e\x72\x74\x6c\x3a\x6f\x62\x6a\x65\x63\x74\x2d"
  "\x3e\x66\x69\x78\x6e\x75\x6d\x2d\x65\x78\x70\x72\x65\x73\x73\x69"
  "\x6f\x6e\x23\x72\x74\x6c\x3a\x73\x65\x74\x2d\x66\x69\x78\x6e\x75"
  "\x6d\x2d\x70\x72\x65\x64\x2d\x31\x2d\x61\x72\x67\x2d\x6f\x70\x65"
  "\x72\x61\x6e\x64\x21\x1e\x72\x74\x6c\x3a\x66\x69\x78\x6e\x75\x6d"
  "\x2d\x70\x72\x65\x64\x2d\x31\x2d\x61\x72\x67\x2d\x6f\x70\x65\x72"
  "\x61\x6e\x64\x23\x72\x74\x6c\x3a\x73\x65\x74\x2d\x66\x6c\x6f\x6e"
  "\x75\x6d\x2d\x70\x72\x65\x64\x2d\x31\x2d\x61\x72\x67\x2d\x6f\x70"
  "\x65\x72\x61\x6e\x64\x21\x1e\x72\x74\x6c\x3a\x66\x6c\x6f\x6e\x75"
  "\x6d\x2d\x70\x72\x65\x64\x2d\x31\x2d\x61\x72\x67\x2d\x6f\x70\x65"
  "\x72\x61\x6e\x64\x1e\x72\x74\x6c\x3a\x73\x65\x74\x2d\x74\x79\x70"
  "\x65\x2d\x74\x65\x73\x74\x2d\x65\x78\x70\x72\x65\x73\x73\x69\x6f"
  "\x6e\x21\x19\x72\x74\x6c\x3a\x74\x79\x70\x65\x2d\x74\x65\x73\x74"
  "\x2d\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x1c\x72\x74\x6c\x3a"
  "\x73\x65\x74\x2d\x70\x72\x65\x64\x2d\x31\x2d\x61\x72\x67\x2d\x6f"
  "\x70\x65\x72\x61\x6e\x64\x21\x17\x72\x74\x6c\x3a\x70\x72\x65\x64"
  "\x2d\x31\x2d\x61\x72\x67\x2d\x6f\x70\x65\x72\x61\x6e\x64\x29\x72"
  "\x74\x6c\x3a\x73\x65\x74\x2d\x69\x6e\x76\x6f\x63\x61\x74\x69\x6f"
  "\x6e\x3a\x63\x61\x63\x68\x65\x2d\x72\x65\x66\x65\x72\x65\x6e\x63"
  "\x65\x2d\x6e\x61\x6d\x65\x21\x24\x72\x74\x6c\x3a\x69\x6e\x76\x6f"
  "\x63\x61\x74\x69\x6f\x6e\x3a\x63\x61\x63\x68\x65\x2d\x72\x65\x66"
  "\x65\x72\x65\x6e\x63\x65\x2d\x6e\x61\x6d\x65\x27\x72\x74\x6c\x3a"
  "\x73\x65\x74\x2d\x69\x6e\x76\x6f\x63\x61\x74\x69\x6f\x6e\x3a\x6c"
  "\x6f\x6f\x6b\x75\x70\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e"
  "\x74\x21\x22\x72\x74\x6c\x3a\x69\x6e\x76\x6f\x63\x61\x74\x69\x6f"
  "\x6e\x3a\x6c\x6f\x6f\x6b\x75\x70\x2d\x65\x6e\x76\x69\x72\x6f\x6e"
  "\x6d\x65\x6e\x74\x32\x72\x74\x6c\x3a\x73\x65\x74\x2d\x69\x6e\x76"
  "\x6f\x63\x61\x74\x69\x6f\x6e\x2d\x70\x72\x65\x66\x69\x78\x3a\x6d"
  "\x6f\x76\x65\x2d\x66\x72\x61\x6d\x65\x2d\x75\x70\x2d\x6c\x6f\x63"
  "\x61\x74\x69\x76\x65\x21\x2d\x72\x74\x6c\x3a\x69\x6e\x76\x6f\x63"
  "\x61\x74\x69\x6f\x6e\x2d\x70\x72\x65\x66\x69\x78\x3a\x6d\x6f\x76"
  "\x65\x2d\x66\x72\x61\x6d\x65\x2d\x75\x70\x2d\x6c\x6f\x63\x61\x74"
  "\x69\x76\x65\x2d\x72\x74\x6c\x3a\x73\x65\x74\x2d\x69\x6e\x74\x65"
  "\x72\x70\x72\x65\x74\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x61\x63\x63"
  "\x65\x73\x73\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x21"
  "\x28\x72\x74\x6c\x3a\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72"
  "\x2d\x63\x61\x6c\x6c\x3a\x61\x63\x63\x65\x73\x73\x2d\x65\x6e\x76"
  "\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x2f\x72\x74\x6c\x3a\x73\x65\x74"
  "\x2d\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72\x2d\x63\x61\x6c"
  "\x6c\x3a\x63\x61\x63\x68\x65\x2d\x72\x65\x66\x65\x72\x65\x6e\x63"
  "\x65\x2d\x6e\x61\x6d\x65\x21\x2a\x72\x74\x6c\x3a\x69\x6e\x74\x65"
  "\x72\x70\x72\x65\x74\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x63\x61\x63"
  "\x68\x65\x2d\x72\x65\x66\x65\x72\x65\x6e\x63\x65\x2d\x6e\x61\x6d"
  "\x65\x31\x72\x74\x6c\x3a\x73\x65\x74\x2d\x69\x6e\x74\x65\x72\x70"
  "\x72\x65\x74\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x63\x61\x63\x68\x65"
  "\x2d\x75\x6e\x61\x73\x73\x69\x67\x6e\x65\x64\x3f\x2d\x6e\x61\x6d"
  "\x65\x21\x2c\x72\x74\x6c\x3a\x69\x6e\x74\x65\x72\x70\x72\x65\x74"
  "\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x63\x61\x63\x68\x65\x2d\x75\x6e"
  "\x61\x73\x73\x69\x67\x6e\x65\x64\x3f\x2d\x6e\x61\x6d\x65\x2d\x72"
  "\x74\x6c\x3a\x73\x65\x74\x2d\x69\x6e\x74\x65\x72\x70\x72\x65\x74"
  "\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x6c\x6f\x6f\x6b\x75\x70\x2d\x65"
  "\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x21\x28\x72\x74\x6c\x3a"
  "\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72\x2d\x63\x61\x6c\x6c"
  "\x3a\x6c\x6f\x6f\x6b\x75\x70\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d"
  "\x65\x6e\x74\x32\x72\x74\x6c\x3a\x73\x65\x74\x2d\x69\x6e\x74\x65"
  "\x72\x70\x72\x65\x74\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x75\x6e\x61"
  "\x73\x73\x69\x67\x6e\x65\x64\x3f\x2d\x65\x6e\x76\x69\x72\x6f\x6e"
  "\x6d\x65\x6e\x74\x21\x2d\x72\x74\x6c\x3a\x69\x6e\x74\x65\x72\x70"
  "\x72\x65\x74\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x75\x6e\x61\x73\x73"
  "\x69\x67\x6e\x65\x64\x3f\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65"
  "\x6e\x74\x2f\x72\x74\x6c\x3a\x73\x65\x74\x2d\x69\x6e\x74\x65\x72"
  "\x70\x72\x65\x74\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x75\x6e\x62\x6f"
  "\x75\x6e\x64\x3f\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74"
  "\x21\x2a\x72\x74\x6c\x3a\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65"
  "\x72\x2d\x63\x61\x6c\x6c\x3a\x75\x6e\x62\x6f\x75\x6e\x64\x3f\x2d"
  "\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x1e\x72\x74\x6c\x3a"
  "\x73\x65\x74\x2d\x65\x71\x2d\x74\x65\x73\x74\x2d\x65\x78\x70\x72"
  "\x65\x73\x73\x69\x6f\x6e\x2d\x32\x21\x19\x72\x74\x6c\x3a\x65\x71"
  "\x2d\x74\x65\x73\x74\x2d\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e"
  "\x2d\x32\x1e\x72\x74\x6c\x3a\x73\x65\x74\x2d\x65\x71\x2d\x74\x65"
  "\x73\x74\x2d\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x2d\x31\x21"
  "\x19\x72\x74\x6c\x3a\x65\x71\x2d\x74\x65\x73\x74\x2d\x65\x78\x70"
  "\x72\x65\x73\x73\x69\x6f\x6e\x2d\x31\x1f\x72\x74\x6c\x3a\x73\x65"
  "\x74\x2d\x70\x72\x65\x64\x2d\x32\x2d\x61\x72\x67\x73\x2d\x6f\x70"
  "\x65\x72\x61\x6e\x64\x2d\x32\x21\x1a\x72\x74\x6c\x3a\x70\x72\x65"
  "\x64\x2d\x32\x2d\x61\x72\x67\x73\x2d\x6f\x70\x65\x72\x61\x6e\x64"
  "\x2d\x32\x1f\x72\x74\x6c\x3a\x73\x65\x74\x2d\x70\x72\x65\x64\x2d"
  "\x32\x2d\x61\x72\x67\x73\x2d\x6f\x70\x65\x72\x61\x6e\x64\x2d\x31"
  "\x21\x1a\x72\x74\x6c\x3a\x70\x72\x65\x64\x2d\x32\x2d\x61\x72\x67"
  "\x73\x2d\x6f\x70\x65\x72\x61\x6e\x64\x2d\x31\x26\x72\x74\x6c\x3a"
  "\x73\x65\x74\x2d\x66\x69\x78\x6e\x75\x6d\x2d\x70\x72\x65\x64\x2d"
  "\x32\x2d\x61\x72\x67\x73\x2d\x6f\x70\x65\x72\x61\x6e\x64\x2d\x32"
  "\x21\x21\x72\x74\x6c\x3a\x66\x69\x78\x6e\x75\x6d\x2d\x70\x72\x65"
  "\x64\x2d\x32\x2d\x61\x72\x67\x73\x2d\x6f\x70\x65\x72\x61\x6e\x64"
  "\x2d\x32\x26\x72\x74\x6c\x3a\x73\x65\x74\x2d\x66\x69\x78\x6e\x75"
  "\x6d\x2d\x70\x72\x65\x64\x2d\x32\x2d\x61\x72\x67\x73\x2d\x6f\x70"
  "\x65\x72\x61\x6e\x64\x2d\x31\x21\x21\x72\x74\x6c\x3a\x66\x69\x78"
  "\x6e\x75\x6d\x2d\x70\x72\x65\x64\x2d\x32\x2d\x61\x72\x67\x73\x2d"
  "\x6f\x70\x65\x72\x61\x6e\x64\x2d\x31\x26\x72\x74\x6c\x3a\x73\x65"
  "\x74\x2d\x66\x6c\x6f\x6e\x75\x6d\x2d\x70\x72\x65\x64\x2d\x32\x2d"
  "\x61\x72\x67\x73\x2d\x6f\x70\x65\x72\x61\x6e\x64\x2d\x32\x21\x21"
  "\x72\x74\x6c\x3a\x66\x6c\x6f\x6e\x75\x6d\x2d\x70\x72\x65\x64\x2d"
  "\x32\x2d\x61\x72\x67\x73\x2d\x6f\x70\x65\x72\x61\x6e\x64\x2d\x32"
  "\x26\x72\x74\x6c\x3a\x73\x65\x74\x2d\x66\x6c\x6f\x6e\x75\x6d\x2d"
  "\x70\x72\x65\x64\x2d\x32\x2d\x61\x72\x67\x73\x2d\x6f\x70\x65\x72"
  "\x61\x6e\x64\x2d\x31\x21\x21\x72\x74\x6c\x3a\x66\x6c\x6f\x6e\x75"
  "\x6d\x2d\x70\x72\x65\x64\x2d\x32\x2d\x61\x72\x67\x73\x2d\x6f\x70"
  "\x65\x72\x61\x6e\x64\x2d\x31\x31\x72\x74\x6c\x3a\x73\x65\x74\x2d"
  "\x69\x6e\x76\x6f\x63\x61\x74\x69\x6f\x6e\x2d\x70\x72\x65\x66\x69"
  "\x78\x3a\x64\x79\x6e\x61\x6d\x69\x63\x2d\x6c\x69\x6e\x6b\x2d\x72"
  "\x65\x67\x69\x73\x74\x65\x72\x21\x2c\x72\x74\x6c\x3a\x69\x6e\x76"
  "\x6f\x63\x61\x74\x69\x6f\x6e\x2d\x70\x72\x65\x66\x69\x78\x3a\x64"
  "\x79\x6e\x61\x6d\x69\x63\x2d\x6c\x69\x6e\x6b\x2d\x72\x65\x67\x69"
  "\x73\x74\x65\x72\x31\x72\x74\x6c\x3a\x73\x65\x74\x2d\x69\x6e\x76"
  "\x6f\x63\x61\x74\x69\x6f\x6e\x2d\x70\x72\x65\x66\x69\x78\x3a\x64"
  "\x79\x6e\x61\x6d\x69\x63\x2d\x6c\x69\x6e\x6b\x2d\x6c\x6f\x63\x61"
  "\x74\x69\x76\x65\x21\x2c\x72\x74\x6c\x3a\x69\x6e\x76\x6f\x63\x61"
  "\x74\x69\x6f\x6e\x2d\x70\x72\x65\x66\x69\x78\x3a\x64\x79\x6e\x61"
  "\x6d\x69\x63\x2d\x6c\x69\x6e\x6b\x2d\x6c\x6f\x63\x61\x74\x69\x76"
  "\x65\x31\x72\x74\x6c\x3a\x73\x65\x74\x2d\x69\x6e\x74\x65\x72\x70"
  "\x72\x65\x74\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x63\x61\x63\x68\x65"
  "\x2d\x61\x73\x73\x69\x67\x6e\x6d\x65\x6e\x74\x2d\x76\x61\x6c\x75"
  "\x65\x21\x2c\x72\x74\x6c\x3a\x69\x6e\x74\x65\x72\x70\x72\x65\x74"
  "\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x63\x61\x63\x68\x65\x2d\x61\x73"
  "\x73\x69\x67\x6e\x6d\x65\x6e\x74\x2d\x76\x61\x6c\x75\x65\x30\x72"
  "\x74\x6c\x3a\x73\x65\x74\x2d\x69\x6e\x74\x65\x72\x70\x72\x65\x74"
  "\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x63\x61\x63\x68\x65\x2d\x61\x73"
  "\x73\x69\x67\x6e\x6d\x65\x6e\x74\x2d\x6e\x61\x6d\x65\x21\x2b\x72"
  "\x74\x6c\x3a\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72\x2d\x63"
  "\x61\x6c\x6c\x3a\x63\x61\x63\x68\x65\x2d\x61\x73\x73\x69\x67\x6e"
  "\x6d\x65\x6e\x74\x2d\x6e\x61\x6d\x65\x27\x72\x74\x6c\x3a\x73\x65"
  "\x74\x2d\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72\x2d\x63\x61"
  "\x6c\x6c\x3a\x64\x65\x66\x69\x6e\x65\x2d\x76\x61\x6c\x75\x65\x21"
  "\x22\x72\x74\x6c\x3a\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72"
  "\x2d\x63\x61\x6c\x6c\x3a\x64\x65\x66\x69\x6e\x65\x2d\x76\x61\x6c"
  "\x75\x65\x2d\x72\x74\x6c\x3a\x73\x65\x74\x2d\x69\x6e\x74\x65\x72"
  "\x70\x72\x65\x74\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x64\x65\x66\x69"
  "\x6e\x65\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x21\x28"
  "\x72\x74\x6c\x3a\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72\x2d"
  "\x63\x61\x6c\x6c\x3a\x64\x65\x66\x69\x6e\x65\x2d\x65\x6e\x76\x69"
  "\x72\x6f\x6e\x6d\x65\x6e\x74\x20\x72\x74\x6c\x3a\x69\x6e\x74\x65"
  "\x72\x70\x72\x65\x74\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x73\x65\x74"
  "\x21\x2d\x76\x61\x6c\x75\x65\x2b\x72\x74\x6c\x3a\x73\x65\x74\x2d"
  "\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72\x2d\x63\x61\x6c\x6c"
  "\x3a\x73\x65\x74\x21\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e"
  "\x74\x21\x26\x72\x74\x6c\x3a\x69\x6e\x74\x65\x72\x70\x72\x65\x74"
  "\x65\x72\x2d\x63\x61\x6c\x6c\x3a\x73\x65\x74\x21\x2d\x65\x6e\x76"
  "\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x25\x72\x74\x6c\x3a\x73\x65\x74"
  "\x2d\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72\x2d\x63\x61\x6c"
  "\x6c\x3a\x73\x65\x74\x21\x2d\x76\x61\x6c\x75\x65\x21\x4c\x0e\x05"
  "\x6c\x69\x73\x74\x04\x0c\x04\x05\x07\x24\x06\x7d\xfc\x01\x80\x80"
  "\x04\x7c\xfa\x01\x81\x81\x02\x7b\xf8\x01\x81\x81\x02\x7a\xf6\x01"
  "\x81\x8b\x02\x79\xf4\x01\x81\x87\x02\x78\xf2\x01\x81\x85\x02\x77"
  "\xf0\x01\x81\x83\x02\x76\xee\x01\x81\x83\x02\x75\xec\x01\x81\x8b"
  "\x02\x74\xea\x01\x81\x89\x02\x73\xe8\x01\x81\x87\x02\x72\xe6\x01"
  "\x81\x85\x02\x71\xe4\x01\x81\x83\x02\x70\xe2\x01\x81\x8b\x02\x6f"
  "\xe0\x01\x81\x89\x02\x6e\xde\x01\x81\x87\x02\x6d\xdc\x01\x81\x85"
  "\x02\x6c\xda\x01\x81\x83\x02\x6b\xd8\x01\x81\x8b\x02\x6a\xd6\x01"
  "\x81\x89\x02\x69\xd4\x01\x81\x87\x02\x68\xd2\x01\x81\x85\x02\x67"
  "\xd0\x01\x81\x83\x02\x66\xce\x01\x81\x8b\x02\x65\xcc\x01\x81\x89"
  "\x02\x64\xca\x01\x81\x87\x02\x63\xc8\x01\x81\x85\x02\x62\xc6\x01"
  "\x81\x83\x02\x61\xc4\x01\x81\x8b\x02\x60\xc2\x01\x81\x89\x02\x5f"
  "\xc0\x01\x81\x87\x02\x5e\xbe\x01\x81\x85\x02\x5d\xbc\x01\x81\x83"
  "\x02\x5c\xba\x01\x81\x8b\x02\x5b\xb8\x01\x81\x89\x02\x5a\xb6\x01"
  "\x81\x87\x02\x59\xb4\x01\x81\x85\x02\x58\xb2\x01\x81\x83\x02\x57"
  "\xb0\x01\x81\x8b\x02\x56\xae\x01\x81\x89\x02\x55\xac\x01\x81\x87"
  "\x02\x54\xaa\x01\x81\x85\x02\x53\xa8\x01\x81\x83\x02\x52\xa6\x01"
  "\x81\x83\x02\x51\xa4\x01\x81\x87\x02\x50\xa2\x01\x81\x85\x02\x4f"
  "\xa0\x01\x81\x83\x02\x4e\x9e\x01\x81\x87\x02\x4d\x9c\x01\x81\x85"
  "\x02\x4c\x9a\x01\x81\x83\x02\x4b\x98\x01\x81\x87\x02\x4a\x96\x01"
  "\x81\x85\x02\x49\x94\x01\x81\x83\x02\x48\x92\x01\x81\x87\x02\x47"
  "\x90\x01\x81\x85\x02\x46\x8e\x01\x81\x83\x02\x45\x8c\x01\x81\x87"
  "\x02\x44\x8a\x01\x81\x85\x02\x43\x88\x01\x81\x83\x02\x42\x86\x01"
  "\x81\x87\x02\x41\x84\x01\x81\x85\x02\x40\x82\x01\x81\x83\x02\x3f"
  "\x80\x01\x81\x87\x02\x3e\x7e\x81\x85\x02\x3d\x7c\x81\x83\x02\x3c"
  "\x7a\x81\x87\x02\x3b\x78\x81\x85\x02\x3a\x76\x81\x83\x02\x39\x74"
  "\x81\x87\x02\x38\x72\x81\x85\x02\x37\x70\x81\x83\x02\x36\x6e\x81"
  "\x87\x02\x35\x6c\x81\x85\x02\x34\x6a\x81\x83\x02\x33\x68\x81\x87"
  "\x02\x32\x66\x81\x85\x02\x31\x64\x81\x83\x02\x30\x62\x81\x87\x02"
  "\x2f\x60\x81\x85\x02\x2e\x5e\x81\x83\x02\x2d\x5c\x81\x87\x02\x2c"
  "\x5a\x81\x85\x02\x2b\x58\x81\x83\x02\x2a\x56\x81\x83\x02\x29\x54"
  "\x81\x83\x02\x28\x52\x81\x83\x02\x27\x50\x81\x85\x02\x26\x4e\x81"
  "\x83\x02\x25\x4c\x81\x9f\x02\x24\x4a\x81\x9f\x02\x23\x48\x81\x9d"
  "\x02\x22\x46\x81\x9d\x02\x21\x44\x81\x9d\x02\x20\x42\x81\x9b\x02"
  "\x1f\x40\x81\x9b\x02\x1e\x3e\x81\x9b\x02\x1d\x3c\x81\x99\x02\x1c"
  "\x3a\x81\x99\x02\x1b\x38\x81\x99\x02\x1a\x36\x81\x97\x02\x19\x34"
  "\x81\x97\x02\x18\x32\x81\x97\x02\x17\x30\x81\x95\x02\x16\x2e\x81"
  "\x95\x02\x15\x2c\x81\x95\x02\x14\x2a\x81\x93\x02\x13\x28\x81\x93"
  "\x02\x12\x26\x81\x93\x02\x11\x24\x81\x91\x02\x10\x22\x81\x91\x02"
  "\x0f\x20\x81\x91\x02\x0e\x1e\x81\x8f\x02\x0d\x1c\x81\x8f\x02\x0c"
  "\x1a\x81\x8f\x02\x0b\x18\x81\x8d\x02\x0a\x16\x81\x8d\x02\x09\x14"
  "\x81\x8d\x02\x08\x12\x81\x8b\x02\x07\x10\x81\x8b\x02\x06\x0e\x81"
  "\x8b\x02\x05\x0c\x81\x89\x02\x04\x0a\x81\x89\x02\x03\x08\x81\x89"
  "\x02\x02\x06\x81\x87\x02\x01\x04\x81\x83\x02\xfb\x01\x8a\x03";

SCHEME_OBJECT *
rinvex_so_data_a18b0e3a6ee30bb4 (entry_count_t dispatch_base)
{
  SCHEME_OBJECT ccb;
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES_FOR_DATA ();

  ccb = (unstackify (((unsigned char *) (& (prog_rinvex_so_data_a18b0e3a6ee30bb4 [0]))), (sizeof (prog_rinvex_so_data_a18b0e3a6ee30bb4)), dispatch_base));
  current_block = (OBJECT_ADDRESS (ccb));
  return (& (current_block [LABEL_134]));
}

DECLARE_COMPILED_DATA_NS ("rinvex.so", rinvex_so_data_a18b0e3a6ee30bb4)

#endif /* !WANT_ONLY_CODE */

DECLARE_DYNAMIC_INITIALIZATION ("rinvex.so", "61543ad0bd79b646")
